<?php
class ProductoController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->pagina = 5;
        
        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig' , $this->view->render('menu-base.phtml'));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Productos";
        
        try {
            $producto = new Shipcode_Model_Producto();
            $this->view->productos = $producto->getAll();
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_Producto();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $producto = new Shipcode_Model_Producto();
                    $producto->crear($form->getValues());
                    $mSession->mensajes = array('El producto fue creado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/producto');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el producto';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/producto');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->cancel->setAttrib('onclick', "javascript:goTo('/producto');");
        $this->view->form = $form;
        $this->view->pageTitle = "Crear producto";
        $this->view->title = "Crear producto";
        $this->renderScript('producto/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_Producto();
        $form->id->setRequired(true);
        $producto = new Shipcode_Model_Producto();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $producto->editar($form->getValues(), (int)$this->_getParam('id'));
                    
                    $mSession->mensajes = array('El producto fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/producto');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar el producto.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/producto');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $producto->setId($id);
        $form->id->setValue($id);
        $form->populate($producto->getRow()->toArray());
        $form->setAction('/producto/editar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/producto');");
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->pageTitle = "Editar producto";
        $this->view->title = "Editar producto";
        $this->renderScript('producto/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        try {

            $producto = new Shipcode_Model_Producto();
            $producto->setId($id);
            $producto->eliminar();
            
            $mSession->mensajes[] = 'El producto fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/producto');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el producto.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/producto');
        }
    }
}