<?php

class SistemaImportacionConfigController extends Zend_Controller_Action {

    public function init() 
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pageTitle = 'Importación de datos configuradas';
        $this->view->pagina = 5;

        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();

        if (!$this->getRequest()->isXmlHttpRequest()) {
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig', $this->view->render('menu-config.phtml'));
        }
    }

    public function indexAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $servicio = new Shipcode_Model_SistemaImportacionData();
        $this->view->servicios = $servicio->getAll();
        $this->view->pageTitle = 'Importaciones configuradas';
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaImportacionData();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $servicio = new Shipcode_Model_SistemaImportacionData();
                    $servicio->crear($form->getValues());
                    $mSession->mensajes = array('El servicio fue agregado de forma exitosa. Por favor realice la configuración avanzada.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-importacion-config');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el servicio de importación de datos.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-importacion-config');
                }
            } else {
                $form->populate($request->getPost());
            }
        }

        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-importacion-config');");
        $this->view->form = $form;
        $this->view->title = "Crear servicio de importación de datos";
        $this->view->pageTitle = "Importación de datos";
        $this->renderScript('sistema-importacion-config/form.phtml');
    }
    
    public function editarAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $servicio = new Shipcode_Model_SistemaImportacionData();
        $id = (int) $this->_getParam('id');
        $servicio->setId($id);
        $row = $servicio->getRow()->toArray();
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaImportacionData();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-importacion-config');");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $servicio->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'El servicio de importación de datos fue editado de forma exitosa. Por favor pruebe el servicio nuevamente en la configuración avanzada.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-importacion-config');
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el servicio de importación de datos.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-importacion-config');
                }
            } else {
                $form->populate($request->getPost());
            }
        }

        $form->populate($row);
        $form->setAction('/sistema-importacion-config/editar/' . $id);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar servicio de importación de datos";
        $this->renderScript('sistema-importacion-config/form.phtml');
    }
    
    
    public function desactivarAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        try {
            $servicio = new Shipcode_Model_SistemaImportacionData();
            $id = (int) $this->_getParam('id');
            $servicio->setId($id);
            $servicio->desactivar();
            $mSession->mensajes[] = 'El servicio de importación de datos fue desactivado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/sistema-importacion-config');
            
        } catch (Exception $e) {
            $mSession->mensajes[] = 'Ocurrió un error al intentar desactivar el servicio de importación de datos.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/sistema-importacion-config');
        }
    }

    public function eliminarAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        try {
            $servicio = new Shipcode_Model_SistemaImportacionData();
            $id = (int) $this->_getParam('id');
            $servicio->setId($id);
            $servicio->eliminar();
            $mSession->mensajes[] = 'El servicio de importación de datos fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/sistema-importacion-config');
            
        } catch (Exception $e) {
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el servicio de imoportación de datos';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/sistema-importacion-config');
        }
    }
    /**************************************************************************/
}
