<?php
class AccesoController extends Zend_Controller_Action
{
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        unset($mSession->identidadUsuario);
        if($mSession->error!='') {
            $this->view->error = $mSession->error;
            $mSession->error = '';
        } 
        
        $this->_helper->layout->setLayout('acceso');
        $this->view->title = "Acceso usuarios";
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_Acceso();  
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $usuario = new Shipcode_Model_SistemaUsuario();

                    $data = $form->getValues();
                    $auth = Zend_Auth::getInstance();

                    $authAdapter = new Zend_Auth_Adapter_DbTable($usuario->getAdapter(),'vista_usuarios');
                    $authAdapter->setIdentityColumn('mail')
                                ->setCredentialColumn('clave');
                    $authAdapter->setIdentity($data['usuario'])
                                ->setCredential(md5($data['clave']));
                    $result = $auth->authenticate($authAdapter);

                    if ($result->isValid()) {

                        $mSession->sistema = "shipcode";
                        
                        $storage = new Zend_Auth_Storage_Session();
                        $storage->write($authAdapter->getResultRowObject());
                        $usuario = Zend_Auth::getInstance()->getIdentity();
                        
                        // registro el ingreso al sistema
                        $logIngreso = new Shipcode_Model_SistemaLogIngreso();
                        $logIngreso->registrar(
                            $usuario->id, 
                            session_id(), 
                            $_SERVER['REMOTE_ADDR']
                        );
                        
                        if($usuario->valido_hasta !== NULL && $usuario->valido_hasta !== '0000-00-00') {
                            $validoHasta = new Zend_Date($usuario->valido_hasta . " 23:59:59");
                            if($validoHasta->isEarlier(Zend_Date::now())){
                                $mSession->error = 'El permiso ha expirado.';
                                $this->_redirect('/acceso');
                            }
                        }
                        
                        if($usuario->tipo === 'IDENTIFICACION'){
                            $mSession->error = 'Debe ingresar al sistema con los datos de la nave, no los de identificación personal.';
                            $this->_redirect('/acceso');
                        }
                        
                        $this->_redirect($usuario->path);    
                        
                    } else {
                        $logIngresoFallido = new Shipcode_Model_SistemaLogIngresoFallido();
                        $logIngresoFallido->registrar(
                            session_id(), 
                            $_SERVER['REMOTE_ADDR'],
                            array(
                                'usuario' => $form->getValue('usuario'),
                                'clave' => $form->getValue('clave'))
                        );
                        $mSession->error = 'El usuario o contraseña no es válido';
                        $this->_redirect('/acceso');
                    }
                } catch(Exception $e) {
                    $mSession->error = $e->getMessage();
                    $this->redirect('/acceso/logout');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        
    }
    
    public function javascriptDisabledAction()
    {
        $this->_helper->layout->setLayout('javascript-error');
        $this->view->title = "Javascript Desactivado";
    }
    
    public function logoutAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        Zend_Auth::getInstance()->clearIdentity();
        session_regenerate_id(true);
        unset($mSession);
        $this->_redirect('/acceso');
    }
}
