<?php
class AdministradorEventosController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 3;
        $this->view->pageTitle = "Gestión de Eventos Programados";
        
        if(!$this->getRequest()->isXmlHttpRequest() 
                && $this->getRequest()->getActionName() != 'exportar-seleccion'){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    /******************* OPERACIONES ADMINISTRADOR EVENTOS ********************/
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $mSession->eventosSeleccionados = array();
        $mSession->navesSelecionadas = array();
        
        $this->view->pageTitle = "Gestión de Eventos Programados";
        $this->view->empresas = Shipcode_Model_Empresa::getPairsToSelect();
        $this->view->servicios = Shipcode_Model_BaseServicio::getPairsToSelect();
    }
    
    public function findAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if($this->getRequest()->isXmlHttpRequest()){
            
            $data = array(
                'empresa' => (int)$this->_getParam('empresa'),
                'nave' => (int)$this->_getParam('nave'),
                'sistema' => (int)$this->_getParam('sistema'),
                'equipo' => (int)$this->_getParam('equipo'),
                'servicio' => (int)$this->_getParam('servicio'),
                'desde' => $this->_getParam('desde', NULL),
                'hasta' => $this->_getParam('hasta', NULL),
                'programacion' => $this->_getParam('programacion', NULL),
                'estado' => 0
            );
            
            try {
                
                $evento = new Shipcode_Model_NaveActividad();
                $eventos = $evento->buscar($data);
                echo Zend_Json::encode($eventos);
                
            } catch (Exception $exc) {
                echo $exc->getTraceAsString();
            }
        }
    }
 
    /****************** OPERACIONES SELECCIÓN Y EXPORTACIÓN *******************/
    public function seleccionarEventoAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        if($this->getRequest()->isXmlHttpRequest()){
            if($this->_getParam('evento_id')){
                
                $data = array();
                
                $id = (int)$this->_getParam('evento_id');
                $nave_id = (int)$this->_getParam('nave_id');
                
                $result = array_key_exists($id, $mSession->eventosSeleccionados);
                if($result === FALSE){
                    $mSession->eventosSeleccionados[$id] = $id;
                    $mSession->navesSeleccionadas[$id] = $nave_id;
                }

                $data['error'] = false;
                echo Zend_Json::encode($data);
                
            } else {
                $data['error'] = true;
                $data['mensaje'] = "No se envió el ID para agregar a los eventos seleccionados";
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function deseleccionarEventoAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if($this->getRequest()->isXmlHttpRequest()){
            if($this->_getParam('evento_id')){
                
                $data = array();
                $id = (int)$this->_getParam('evento_id');
                
                $result = array_key_exists($id, $mSession->eventosSeleccionados);
                if($result == TRUE){
                    unset($mSession->eventosSeleccionados[$id]);
                    unset($mSession->navesSeleccionadas[$id]);
                }
                $data['error'] = false;
                echo Zend_Json::encode($data);
            } else {
                $data['error'] = true;
                $data['mensaje'] = "No se envió el ID para eliminar de los eventos seleccionados";
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function seleccionarTodosAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        if($this->getRequest()->isXmlHttpRequest()){
            
            if($this->_getParam('ids')){
                
                $data = array();
                $count = 0;
                $ids = $this->_getParam('ids');
                $naves = $this->_getParam('naveIds');
                
                $eventosIds = explode(",", $ids);
                $navesIds = explode(",", $naves);
                
                for($i = 0; $i < count($eventosIds); $i++){
                    $result = array_key_exists($eventosIds[$i], $mSession->eventosSeleccionados);
                    if($result == FALSE){
                        $mSession->eventosSeleccionados[$eventosIds[$i]] = $eventosIds[$i];
                        $mSession->navesSeleccionadas[$eventosIds[$i]] = $navesIds[$i];
                        $count++;
                    }
                }
                
                $data['error'] = false;
                $data['cantidad'] = $count;
                echo Zend_Json::encode($data);
                
            } else {
                $data['error'] = true;
                $data['mensaje'] = "No se envió el ID para agregar a los eventos seleccionados";
                echo Zend_Json::encode($data);
            }
            
        }
    }
    
    public function deseleccionarTodosAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if($this->getRequest()->isXmlHttpRequest()){
            
            if($this->_getParam('ids')){
                
                $data = array();
                $count = 0;
                $ids = $this->_getParam('ids');
                $eventosIds = explode(",", $ids);
                
                for($i = 0; $i < count($eventosIds); $i++){
                    $result = array_key_exists($eventosIds[$i], $mSession->eventosSeleccionados);
                    if($result == TRUE){
                        unset($mSession->eventosSeleccionados[$eventosIds[$i]]);
                        unset($mSession->navesSeleccionadas[$eventosIds[$i]]);
                        $count++;
                    }
                }
                $data['error'] = false;
                $data['cantidad'] = $count;
                echo Zend_Json::encode($data);
                
            } else {
                $data['error'] = true;
                $data['mensaje'] = "No se envió el ID para eliminar de los eventos seleccionados";
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function resetearEventosSeleccionadosAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        if($this->getRequest()->isXmlHttpRequest()){
            $mSession->eventosSeleccionados = array();
            $mSession->navesSeleccionadas = array();
            $this->forward('eventos-seleccionados');
        }
    }
    
    public function eventosSeleccionadosAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        
        if($this->getRequest()->isXmlHttpRequest()){
            
            $modelEvento = new Shipcode_Model_NaveActividad();
            $this->view->eventos = $modelEvento->getRowsByEventosId($mSession->eventosSeleccionados);
        }
    }
    
    public function exportarSeleccionAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();

        define('EOL',(PHP_SAPI == 'cli') ? PHP_EOL : '<br />');
        require_once Zend_Registry::get('OTHERS_PHP_CLASSES') . '/phpexcel/PHPExcel.php';
        PHPExcel_Settings::setLocale('es');
        
        $objPHPExcel = new PHPExcel();
        $objPHPExcel->getProperties()->setCreator(" Sistema de Gestión de Mantenimiento")
                                     ->setTitle("Informe")
                                     ->setSubject("Informe");
        $objPHPExcel->setActiveSheetIndex(0)
                    ->setCellValue('A1', 'Nave')
                    ->setCellValue('B1', 'Sistema')
                    ->setCellValue('C1', 'Equipo')
                    ->setCellValue('D1', 'Servicio')
                    ->setCellValue('E1', 'Fecha');
        
        $styleArray = array(
            'font' => array('bold' => true, 'size' => 14, 'color' => array('argb' => 'ffffffff'),),
            'alignment' => array('horizontal' => PHPExcel_Style_Alignment::HORIZONTAL_LEFT,),
            'borders' => array('top' => array('style' => PHPExcel_Style_Border::BORDER_THIN,), ),
            'fill' => array('type' => PHPExcel_Style_Fill::FILL_SOLID, 'color' => array('argb' => '00000000',),),
        );
        
        $objPHPExcel->getActiveSheet()->getStyle('A1:E1')->applyFromArray($styleArray);
        $objPHPExcel->getActiveSheet()->getColumnDimension('A')->setWidth(12);
        $objPHPExcel->getActiveSheet()->getColumnDimension('B')->setAutoSize(true);
        $objPHPExcel->getActiveSheet()->getColumnDimension('C')->setAutoSize(true);
        $objPHPExcel->getActiveSheet()->getColumnDimension('D')->setAutoSize(true);
        $objPHPExcel->getActiveSheet()->getColumnDimension('E')->setAutoSize(true);
        
        $modelEvento = new Shipcode_Model_NaveActividad();
        $eventos = $modelEvento->getRowsByEventosId($mSession->eventosSeleccionados);
        
        if(count($eventos) > 0 ) { 
            $fila = 2;
            foreach($eventos as $evento) { 
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(0, $fila, $evento['nave']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(1, $fila, $evento['sistema']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(2, $fila, $evento['equipo']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(3, $fila, $evento['servicio']);
                $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(4, $fila, $evento['fecha_editada']);
                $fila++;
            }
        } else {
             $objPHPExcel->getActiveSheet()->setCellValueByColumnAndRow(2, 1, "No se seleccionaron eventos para exportar.");
        }

        // redirect output to client browser
        header('Content-Type: application/vnd.ms-excel');
        header('Content-Disposition: attachment;filename="Eventos_Seleccionados.xls"');
        header('Cache-Control: max-age=0');
        $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel5');
        $objWriter->save('php://output');

        $objPHPExcel->disconnectWorksheets();
        
        unset($objPHPExcel);  
        unset($objPHPExcel);
    }

    /*********************  OPERACIONES ASIGNACIÓN FECHAS *********************/
    public function getFormAsignarFechaAction()
    {
        $this->_helper->layout->disableLayout();
        if($this->getRequest()->isXmlHttpRequest()){
            $mSession = new Zend_Session_Namespace('shipcode');
            $this->view->numEventos = count($mSession->eventosSeleccionados);
            $this->renderScript('administrador-eventos/form-asignar-fecha.phtml');
        }
    }
    
    public function asignarFechaManualMasivamenteAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if($this->getRequest()->isXmlHttpRequest()){
            
            try {
                $fecha = $this->_getParam('fecha');
                $evento = new Shipcode_Model_NaveActividad();
                $evento->asignarFechaManualMasivamente($mSession->eventosSeleccionados, $fecha, $this->usuario->id);

                $data['error'] = false;
                echo Zend_Json::encode($data);
            } catch(Exception $e){
                $data['error'] = true;
                $data['mensaje'] = $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function resetearProgramacionEventosAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        try {
            
            $evento = new Shipcode_Model_NaveActividad();
            $evento->resetearProgramacionEventosMasivamente($mSession->eventosSeleccionados, $this->usuario->id);
            $mSession->mensajes[] = "Los eventos fueron reseteados de forma satisfactoria, quedando con fechas automáticas.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/administrador-eventos');
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar resetear los eventos.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/administrador-eventos');
        }
    }
    
    public function anclarACarenaAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        try {
            
            $evento = new Shipcode_Model_NaveActividad();
            $evento->anclarEventoCarenaMasivamente($mSession->eventosSeleccionados, $this->usuario->id);
            $mSession->mensajes[] = "Los eventos fueron anclados a la carena su nave de forma satisfactoria.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/administrador-eventos');
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar anclar los eventos a la carena.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/administrador-eventos');
        }
    }
    
    public function seleccionarEventoParaAnclajeAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        
        if($this->getRequest()->isXmlHttpRequest()){
            
            $naves = array_unique($mSession->navesSeleccionadas);
            if(count($naves) > 1){
                $this->view->error = TRUE;
            } elseif(count($naves) == 1) {
                
                $nave = new Shipcode_Model_Nave();
                $nave->setId(array_shift(array_values($naves)));
                $this->view->sistemas = $nave->getEquiposConPlanParaAnclaje();
                
            }
        }
    }
    
    /*public function eventoAction()
    {
        $this->_helper->layout->disableLayout();
        if($this->getRequest()->isXmlHttpRequest()){
            $id = (int)$this->_getParam('id');
            try {
                $evento = new Shipcode_Model_NaveActividad();
                $evento->setId($id);
                $this->view->evento = $evento->getRow();
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }*/
}