<?php
class AuditoriaInternaController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 1;
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    public function agregarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->getParam('id');
        $request = $this->getRequest();
        $form = new Shipcode_Form_AuditoriaInterna();
        $form->nave_id->setValue($id);
        $sistema = new Shipcode_Model_NaveSistema();
        $form->area_id->addMultiOptions($sistema->getPairsToSelectByNaveId($id));
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $modelNave = new Shipcode_Model_Nave();
                    $result = $modelNave->agregarAuditoriaInterna($form->getValues(), $this->usuario->id);
                    
                    if($result){
                        
                        $auditoria = new Shipcode_Model_AuditoriaInterna();
                        $auditoria->setId($result);
                        $dataAuditoria = $auditoria->getRowFull();
                        $mail = new App_HtmlMailerDocument('UTF-8');
                        $mail->setFrom(Zend_Registry::get('MAIL_FROM'), Zend_Registry::get('FIRMA_EMPRESA'));
                        $mail->setSubject('Nueva auditoría asignada - ' . $dataAuditoria['titulo']);
                        $mail->addTo($dataAuditoria['mail_responsable'], $dataAuditoria['responsable']);
                        $mail->addCc($dataAuditoria['mail_ingreso'], $dataAuditoria['ingreso_por']);
                        $mail->setViewParam('auditoria', $dataAuditoria);
                        $mail->setViewParam('firma', Zend_Registry::get('FIRMA_EMPRESA'));
                        $mail->sendHtmlTemplate('auditoria-notificacion.phtml');


                        $mSession->mensajes = array('La auditoria interna fue ingresada de forma exitosa.');
                        $mSession->claseMensaje = 'confirmacion';
                        $this->_redirect('/nave/ver/' . $form->getValue('nave_id') .'#auditorias_internas');
                        
                    } else {
                        
                        $mSession->mensajes = array('Ocurrió un error al ingresar la auditoría.');
                        $mSession->claseMensaje = 'error';
                        $this->_redirect('/nave/ver/' . $form->getValue('nave_id') .'#auditorias_internas');
                    }
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar ingresar la auditoría interna.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/nave/ver/' . $form->getValue('nave_id') .'#auditorias_internas');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $form->setAction('/auditoria-interna/agregar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/nave/ver/$id#auditorias_internas');");
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($id);
        $this->view->nave = $modelNave->getRowFull();
        $this->view->form = $form;
        $this->view->title = "Agregar auditoría interna";
        $this->view->pageTitle = $this->view->nave->nombre . " > Agregar Auditoría Interna";
        $this->renderScript('auditoria-interna/form.phtml');
    }

    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_AuditoriaInterna();
        $audInterna = new Shipcode_Model_AuditoriaInterna(); 
       
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $audInterna->editar($form->getValues(), $this->usuario->id, (int)$this->_getParam('id'));
                    
                    $mSession->mensajes = array('La auditoría interna fue editada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/nave/ver/' . $form->getValue('nave_id') .'#auditorias_internas');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar la auditoría interna.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/nave/ver/' . $form->getValue('nave_id') .'#auditorias_internas');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $audInterna->setId($id);
        $nave_id = $audInterna->getNaveId();
        $form->populate($audInterna->getRow()->toArray());
        $form->setAction('/auditoria-interna/editar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/nave/ver/$nave_id#auditorias_internas');");
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->nave = $audInterna->getNave();
        $this->view->title = "Editar Auditoría Interna";
        $this->view->pageTitle = $this->view->nave->nombre . " > Editar Auditoría Interna";
        $this->renderScript('auditoria-interna/form.phtml');
    }
    
    public function cerrarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_AuditoriaInternaCierre();
        $audInterna = new Shipcode_Model_AuditoriaInterna(); 
       
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $audInterna->setId((int)$this->_getParam('id'));
                    $audInterna->cerrar($form->getValues(), $this->usuario->id);
                    $nave_id = $audInterna->getNaveId();
                    $mSession->mensajes = array('La auditoría interna fue cerrada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/nave/ver/' . $nave_id .'#auditorias_internas');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar cerrar la auditoría interna.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/nave/ver/' . $form->getValue('nave_id') .'#auditorias_internas');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $audInterna->setId($id);
        $nave_id = $audInterna->getNaveId();
        $form->populate($audInterna->getRow()->toArray());
        $form->setAction('/auditoria-interna/cerrar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/nave/ver/$nave_id/auditorias_internas');");
        $form->submit->setLabel('Cerrar');
        $this->view->form = $form;
        $this->view->nave = $audInterna->getNave();
        $this->view->title = "Cerrar Auditoría Interna";
        $this->view->pageTitle = $this->view->nave->nombre . " > Cerrar Auditoría Interna";
        $this->renderScript('auditoria-interna/form-cierre.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        $audInterna = new Shipcode_Model_AuditoriaInterna();
        $audInterna->setId($id);
        
        try {

            $audInterna->eliminar();
            $mSession->mensajes[] = 'La auditoría interna y sus archivos fueron eliminados de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect($_SERVER['HTTP_REFERER']);

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la auditoría interna.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect($_SERVER['HTTP_REFERER']);
        }
    }
    
    public function archivosAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        try {
            $id = (int)$this->_getParam('id');
            $audInterna = new Shipcode_Model_AuditoriaInterna();
            $audInterna->setId($id);
            $this->view->archivos = $audInterna->getArchivos();
            $this->view->auditoria = $audInterna->getRowFull();
            $this->view->nave = $audInterna->getNave();
            $this->view->title = "Administrar archivos de la auditoría interna";
            $this->view->pageTitle = "Administrar archivos de la auditoría interna";

        } catch (Exception $e) {
            $mSession->mensajes[] = 'Ocurrió un error al intentar ingresar al administrador de archivos de la auditoría interna.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect($_SERVER['HTTP_REFERER']);
        }
    } 

    public function subirArchivoAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        if($this->getRequest()->isXmlHttpRequest()){
            
            $path = 'tmp/';
            $uploader = new Shipcode_Upload_QqFileUploader(
                Zend_Registry::get('ACCEPTED_FILE_FORMAT'),
                Zend_Registry::get('MAX_SIZE_FILE_UPLOAD')
            );
            $result = $uploader->handleUpload($path, TRUE);
            if($result == TRUE){
                $name = $uploader->getName();
                $newName = Shipcode_Archivo::renombrar($name);
                if($newName !== FALSE){
                    echo Zend_Json_Encoder::encode(array('success' => true, 'name' => $newName));
                } else {
                    echo Zend_Json_Encoder::encode(array('success' => false, 'name' => $name));
                }
                    
            } 
        }
    }
    
    public function guardarArchivoAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        if($this->getRequest()->isXmlHttpRequest()){
            
            $audInterna = new Shipcode_Model_AuditoriaInterna();
            
            try {
                
                $data = array();
                $data['auditoria_id'] = (int)$this->_getParam('p_id'); 
                $data['archivo'] = $this->_getParam('archivo'); 
                $data['nombre'] = $this->_getParam('nombre'); 
                
                $idContador = "#num-archivos-documentos";
                $idTabla    = "#list-acc-documentos";
                $idTrigger  = "#trigger-acc-documentos";
                
                $id = $audInterna->guardarArchivo($data, $this->usuario->id);
                $num = Shipcode_Model_AuditoriaInterna::getNumArchivos($data['auditoria_id']);
                
                echo Zend_Json::encode(array(
                    'error'     => false, 
                    'mensaje'   => 'El archivo fue guardado de forma satisfactoria.',
                    'id'        => $id,
                    'numTotal'  => $num,
                    'numCarpeta'=> $num,
                    'pid'       => $data['auditoria_id'],
                    'folder'    => 'auditorias-internas',
                    'controller'=> 'auditoria-interna',
                    'nombre'    => $data['nombre'],
                    'archivo'   => $data['archivo'],
                    'idTabla'   => $idTabla,
                    'idContador'=> $idContador,
                    'idTrigger' => $idTrigger,
                    'formato'   => 'pdf',
                    'carpeta'   => "0",
                ));
                
            } catch(Exception $e){
                echo Zend_Json::encode(array(
                    'error'     => true, 
                    'mensaje'   => 'Ocurrió un error al intentar guardar el archivo. Error: ' . $e->getMessage(),
                    'clases'    => 'alert alert-error'
                ));
            }
        }
    }
    
    public function editarArchivoAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        if($this->getRequest()->isXmlHttpRequest()){
            
            $audInterna = new Shipcode_Model_AuditoriaInterna();
            
            try {
                
                $data = array();
                $data['id'] = (int)$this->_getParam('id'); 
                $data['nombre'] = $this->_getParam('nombre'); 
                $id = $audInterna->editarArchivo($data, $this->usuario->id);
                
                echo Zend_Json::encode(array(
                    'error'     => false, 
                    'mensaje'   => 'El archivo fue editado de forma satisfactoria.',
                    'id'        => $id,
                    'nombre'    => $data['nombre']
                ));
                
            } catch(Exception $e){
                echo Zend_Json::encode(array(
                    'error'     => true, 
                    'mensaje'   => 'Ocurrió un error al intentar editar el archivo. Error: ' . $e->getMessage(),
                    'clases'    => 'alert alert-error'
                ));
            }
        }
    }
    
    public function eliminarArchivoAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if($this->getRequest()->isXmlHttpRequest()){
            try {
                
                $id = $this->_getParam('id');
                $auditoria_id = $this->_getParam('from_id');
                $archivo = new Shipcode_Model_AuditoriaInternaArchivo();
                $archivo->setId($id);
                $result = $archivo->eliminar();
                $num = Shipcode_Model_AuditoriaInterna::getNumArchivos($auditoria_id);
                $idContador = "#num-archivos-documentos";
                
                if(TRUE == $result){
                    echo Zend_Json::encode(array(
                        'error'     => false, 
                        'id'        => $id,
                        'pid'       => $auditoria_id,
                        'numTotal'  => $num,
                        'numCarpeta'=> $num,
                        'idContador'=> $idContador,
                        'clases'    => 'alert alert-success',
                        'mensaje'   => 'La imagen fue eliminada de forma exitosa'
                    ));
                } else {
                    
                    echo Zend_Json::encode(array(
                        'error'     => true, 
                        'clases'    => 'alert alert-error',
                        'mensaje'   => 'Ocurrió un error al intenar eliminar la imagen'
                    ));
                }
            } catch (Exception $e){
                echo Zend_Json::encode(array(
                    'error'     => true, 
                    'clases'    => 'alert alert-error',
                    'mensaje'   => $e->getMessage()
                ));
            }
        }
    }
}