<?php
class AuditoriaInternaPrioridadController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 5;
        
        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();
        
        if(!$this->getRequest()->isXmlHttpRequest() && $this->usuario){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig' , $this->view->render('menu-base.phtml'));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Prioridades de Auditorías Internas";
        
        try {
            $prioridad = new Shipcode_Model_AuditoriaInternaPrioridad();
            $this->view->prioridades = $prioridad->getAll();
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_AuditoriaInternaPrioridad();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/auditoria-interna-prioridad');");
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $categoria = new Shipcode_Model_AuditoriaInternaPrioridad();
                    $categoria->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('La prioridad de auditoría interna fue creada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/auditoria-interna-prioridad');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la prioridad de auditoría interna.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/auditoria-interna-prioridad');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $this->view->form = $form;
        $this->view->title = "Crear prioridad de auditoria interna";
        $this->view->pageTitle = "Prioridad de auditoria interna";
        $this->renderScript('auditoria-interna-prioridad/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_AuditoriaInternaPrioridad();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/auditoria-interna-prioridad');");
        $prioridad = new Shipcode_Model_AuditoriaInternaPrioridad();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $prioridad->editar($form->getValues(), $this->usuario->id, (int)$this->_getParam('id'));
                    
                    $mSession->mensajes = array('La prioridad de auditoría interna fue creada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/auditoria-interna-prioridad');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar la prioridad de auditoría interna.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/auditoria-interna-prioridad');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $prioridad->setId($id);
        $form->populate($prioridad->getRow()->toArray());
        $form->setAction('/auditoria-interna-prioridad/editar/' . $id);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar prioridad de auditoría interna";
        $this->view->pageTitle = "Editar prioridad de auditoría interna";
        $this->renderScript('auditoria-interna-prioridad/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $prioridad = new Shipcode_Model_AuditoriaInternaPrioridad();
            $prioridad->setId($id);
            $prioridad->eliminar();
            
            $mSession->mensajes[] = 'La prioridad de auditoría interna fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/auditoria-interna-prioridad');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la prioridad de auditoría interna.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/auditoria-interna-prioridad');
        }
    }
}