<?php
class BaseSistemaController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 5;
        
        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();
        
        if(!$this->getRequest()->isXmlHttpRequest() && $this->usuario){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig' , $this->view->render('menu-base.phtml'));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Base Sistemas";
        
        try {
            $sistema= new Shipcode_Model_BaseSistema();
            $this->view->sistemas = $sistema->getAll();
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_BaseSistema();
        $form->padre_id->addMultiOptions(Shipcode_Model_BaseSistema::getPairsToSelect());
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $sistema = new Shipcode_Model_BaseSistema();
                    $sistema->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('El sistema base fue creado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/base-sistema');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el sistema-base.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/base-sistema');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->padre_id->addMultiOptions(Shipcode_Model_BaseSistema::getPairsToSelect());
        $form->cancel->setAttrib('onclick', "javascript:goTo('/base-sistema');");
        $this->view->form = $form;
        $this->view->title = "Crear sistema base";
        $this->view->pageTitle = "Sistema base";
        $this->renderScript('base-sistema/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_BaseSistema();
        $form->padre_id->addMultiOptions(Shipcode_Model_BaseSistema::getPairsToSelect());
        $sistema = new Shipcode_Model_BaseSistema();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $sistema->editar($form->getValues(), $this->usuario->id, (int)$this->_getParam('id'));
                    
                    $mSession->mensajes = array('El sistema base fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/base-sistema');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar el sistema base.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/base-sistema');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $sistema->setId($id);
        $form->padre_id->setMultiOptions(Shipcode_Model_BaseSistema::getPairsToSelect($id));
        $form->populate($sistema->getRow()->toArray());
        $form->setAction('/base-sistema/editar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/base-sistema');");
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar sistema base";
        $this->renderScript('base-sistema/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $sistema = new Shipcode_Model_BaseSistema();
            $sistema->setId($id);
            $sistema->eliminar();
            
            $mSession->mensajes[] = 'El sistema base fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/base-sistema');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el sistema base.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/base-sistema');
        }
    }
}