<?php
class CentroCostoController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 5;
        
        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig' , $this->view->render('menu-base.phtml'));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Centros de Costos";
        
        try {
            $centro = new Shipcode_Model_CentroCosto();
            $this->view->centros = $centro->getAll();
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_CentroCosto();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $centro = new Shipcode_Model_CentroCosto();
                    $centro->crear($form->getValues());
                    $mSession->mensajes = array('El centro de costos fue creado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/centro-costo');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el centro de costos.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/centro-costo');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->cancel->setAttrib('onclick', "javascript:goTo('/centro-costo');");
        $this->view->form = $form;
        $this->view->pageTitle = "Crear centro de costos";
        $this->view->title = "Crear centro de costos";
        $this->renderScript('centro-costo/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_CentroCosto();
        $form->id->setRequired(true);
        $centro = new Shipcode_Model_CentroCosto();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $centro->editar($form->getValues(), (int)$this->_getParam('id'));
                    
                    $mSession->mensajes = array('El centro de costos fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/centro-costo');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar el centro de costos.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/centro-costo');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $centro->setId($id);
        $form->id->setValue($id);
        $form->populate($centro->getRow()->toArray());
        $form->setAction('/centro-costo/editar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/centro-costo');");
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->pageTitle = "Editar centro de costos";
        $this->view->title = "Editar centro de costos";
        $this->renderScript('centro-costo/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $centro = new Shipcode_Model_CentroCosto();
            $centro->setId($id);
            $centro->eliminar();
            
            $mSession->mensajes[] = 'El centro de costos fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/centro-costo');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el centro de costos.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/centro-costo');
        }
    }
}