<?php
class CodigoObservacionController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 5;
        
        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();
        
        if(!$this->getRequest()->isXmlHttpRequest() && $this->usuario){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig' , $this->view->render('menu-base.phtml'));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Códigos de Observaciones de Revista";
        
        try {
            $codigo = new Shipcode_Model_CodigoObservacion();
            $this->view->codigos = $codigo->getAll();
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_CodigoObservacion();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $codigo = new Shipcode_Model_CodigoObservacion();
                    $codigo->crear($form->getValues());
                    $mSession->mensajes = array('El código de observación fue creado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/codigo-observacion');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el código observación.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/codigo-observacion');
                }
            } else {
                $form->populate($request->getPost());
            }
        }

        $form->cancel->setAttrib('onclick', "javascript:goTo('/codigo-observacion');");
        $this->view->form = $form;
        $this->view->title = "Crear código de observación";
        $this->view->pageTitle = "Códigos de plazo en observaciones de revista";
        $this->renderScript('codigo-observacion/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_CodigoObservacion();
        $codigo = new Shipcode_Model_CodigoObservacion();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $codigo->editar($form->getValues(), (int)$this->_getParam('id'));
                    
                    $mSession->mensajes = array('El código de observación fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/codigo-observacion');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar código de observación.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/codigo-observacion');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $codigo->setId($id);
        $form->populate($codigo->getRow()->toArray());
        $form->setAction('/codigo-observacion/editar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/codigo-observacion');");
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar código de observación";
        $this->renderScript('codigo-observacion/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $codigo = new Shipcode_Model_CodigoObservacion();
            $codigo->setId($id);
            $codigo->eliminar();
            
            $mSession->mensajes[] = 'El código de observación fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/codigo-observacion');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el código de observación.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/codigo-observacion');
        }
    }
}