<?php
class ConceptoImputacionController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 5;
        
        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig' , $this->view->render('menu-base.phtml'));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Conceptos de Imputación";
        
        try {
            $concepto = new Shipcode_Model_ConceptoImputacion();
            $this->view->conceptos = $concepto->getAll();
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_ConceptoImputacion();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $concepto = new Shipcode_Model_ConceptoImputacion();
                    $concepto->crear($form->getValues());
                    $mSession->mensajes = array('El concepto de imputación fue creado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/concepto-imputacion');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el concepto de imputación.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/concepto-imputacion');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->cancel->setAttrib('onclick', "javascript:goTo('/concepto-imputacion');");
        $this->view->form = $form;
        $this->view->pageTitle = "Crear concepto de imputación";
        $this->view->title = "Crear concepto de imputación";
        $this->renderScript('concepto-imputacion/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_ConceptoImputacion();
        $form->vid->setRequired(true);
        $concepto = new Shipcode_Model_ConceptoImputacion();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $concepto->editar($form->getValues());
                    
                    $mSession->mensajes = array('El concepto de imputación fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/concepto-imputacion');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar el concepto de imputación.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/concepto-imputacion');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $concepto->setId($id);
        $form->vid->setValue($id);
        $form->populate($concepto->getRow()->toArray());
        $form->setAction('/concepto-imputacion/editar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/concepto-imputacion');");
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->pageTitle = "Editar concepto de imputación";
        $this->view->title = "Editar concepto de imputación";
        $this->renderScript('concepto-imputacion/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $concepto = new Shipcode_Model_ConceptoImputacion();
            $concepto->setId($id);
            $concepto->eliminar();
            
            $mSession->mensajes[] = 'El concepto de imputación fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/concepto-imputacion');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el concepto de imputación.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/concepto-imputacion');
        }
    }
}