<?php
class ConfigListasVerificacionController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 5;
        
        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();
        
        $this->view->pageTitle = "Configuración de listas de verificación";
       
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig' , $this->view->render('menu-base.phtml'));
        }
    }
    
    /******************* OPERACIONES OPCIONES RESPUESTAS **********************/
    public function opcionesRespuestasAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        try {
            $opcion = new Shipcode_Model_ListaVerificacionOpcionesRespuesta();
            $this->view->opciones = $opcion->getAll();
            $this->view->title = "Opciones de respuesta para Listas de Verificación";
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function agregarOpcionesRespuestasAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_ListaVerificacionOpcionesRespuesta();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/config-listas-verificacion/opciones-respuestas');");
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $opciones = new Shipcode_Model_ListaVerificacionOpcionesRespuesta();
                    $opciones->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('El set de opciones fue creado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/config-listas-verificacion/opciones-respuestas');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar agregar el set de respuestas.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/config-listas-verificacion/opciones-respuestas');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $this->view->form = $form;
        $this->view->title = "Opciones de respuesta : Crear";
        $this->renderScript('config-listas-verificacion/form-opciones-respuestas.phtml');
    }
    
    public function editarOpcionesRespuestasAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_ListaVerificacionOpcionesRespuesta();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/config-listas-verificacion/opciones-respuestas');");
        $opciones = new Shipcode_Model_ListaVerificacionOpcionesRespuesta();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $opciones->editar($form->getValues(), (int)$this->_getParam('id'));
                    
                    $mSession->mensajes = array('El set de respuestas fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/config-listas-verificacion/opciones-respuestas');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar el set de respuestas.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/config-listas-verificacion/opciones-respuestas');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $opciones->setId($id);
        $form->populate($opciones->getRow()->toArray());
        $form->setAction('/config-listas-verificacion/editar-opciones-respuestas/' . $id);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Opciones de respuesta : Editar";
        $this->renderScript('config-listas-verificacion/form-opciones-respuestas.phtml');
    }
    
    public function eliminarOpcionesRespuestasAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $opciones = new Shipcode_Model_ListaVerificacionOpcionesRespuesta();
            $opciones->setId($id);
            $opciones->eliminar();
            
            $mSession->mensajes[] = 'El set de respuestas fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/config-listas-verificacion/opciones-respuestas');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el set de respuestas.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/config-listas-verificacion/opciones-respuestas');
        }
    }
    /**************************************************************************/
    
    /************************** OPERACIONES LISTAS ****************************/
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        try {
            $lista = new Shipcode_Model_ListaVerificacion();
            $this->view->listas = $lista->getAll();
            $this->view->title = "Listas de verificación";
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_ListaVerificacion();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/config-listas-verificacion');");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $lista = new Shipcode_Model_ListaVerificacion();
                    $id = $lista->crear($form->getValues());
                    $mSession->mensajes = array('La lista de verificación fue creada de forma exitosa. Ahora puede agregar ítems.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/config-listas-verificacion/ver/' . $id);

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la lista de verificación.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/config-listas-verificacion');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $this->view->form = $form;
        $this->view->title = "Listas de verificación : Crear";
        $this->renderScript('config-listas-verificacion/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_ListaVerificacion();
        $lista = new Shipcode_Model_ListaVerificacion();
        $id = (int)$this->_getParam('id');
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $lista->editar($form->getValues(), (int)$this->_getParam('id'));
                    $mSession->mensajes = array('La lista de verificación fue editada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/config-listas-verificacion/ver/' . $form->getValue('id'));

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar la lista de verificación.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/config-listas-verificacion/ver/' . $id);
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        
        $lista->setId($id);
        $form->populate($lista->getRow()->toArray());
        $form->setAction('/config-listas-verificacion/editar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/config-listas-verificacion/ver/$id');");
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->lista = $lista->getRow();
        $this->view->title = "Listas de Verificación : Editar";
        $this->renderScript('config-listas-verificacion/form.phtml');
    }
    
    public function habilitarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $id = (int)$this->_getParam('id');
        
        try {

            $lista = new Shipcode_Model_ListaVerificacion();
            $lista->setId($id);
            $lista->habilitar();
            $mSession->mensajes = array('La lista de verificación fue habilitada de forma exitosa.');
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/config-listas-verificacion/ver/' . $id);

        } catch (Exception $e) {

            $mSession->mensajes = array('Ocurrió un error al intentar habilitar la lista de verificación.');
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/config-listas-verificacion/ver/' . $id);
        }
    }
    
    public function deshabilitarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $id = (int)$this->_getParam('id');
        
        try {

            $lista = new Shipcode_Model_ListaVerificacion();
            $lista->setId($id);
            $lista->deshabilitar();
            $mSession->mensajes = array('la lista de verificación fue deshabilitada de forma exitosa.');
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/config-listas-verificacion/ver/' . $id);

        } catch (Exception $e) {

            $mSession->mensajes = array('Ocurrió un error al intentar deshabilitar la lista de verificación.');
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/config-listas-verificacion/ver/' . $id);
        }
    }
    
    public function verAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            
            $lista = new Shipcode_Model_ListaVerificacion();
            $lista->setId($id);
            $this->view->title = "Listas de Verificación : Detalle";
            $this->view->lista = $lista->getRow();
            $this->view->items = $lista->getItems();
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar visualizar la lista e verificación.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/config-listas-verificacion');
        }
    }
    
    public function clonarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            
            $lista = new Shipcode_Model_ListaVerificacion();
            $lista->setId($id);
            $nueva_id = $lista->clonar($this->usuario->id);
            $mSession->mensajes = array('La lista de verificación fue clonada de forma exitosa.');
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/config-listas-verificacion/ver/' . $nueva_id);
            
        } catch (Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar clonar la lista de verificación.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/config-listas-verificacion/ver/' . $id);
        }
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $lista = new Shipcode_Model_ListaVerificacion();
            $lista->setId($id);
            $lista->eliminar();
            
            $mSession->mensajes[] = 'La lista de verificación fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/config-listas-verificacion');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la lista de verificación';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/config-listas-verificacion');
        }
    }
    /**************************************************************************/
    
    /*********************** OPERACIONES ITEMS LISTAS *************************/
    public function agregarItemAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_ListaVerificacionItem();
        $id = (int)$this->_getParam('id');
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $item = new Shipcode_Model_ListaVerificacionItem();
                    $item->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('El ítem fue agregado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/config-listas-verificacion/ver/' . $form->getValue('lista_id'));

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar agregar el ítem.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/config-listas-verificacion/ver/' . $id);
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $lista = new Shipcode_Model_ListaVerificacion();
        $lista->setId($id);
        $dataLista = $lista->getRow();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/config-listas-verificacion/ver/$id');");
        $form->lista_id->setValue($id);
        $this->view->lista = $dataLista;
        $this->view->form = $form;
        $this->view->title = "Listas de Verificación : Agregar ítem";
        $this->renderScript('config-listas-verificacion/form-item.phtml');
    }
    
    public function editarItemAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_ListaVerificacionItem();
        $item = new Shipcode_Model_ListaVerificacionItem();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $item->editar($form->getValues(), (int)$this->_getParam('id'));
                    $mSession->mensajes = array('El ítem fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/config-listas-verificacion/ver/' . $form->getValue('lista_id'));

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar el ítem.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/config-listas-verificacion/ver/' . $form->getValue('lista_id'));
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $item->setId($id);
        $lista_id = $item->getListaId();
        $form->populate($item->getRow()->toArray());
        $form->setAction('/config-listas-verificacion/editar-item/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/config-listas-verificacion/ver/$lista_id');");
        $form->submit->setLabel('Guardar cambios');
        $this->view->lista = $item->getLista();
        $this->view->form = $form;
        $this->view->title = "Listas de Verificación : Editar ítem";
        $this->renderScript('config-listas-verificacion/form-item.phtml');
    }
    
    public function ordenarAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
       
        $data = $this->_getParam('data');
        
        if (isset($data)) {
            try {
                
                $item = new Shipcode_Model_ListaVerificacionItem();
                $item->setOrden($data);
                $result = array(
                    'error'     => false
                );
                
                echo Zend_Json_Encoder::encode($result);
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function eliminarItemAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            
            $item = new Shipcode_Model_ListaVerificacionItem();
            $item->setId($id);
            $lista_id = $item->getListaId();
            $item->eliminar($id);
            
            $mSession->mensajes[] = 'El ítem fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/config-listas-verificacion/ver/' . $lista_id);

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el ítem.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/config-listas-verificacion');
        }
    }
    /**************************************************************************/
    
    /********************** OPERACIONES ASIGNACIONES **************************/
    public function asignacionesAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        try {
            $asignacion = new Shipcode_Model_ListaVerificacionAsignacion();
            $this->view->asignaciones = $asignacion->getAll();
            $this->view->title = "Asignaciones de Listas de Verificación";
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function asignarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_ListaVerificacionAsignacion();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/config-listas-verificacion/asignaciones');");
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $asignacion = new Shipcode_Model_ListaVerificacionAsignacion();
                    $asignacion->crear($form->getValues());
                    $mSession->mensajes = array('La lista fue asignada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/config-listas-verificacion/asignaciones');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar asignar la lista.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/config-listas-verificacion/asignaciones');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $this->view->form = $form;
        $this->view->title = "Asignaciones de Listas : Crear";
        $this->renderScript('config-listas-verificacion/form-asignacion.phtml');
    }
    
    public function eliminarAsignacionAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $asignacion = new Shipcode_Model_ListaVerificacionAsignacion();
            $asignacion->setId($id);
            $asignacion->eliminar();
            
            $mSession->mensajes[] = 'La asignación fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/config-listas-verificacion/asignaciones');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la asignación de la lista.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/config-listas-verificacion/asignaciones');
        }
    }
    /**************************************************************************/
}