<?php
class CuentaCarenaController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 5;
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Cuentas de Carenas";
        
        try {
            $cuenta = new Shipcode_Model_CuentaCarena();
            $this->view->cuentas = $cuenta->getAll();
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_CuentaCarena();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $cuenta = new Shipcode_Model_CuentaCarena();
                    $cuenta->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('La cuenta de gastos de carena fue creada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/cuenta-carena');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la cuenta de gastos de carena.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/cuenta-carena');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->cancel->setAttrib('onclick', "javascript:goTo('/cuenta-carena');");
        $this->view->form = $form;
        $this->view->pageTitle = "Crear cuenta de carena";
        $this->view->title = "Crear cuenta de carena";
        $this->renderScript('cuenta-carena/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_CuentaCarena();
        $form->id->setRequired(true);
        $cuenta = new Shipcode_Model_CuentaCarena();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $cuenta->editar($form->getValues(), $this->usuario->id, (int)$this->_getParam('id'));
                    
                    $mSession->mensajes = array('La cuenta de gastos de carena fue editada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/cuenta-carena');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar la cuenta de gastos de carena.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/cuenta-carena');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $cuenta->setId($id);
        $form->id->setValue($id);
        $form->populate($cuenta->getRow()->toArray());
        $form->setAction('/cuenta-carena/editar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/cuenta-carena');");
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->pageTitle = "Editar cuenta de carena";
        $this->view->title = "Editar cuenta de carena";
        $this->renderScript('cuenta-carena/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $cuenta = new Shipcode_Model_CuentaCarena();
            $cuenta->setId($id);
            $cuenta->eliminar();
            
            $mSession->mensajes[] = 'La cuenta de gastos de carena fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/cuenta-carena');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la cuenta de gastos de carena.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/cuenta-carena');
        }
    }
}