<?php
class EmpresaController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 1;
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Empresas";
        
        try {
            
            $empresa = new Shipcode_Model_Empresa();
            $this->view->empresas = $empresa->getAll();
            $empresa->setId(1);
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_Empresa();
        $form->cancel->setAttrib('onclick', 'javascript:goTo("/empresa");');
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $empresa = new Shipcode_Model_Empresa();
                    $id = $empresa->crear($form->getValues(), $this->usuario->id);
                    
                    $mSession->mensajes = array('La empresa fue creada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/empresa/ver/' . $id);

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la empresa.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/empresa');
                    
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->view->title = "Agregar empresa";
        $this->view->pageTitle = "Agregar empresa";
        $this->renderScript('empresa/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_Empresa();
        $form->id->setRequired(true);
        $empresa = new Shipcode_Model_Empresa();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $empresa->editar($form->getValues(), $this->usuario->id, (int)$this->_getParam('id'));
                    $mSession->mensajes = array('La información de la empresa fue editada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/empresa/ver/' . (int)$this->_getParam('id'));

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar la información de la empresa.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/empresa/ver/' . (int)$form->getValue('id'));
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $empresa->setId($id);
        $form->populate($empresa->getRow()->toArray());
        $form->id->setValue($id);
        $form->setAction('/empresa/editar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/empresa/ver/$id');");
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar empresa";
        $this->view->pageTitle = "Editar empresa";
        $this->renderScript('empresa/form.phtml');
    }
    
    public function verAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            
            $empresa = new Shipcode_Model_Empresa();
            $empresa->setId($id);
            $this->view->empresa = $empresa->getRowFull();
            $this->view->naves = $empresa->getNaves();
            $this->view->pageTitle = "Detalle empresa :: " . $this->view->empresa['nombre'];
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar la empresa.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/empresa');
            
        }
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $empresa = new Shipcode_Model_Empresa();
            $empresa->setId($id);
            $empresa->eliminar();
            
            $mSession->mensajes[] = "La empresa fue eliminado de forma exitosa";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/empresa');
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar eliminar la empresa";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/empresa');
            
        }
    }
    
    /*
     *  ELIMINAR FUNCION, YA NO SE USA  
     * 
    public function configurarSupervisoresAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        $empresa = new Shipcode_Model_Empresa();
        $empresa->setId($id);
        
        $usuario = new Shipcode_Model_SistemaUsuario();
        $usuariosSupervisores = $usuario->getSupervisores();
        
        if(!count($usuariosSupervisores) > 0) {
            $mSession->mensajes[] = 'No se han creado usuarios con el perfil de supervisores para ser asignados a la empresa.';
            $mSession->mensajes[] = "Por favor primero cree los usuarios supervisores antes de asignarlos.";
            $mSession->claseMensaje = 'advertencia';
            $this->_redirect('/empresa/ver/' . $id);
        }
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_EmpresaSupervisor(null, $empresa->getSupervisoresId());
        $form->empresa_id->setValue($id);
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $empresa = new Shipcode_Model_Empresa();
                    $empresa->configurarSupervisores($form->getValues(), $this->usuario->id);
                    
                    $mSession->mensajes = array('Los supervisores fueron configurados de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/empresa/ver/' . $form->getValue('empresa_id'));
                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar configurar los supervisores.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/empresa/ver/' . $form->getValue('empresa_id'));
                    
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $this->view->empresa = $empresa->getRow();
        $this->view->form = $form;
        $this->view->title = "Configurar supervisores " . $this->view->empresa->nombre;
        $this->view->pageTitle = "Configurar supervisores :: " . $this->view->empresa->nombre;
        $this->renderScript('empresa/form-configurar-supervisores.phtml');
    } 
     */
}