<?php

class EquipoMantenimientoController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 1;
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }

    public function reporteAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->getParam('id');
        
        try {
            
            $modelEquipo = new Shipcode_Model_NaveEquipo();
            $modelEquipo->setId($id);
            $this->view->mantenimientos = $modelEquipo->getMantenimientos(0); 
            $this->view->equipo = $modelEquipo->getRowFull();
            $this->view->tiposMantenimientos = Shipcode_Model_TipoMantenimiento::getPairsToSelect(1);
            $this->view->plan = $modelEquipo->getPlanMantenimientoBasico($this->view->equipo['planmant_id']);
            $this->view->otrosServicios = $modelEquipo->getOtrosServicios($this->view->equipo['planmant_id']); 
            $this->view->title = "Reporte de Mantenimiento";
            $this->view->pageTitle = $this->view->equipo['nombre'] . " > Ingresar reporte de mantenimiento";
            $this->renderScript('equipo-mantenimiento/reporte.phtml');
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar crear un reporte de mantenimiento";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/equipo/ver/' . $id . '/historial-de-mantenimiento');
        }
    }
    
    public function confirmarReporteAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        $from_id = (int)$this->_getParam('from_id', 0);
        
        try {
            
            $equipo = new Shipcode_Model_NaveEquipo();
            $equipo->setId($id);
            $equipo->confirmarReporte($this->usuario->id);
            if($from_id == 0) {
                $mSession->mensajes[] = "Los registros de mantenimiento fueron guardados de forma exitosa.";
                $mSession->claseMensaje = "confirmacion";
                $this->_redirect("/equipo/ver/" . $id . "#historial-de-mantenimiento");
            } else {
                $mSession->mensajes[] = "Los registros de mantenimiento fueron asignados de forma exitosa.";
                $mSession->claseMensaje = "confirmacion";
                $this->_redirect("/mantenimiento-informado");
            }
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar guardar los registros de mantenimiento";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect("/equipo/ver/" . $id . "#historial-de-mantenimientos");
            
        }
    }
    
    public function descartarReporteAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $equipo = new Shipcode_Model_NaveEquipo();
            $equipo->setId($id);
            $equipo->descartarReporte();
            
            $mSession->mensajes[] = "El reporte de mantenimiento fue descartado de forma satisfactoria.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect("/equipo/ver/" . $id . "#historial-de-mantenimiento" );
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar descartar el reporte de mantenimiento.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect("/equipo/ver/" . $id . "#historial-de-mantenimientos");
            
        }
    }
    
    public function agregarAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            try {
                
                $values = array(
                    'fecha' => $this->_getParam('fecha'),
                    'equipo_id' => (int)$this->_getParam('equipo_id'),
                    'horometro' => $this->_getParam('horometro', NULL),
                    'servicio_id' => (int)$this->_getParam('servicio_id'),
                    'detalles' => $this->_getParam('detalles', NULL)
                );
                
                $equipo = new Shipcode_Model_NaveEquipo();
                $result = $equipo->registrarMantenimiento($values, $this->usuario->id);
                
                if($result != FALSE && $result != NULL) {
                    $data['error'] = false;
                    $data['fila']['tipo_id'] = $result['tipo_id'];
                    $data['fila']['tipo'] = $result['tipo'];
                    $data['fila']['id'] = $result['id'];
                    if($result['horometro'] == NULL) {
                        $data['fila']['horometro'] = '';
                    } else {
                        $data['fila']['horometro'] = $this->view->formatDecimal($result['horometro'], 0);
                    }
                    $data['fila']['fecha'] = $this->view->formatFecha($result['fecha']);
                    $data['fila']['detalles'] = $result['detalles'];
                    $data['fila']['observaciones'] = '';
                    echo Zend_Json::encode($data);
                    
                } else {
                    $data['error'] = true;
                    $data['mensaje'] = "Ocurrió un error al intentar guardar el registro de mantenimiento";
                    echo Zend_Json::encode($data);
                }
            } catch(Exception $e){
                $data['error'] = true;
                $data['mensaje'] = "Ocurrió un error al intentar guardar el registro de mantenimiento" . $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }    
    }
    
    public function editarAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
         
            $id = (int)$this->_getParam('id');
            $mantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
            $mantenimiento->setId($id);
            $dataMantenimiento = $mantenimiento->getRow()->toArray();
            $form = new Shipcode_Form_EquipoMantenimiento();
            $form->setAction('/equipo-mantenimiento/guardar/' . $id);
            $form->populate($dataMantenimiento);
            $this->view->form = $form;
            $this->renderScript('equipo-mantenimiento/form.phtml');
        } 
    }
    
    public function guardarAction()
    {
         if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
         
            try {
                
                $values = array(
                    'id' => (int)$this->_getParam('id'),
                    'fecha' => $this->_getParam('fecha'),
                    'horometro' => $this->_getParam('horometro', NULL),
                    'observaciones' => $this->_getParam('observaciones', NULL)
                );
                
                $mantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
                
                $result = $mantenimiento->editarBorrador($values, $this->usuario->id);
  
                if($result != FALSE && $result != NULL) {
                    
                    $data['error'] = false;
                    $data['fila']['tipo_id'] = $result['tipo_id'];
                    $data['fila']['tipo'] = $result['tipo'];
                    $data['fila']['id'] = $result['id'];
                    
                    if($result['horometro'] == NULL) {
                        $data['fila']['horometro'] = '';
                    } else {
                        $data['fila']['horometro'] = $this->view->formatDecimal($result['horometro'], 0);
                    }
                    
                    $data['fila']['fecha'] = $this->view->formatFecha($result['fecha']);
                    $data['fila']['detalles'] = $result['detalles'];
                    
                    if($result['observaciones'] != NULL){
                        $data['fila']['observaciones'] = $result['observaciones'];
                    } else {
                        $data['fila']['observaciones'] = '';
                    }
                        
                    echo Zend_Json::encode($data);
                    
                } else {
                    
                    $data['error'] = true;
                    $data['mensaje'] = "Ocurrió un error al intentar guardar el registro de mantenimiento";
                    echo Zend_Json::encode($data);
                    
                }
            } catch(Exception $e){
                
                $data['error'] = true;
                $data['mensaje'] = "Ocurrió un error al intentar guardar el registro de mantenimiento" . $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function eliminarAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            $id = (int)$this->_getParam('id');
            
            try {
                $mantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
                $mantenimiento->setId($id);
                $mantenimiento->eliminarBorrador();
                $data['error'] = false;
                $data['deleted'] = $id;
                echo Zend_Json::encode($data);
                
            } catch(Exception $e){
                echo Zend_Json::encode(array(
                    'error' => true,
                    'mensaje' => 'Ocurrió un error al intentar eliminar el mantenimiento' . $e->getMessage(),
                    'clase' => 'error'
                ));
            }
        } 
    }
    
    /* a diferencia del action editarMantenimiento 
     * este edita registros definitivos (ya confirmados) */
    public function editarRegistroAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_EquipoMantenimientoFull();
        $mantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
        $id = (int)$this->_getParam('id');
        $mantenimiento->setId($id);
        $equipo_id = $mantenimiento->getEquipoId();
        $dataMantenimiento = $mantenimiento->getRow()->toArray();
        
        $form->tipo_id->addMultiOptions(Shipcode_Model_TipoMantenimiento::getGrupoToSelect($dataMantenimiento['tipo_id']));
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $mantenimiento->editar($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('El registro de mantenimiento fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/equipo/ver/' . $equipo_id .'#historial-de-mantenimiento');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar el registro de mantenimiento.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/equipo/ver/' . $equipo_id .'#historial-de-mantenimiento');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        
        $form->setAction('/equipo-mantenimiento/editar-registro/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/equipo/ver/$equipo_id#historial-de-mantenimiento');");
        $form->populate($dataMantenimiento);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->equipo = $mantenimiento->getEquipo();
        $this->view->title = "Editar registro de mantenimiento";
        $this->view->pageTitle = $this->view->equipo['nombre'] . " > Editar registro de mantenimiento";
        $this->renderScript('equipo-mantenimiento/form.phtml');
    }
    
    /* a diferencia del action eliminarMantenimiento 
     * este elimina registros definitivos (ya confirmados) */
    public function eliminarRegistroAction()
    {
       $this->_helper->viewRenderer->setNoRender();
       $mSession = new Zend_Session_Namespace('shipcode');
       
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        $mantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
        $mantenimiento->setId($id);
        $equipo_id = $mantenimiento->getEquipoId();
            
        try {
            
            $mantenimiento->eliminar($this->usuario->id);
            $mSession->mensajes[] = "El registro de mantenimiento fue eliminado de forma exitosa.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/equipo/ver/' . $equipo_id . '#historial-de-mantenimiento');
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar eliminar el registro de mantenimiento";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/equipo/ver/' . $equipo_id . '#historial-de-mantenimiento');
        }
    }

    public function archivosAction()
    {
        $this->_helper->layout->disablelayout();
        $id = (int)$this->_getParam('id');
        $mantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
        $mantenimiento->setId($id);
        $this->view->archivos = $mantenimiento->getArchivos();
        $this->view->id= $id;
    }
    
    public function filtrarOtrosServiciosAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        if($this->getRequest()->isXmlHttpRequest()){
            $criterio = $this->_getParam('criterio-filtro', NULL);
            $id = (int)$this->_getParam('equipo_id');
            $modelEquipo = new Shipcode_Model_NaveEquipo();
            $modelEquipo->setId($id);
            $equipo = $modelEquipo->getRow();
            $servicios =  $modelEquipo->getOtrosServicios($equipo->planmant_id, $criterio);
            echo Zend_Json::encode($servicios);
        }
    }
    
    public function registroReparacionesAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $id = (int)$this->_getParam('id');
            $tipo_id = (int)$this->_getParam('from_id');
            $equipo = new Shipcode_Model_NaveEquipo();
            $equipo->setId($id);
            $this->view->reparaciones = $equipo->getMantenimientosPorTipoId($tipo_id);
        }
    }
    
    /*
    public function subirArchivoAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
            
        if($this->getRequest()->isXmlHttpRequest()){
            
            $path = 'tmp/';
            $uploader = new Shipcode_Upload_QqFileUploader(
                Zend_Registry::get('ACCEPTED_FILE_FORMAT'),
                Zend_Registry::get('MAX_SIZE_FILE_UPLOAD')
            );
            $result = $uploader->handleUpload($path, TRUE);
            if($result == TRUE){
                $name = $uploader->getName();
                $newName = Shipcode_Archivo::renombrar($name);
                if($newName !== FALSE){
                    echo Zend_Json_Encoder::encode(array('success' => true, 'name' => $newName));
                } else {
                    echo Zend_Json_Encoder::encode(array('success' => false, 'name' => $name));
                }
            } 
        }    
    }
    
    public function guardarArchivoAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
            
        if($this->getRequest()->isXmlHttpRequest()){
            $mantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
            try {
                $data = array();
                $data['mantenimiento_id'] = (int)$this->_getParam('mantenimiento_id'); 
                $data['archivo'] = $this->_getParam('archivo'); 
                $data['nombre'] = $this->_getParam('nombre'); 
                $id = $mantenimiento->guardarArchivo($data, $this->usuario->id);
                echo Zend_Json::encode(array(
                    'error'     => false, 
                    'mensaje'   => 'El archivo fue guardado de forma satisfactoria.',
                    'id'        => $id,
                    'num'       => Shipcode_Model_NaveEquipoMantenimiento::getNumArchivos($data['mantenimiento_id']),
                    'mid'       => $data['mantenimiento_id'],
                    'clases'    => 'alert alert-success',
                    'nombre'    => $data['nombre']
                ));
            } catch(Exception $e){
                echo Zend_Json::encode(array(
                    'error'     => true, 
                    'mensaje'   => 'Ocurrió un error al intentar guardar el archivo. Error: ' . $e->getMessage(),
                    'clases'    => 'alert alert-error'
                ));
            }
        }
    }
    
    public function descargarArchivoAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        $id = (int)$this->_getParam('id');
        $archivo = new Shipcode_Model_NaveEquipoMantenimientoArchivo();
        $archivo->setId($id);
        $row = $archivo->getRow();
        $fileFullPath = Zend_Registry::get('PATH_SERVER') . 'files/mantenimientos/' . $row->archivo;
        
        if(file_exists($fileFullPath)){
            $download_path = Zend_Registry::get('PATH_SERVER') . "files/mantenimientos/";
            $args = array(
		'download_path'		=>	$download_path,
		'file'                  =>	$row->archivo,		
		'extension_check'	=>	TRUE,
		'referrer_check'	=>	FALSE,
		'referrer'		=>	NULL,
		);
            $download = new App_Download($args);
            $download_hook = $download->get_download_hook();
            if( $download_hook['download'] == TRUE ) {
        	$download->get_download();
            }
        } else {
            $mSession = new Zend_Session_Namespace('shipcode');
            $mSession->mensajes[] = "El archivo solicitado no existe.";
            $mSession->claseMensaje = "error";
            $this->_redirect($_SERVER['HTTP_REFERER']);
        }
    }

    public function eliminarArchivoAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if($this->getRequest()->isXmlHttpRequest()){
            try {
                $id = (int)$this->_getParam('id');
                $archivo = new Shipcode_Model_NaveEquipoMantenimientoArchivo();
                $archivo->setId($id);
                $mantenimiento_id = $archivo->eliminar();
                $numArchivos = Shipcode_Model_NaveEquipoMantenimiento::getNumArchivos($mantenimiento_id);
                
                if(FALSE != $id){
                    echo Zend_Json::encode(array(
                        'error'     => false, 
                        'id'        => $id,
                        'mid'       => $mantenimiento_id,
                        'num'       => $numArchivos,
                        'clases'    => 'alert alert-success',
                        'mensaje'   => 'El archivo fue eliminado de forma exitosa'
                    ));
                } else {
                    echo Zend_Json::encode(array(
                        'error'     => true, 
                        'clases'    => 'alert alert-error',
                        'mensaje'   => 'Ocurrió un error al intenar eliminar el archivo'
                    ));
                }
            } catch (Exception $e){
                echo Zend_Json::encode(array(
                    'error'     => true, 
                    'clases'    => 'alert alert-error',
                    'mensaje'   => $e->getMessage()
                ));
            }
        }
    }
    */
}