<?php
class EquipoParametroController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 5;
        
        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();
        
        if(!$this->getRequest()->isXmlHttpRequest() && $this->usuario){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig' , $this->view->render('menu-base.phtml'));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Parámetros equipos";
        
        try {
            $parametro = new Shipcode_Model_EquipoParametro();
            $this->view->parametros = $parametro->getAll();
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_EquipoParametro();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $parametro = new Shipcode_Model_EquipoParametro();
                    $parametro->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('El parámetro fue creado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/equipo-parametro');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el parámetro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/equipo-parametro');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->cancel->setAttrib('onclick', "javascript:goTo('/equipo-parametro');");
        $this->view->form = $form;
        $this->view->title = "Agregar parámetro de equipo";
        $this->view->pageTitle = "Parámetro equipos";
        $this->renderScript('equipo-parametro/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_EquipoParametro();
        $parametro = new Shipcode_Model_EquipoParametro();
        
        if($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $parametro->editar($form->getValues(), $this->usuario->id, (int)$this->_getParam('id'));
                    $mSession->mensajes = array('El parámetro fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/equipo-parametro');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar el parámetro.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/equipo-parametro');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $parametro->setId($id);
        $form->populate($parametro->getRow()->toArray());
        $form->setAction('/equipo-parametro/editar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/equipo-parametro');");
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar el parámetro";
        $this->view->pageTitle = "Parámetro equipos";
        $this->renderScript('equipo-parametro/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $parametro = new Shipcode_Model_EquipoParametro();
            $parametro->setId($id);
            $parametro->eliminar();
            $mSession->mensajes[] = 'El parámetro fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/equipo-parametro');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el parámetro.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/equipo-parametro');
        }
    }
}