<?php
class EventoController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    public function getInfoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            
            try {
                
                $id = (int)$this->_getParam('id');
                $actividad = new Shipcode_Model_NaveActividad();
                $actividad->setId($id);
                $this->view->actividad = $actividad->getRowFull();
                
            } catch (Exception $ex) {
                $data['error'] = true;
                $data['mensaje'] = $ex->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function asignarFechaManualAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            try {
                
                $values = array(
                    'fecha' => $this->_getParam('fecha', NULL),
                    'id' => (int)$this->_getParam('id', 0),
                );
                
                $actividad = new Shipcode_Model_NaveActividad();
                $result = $actividad->asignarFechaManual($values, $this->usuario->id);
                
                if($result != FALSE) {
                    
                    $data['error'] = false;
                    $data['fila'] = array(
                        'id' => $values['id'], 
                        'tipo' => 'M',
                        'title' => 'Configurado por ' . $this->usuario->nombre . ' el ' . $this->view->formatFecha(date("Y-m-d")),    
                        'codigo' => 401,
                        'dependencia_tipo' => false,
                        'fecha_formateada' => $this->view->formatFechaCorta($values['fecha'])
                    );
                    
                    echo Zend_Json::encode($data);
                    
                } else {
                    
                    $data['error'] = true;
                    $data['mensaje'] = "Ocurrió un error al intentar agendar el mantenimiento";
                    echo Zend_Json::encode($data);
                    
                }
            } catch(Exception $e){
                
                $data['error'] = true;
                $data['mensaje'] = $e->getMessage();
                echo Zend_Json::encode($data);
                
            }
        }
    }
    
    public function anclarEnCarenaAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');    
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        try {

            $id = (int)$this->_getParam('id');
            $actividad = new Shipcode_Model_NaveActividad();
            $result = $actividad->anclarEventoCarena($id, $this->usuario->id);
            $mSession->mensajes[] = "El ítem fue anclado a la carena de la nave de forma exitosa.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/equipo/ver/' . $result['equipo_id'] . '/plan-de-mantenimiento');
            
        } catch(Exception $e){

            $mSession->mensajes[] = "Ocurrió un error al intentar anclar el ítem a la carena de la nave.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect($_SERVER['HTTP_REFERER']);

        }
    }
    
    public function desanclarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');    
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        try {

            $id = (int)$this->_getParam('id');
            $actividad = new Shipcode_Model_NaveActividad();
            $result = $actividad->resetearProgramacionEvento($id, $this->usuario->id);
            $mSession->mensajes[] = "El ítem fue desanclado y reprogramado automáticamente de forma exitosa.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/equipo/ver/' . $result['equipo_id'] . '/plan-de-mantenimiento');
            
        } catch(Exception $e){

            $mSession->mensajes[] = "Ocurrió un error al intentar desanclar el ítem y reprogramarlo.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect($_SERVER['HTTP_REFERER']);

        }
    }
    
    public function seleccionarMantenimientoAnclajeAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            try {
                $id = (int)$this->_getParam('id');
                $evento = new Shipcode_Model_NaveActividad();
                $evento->setId($id);
                $nave = new Shipcode_Model_Nave();
                $nave->setId($evento->getNaveId());
                $this->view->sistemas = $nave->getEquiposConPlanParaAnclaje();
                $this->view->evento = $evento->getRow()->toArray();
            } catch(Exception $e){
                $data['error'] = true;
                $data['mensaje'] = $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function anclarItemAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');    
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        try {

            $secundario_id = (int)$this->_getParam('id');
            $primario_id = (int)$this->_getParam('from_id');
            
            $actividad = new Shipcode_Model_NaveActividad();
            $result = $actividad->anclarEventoEnEvento($primario_id, $secundario_id, $this->usuario->id);
            $mSession->mensajes[] = "Los ítems fueron anclados de forma exitosa.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/equipo/ver/' . $result['equipo_id'] . '/plan-de-mantenimiento');
            
        } catch(Exception $e){

            $mSession->mensajes[] = "Ocurrió un error al intentar anclar los ítems.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect($_SERVER['HTTP_REFERER']);

        }
    }
}