<?php
class GestionProyectosController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 3;
        $this->view->pageTitle = "Gestión de Proyectos";
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }

    /***************** OPERACIONES ADMINISTRADOR HORÓMETROS *******************/
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->centrosCosto = Shipcode_Model_CentroCosto::getPairsToSelect();
        $this->view->conceptosImputacion = Shipcode_Model_ConceptoImputacion::getPairsToSelect();
        $this->view->tiposProyectos = Shipcode_Model_TipoProyecto::getPairsToSelect();
        $this->view->year = date("Y");
        //echo md5("EnvíoAutomáticoDeInformes" . date("Ymd"));
    }
    
    public function getDataProrrateoAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        if($this->getRequest()->isXmlHttpRequest()){
            try {
                $year = $this->_getParam('year', date("Y"));
                $parametros = array(
                    'year' => $year,
                    'centros' => $this->_getParam('centro'),
                    'conceptos' => $this->_getParam('concepto'),
                    'tipos' => $this->_getParam('tipo')
                );
                $mSession->parametros = $parametros;
                $proyecto = new Shipcode_Model_Proyecto();
                $this->view->year = $year;
                $this->view->proyectos = $proyecto->getDataProrrateos($parametros);
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
            $this->renderScript('gestion-proyectos/data-prorrateos.phtml');
        }
    }
    
    public function getDataProrrateoNextYearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        if($this->getRequest()->isXmlHttpRequest()){
            try {
                
                $parametros = $mSession->parametros;
                $parametros['year']++;
                unset($mSession->parametros);
                $mSession->parametros = $parametros;
                $proyecto = new Shipcode_Model_Proyecto();
                $this->view->year = $parametros['year'];
                $this->view->proyectos = $proyecto->getDataProrrateos($parametros);
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
            $this->renderScript('gestion-proyectos/data-prorrateos.phtml');
        }
    }
    
    public function getDataProrrateoPrevYearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        if($this->getRequest()->isXmlHttpRequest()){
            try {
                
                $parametros = $mSession->parametros;
                $parametros['year']--;
                unset($mSession->parametros);
                $mSession->parametros = $parametros;
                $proyecto = new Shipcode_Model_Proyecto();
                $this->view->year = $parametros['year'];
                $this->view->proyectos = $proyecto->getDataProrrateos($parametros);
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
            $this->renderScript('gestion-proyectos/data-prorrateos.phtml');
        }
    }
    
    public function listadoAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        try {
            
            $proyecto = new Shipcode_Model_Proyecto();
            $this->view->proyectos = $proyecto->getAll();
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar visualizar el listado de proyectos';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
        }
    }
    
    public function verAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $proyecto = new Shipcode_Model_Proyecto();
            $proyecto->setId($id);
            $this->view->proyecto = $proyecto->getRowFull();
            $this->view->pageTitle = "Detalle Proyecto :: " . $this->view->proyecto['nombre'];
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar el proyecto.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/gestion-proyectos/listado');
        }
    }
    
    public function resumenAction()
    {
        $this->_helper->layout->disableLayout();
        if($this->getRequest()->isXmlHttpRequest()){
            $id = (int)$this->_getParam('id');
            try {
                $proyecto = new Shipcode_Model_Proyecto();
                $proyecto->setId($id);
                $this->view->proyecto = $proyecto->getRowFull();

            } catch(Exception $e){
               echo $e->getMessage();
            }
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_Proyecto();
        
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $proyecto = new Shipcode_Model_Proyecto();
                    $id = $proyecto->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('El proyecto fue creado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/gestion-proyectos/ver/' . $id);

                } catch (Exception $e) {
                    unset($this->view->mensajes);
                    $this->view->mensajes = array(
                        'Ocurrió un error al intentar crear el proyecto.', 
                        $e->getMessage()
                    );
                    $this->view->claseMensaje = 'error';
                    $form->populate($request->getPost());
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $form->cancel->setAttrib('onclick', "javascript:goTo('/gestion-proyectos/listado');");
        $this->view->form = $form;
        $this->view->title = "Gestión de Proyectos : Crear";
        $this->renderScript('gestion-proyectos/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_Proyecto();
        $proyecto = new Shipcode_Model_Proyecto();
        $id = (int)$this->_getParam('id');
        $proyecto->setId($id);
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $id = $proyecto->editar($form->getValues(), $this->usuario->id);
                    
                    $mSession->mensajes = array('El proyecto fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/gestion-proyectos/ver/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar el proyecto.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/gestion-proyectos/ver/' . $id);
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $form->populate($proyecto->getRowToForm());
        $form->setAction('/gestion-proyectos/editar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/gestion-proyectos/ver/$id');");
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Gestión de Proyectos : Editar";
        $this->renderScript('gestion-proyectos/form.phtml');
    }
    
    public function ponerEnLiquidacionAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $proyecto = new Shipcode_Model_Proyecto();
        $id = (int)$this->_getParam('id');
        try {

            $proyecto->setId($id);
            $result = $proyecto->checkInfoLiquidacion();
            if($result === TRUE){
                $proyecto->setEstado('EN LIQUIDACION');
                $mSession->mensajes = array('El proyecto fue puesto en liquidación de forma exitosa.');
                $mSession->claseMensaje = 'confirmacion';
                $this->_redirect('/gestion-proyectos/ver/' . $id);
            } else {
                $mSession->mensajes[] = 'No se ha completado toda la información requerida para realizar la operación.';
                $mSession->mensajes[] = 'Por favor, asegúrese de completar los campos: costo total, meses de prorrateo y fecha de inicio del prorrateo';
                $mSession->claseMensaje = 'error';
                $this->_redirect('/gestion-proyectos/ver/' . $id);
            }

        } catch (Exception $e) {

            $mSession->mensajes = array('Ocurrió un error al intentar poner el proyecto en liquidación.');
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/gestion-proyectos/ver/' . $id);
        }
    }
    
    public function liquidarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_ProyectoLiquidacion();
        $proyecto = new Shipcode_Model_Proyecto();
        $id = (int)$this->_getParam('id');
        $proyecto->setId($id);
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $proyecto->liquidar($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('El proyecto fue liquidado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/gestion-proyectos/ver/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar liquidar el proyecto.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/gestion-proyectos/ver/' . $id);
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $form->id->setValue($id);
        $form->setAction('/gestion-proyectos/liquidar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/gestion-proyectos/ver/$id');");
        $this->view->form = $form;
        $this->view->proyecto = $proyecto->getRowFull();
        $this->view->title = "Prorrateo de proyectos";
        $this->renderScript('gestion-proyectos/form-liquidacion.phtml');
    }

    public function formBusquedaAction()
    {
        $this->view->title = "Buscar proyectos";
        $this->view->centrosCosto = Shipcode_Model_CentroCosto::getPairsToSelect();
        $this->view->conceptosImputacion = Shipcode_Model_ConceptoImputacion::getPairsToSelect();
        $this->view->tipos = Shipcode_Model_TipoProyecto::getPairsToSelect();
    }
    
    public function buscarAction()
    {
        $parametros = array(
            'centro_costo_id' => $this->_getParam('centro_costo_id'),
            'concepto_imputacion_id' => $this->_getParam('concepto_imputacion_id'),
            'tipo_id' => $this->_getParam('tipo_id'),
            'nombre' => $this->_getParam('nombre'),
            'estado' => $this->_getParam('estado'),
            'terminados' => $this->_getparam('terminados'),
            'inicioProrrateo' => $this->_getparam('inicio_prorrateo'),
            'terminoProrrateo' => $this->_getparam('termino_prorrateo'),
            'liquidados' => $this->_getparam('liquidacion')
        );
        
        $proyecto = new Shipcode_Model_Proyecto();
        $this->view->proyectos = $proyecto->buscar($parametros);
        $this->renderScript('gestion-proyectos/resultados-busqueda.phtml');
     
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        try {
            $proyecto = new Shipcode_Model_Proyecto();
            $proyecto->setId($id);
            $proyecto->eliminar();
            $mSession->mensajes[] = 'El proyecto ha sido eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/gestion-proyectos/listado');
        } catch (Exception $e) {
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el proyecto.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/gestion-proyectos/listado');
        }
    }
}