<?php
class GestionSolicitudesController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->controller = $this->getRequest()->getControllerName();
        $this->view->action = $this->getRequest()->getActionName();
        $this->empresa_id = $this->view->empresa_id = Shipcode_Model_SistemaUsuario::getEmpresaAsignada($this->view->autorizaciones['empresas']);
        $this->ultimaVisita = Shipcode_Model_SistemaLogIngreso::getVisitaAnteriorByUsuarioId($this->usuario->id);
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Gestión de solicitudes";
        
        try {
            $solicitud = new Shipcode_Model_Solicitud();
            $empresa = new Shipcode_Model_Empresa();
            $this->view->empresas = $empresa->getAll();
            
            if($this->_getParam('submit') === 'buscar') {
                $this->view->title = "Resultados búsqueda";
                $parametros = array(
                    'estado' => $this->_getParam('estado'),
                    'desde' => $this->_getParam('desde'),
                    'hasta' => $this->_getParam('hasta'),
                    'enviado_por' => $this->_getParam('enviado_por'),
                    'prioridad' => $this->_getParam('prioridad'),
                    'nave' => $this->_getParam('nave'),
                    'empresa' => $this->empresa_id 
                );
                $this->view->parametros = $parametros;
                $this->view->solicitudes = $solicitud->filtrar($parametros, $this->view->autorizaciones['naves']);
                $this->view->solicitudesConNuevosComentarios = $solicitud->getConNuevosComentarios($this->ultimaVisita);
                $this->view->numSolicitudesConNuevosComentarios = count(array_unique($this->view->solicitudesConNuevosComentarios));
                $this->view->fechaUltimaVisita = new Zend_Date($this->ultimaVisita['creacion']);
                
            } else {
                $parametros = array(
                    'estado' => 20,
                    'desde' => '',
                    'hasta' => '',
                    'enviado_por' => '',
                    'prioridad' => 2,
                    'nave' => 0,
                    'empresa' => $this->empresa_id 
                );
                $this->view->title = "Activas";
                $this->view->solicitudes = $solicitud->filtrar($parametros, $this->view->autorizaciones['naves']);
                $this->view->solicitudesConNuevosComentarios = $solicitud->getConNuevosComentarios($this->ultimaVisita);
                $this->view->numSolicitudesConNuevosComentarios = count(array_unique($this->view->solicitudesConNuevosComentarios));
                $this->view->fechaUltimaVisita = new Zend_Date($this->ultimaVisita['creacion']);
            }
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function aceptarAction()
    { 
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if($this->getRequest()->isXmlHttpRequest()){
            $id = (int)$this->_getParam('id');
            try{
                $solicitud = new Shipcode_Model_Solicitud();
                $solicitud->setId($id);
                $solicitud->recibir();
                $data['error'] = false;
                $data['id'] = $id;
                echo Zend_Json::encode($data);
                
            } catch(Exception $e){
                $data['error'] = true;
                $data['mensaje'] = "Ocurrió un error al intentar aceptar la solicitud. " . $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function terminarAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if($this->getRequest()->isXmlHttpRequest()){
            $id = (int)$this->_getParam('id');
            try{
                $solicitud = new Shipcode_Model_Solicitud();
                $solicitud->setId($id);
                $solicitud->terminar();
                $data['error'] = false;
                $data['id'] = $id;
                echo Zend_Json::encode($data);
                
            } catch(Exception $e){
                $data['error'] = true;
                $data['mensaje'] = "Ocurrió un error al intentar terminar la solicitud. " . $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function rechazarAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if($this->getRequest()->isXmlHttpRequest()){
            $id = (int)$this->_getParam('id');
            try{
                $solicitud = new Shipcode_Model_Solicitud();
                $solicitud->setId($id);
                $solicitud->rechazar($this->usuario->id);
                $data['error'] = false;
                $data['id'] = $id;
                echo Zend_Json::encode($data);
                
            } catch(Exception $e){
                $data['error'] = true;
                $data['mensaje'] = "Ocurrió un error al intentar terminar la solicitud. " . $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function comentarAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $id = (int)$this->_getParam('id');
            
            if($this->_getParam('c')){
                
                try{
                    
                    $comentario = $this->_getParam('c');
                    $tipo = $this->_getParam("t");
                    $solicitud = new Shipcode_Model_Solicitud();
                    $solicitud->setId($id);
                    $row = $solicitud->agregarComentario($comentario, $tipo, $this->usuario->id);
                    $data['error'] = false;
                    $data['fecha'] = $this->view->formatFechaCorta($row->creacion);
                    $data['comentario'] = $row->comentarios;
                    
                } catch(Exception $e){
                    
                    $data['error'] = true;
                    $data['mensaje'] = $e->getMessage();
                    
                }
                echo Zend_Json::encode($data);
            }
        }
    }
    /**************************************************************************/
}