<?php
class HorometroLecturaController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 1;
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    public function adminRegistroAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            
            $id = (int)$this->_getParam('id');
            
            $equipo = new Shipcode_Model_NaveEquipo();
            $equipo->setId($id);
            $this->view->equipo = $equipo->getRowFull();
            $this->view->lecturas = $equipo->getLecturasHorometro();
        }
    }
    
    public function verRegistroAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $equipo_id = (int)$this->_getParam('id');
            $back = (int)$this->_getParam('from_id');
            $horometro = new Shipcode_Model_NaveHorometroLectura();
            $this->view->lecturas = $horometro->getLecturasPorEquipoId($equipo_id);
            $this->view->equipo_id = $equipo_id;
            $this->view->back = $back;
        }
    }
    
    public function ingresarAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            try {
                
                $equipo_id = (int)$this->_getParam('equipo_id');
                $fecha = $this->_getParam('fecha');
                $lectura = (int)$this->_getParam('lectura');
                $equipo = new Shipcode_Model_NaveEquipo();
                $equipo->setId($equipo_id);
                $id = $equipo->registrarLecturaHorometro($lectura, $fecha, $this->usuario->id);
                
                if($id !== FALSE || $id !== NULL) {
                    
                    // Lectura siguiente : es decir, la que va antes en la tabla HTML, 
                    // ya que se muestran en orden descendente. 
                    $idLecturaSiguiente = $equipo->getIdLecturaSiguiente($id);
                    if($idLecturaSiguiente === NULL || $idLecturaSiguiente === FALSE){
                        $ubicacion = false;
                    } else {
                        $ubicacion = "#l" .$idLecturaSiguiente;
                    }
                    $puntosAnclaje = $equipo->getPuntosAnclaje(); 
                    
                    if(count($puntosAnclaje) > 0) {
                        $lecturaAnterior = $equipo->getLecturaAnterior($id);
                        
                        foreach($puntosAnclaje as $puntoAnclaje){
                            $fechaAnclaje = new Zend_Date($puntoAnclaje['fecha']);
                            $fechaLectura = new Zend_Date($fecha);
                            if($fechaLectura->isLater($fechaAnclaje)){
                                
                                $diferenciaHoras = $lectura - $lecturaAnterior['lectura'];
                                $equipoAnclado = new Shipcode_Model_NaveEquipo();
                                $equipoAnclado->setId($puntoAnclaje['equipo_id']);
                                $lecturaDependiente = $equipoAnclado->getLecturaHorometroDependiente($lecturaAnterior['id']);
                                if($lecturaDependiente) {
                                    $lecturaAnclado = $lecturaDependiente->lectura + $diferenciaHoras;
                                    $equipoAnclado->registrarLecturaHorometro($lecturaAnclado, $fecha, $this->usuario->id, $id);
                                }
                            }
                        }
                    }
                    
                    $data['error'] = false;
                    $data['ubicacion'] = $ubicacion;
                    $data['fila'] = $equipo->getLecturaHorometroByIdToJson($id);
                    $data['sumario'] = $equipo->getSumarioHorometroToJson();
                    $data['horasOperacion'] = $equipo->getHorasOperacionMensuales();
                    echo Zend_Json::encode($data);
                    
                } elseif($id == 0) {
                    
                    $data['error'] = true;
                    $data['mensaje'] = "Ya existe otro registro con los valores ingresados";
                    echo Zend_Json::encode($data);
                    
                } else {    
                    $data['error'] = true;
                    $data['mensaje'] = "Ocurrió un error al intentar guardar el registro de horómetro";
                    echo Zend_Json::encode($data);
                }
            } catch(Exception $e){
                
                $data['error'] = true;
                $data['mensaje'] = $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function editarAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            try {
                
                $id = (int)$this->_getParam('id');
                $fecha = $this->_getParam('fecha');
                $valor = (int)$this->_getParam('lectura');
                $lectura = new Shipcode_Model_NaveHorometroLectura();
                $lectura->setId($id);
                $equipoPrincipal = $lectura->getEquipo();
                $result = $equipoPrincipal->editarLecturaHorometro($id, $valor, $fecha, $this->usuario->id);
                
                if($result !== FALSE && $result !== NULL) {
                    
                    if(count($result['registrosReferidos']) > 0 ) {
                        foreach($result['registrosReferidos'] as $reg){
                            $equipoReferido = new Shipcode_Model_NaveEquipo();
                            $equipoReferido->setId($reg['equipo_id']);  
                            $valorActualizado = $reg['lectura'] + ($result['diferenciaHoras']);
                            $equipoReferido->editarLecturaHorometro($reg['id'], $valorActualizado, $fecha, $this->usuario->id);
                        }
                    }
                    
                    // Lectura siguiente : es decir, la que va antes en la tabla HTML, 
                    // ya que se muestran en orden descendente. 
                    $idLecturaSiguiente = $equipoPrincipal->getIdLecturaSiguiente($id);
                    if($idLecturaSiguiente === NULL || $idLecturaSiguiente === FALSE){
                        $ubicacion = false;
                    } else {
                        $ubicacion = "#l" .$idLecturaSiguiente;
                    }
                    
                    $data['error'] = false;
                    $data['ubicacion'] = $ubicacion;
                    $data['fila'] = $equipoPrincipal->getLecturaHorometroByIdToJson($id);
                    $data['sumario'] = $equipoPrincipal->getSumarioHorometroToJson();
                    $data['horasOperacion'] = $equipoPrincipal->getHorasOperacionMensuales();
                    echo Zend_Json::encode($data);
                    
                 } elseif($id == 0) {
                    
                    $data['error'] = true;
                    $data['mensaje'] = "Ya existe otro registro con los valores ingresados";
                    echo Zend_Json::encode($data);
                    
                }  else {    
                    $data['error'] = true;
                    $data['mensaje'] = "Ocurrió un error al intentar editar el registro de horómetro";
                    echo Zend_Json::encode($data);
                }
                
            } catch(Exception $e){
                
                $data['error'] = true;
                $data['mensaje'] = $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function eliminarAction()
    {
        
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if($this->getRequest()->isXmlHttpRequest()){
            try {
                $id = (int)$this->_getParam('id');
                $lectura = new Shipcode_Model_NaveHorometroLectura();
                $lectura->setId($id);
                $equipoPrincipal = $lectura->getEquipo();
                $result = $equipoPrincipal->eliminarLecturaHorometro($id, $this->usuario->id);
                
                if(FALSE != $result['dataEliminado'] && NULL != $result['dataEliminado']){
                    
                    if(count($result['registrosReferidos']) > 0 ) {
                        foreach($result['registrosReferidos'] as $reg){
                            $equipoReferido = new Shipcode_Model_NaveEquipo();
                            $equipoReferido->setId($reg['equipo_id']);  
                            $equipoReferido->eliminarLecturaHorometro($reg['id'], $this->usuario->id);
                            if($equipoReferido->tieneLecturasReferidas() == FALSE){
                                $equipoReferido->eliminarAnclajeHorometro(FALSE);
                            }
                        }
                    }
                    
                    $data['error'] = false;
                    $data['equipo_id'] = $result['dataEliminado']['equipo_id'];
                    $data['eliminado_id'] = $result['dataEliminado']['id'];
                    $data['sumario'] = $equipoPrincipal->getSumarioHorometroToJson();
                    echo Zend_Json::encode($data);
                    
                } else {
                    echo Zend_Json::encode(array(
                        'error'     => true, 
                        'clase'     => 'error',
                        'mensaje'   => 'Ocurrió un error al intenar eliminar la lectura del horómetro'
                    ));
                }
            } catch (Exception $e){
                echo Zend_Json::encode(array(
                    'error'     => true, 
                    'clase'     => 'error',
                    'mensaje'   => $e->getMessage()
                ));
            }
        }
    }    
}