<?php
class InventarioCategoriaController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 5;
        
        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();
        
        if(!$this->getRequest()->isXmlHttpRequest() && $this->usuario){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig' , $this->view->render('menu-base.phtml'));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Categorías de artículos";
        
        try {
            $categoria = new Shipcode_Model_InventarioCategoria();
            $this->view->categorias = $categoria->getAll();
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_InventarioCategoria();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/inventario-categoria');");
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $categoria = new Shipcode_Model_InventarioCategoria();
                    $categoria->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('La categoría de artículos fue creada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/inventario-categoria');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la categoría de artículos.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/inventario-categoria');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $this->view->form = $form;
        $this->view->title = "Crear categoría de artículos";
        $this->view->pageTitle = "Categoría artículos";
        $this->renderScript('inventario-categoria/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_InventarioCategoria();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/inventario-categoria');");
        $categoria = new Shipcode_Model_InventarioCategoria();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $categoria->editar($form->getValues(), $this->usuario->id, (int)$this->_getParam('id'));
                    
                    $mSession->mensajes = array('La categoría de artículos fue editada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/inventario-categoria');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar la categoría de artículos.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/inventario-categoria');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $categoria->setId($id);
        $form->populate($categoria->getRow()->toArray());
        $form->setAction('/inventario-categoria/editar/' . $id);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar categoría de artículos";
        $this->renderScript('inventario-categoria/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $categoria = new Shipcode_Model_InventarioCategoria();
            $categoria->setId($id);
            $categoria->eliminar();
            
            $mSession->mensajes[] = 'La categoría fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/inventario-categoria');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la categoría de artículos.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/inventario-categoria');
        }
    }
}