<?php
class ListasDeVerificacionController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 3;
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $this->view->pageTitle = "Listas de verificación";
        try {
            $lista = new Shipcode_Model_ListaVerificacionEmitida();
            $this->view->empresas = Shipcode_Model_Empresa::getPairsToSelect();
            $this->view->naves = Shipcode_Model_Nave::getPairsToSelect();
            if($this->getRequest()->isPost()) {
                $this->view->title = "Resultados búsqueda";
                $parametros = array(
                    'estado' => $this->_getParam('estado'),
                    'desde' => $this->_getParam('desde'),
                    'hasta' => $this->_getParam('hasta'),
                    'enviado_por' => $this->_getParam('enviado_por'),
                    'empresa' => $this->_getParam('empresa'),
                    'nave' => $this->_getParam('nave')
                );
                $this->view->parametros = $parametros;
                $this->view->programaciones = $lista->buscar($parametros);
            } else {
                $this->view->title = "Abiertas";
                $this->view->listas = $programacion->getAll('ABIERTA');
            }
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_ProgramacionMensual();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $programacion = new Shipcode_Model_ProgramacionMensual();
                    $id = $programacion->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('La programación fue creada de forma exitosa. Ahora puede seleccionar los trabajos a asignar.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/programacion-mensual/configuracion/' . $id);

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la programación mensual.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/programacion-mensual');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->cancel->setAttrib('onclick', "javascript:goTo('/programacion-mensual');");
        $this->view->form = $form;
        $this->view->title = "Crear programación mensual";
        $this->view->pageTitle = "Programación Mensual de Mantenimiento";
        $this->renderScript('programacion-mensual/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            $programacion->eliminar();
            
            $mSession->mensajes[] = 'La programación mensual fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/programacion-mensual');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar programación mensual.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/programacion-mensual');
        }
    }
    
    public function configuracionAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $this->view->pageTitle = "Programación mensual de mantenimiento";
        try {
            $id = (int)$this->_getParam('id');
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            $this->view->title = "Programación Mensual - Nave " . $this->view->programacion['nave'];
            $this->view->programacion = $programacion->getRowFull();
            $this->view->equiposTrabajos = $programacion->getTrabajosSeleccionados();
            
            $infoMes = $this->view->programacion['year'] . "-" . $this->view->programacion['mes'];
            $mes = new Shipcode_Model_AuxMes();
            $mes->setMes($infoMes . "-01");
            $this->view->diasMes = $mes->getDiasMes();
            $this->view->mes = $infoMes;
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar la programación mensual";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/programacion-mensual');
        }
    }
    
    public function enviarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $id = (int)$this->_getParam('id');
        
        try {
            
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            $programacion->enviar();
            
            $mSession->mensajes[] = "La programación fue enviada de forma satisfactoria.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/programacion-mensual/proceso/' . $id);
            
        } catch (Exception $e) {
            $mSession->mensajes[] = "Ocurrió un problema al intentar enviar la programación mensual";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/programacion-mensual/configuracion/' . $id);
        }
    }
    
    public function procesoAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $this->view->pageTitle = "Programación mensual de mantenimiento";
        try {
            $id = (int)$this->_getParam('id');
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            $this->view->title = "Programación Mensual - Nave " . $this->view->programacion['nave'];
            $this->view->programacion = $programacion->getRowFull();
            $this->view->equiposTrabajos = $programacion->getTrabajosSeleccionados(1);
            $this->view->perfil = "ADMIN";
            
            $infoMes = $this->view->programacion['year'] . "-" . $this->view->programacion['mes'];
            $mes = new Shipcode_Model_AuxMes();
            $mes->setMes($infoMes . "-01");
            $this->view->diasMes = $mes->getDiasMes();
            $this->view->mes = $infoMes;
            
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar la programación mensual";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/programacion-mensual');
        }
    }
    
    public function cerrarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $id = (int)$this->_getParam('id');
        
        try {
            
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            $programacion->cerrar();
            
            $mSession->mensajes[] = "La programación fue cerrada de forma satisfactoria.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/programacion-mensual/informe/' . $id);
            
        } catch (Exception $e) {
            $mSession->mensajes[] = "Ocurrió un problema al intentar cerrar la programación mensual";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/programacion-mensual/proceso/' . $id);
        }
    }
    
    public function informeAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $this->view->pageTitle = "Programación mensual de mantenimiento";
        try {
            $id = (int)$this->_getParam('id');
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            $this->view->title = "Programación Mensual - Nave " . $this->view->programacion['nave'];
            $this->view->programacion = $programacion->getRowFull();
            $this->view->equiposTrabajos = $programacion->getTrabajosSeleccionados();
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar el informe de la programación mensual";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/programacion-mensual');
        }
    }
    /************************** FUNCIONES TRABAJOS ****************************/
    public function asignarAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                $id = (int)$this->_getParam('id');
                $responsable = $this->_getParam('responsable');
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
                $trabajo->setId($id);
                $trabajo->asignar($responsable);
                $data['error'] = false;
                $data['id'] = $id;
                echo Zend_Json::encode($data);
                
            } catch (Exception $ex) {
                $data['error'] = true;
                $data['mensaje'] = $ex->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function editarFechaTrabajoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
                $id = (int)$this->_getParam('id');
                $fecha = $this->_getParam('fecha');
                $n = $this->_getParam('numero');
                $trabajo->setId($id);
                $trabajo->editarFecha($fecha);
                $data['error'] = false;
                $data['id'] = $id;
                $data['fecha'] = $fecha;
                $data['numero'] = $n;
                $data['estado'] = 'TERMINADO';
                echo Zend_Json::encode($data);
                
            } catch (Exception $ex) {
                $data['error'] = true;
                $data['mensaje'] = $ex->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function setTrabajoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $id = (int)$this->_getParam('trabajo_id');
            
            try {
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
                $trabajo->setId($id);
                $trabajo->cambiarEstadoSeleccion();
                $data['error'] = false;
                echo Zend_Json::encode($data);

            } catch(Exception $e){
                $data['error'] = true;
                $data['mensaje'] = $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function terminarTrabajoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
           
                $id = (int)$this->_getParam('trabajo_id');
                $data['trabajo_id'] = $id;
                $data['horas_realizacion'] = $this->_getParam('horas');
                $data['fecha'] = $this->_getParam('fecha');
                $data['fecha_realizacion'] = $this->_getParam('fecha');
                $data['fecha_informe'] = date("Y-m-d");
                $data['numero'] = $this->_getParam('numero');
                $data['comentarios'] = $this->_getParam('comentarios');
                $data['rechazo_comentarios'] = NULL;
                $data['postergacion_comentarios'] = NULL;
                $data['postergacion_motivo'] = NULL;
                
                $trabajo->setId($id);
                $rowTrabajo = $trabajo->getRow()->toArray();
                $data['estado'] = $trabajo->terminar($data);
                $data['sumario'] = array(
                    'trabajos'      => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id']),
                    'programados'   => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1),
                    'realizados'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "TERMINADO"),
                    'pendientes'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "PENDIENTE"),
                    'no_realizados' => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "NO REALIZADO"),
                    'postergados'   => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "POSTERGADO"),
                    'rechazados'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "RECHAZADO")
                );
                $data['error'] = false;
                echo Zend_Json::encode($data);
                
            } catch (Exception $ex) {
                $data['error'] = true;
                $data['mensaje'] = $ex->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function rechazarTrabajoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
           
                $id = (int)$this->_getParam('trabajo_id');
                
                $data['id'] = $id;
                $data['horas_realizacion'] = NULL;
                $data['fecha'] = NULL;
                $data['fecha_realizacion'] = NULL;
                $data['fecha_informe'] = date("Y-m-d");
                $data['comentarios'] = NULL;
                $data['rechazo_comentarios'] = $this->_getParam('comentarios');
                $data['postergacion_comentarios'] = NULL;
                $data['postergacion_motivo'] = NULL;
                
                $trabajo->setId($id);
                $rowTrabajo = $trabajo->getRow()->toArray();
                $data['estado'] = $trabajo->rechazar($data);
                $data['numero'] = false;
                $data['sumario'] = array(
                    'trabajos'      => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id']),
                    'programados'   => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1),
                    'realizados'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "TERMINADO"),
                    'pendientes'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "PENDIENTE"),
                    'no_realizados' => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "NO REALIZADO"),
                    'postergados'   => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "POSTERGADO"),
                    'rechazados'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "RECHAZADO")
                );
                $data['error'] = false;
                echo Zend_Json::encode($data);
                
            } catch (Exception $ex) {
                $data['error'] = true;
                $data['mensaje'] = $ex->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function postergarTrabajoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
           
                $id = (int)$this->_getParam('trabajo_id');
                $data['id'] = $id;
                $data['horas_realizacion'] = NULL;
                $data['fecha'] = NULL;
                $data['fecha_realizacion'] = NULL;
                $data['fecha_informe'] = date("Y-m-d");
                $data['comentarios'] = NULL;
                $data['rechazo_comentarios'] = NULL;
                $data['postergacion_comentarios'] = $this->_getParam('comentarios');
                $data['postergacion_motivo'] = (int)$this->_getParam('motivo');
                
                $trabajo->setId($id);
                $rowTrabajo = $trabajo->getRow()->toArray();
                $data['estado'] = $trabajo->postergar($data);
                $data['numero'] = false;
                $data['sumario'] = array(
                    'trabajos'      => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id']),
                    'programados'   => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1),
                    'realizados'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "TERMINADO"),
                    'pendientes'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "PENDIENTE"),
                    'no_realizados' => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "NO REALIZADO"),
                    'postergados'   => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "POSTERGADO"),
                    'rechazados'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "RECHAZADO")
                );
                $data['error'] = false;
                echo Zend_Json::encode($data);
                
            } catch (Exception $ex) {
                $data['error'] = true;
                $data['mensaje'] = $ex->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
}