<?php
class NaveArchivoController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 1;
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    public function subirAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
            
        if($this->getRequest()->isXmlHttpRequest()){
            
            $path = 'tmp/';
            $uploader = new Shipcode_Upload_QqFileUploader(
                Zend_Registry::get('ACCEPTED_FILE_FORMAT'),
                Zend_Registry::get('MAX_SIZE_FILE_UPLOAD')
            );
            $result = $uploader->handleUpload($path, TRUE);
            if($result == TRUE){
                $name = $uploader->getName();
                $newName = Shipcode_Archivo::renombrar($name);
                if($newName !== FALSE){
                    echo Zend_Json_Encoder::encode(array('success' => true, 'name' => $newName));
                } else {
                    echo Zend_Json_Encoder::encode(array('success' => false, 'name' => $name));
                }
                    
            } 
        }      
    }
    
    public function adjuntarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_NaveArchivo();
        $nave = new Shipcode_Model_Nave();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $nave->adjuntarArchivo($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('El archivo fue subido de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/nave/ver/' . $form->getValue('nave_id') . '#archivos');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar subir un archivo adjunto.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/nave/ver/' . $form->getValue('nave_id') . '#archivos');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $nave->setId($id);
        $form->nave_id->setValue($id);
        $form->setAction('/nave-archivo/adjuntar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/nave/ver/$id#archivos');");
        $this->view->form = $form;
        $this->view->empresa = $nave->getEmpresa();
        $this->view->title = "Adjuntar archivo";
        $this->view->nave = $nave->getRow();
        $this->view->pageTitle = $this->view->empresa->nombre . " > Subir archivo";
        $this->renderScript('nave-archivo/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_NaveArchivoEdit();
        $id = (int)$this->getParam('id');
        $nave_id = (int)$this->getParam('from_id');
        
        $archivo = new Shipcode_Model_NaveArchivo();
        $archivo->setId($id);
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $archivo->editar($form->getValues(), $this->usuario->id, (int)$this->_getParam('id'));
                    $mSession->mensajes = array('El archivo fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/nave/ver/' . $nave_id . '#archivos');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el archivo';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/nave/ver/' . $nave_id . '#archivos');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $nave = new Shipcode_Model_Nave();
        $nave->setId($nave_id);
        
        $form->populate($archivo->getRow()->toArray());
        $form->setAction("/nave-archivo/editar/" . $id . "/" . $nave_id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/nave/ver/$nave_id#archivos');");
        $this->view->nave = $nave->getRowFull();
        $this->view->form = $form;
        $this->view->title = "Editar información del archivo";
        $this->view->pageTitle = $this->view->nave->nombre . " > Editar archivo";
        $this->renderScript('nave-archivo/form-editar.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        $archivo = new Shipcode_Model_NaveArchivo();
        $archivo->setId($id);
        
        try {

            $archivo->eliminar();
            $mSession->mensajes[] = 'El archivo adjunto fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect($_SERVER['HTTP_REFERER']);

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el archivo adjunto.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect($_SERVER['HTTP_REFERER']);
        }
    }
    
    public function descargarAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        $id = (int)$this->_getParam('id');
        
        $archivo = new Shipcode_Model_NaveArchivo();
        $archivo->setId($id);
        $nombre = $archivo->getRow()->archivo;
        
        
        $fileFullPath = Zend_Registry::get('PATH_SERVER') . 'files/naves/' . $nombre;
        $nave_id = (int)$this->_getParam('from_id');
        
        if(file_exists($fileFullPath)){
            
            $download_path = Zend_Registry::get('PATH_SERVER') . "files/naves/";
            $args = array(
		'download_path'		=>	$download_path,
		'file'                  =>	$nombre,		
		'extension_check'	=>	TRUE,
		'referrer_check'	=>	FALSE,
		'referrer'		=>	NULL,
		);
            $download = new App_Download($args);
            $download_hook = $download->get_download_hook();

            if( $download_hook['download'] == TRUE ) {
        	$download->get_download();
            }
            
        } else {
            $mSession = new Zend_Session_Namespace('shipcode');
            $mSession->mensajes[] = "El archivo solicitado no existe.";
            $mSession->claseMensaje = "error";
            $this->_redirect($_SERVER['HTTP_REFERER']);
        }
    }
    /**************************************************************************/
}
     