<?php
class NaveCarenaArchivoController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 1;
        $this->_helper->layout->disablelayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function subirAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $path = 'tmp/';
            $uploader = new Shipcode_Upload_QqFileUploader(
                Zend_Registry::get('ACCEPTED_FILE_FORMAT'),
                Zend_Registry::get('MAX_SIZE_FILE_UPLOAD')
            );
            $result = $uploader->handleUpload($path, TRUE);
            if($result == TRUE){
                $name = $uploader->getName();
                $newName = Shipcode_Archivo::renombrar($name);
                if($newName !== FALSE){
                    echo Zend_Json_Encoder::encode(array('success' => true, 'name' => $newName));
                } else {
                    echo Zend_Json_Encoder::encode(array('success' => false, 'name' => $name));
                }
            } 
        }    
    }
    
    public function guardarAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $carena = new Shipcode_Model_NaveCarena();
            try {
                $data = array();
                $data['carena_id'] = (int)$this->_getParam('carena_id'); 
                $data['archivo'] = $this->_getParam('archivo'); 
                $data['nombre'] = $this->_getParam('nombre'); 
                $id = $carena->guardarArchivo($data, $this->usuario->id);
                echo Zend_Json::encode(array(
                    'error'     => false, 
                    'mensaje'   => 'El archivo fue guardado de forma satisfactoria.',
                    'id'        => $id,
                    'num'       => (int)Shipcode_Model_NaveCarena::getNumArchivos($data['carena_id']),
                    'cid'       => $data['carena_id'],
                    'clases'    => 'alert alert-success',
                    'nombre'    => $data['nombre']
                ));
            } catch(Exception $e){
                echo Zend_Json::encode(array(
                    'error'     => true, 
                    'mensaje'   => 'Ocurrió un error al intentar guardar el archivo. Error: ' . $e->getMessage(),
                    'clases'    => 'alert alert-error'
                ));
            }
        }
    }
    
    public function descargarAction()
    {
        $id = (int)$this->_getParam('id');
        $archivo = new Shipcode_Model_NaveCarenaArchivo();
        $archivo->setId($id);
        $row = $archivo->getRow();
        $fileFullPath = Zend_Registry::get('PATH_SERVER') . 'files/carenas/' . $row->archivo;
        if(file_exists($fileFullPath)){
            
            $download_path = Zend_Registry::get('PATH_SERVER') . "files/carenas/";
            $args = array(
		'download_path'		=>	$download_path,
		'file'                  =>	$row->archivo,		
		'extension_check'	=>	TRUE,
		'referrer_check'	=>	FALSE,
		'referrer'		=>	NULL,
		);
            $download = new App_Download($args);
            $download_hook = $download->get_download_hook();

            if( $download_hook['download'] == TRUE ) {
        	$download->get_download();
            }
            
        } else {
            $mSession = new Zend_Session_Namespace('shipcode');
            $mSession->mensajes[] = "El archivo solicitado no existe.";
            $mSession->claseMensaje = "error";
            $this->_redirect($_SERVER['HTTP_REFERER']);
        }
    }
    
    public function eliminarAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            try {
                $id = (int)$this->_getParam('id');
                $archivo = new Shipcode_Model_NaveCarenaArchivo();
                $archivo->setId($id);
                $carena_id = $archivo->eliminar();
                $numArchivos = Shipcode_Model_NaveCarena::getNumArchivos($carena_id);
                if(FALSE != $id){
                    
                    echo Zend_Json::encode(array(
                        'error'     => false, 
                        'id'        => $id,
                        'cid'       => $carena_id,
                        'num'       => (int)$numArchivos,
                        'clases'    => 'alert alert-success',
                        'mensaje'   => 'El archivo fue eliminado de forma exitosa'
                    ));
                    
                } else {
                    
                    echo Zend_Json::encode(array(
                        'error'     => true, 
                        'clases'    => 'alert alert-error',
                        'mensaje'   => 'Ocurrió un error al intenar eliminar el archivo'
                    ));
                    
                }
            } catch (Exception $e){
                echo Zend_Json::encode(array(
                    'error'     => true, 
                    'clases'    => 'alert alert-error',
                    'mensaje'   => $e->getMessage()
                ));
            }
        }
    }
}
     