<?php

class NaveCarenaController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->pagina = 1;
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    /************************* OPERACIONES CARENAS ****************************/
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $id = (int)$this->getParam('id');
        try {
            $modelNave = new Shipcode_Model_Nave();
            $modelNave->setId($id);
            $carena_id = $modelNave->crearCarena($this->usuario->id);
            $this->_redirect('/nave-carena/editar/' . $carena_id);
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar crear la carena";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/nave/ver/' . $id . '/carenas');
        }
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $id = (int)$this->getParam('id');
        $form = new Shipcode_Form_Carena($id);
        $modelCarena = new Shipcode_Model_NaveCarena();
        $modelCarena->setId($id);
        $nave = $modelCarena->getNave();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $modelCarena = new Shipcode_Model_NaveCarena();
                    $modelCarena->guardar($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('La carena fue guardada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/nave/ver/' . $nave->id .'#carenas');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar registrar la carena.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/nave/ver/' . $nave->id .'#carenas');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $form->populate($modelCarena->getRow()->toArray());
        $form->setAction('/nave-carena/editar/' . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/nave/ver/$nave->id#carenas');");
        $this->view->nave = $nave;
        $this->view->form = $form;
        $this->view->title = "Ingresar carena";
        $this->view->pageTitle = $nave->nombre . " > Ingresar carena";
        $this->renderScript('nave-carena/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        $carena = new Shipcode_Model_NaveCarena();
        $carena->setId($id);
        $nave_id = $carena->getNaveId();
        
        try {

            $carena->eliminar();
            $mSession->mensajes[] = 'El registro de carena fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/nave/ver/' . $nave_id .'/carenas');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el registro de la carena.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/nave/ver/' .  $nave_id .'/carenas');
        }
    }

    public function configurarProximaAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $nave = new Shipcode_Model_Nave();
        
        $this->_helper->layout->disablelayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if ($this->getRequest()->isPost()) {
            
            $actual = date("Y");
            $years = array($actual, $actual + 1, $actual + 2, $actual + 3, $actual + 4);
            $meses = array('1','2','3','4','5','6','7','8','9','10','11','12');
            
            if (in_array($this->_getParam('sig_carena_year'), $years) && 
                in_array($this->_getParam('sig_carena_mes'), $meses)){
                
                try {

                    $nave->setId($this->_getParam('nave_id'));
                    $nave->actualizarProximaCarena(array(
                        'sig_carena_mes' => (int)$this->_getParam('sig_carena_mes'),
                        'sig_carena_year' => (int)$this->_getParam('sig_carena_year')
                    ), $this->usuario->id);
                    
                    $mSession->mensajes = array('La programación de la próxima carena fue editada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/nave/ver/' . $this->_getParam('nave_id'));

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar la programación de la próxima carena.', $e->getMessage());
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/nave/ver/' . $this->_getParam('nave_id'));
                }
            } else {
                $mSession->mensajes = array($this->_getParam('sig_carena_mes'));
                $mSession->claseMensaje = 'error';
                $this->_redirect('/nave/ver/' . $this->_getParam('nave_id'));
            }
        } 
    }
    
    public function archivosAction()
    {
        $this->_helper->layout->disablelayout();
        $id = (int)$this->_getParam('id');
        $carena = new Shipcode_Model_NaveCarena();
        $carena->setId($id);
        $this->view->archivos = $carena->getArchivos();
        $this->view->id= $id;
    }

    public function subirArchivoAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
            
        if($this->getRequest()->isXmlHttpRequest()){
            
            $path = 'tmp/';
            $uploader = new Shipcode_Upload_QqFileUploader(
                Zend_Registry::get('ACCEPTED_FILE_FORMAT'),
                Zend_Registry::get('MAX_SIZE_FILE_UPLOAD')
            );
            $result = $uploader->handleUpload($path, TRUE);
            if($result == TRUE){
                $name = $uploader->getName();
                $newName = Shipcode_Archivo::renombrar($name);
                if($newName !== FALSE){
                    echo Zend_Json_Encoder::encode(array('success' => true, 'name' => $newName));
                } else {
                    echo Zend_Json_Encoder::encode(array('success' => false, 'name' => $name));
                }
            } 
        }    
    }
    
    public function guardarArchivoAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
            
        if($this->getRequest()->isXmlHttpRequest()){
            
            $carena = new Shipcode_Model_NaveCarena();
            
            try {
                
                $data = array();
                $data['carena_id'] = (int)$this->_getParam('carena_id'); 
                $data['archivo'] = $this->_getParam('archivo'); 
                $data['nombre'] = $this->_getParam('nombre'); 
                $id = $carena->guardarArchivo($data, $this->usuario->id);
                echo Zend_Json::encode(array(
                    'error'     => false, 
                    'mensaje'   => 'El archivo fue guardado de forma satisfactoria.',
                    'id'        => $id,
                    'num'       => Shipcode_Model_NaveCarena::getNumArchivos($data['carena_id']),
                    'cid'       => $data['carena_id'],
                    'clases'    => 'alert alert-success',
                    'nombre'    => $data['nombre']
                ));
                
            } catch(Exception $e){
                echo Zend_Json::encode(array(
                    'error'     => true, 
                    'mensaje'   => 'Ocurrió un error al intentar guardar el archivo. Error: ' . $e->getMessage(),
                    'clases'    => 'alert alert-error'
                ));
            }
        }
    }
    
    public function descargarArchivoAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        $id = (int)$this->_getParam('id');
        
        $archivo = new Shipcode_Model_NaveCarenaArchivo();
        $archivo->setId($id);
        $row = $archivo->getRow();
        $fileFullPath = Zend_Registry::get('PATH_SERVER') . 'files/carenas/' . $row->archivo;
        
        if(file_exists($fileFullPath)){
            
            $download_path = Zend_Registry::get('PATH_SERVER') . "files/carenas/";
            $args = array(
		'download_path'		=>	$download_path,
		'file'                  =>	$row->archivo,		
		'extension_check'	=>	TRUE,
		'referrer_check'	=>	FALSE,
		'referrer'		=>	NULL,
		);
            $download = new App_Download($args);
            $download_hook = $download->get_download_hook();

            if( $download_hook['download'] == TRUE ) {
        	$download->get_download();
            }
            
        } else {
            $mSession = new Zend_Session_Namespace('shipcode');
            $mSession->mensajes[] = "El archivo solicitado no existe.";
            $mSession->claseMensaje = "error";
            $this->_redirect($_SERVER['HTTP_REFERER']);
        }
    }
    
    public function eliminarArchivoAction()
    {
        
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if($this->getRequest()->isXmlHttpRequest()){
            try {
                
                $id = (int)$this->_getParam('id');
                $archivo = new Shipcode_Model_NaveCarenaArchivo();
                $archivo->setId($id);
                $carena_id = $archivo->eliminar();
                $numArchivos = Shipcode_Model_NaveCarena::getNumArchivos($carena_id);
                
                if(FALSE != $id){
                    
                    echo Zend_Json::encode(array(
                        'error'     => false, 
                        'id'        => $id,
                        'cid'       => $carena_id,
                        'num'       => $numArchivos,
                        'clases'    => 'alert alert-success',
                        'mensaje'   => 'El archivo fue eliminado de forma exitosa'
                    ));
                    
                } else {
                    
                    echo Zend_Json::encode(array(
                        'error'     => true, 
                        'clases'    => 'alert alert-error',
                        'mensaje'   => 'Ocurrió un error al intenar eliminar el archivo'
                    ));
                    
                }
                    
            } catch (Exception $e){
                echo Zend_Json::encode(array(
                    'error'     => true, 
                    'clases'    => 'alert alert-error',
                    'mensaje'   => $e->getMessage()
                ));
            }
        }
    }
    /**************************************************************************/
}
     