<?php

class NaveSistemaController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 1;
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    /************************* OPERACIONES SISTEMAS ***************************/
    public function configurarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        try {
            $nave = new Shipcode_Model_Nave();
            $nave->setId($id);
            $this->view->nave = $nave->getRowFull();
            $this->view->sistemas = $nave->getSistemas();
            $this->view->title = "Configuración de Sistemas";
            $this->view->pageTitle = $this->view->nave->nombre . " > Configuración de sistemas";
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar ingresar a la configuración de sistemas de la nave.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect("/nave/ver/" . $id . "/equipos");
        }
    }
    
    public function agregarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_Sistema();
        $id = (int)$this->getParam('id');
        $nave = new Shipcode_Model_Nave();
        $nave->setId($id);
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $nave->agregarSistema($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('El sistema fue agregado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/nave-sistema/configurar/' . $id);

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar agregar el sistema a la nave.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/nave-sistema/configurar/' . $id);
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $form->nave_id->setValue($id);
        $form->setAction("/nave-sistema/agregar/" . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/nave-sistema/configurar/$id');");
        $this->view->nave = $nave->getRowFull();
        $this->view->form = $form;
        $this->view->title = "Agregar sistema principal";
        $this->view->pageTitle = $this->view->nave->nombre . " > Agregar sistema principal";
        $this->renderScript('nave-sistema/form.phtml');
    }
    
     public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaEdit();
        $id = (int)$this->getParam('id');
        $sistema = new Shipcode_Model_NaveSistema();
        $sistema->setId($id);
        $nave_id = $sistema->getNaveId();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $sistema->editar($form->getValues(), $this->usuario->id, (int)$this->_getParam('id'));
                    $mSession->mensajes = array('El sistema fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/nave-sistema/configurar/' . $nave_id);

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el sistema';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/nave-sistema/configurar/' . $nave_id);
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $form->populate($sistema->getRow()->toArray());
        $form->setAction("/nave-sistema/editar/" . $id);
        $form->submit->setLabel('Guardar');
        $form->cancel->setAttrib('onclick', "javascript:goTo('/nave-sistema/configurar/$nave_id');");
        $this->view->nave = $sistema->getNave();
        $this->view->form = $form;
        $this->view->title = "Editar nombre del sistema";
        $this->view->pageTitle = $this->view->nave->nombre . " > Editar nombre del sistema";
        $this->renderScript('nave-sistema/form.phtml');
    }
     
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            
            $sistema = new Shipcode_Model_NaveSistema();
            $sistema->setId($id);
            $nave_id = $sistema->getNaveId();
            $sistema->eliminar();
            $mSession->mensajes[] = 'El sistema fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/nave-sistema/configurar/' . $nave_id );

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el sistema.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/nave-sistema/configurar/' .  $nave_id );
        }
    }
    
    public function configurarEquiposAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        try {
            $nave = new Shipcode_Model_Nave();
            $nave->setId($id);
            $this->view->nave = $nave->getRowFull();
            $this->view->sistemas = $nave->getSistemas();
            $this->view->title = "Configuración de Equipos";
            $this->view->pageTitle = $this->view->nave->nombre . " > Configuración de equipos";
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar ingresar a la configuración de equipos de la nave.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect("/nave/ver/" . $id . "/equipos");
        }
    }
    
    public function agregarSubsistemaAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_Subsistema();
        $id = (int)$this->_getParam('id');
        $nave = new Shipcode_Model_Nave();
        $nave->setId($id);
        $form->padre_id->addMultiOptions(Shipcode_Model_Nave::getSistemasPrincipalesToSelect($id));
        $form->nave_id->setValue($id);
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $nave->agregarSubsistema($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('El subsistema fue agregado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/nave-sistema/configurar/' . $id);

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar agregar el sistema a la nave.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/nave-sistema/configurar/' . $id);
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        
        $form->setAction("/nave-sistema/agregar-subsistema/" . $id);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/nave-sistema/configurar/$id');");
        $this->view->nave = $nave->getRowFull();
        $this->view->form = $form;
        $this->view->title = "Agregar subsistema";
        $this->view->pageTitle = $this->view->nave->nombre . " > Agregar subsistema";
        $this->renderScript('nave-sistema/form.phtml');
    }
    
   
    /**************************************************************************/
}
     