<?php
class ProgramacionMensualController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pagina = 3;
        $this->view->controller = $this->getRequest()->getControllerName();
        $this->view->action = $this->getRequest()->getActionName();
        
        switch ($this->usuario->tipo) {
            case 0:
            case 1:  
                $this->empresa_id = NULL;
                $this->data['perfil'] = "ADMIN";
                $this->data['asignado_a'] = NULL;
                break;
            case 2:
                $this->empresa_id = $this->view->empresa_id = Shipcode_Model_SistemaUsuario::getEmpresaAsignada($this->view->privilegios['autorizaciones']['empresas']);
                $this->data['perfil'] = "SUPERVISOR";
                $this->data['asignado_a'] = "EXTERNO";
                break;
            case 5:
                $this->empresa_id = NULL;
                $this->data['perfil'] = "NAVE";
                $this->data['asignado_a'] = "NAVE";
                break;
        }
        
        if(!$this->getRequest()->isXmlHttpRequest() && $this->view->action != 'exportar'){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render(Shipcode_Model_SistemaUsuario::getHeaderByTipoUsuarioId($this->usuario->tipo)));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $this->view->pageTitle = "Programación mensual de mantenimiento";
        try {
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $this->view->empresas = Shipcode_Model_Empresa::getPairsToSelect();
            $this->view->naves = Shipcode_Model_Nave::getPairsToSelect();
            if($this->getRequest()->isPost()) {
                $this->view->title = "Resultados búsqueda";
                $parametros = array(
                    'estado' => $this->_getParam('estado'),
                    'desde' => $this->_getParam('desde'),
                    'hasta' => $this->_getParam('hasta'),
                    'enviado_por' => $this->_getParam('enviado_por'),
                    'empresa' => $this->_getParam('empresa'),
                    'nave' => $this->_getParam('nave')
                );
                $this->view->parametros = $parametros;
                if($this->data['perfil'] == "SUPERVISOR"){
                    $this->view->programaciones = $programacion->buscar($parametros, $this->empresa_id, $this->view->privilegios['autorizaciones']['naves']);
                    $this->view->naves = Shipcode_Model_Nave::getPairsToSelect($this->empresa_id);
                } else {
                    $this->view->programaciones = $programacion->buscar($parametros, $this->empresa_id, $this->view->privilegios['autorizaciones']['naves']);
                }
                    
            } else {
                $this->view->title = "En proceso";
                $this->view->programaciones = $programacion->getAll(1, $this->empresa_id, $this->view->privilegios['autorizaciones']['naves']);
            }
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_ProgramacionMensual();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $programacion = new Shipcode_Model_ProgramacionMensual();
                    $id = $programacion->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('La programación fue creada de forma exitosa. Ahora puede seleccionar los trabajos a asignar.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/programacion-mensual/configuracion/' . $id);

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la programación mensual.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/programacion-mensual');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->cancel->setAttrib('onclick', "javascript:goTo('/programacion-mensual');");
        $this->view->form = $form;
        $this->view->title = "Crear programación mensual";
        $this->view->pageTitle = "Programación Mensual de Mantenimiento";
        $this->renderScript('programacion-mensual/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            $programacion->eliminar();
            
            $mSession->mensajes[] = 'La programación mensual fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/programacion-mensual');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar programación mensual.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/programacion-mensual');
        }
    }
    
    public function configuracionAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $this->view->pageTitle = "Programación mensual de mantenimiento";
        try {
            $id = (int)$this->_getParam('id');
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            $this->view->title = "Programación Mensual - Nave " . $this->view->programacion['nave'];
            $this->view->programacion = $programacion->getRowFull();
            $this->view->equiposTrabajos = $programacion->getTrabajosSeleccionados();
            
            $infoMes = $this->view->programacion['year'] . "-" . $this->view->programacion['mes'];
            $mes = new Shipcode_Model_AuxMes();
            $mes->setMes($infoMes . "-01");
            $this->view->diasMes = $mes->getDiasMes();
            $this->view->mes = $infoMes;
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar la programación mensual";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/programacion-mensual');
        }
    }
    
    public function enviarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $id = (int)$this->_getParam('id');
        
        try {
            
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            $programacion->enviar();
            
            $dataProgramacion = $programacion->getRowFull();
            $nave = new Shipcode_Model_Nave();
            $nave->setId($dataProgramacion['nave_id']);
            $dataNave = $nave->getRowFull();
            
            $usuario = new Shipcode_Model_SistemaUsuario();
            
            $supervisores = $usuario->getSupervisoresByEmpresaId($dataProgramacion['empresa_id']);
            $motoristas = $usuario->getMotoristasByNaveId($dataProgramacion['nave_id']);
            
            $mailSupervisores = new App_HtmlMailerDocument('UTF-8');
            $mailSupervisores->setFrom(Zend_Registry::get('MAIL_FROM'), Zend_Registry::get('FIRMA_EMPRESA'));
            $mailSupervisores->setSubject('Mantenimiento programado -  ' . $dataProgramacion['mes'] . "/" . $dataProgramacion['year'])
                             ->setViewParam('programacion', $dataProgramacion)
                             ->setViewParam('perfil', 'SUPERVISOR')
                             ->setViewParam('nave', $dataNave);
            
            //$mailSupervisores->addTo('avelasquez@cpt.cl', 'Aquiles Velasquez');
            if(count($supervisores) > 0 ) {
                foreach($supervisores as $supervisor){
                    $mailSupervisores->addTo($supervisor['mail'], $supervisor['nombre']);
                }
                $mailSupervisores->sendHtmlTemplate('notificacion-mantenimiento-programado.phtml');
            }
           
            $mailMotoristas = new App_HtmlMailerDocument('UTF-8');
            $mailMotoristas->setFrom(Zend_Registry::get('MAIL_FROM'), Zend_Registry::get('FIRMA_EMPRESA'));
            $mailMotoristas->setSubject('Mantenimiento programado -  ' . $dataProgramacion['mes'] . "/" . $dataProgramacion['year'])
                           ->setViewParam('programacion', $dataProgramacion)
                           ->setViewParam('perfil', 'MOTORISTA')
                           ->setViewParam('nave', $dataNave);
            //$mailMotoristas->addTo('avelasquez@cpt.cl', 'Aquiles Velasquez');
            if(count($motoristas) > 0 ) {
                foreach($motoristas as $motorista){
                    $mailMotoristas->addTo($motorista['mail'], $motorista['nombre']);
                }
                $mailMotoristas->sendHtmlTemplate('notificacion-mantenimiento-programado.phtml');
            }
            
            $mSession->mensajes[] = "La programación fue enviada de forma satisfactoria.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/programacion-mensual/proceso/' . $id);
            
        } catch (Exception $e) {
            $mSession->mensajes[] = "Ocurrió un problema al intentar enviar la programación mensual";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/programacion-mensual/configuracion/' . $id);
        }
    }
    
    public function procesoAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $this->view->pageTitle = "Programación mensual de mantenimiento";
        try {
            $id = (int)$this->_getParam('id');
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            
            
            
            $this->view->title = "Programación Mensual - Nave " . $this->view->programacion['nave'];
            $this->view->programacion = $programacion->getRowFull();
            $this->view->equiposTrabajos = $programacion->getTrabajosSeleccionados(1, $this->data['asignado_a']);
            $this->view->perfil = $this->data['perfil'];
            $infoMes = $this->view->programacion['year'] . "-" . $this->view->programacion['mes'];
            $mes = new Shipcode_Model_AuxMes();
            $mes->setMes($infoMes . "-01");
            $this->view->diasMes = $mes->getDiasMes();
            $this->view->mes = $infoMes;
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar la programación mensual";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/programacion-mensual');
        }
    }
    
    public function exportarAction()
    {
        $this->_helper->viewRenderer->setNoRender();
        try {
            $id = (int)$this->_getParam('id');
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            $dataProgramacion = $programacion->getRowFull();
            $dataEquiposTrabajos = $programacion->getTrabajosSeleccionados(1, $this->data['asignado_a']);
            $title = "Programación Mensual - Nave " . $dataProgramacion['nave'];
            $this->_helper->layout->disableLayout();
            define('EOL',(PHP_SAPI == 'cli') ? PHP_EOL : '<br />');
            require_once Zend_Registry::get('OTHERS_PHP_CLASSES') . '/phpexcel/PHPExcel.php';
            PHPExcel_Settings::setLocale('es');
            
            
            $objPHPExcel = new PHPExcel();
            $objPHPExcel->getActiveSheet()->getColumnDimension('A')->setAutoSize(true);
            $objPHPExcel->getActiveSheet()->getColumnDimension('B')->setWidth(40);
            $objPHPExcel->getActiveSheet()->getColumnDimension('C')->setAutoSize(true);
            $objPHPExcel->getActiveSheet()->getColumnDimension('D')->setAutoSize(true);
            $objPHPExcel->getActiveSheet()->getColumnDimension('E')->setAutoSize(true);
            $objPHPExcel->setActiveSheetIndex(0)->setCellValue('A1', $title);
            $objPHPExcel->setActiveSheetIndex(0)->setCellValue('E1', $this->view->formatMes($dataProgramacion['mes']) . " " . $dataProgramacion['year']);
            $objPHPExcel->setActiveSheetIndex(0)->setCellValue('A2', "Prog. ID");
            $objPHPExcel->setActiveSheetIndex(0)->setCellValue('B2', $id);
            $objPHPExcel->setActiveSheetIndex(0)->setCellValue('C2', "Exportada el " .  Shipcode_Model_Fecha::formatShort(date("Y-m-d")));
            $objPHPExcel->getActiveSheet()->mergeCells('A1:D1');
            $objPHPExcel->getActiveSheet()->mergeCells('C2:E2');
            $objPHPExcel->setActiveSheetIndex(0)->setCellValue('A3', "ID Trabajo");
            $objPHPExcel->setActiveSheetIndex(0)->setCellValue('B3', "Descripción trabajo");
            $objPHPExcel->setActiveSheetIndex(0)->setCellValue('C3', "Realizado el (dd/mm/yy)");
            $objPHPExcel->setActiveSheetIndex(0)->setCellValue('D3', "Horas");
            $objPHPExcel->setActiveSheetIndex(0)->setCellValue('E3', "Comentarios");
            
            $styleArrayTitulo = array(
                'font' => array('bold' => true, 'size' => 18, 'color' => array('argb' => '00000000'),),
                'alignment' => array('horizontal' => PHPExcel_Style_Alignment::HORIZONTAL_LEFT,),
            );
            $styleArrayCabeceras = array(
                'font' => array('bold' => true, 'size' => 12, 'color' => array('argb' => 'ffffffff'),),
                'alignment' => array('horizontal' => PHPExcel_Style_Alignment::HORIZONTAL_LEFT,),
                'borders' => array('top' => array('style' => PHPExcel_Style_Border::BORDER_THIN,), ),
                'fill' => array('type' => PHPExcel_Style_Fill::FILL_SOLID, 'color' => array('argb' => '33333300',),),
            );
            
            $objPHPExcel->getActiveSheet()
                        ->getStyle('A1')
                        ->applyFromArray($styleArrayTitulo);
            $objPHPExcel->getActiveSheet()
                        ->getStyle('E1')
                        ->applyFromArray($styleArrayTitulo);
            
            if(count($dataEquiposTrabajos) > 0) {
                $fila = 4;
                foreach($dataEquiposTrabajos as $equipoTrabajo) {
                    $objPHPExcel->getActiveSheet()
                                ->setCellValueByColumnAndRow(0, $fila, $equipoTrabajo['equipo']);
                    $objPHPExcel->getActiveSheet()
                                ->mergeCellsByColumnAndRow(0, $fila, 4, $fila);
                    $objPHPExcel->getActiveSheet()
                                ->getStyle('A'.$fila)
                                ->applyFromArray($styleArrayCabeceras);
                    $fila++;
                    if(count($equipoTrabajo['trabajos']) > 0) {
                        foreach($equipoTrabajo['trabajos'] as $trabajo) {
                            $objPHPExcel->getActiveSheet()
                                        ->setCellValueByColumnAndRow(0, $fila, $trabajo['trabajo_id']);
                            $objPHPExcel->getActiveSheet()
                                        ->setCellValueByColumnAndRow(1, $fila, $trabajo['servicio']);
                            $objPHPExcel->getActiveSheet()
                                        ->getStyleByColumnAndRow(2, $fila)
                                        ->getNumberFormat()
                                        ->setFormatCode(PHPExcel_Style_NumberFormat::FORMAT_DATE_DDMMYYYY);
                            $fila++;
                        }
                    }
                }
            }
            // redirect output to client browser
            header('Content-Type: application/vnd.ms-excel');
            header('Content-Disposition: attachment;filename="Programacion_Mensual_' . $id . '.xls"');
            header('Cache-Control: max-age=0');
            $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel5');
            $objWriter->save('php://output');
            $objPHPExcel->disconnectWorksheets();
            unset($objPHPExcel);
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function cerrarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $id = (int)$this->_getParam('id');
        
        try {
            
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            $programacion->cerrar($this->usuario->id);
            
            $mSession->mensajes[] = "La programación fue cerrada de forma satisfactoria.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/programacion-mensual/informe/' . $id);
            
        } catch (Exception $e) {
            $mSession->mensajes[] = "Ocurrió un problema al intentar cerrar la programación mensual";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/programacion-mensual/proceso/' . $id);
        }
    }
    
    public function informeAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $this->view->pageTitle = "Programación mensual de mantenimiento";
        try {
            $id = (int)$this->_getParam('id');
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $programacion->setId($id);
            $this->view->title = "Programación Mensual - Nave " . $this->view->programacion['nave'];
            $this->view->programacion = $programacion->getRowFull();
            $this->view->equiposTrabajos = $programacion->getTrabajosSeleccionados();
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar el informe de la programación mensual";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/programacion-mensual');
        }
    }
    /************************** FUNCIONES TRABAJOS ****************************/
    public function asignarAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                $id = (int)$this->_getParam('id');
                $responsable = $this->_getParam('responsable');
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
                $trabajo->setId($id);
                $trabajo->asignar($responsable);
                $data['error'] = false;
                $data['id'] = $id;
                echo Zend_Json::encode($data);
                
            } catch (Exception $ex) {
                $data['error'] = true;
                $data['mensaje'] = $ex->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function editarFechaTrabajoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
                $id = (int)$this->_getParam('id');
                $fecha = $this->_getParam('fecha');
                $n = $this->_getParam('numero');
                $trabajo->setId($id);
                $trabajo->editarFecha($fecha);
                $data['error'] = false;
                $data['id'] = $id;
                $data['fecha'] = $fecha;
                $data['numero'] = $n;
                $data['estado'] = 'TERMINADO';
                echo Zend_Json::encode($data);
                
            } catch (Exception $ex) {
                $data['error'] = true;
                $data['mensaje'] = $ex->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function setTrabajoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $id = (int)$this->_getParam('trabajo_id');
            
            try {
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
                $trabajo->setId($id);
                $trabajo->cambiarEstadoSeleccion();
                $data['error'] = false;
                echo Zend_Json::encode($data);

            } catch(Exception $e){
                $data['error'] = true;
                $data['mensaje'] = $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function terminarTrabajoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
           
                $id = (int)$this->_getParam('trabajo_id');
                $data['trabajo_id'] = $id;
                $data['horas_realizacion'] = $this->_getParam('horas');
                $data['fecha'] = $this->_getParam('fecha');
                $data['fecha_realizacion'] = $this->_getParam('fecha');
                $data['fecha_informe'] = date("Y-m-d");
                $data['numero'] = $this->_getParam('numero');
                $data['comentarios'] = $this->_getParam('comentarios');
                $data['rechazo_comentarios'] = NULL;
                $data['postergacion_comentarios'] = NULL;
                $data['postergacion_motivo'] = NULL;
                
                $trabajo->setId($id);
                $rowTrabajo = $trabajo->getRow()->toArray();
                $data['estado'] = $trabajo->terminar($data);
                $data['sumario'] = array(
                    'trabajos'      => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id']),
                    'programados'   => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1),
                    'realizados'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "TERMINADO"),
                    'pendientes'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "PENDIENTE"),
                    'no_realizados' => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "NO REALIZADO"),
                    'postergados'   => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "POSTERGADO"),
                    'rechazados'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "RECHAZADO")
                );
                $data['error'] = false;
                echo Zend_Json::encode($data);
                
            } catch (Exception $ex) {
                $data['error'] = true;
                $data['mensaje'] = $ex->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function rechazarTrabajoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
           
                $id = (int)$this->_getParam('trabajo_id');
                
                $data['id'] = $id;
                $data['horas_realizacion'] = NULL;
                $data['fecha'] = NULL;
                $data['fecha_realizacion'] = NULL;
                $data['fecha_informe'] = date("Y-m-d");
                $data['comentarios'] = NULL;
                $data['rechazo_comentarios'] = $this->_getParam('comentarios');
                $data['postergacion_comentarios'] = NULL;
                $data['postergacion_motivo'] = NULL;
                
                $trabajo->setId($id);
                $rowTrabajo = $trabajo->getRow()->toArray();
                $data['estado'] = $trabajo->rechazar($data);
                $data['numero'] = false;
                $data['sumario'] = array(
                    'trabajos'      => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id']),
                    'programados'   => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1),
                    'realizados'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "TERMINADO"),
                    'pendientes'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "PENDIENTE"),
                    'no_realizados' => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "NO REALIZADO"),
                    'postergados'   => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "POSTERGADO"),
                    'rechazados'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "RECHAZADO")
                );
                $data['error'] = false;
                echo Zend_Json::encode($data);
                
            } catch (Exception $ex) {
                $data['error'] = true;
                $data['mensaje'] = $ex->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function postergarTrabajoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
           
                $id = (int)$this->_getParam('trabajo_id');
                $data['id'] = $id;
                $data['horas_realizacion'] = NULL;
                $data['fecha'] = NULL;
                $data['fecha_realizacion'] = NULL;
                $data['fecha_informe'] = date("Y-m-d");
                $data['comentarios'] = NULL;
                $data['rechazo_comentarios'] = NULL;
                $data['postergacion_comentarios'] = $this->_getParam('comentarios');
                $data['postergacion_motivo'] = (int)$this->_getParam('motivo');
                
                $trabajo->setId($id);
                $rowTrabajo = $trabajo->getRow()->toArray();
                $data['estado'] = $trabajo->postergar($data);
                $data['numero'] = false;
                $data['sumario'] = array(
                    'trabajos'      => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id']),
                    'programados'   => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1),
                    'realizados'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "TERMINADO"),
                    'pendientes'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "PENDIENTE"),
                    'no_realizados' => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "NO REALIZADO"),
                    'postergados'   => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "POSTERGADO"),
                    'rechazados'    => $trabajo->getNumTrabajosByProgramacionId($rowTrabajo['programacion_id'], 1, "RECHAZADO")
                );
                $data['error'] = false;
                echo Zend_Json::encode($data);
                
            } catch (Exception $ex) {
                $data['error'] = true;
                $data['mensaje'] = $ex->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
}