<?php
class SistemaEnvioMensajeController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pageTitle = 'Envío de Mensajes';
        $this->view->pagina = 5;

        $action = $this->getRequest()->getActionName();
        if(!$this->getRequest()->isXmlHttpRequest() && $action != 'enviar'){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    public function informeAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $form = new Shipcode_Form_SistemaMensaje();
        $form->copia->setLabel('Enviarme una copia');
        $this->view->title = "Enviar Informe por Email";
        $this->view->form = $form;
    }
    
    public function enviarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaMensaje();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $informe = new Shipcode_Model_SistemaInformePreconfigurado();
                    $informe->setId($form->getValue('informe'));
                    $dataInforme = $informe->getRow()->toArray();
                    
                    $mail = new App_HtmlMailerDocument('UTF-8');
                    $mail->setFrom($this->usuario->mail, $this->usuario->nombre);
                    $mail->setType(Zend_Mime::MULTIPART_RELATED);
                    $mail->setSubject('Informe SGM')
                         ->setViewParam('nombre', $form->getValue('nombre'))
                         ->setViewParam('usuario', $this->usuario->nombre)
                         ->setViewParam('mensaje', $form->getValue('mensaje'));
                    $mail->addTo($form->getValue('mail'), $form->getValue('nombre'));

                    if($form->copia->getValue()==1){
                        $mail->addBcc($this->usuario->mail);
                    }
                    // Adjuntar el PDF del Informe
                    require_once(Zend_Registry::get('LIBRARY') . 'Shipcode/Pdf.php');
                    $pdf = new Shipcode_Pdf($this->_getContents($dataInforme));
                    $attach = $mail->createAttachment($pdf->getContent());
                    $attach->filename = $dataInforme['nombre'] . '.pdf';
                    
                    $mail->sendHtmlTemplate('envio-informe.phtml');
                    $envio = new Shipcode_Model_SistemaMensaje();
                    $envio->log(
                        array(
                            'creador' => $this->usuario->id,
                            'informe_base' => $dataInforme['base'],
                            'informe_parametros' => $dataInforme['parametros'],
                            'nombre' => $form->getValue('nombre'),
                            'mail' => $form->getValue('mail')
                        )
                    );
                    
                    $mSession->mensajes[] = 'El informe fue enviado y su envío registrado de forma satisfactoria.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-envio-mensaje');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar enviar el mensaje, por favor inténtelo más tarde.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-envio-mensaje');
                }
            }
        }    
        $this->_redirect('/sistema-envio-mensaje');
    }
    
    private function _getContents($dataInforme)
    {
        $url = Zend_Registry::get('URL_SERVER') . 'informes/enviar-informe-' . $dataInforme['base'];
        $parametros = Zend_Json::decode($dataInforme['parametros']);
        $i = 0;
        $url .= '?';
        foreach($parametros as $nombre => $valor){
            if($i!=0) {  
                $url .= '&'; 
            }
            $url .= $nombre . '=' . $valor;
            $i++;
        }
        return file_get_contents($url);
    }
}
     