<?php
class SistemaInformeAutomaticoController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pageTitle = 'Envío Automático de Informes';
        $this->view->pagina = 5;
        
        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig' , $this->view->render('menu-config.phtml'));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $informeAuto = new Shipcode_Model_SistemaInformeAutomatico();
        $this->view->enviosAutomaticos = $informeAuto->getAll();
        $this->view->pageTitle = 'Configuración de envío automático de informes';
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaInformeAutomatico();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-informe-automatico');");
        $informeAuto = new Shipcode_Model_SistemaInformeAutomatico();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $informeAuto->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes[] = 'El informe preconfigurado fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-informe-automatico');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar guardar el informe preconfigurado.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-informe-automatico');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $this->view->form = $form;
        $this->view->title = "Configurar envío automático de informe";
        $this->renderScript('sistema-informe-automatico/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $informeAuto = new Shipcode_Model_SistemaInformeAutomatico();
        $id = (int)$this->_getParam('id');
        $informeAuto->setId($id);
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaInformeAutomatico();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-informe-automatico');");
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $informeAuto->editar($form->getValues(), $this->usuario->id, $id);
                    $mSession->mensajes[] = 'El envío automático fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-informe-automatico');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el envío automático.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-informe-automatico');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        
        $form->populate($informeAuto->getRow()->toArray());
        $form->setAction('/sistema-informe-automatico/editar/' . $id);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar envío automático";
        $this->renderScript('sistema-informe-automatico/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        
        try {
            
            $id = (int)$this->_getParam('id');
            $informeAuto = new Shipcode_Model_SistemaInformeAutomatico();
            $informeAuto->setId($id);
            $informeAuto->eliminar();
            $mSession->mensajes[]   = 'El envío automático fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/sistema-informe-automatico');

        } catch (Exception $e) {
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el envío automático.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/sistema-informe-automatico');
        }
    }
}
     