<?php

class SistemaPerfilUsuarioController extends Zend_Controller_Action {

    public function init() 
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        
        $this->view->pageTitle = 'Perfiles Usuarios';
        $this->view->pagina = 5;

        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();

        if (!$this->getRequest()->isXmlHttpRequest()) {
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig', $this->view->render('menu-config.phtml'));
        }
    }

    public function indexAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $perfil = new Shipcode_Model_SistemaPerfilUsuario();
        $this->view->perfiles = $perfil->getAll();
        $this->view->pageTitle = 'Perfiles de usuarios del sistema';
    }
    
    public function crearAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaPerfilUsuario();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $perfil = new Shipcode_Model_SistemaPerfilUsuario();
                    $perfil->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('El perfil de usuario fue creado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-perfil-usuario');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el perfil de usuario.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-perfil-usuario');
                }
            } else {
                $form->populate($request->getPost());
            }
        }

        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-perfil-usuario');");
        $this->view->form = $form;
        $this->view->title = "Crear perfil de usuario";
        $this->view->pageTitle = "Perfil de usuario";
        $this->renderScript('sistema-perfil-usuario/form.phtml');
    }
    
    public function editarAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $perfil = new Shipcode_Model_SistemaPerfilUsuario();
        $id = (int) $this->_getParam('id');
        $perfil->setId($id);
        $row = $perfil->getRow()->toArray();
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaPerfilUsuario();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-perfil-usuario');");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $perfil->editar($form->getValues(), $this->usuario->id, $id);
                    $mSession->mensajes[] = 'El perfil de usuario fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-perfil-usuario');
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el perfil de usuario.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-perfil-usuario');
                }
            } else {
                $form->populate($request->getPost());
            }
        }

        $form->populate($row);
        $form->setAction('/sistema-perfil-usuario/editar/' . $id);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar perfil de usuario";
        $this->renderScript('sistema-perfil-usuario/form.phtml');
    }

    public function eliminarAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        try {
            $perfil = new Shipcode_Model_SistemaPerfilUsuario();
            $id = (int) $this->_getParam('id');
            $perfil->setId($id);
            $perfil->eliminar();
            $mSession->mensajes[] = 'El perfil de usuario fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/sistema-perfil-usuario');
            
        } catch (Exception $e) {
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el perfil de usuario. Posiblemente tiene usuariuos asociados.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/sistema-perfil-usuario');
        }
    }
    
    public function configPrivilegiosAction() {
        try {
            $id = (int) $this->_getParam('id');
            $perfil = new Shipcode_Model_SistemaPerfilUsuario();
            $perfil->setId($id);
            $this->view->perfil = $perfil->getRow();
            $this->view->title = "Configuración de privilegios para el perfil: " . $this->view->perfil->nombre;
            $this->view->privilegios = Zend_Json::decode($this->view->perfil->privilegios);
            
        } catch (Exception $ex) {
            echo $ex->getMessage();
        }
    }
    public function setPrivilegioAction() {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();

        if ($this->getRequest()->isXmlHttpRequest()) {

            $perfil_id = (int) $this->_getParam('perfil_id');
            $ruta = $this->_getParam('ruta');
            $valor = $this->getParam('valor');

            $perfil = new Shipcode_Model_SistemaPerfilUsuario();
            $perfil->setId($perfil_id);
            $data['debug'] = $perfil->setPrivilegio($ruta, $valor);
            $data['error'] = false;
            echo Zend_Json::encode($data);
        }
    }
}
