<?php

class SistemaUsuarioController extends Zend_Controller_Action {

    public function init() 
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        $this->view->pageTitle = 'Usuarios';
        $this->view->pagina = 5;

        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();

        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        if (!$this->getRequest()->isXmlHttpRequest()) {
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig', $this->view->render('menu-config.phtml'));
        }
    }

    public function indexAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $usuario = new Shipcode_Model_SistemaUsuario();
        $this->view->usuarios = $usuario->getAll();
        $this->view->pageTitle = 'Usuarios del sistema';
    }

    public function ultimosAccesosAction() {
        if ($this->getRequest()->isXmlHttpRequest()) {
            $this->_helper->layout->disableLayout();

            $usuario_id = (int) $this->_getParam('id');
            $logIngreso = new Shipcode_Model_SistemaLogIngreso();
            $this->view->accesos = $logIngreso->getRowsByUsuarioId($usuario_id);
        }
    }

    public function resetearClaveAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        $id = (int) $this->_getParam('id');
        $usuario = new Shipcode_Model_SistemaUsuario();
        $usuario->setId($id);
        $nuevaClave = $usuario->resetearClave();

        try {

            $row = $usuario->getRow();

            $mail = new App_HtmlMailerDocument('UTF-8');
            $mail->setFrom(Zend_Registry::get('MAIL_FROM'), Zend_Registry::get('FIRMA_EMPRESA'));
            $mail->setSubject('Acceso a sistema')
                    ->setViewParam('nombre', $row->nombre)
                    ->setViewParam('usuario', $row->mail)
                    ->setViewParam('clave', $nuevaClave);

            $mail->addTo($row->mail, $row->nombre);
            $mail->sendHtmlTemplate('nueva-clave.phtml');

            $mSession->mensajes[] = 'La clave fue reseteada y enviada de forma satisfactoria.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect($_SERVER['HTTP_REFERER']);
        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar resetear la clave.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect($_SERVER['HTTP_REFERER']);
        }
    }

    public function activarAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        try {
            $usuario = new Shipcode_Model_SistemaUsuario();
            $id = (int) $this->_getParam('id');
            $usuario->setId($id);
            $usuario->activar();
            $mSession->mensajes[] = 'El usuario fue activado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/sistema-usuario');
        } catch (Exception $e) {
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar al usuario.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/sistema-usuario');
        }
    }

    public function eliminarAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        try {
            $usuario = new Shipcode_Model_SistemaUsuario();
            $id = (int) $this->_getParam('id');
            $usuario->setId($id);
            try {
                $usuario->eliminar();
                $mSession->mensajes[] = 'El usuario fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
            } catch (Exception $e) {

                $usuario->bloquear();
                $mSession->mensajes[] = 'El usuario fue bloqueado de forma exitosa. '
                        . 'Tiene información relacionada que no se puede eliminar';
                //$mSession->mensajes[]   = $e->getMessage();
                $mSession->claseMensaje = 'advertencia';
            }

            $this->_redirect($_SERVER['HTTP_REFERER']);
        } catch (Exception $e) {
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar al usuario.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect($_SERVER['HTTP_REFERER']);
        }
    }

    public function cambiarClaveAccesoAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_CambiarClaveAcceso();
        $form->cancel->setAttrib('onclick', "javascript:goTo('" . $_SERVER['HTTP_REFERER'] . "');");
        $usuario = new Shipcode_Model_SistemaUsuario();
        $id = $this->usuario->id;

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $usuario->cambiarClave($form->getValues(), $this->usuario->id);
                    $mSession->mensajes[] = 'La clave fue cambiada de forma exitosa. Comenzará a '
                            . 'utilizarla desde próxima la vez que ingrese al sistema';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-usuario/cambiar-clave-acceso');
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar cambiar la clave.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-usuario/cambiar-clave-acceso');
                }
            }
        }
        $usuario->setId($id);
        $this->view->user = $usuario->getRow();
        $this->view->title = 'Usuario';
        $this->view->form = $form;
        $this->renderScript('sistema-usuario/form-cambio-clave-acceso.phtml');
    }

    public function crearAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaUsuario();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-usuario');");
        $usuario = new Shipcode_Model_SistemaUsuario();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $data = $usuario->crear($form->getValues(), $this->usuario->id);
                    
                    if($data['mail'] !== NULL && $data['notificaciones'] == 1){
                        $mail = new App_HtmlMailerDocument('UTF-8');
                        $mail->setFrom(Zend_Registry::get('MAIL_FROM'), Zend_Registry::get('FIRMA_EMPRESA'));
                        $mail->setSubject('Acceso a sistema')
                                ->setViewParam('nombre', $form->getValue('nombre'))
                                ->setViewParam('usuario', $form->getValue('usuario'))
                                ->setViewParam('clave', $data['clave']);

                        $mail->addTo($form->getValue('mail'), $form->getValue('nombre'));
                        $mail->sendHtmlTemplate('enable-user-sistema.phtml');
                    }
                    
                    $mSession->mensajes[] = 'El usuario fue creado y su clave fue enviada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-usuario');
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el usuario.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-usuario');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->view->title = "Crear usuario";
        $this->renderScript('sistema-usuario/form.phtml');
    }

    public function editarAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $usuario = new Shipcode_Model_SistemaUsuario();
        $id = (int) $this->_getParam('id');
        $usuario->setId($id);
        $row = $usuario->getRow()->toArray();
        $request = $this->getRequest();

        if ($row['perfil_id'] == 0) {
            $form = new Shipcode_Form_SistemaUsuarioSuperAdmin();
        } else {
            $form = new Shipcode_Form_SistemaUsuario();
        }

        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-usuario');");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $usuario->editar($form->getValues(), $this->usuario->id, $id);
                    $mSession->mensajes[] = 'El usuario fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-usuario');
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el usuario.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-usuario');
                }
            } else {
                $form->populate($request->getPost());
            }
        }

        $form->populate($row);
        $form->setAction('/sistema-usuario/editar/' . $id);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar usuario";
        $this->renderScript('sistema-usuario/form.phtml');
    }

    public function configAccesoRecursosAction() {
        try {
            $id = (int) $this->_getParam('id');
            $usuario = new Shipcode_Model_SistemaUsuario();
            $usuario->setId($id);
            $this->view->usuarioSistema = $usuario->getRow();
            $this->view->title = "Configuración de accesos para " . $this->view->usuarioSistema->nombre;
            $this->view->empresas = Shipcode_Model_Nave::getAgrupadasPorEmpresa();
            $this->view->autorizaciones = Zend_Json::decode($this->view->usuarioSistema->autorizaciones);
            
        } catch (Exception $ex) {
            echo $ex->getMessage();
        }
    }
    
    public function setAccesoRecursoAction() {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();

        if ($this->getRequest()->isXmlHttpRequest()) {

            $usuario_id = (int) $this->_getParam('usuario_id');
            $recurso_id = $this->_getParam('recurso_id');
            $recurso_tipo = $this->_getParam('recurso_tipo');
            $valor = $this->getParam('valor');

            $usuario = new Shipcode_Model_SistemaUsuario();
            $usuario->setId($usuario_id);
            $data['debug'] = $usuario->setAccesoRecurso($recurso_tipo, $recurso_id, $valor);
            $data['error'] = false;
            echo Zend_Json::encode($data);
        }
    }
    public function setPrivilegioAction() {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();

        if ($this->getRequest()->isXmlHttpRequest()) {

            $usuario_id = (int) $this->_getParam('usuario_id');
            $privilegio_id = $this->_getParam('privilegio_id');
            $grupo = $this->_getParam('grupo');
            $valor = $this->getParam('valor');

            $usuario = new Shipcode_Model_SistemaUsuario();
            $usuario->setId($usuario_id);
            $data['debug'] = $usuario->setAutorizacion($grupo, $privilegio_id, $valor);
            $data['error'] = false;
            echo Zend_Json::encode($data);
        }
    }
    /*
     * Funciones de configuración antiguas
     *
     * 
    public function supervisoresAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $usuario = new Shipcode_Model_SistemaUsuario();
        $this->view->supervisores = $usuario->getSupervisoresFull();
        $this->view->pageTitle = 'Supervisores';
    }
    public function crearSupervisorAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaUsuarioSupervisor();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-usuario/supervisores');");
        $usuario = new Shipcode_Model_SistemaUsuario();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $usuario->crearSupervisor($form->getValues(), $this->usuario->id);
                    $mSession->mensajes[] = 'El usuario fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-usuario/supervisores');
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el usuario supervisor.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-usuario/supervisores');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->view->title = "Crear usuario supervisor";
        $this->renderScript('sistema-usuario/form-supervisor.phtml');
    }
    public function editarSupervisorAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int) $this->_getParam('id');

        $usuario = new Shipcode_Model_SistemaUsuario();
        $usuario->setId($id);

        $row = $usuario->getRowSupervisor();

        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaUsuarioSupervisor();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-usuario/supervisores');");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $usuario->editarSupervisor($form->getValues(), $this->usuario->id, $id);
                    $mSession->mensajes[] = 'El usuario supervisor fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-usuario/supervisores');
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el usuario supervisor.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-usuario/supervisores');
                }
            } else {
                $form->populate($request->getPost());
            }
        }

        $form->populate($row);
        $form->setAction('/sistema-usuario/editar-supervisor/' . $id);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar usuario supervisor";
        $this->view->instrucciones = "Si no desea cambiar la clave, deje esos campos en blanco."
                . "Para cambiarla debe completar los dos campos siguiendo las instrucciones.";
        $this->renderScript('sistema-usuario/form-supervisor.phtml');
    }
    public function motoristasAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $usuario = new Shipcode_Model_SistemaUsuario();
        $this->view->motoristas = $usuario->getMotoristasFull();
        $this->view->pageTitle = 'Motoristas';
    }
    public function crearMotoristaAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaUsuarioMotorista();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-usuario/motoristas');");
        $usuario = new Shipcode_Model_SistemaUsuario();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $usuario->crearMotorista($form->getValues(), $this->usuario->id);
                    $mSession->mensajes[] = 'El usuario fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-usuario/motoristas');
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el usuario motorista.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-usuario/motoristas');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->clave1->setvalue('');
        $this->view->form = $form;
        $this->view->title = "Crear usuario motorista";
        $this->renderScript('sistema-usuario/form-motorista.phtml');
    }
    public function editarMotoristaAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int) $this->_getParam('id');

        $usuario = new Shipcode_Model_SistemaUsuario();
        $usuario->setId($id);

        $row = $usuario->getRowMotorista();

        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaUsuarioMotorista();
        $form->clave1->setRequired(false);
        $form->clave2->setRequired(false);
        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-usuario/motoristas');");

        if ($this->getRequest()->isPost()) {

            if ($form->getValue('clave1') != '' || $form->getValue('clave2') != '') {
                $form->clave1->setRequired(true);
                $form->clave2->setRequired(true);
            }

            if ($form->isValid($request->getPost())) {
                try {

                    $usuario->editarMotorista($form->getValues(), $this->usuario->id, $id);
                    $mSession->mensajes[] = 'El usuario motorista fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-usuario/motoristas');
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el usuario motorista.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-usuario/motoristas');
                }
            } else {
                $form->populate($request->getPost());
            }
        }

        $form->populate($row);
        $form->setAction('/sistema-usuario/editar-motorista/' . $id);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar usuario motorista";
        $this->view->instrucciones = "Si no desea cambiar la clave, deje esos campos en blanco."
                . "Para cambiarla debe completar los dos campos siguiendo las instrucciones.";
        $this->renderScript('sistema-usuario/form-motorista.phtml');
    }
    public function crearPersonalizadoLecturaAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaUsuarioPersonalizadoLectura();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-usuario/personalizados-lectura');");
        $usuario = new Shipcode_Model_SistemaUsuario();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $data = $usuario->crearPersonalizadoLectura($form->getValues(), $this->usuario->id);

                    $mail = new App_HtmlMailerDocument('UTF-8');
                    $mail->setFrom(Zend_Registry::get('MAIL_FROM'), Zend_Registry::get('FIRMA_EMPRESA'));
                    $mail->setSubject('Acceso a sistema')
                            ->setViewParam('nombre', $form->getValue('nombre'))
                            ->setViewParam('usuario', $form->getValue('mail'))
                            ->setViewParam('clave', $data['clave']);

                    $mail->addTo($form->getValue('mail'), $form->getValue('nombre'));
                    $mail->sendHtmlTemplate('enable-user-sistema.phtml');

                    $mSession->mensajes[] = 'El usuario fue creado y su clave fue enviada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-usuario/personalizados-lectura');
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el usuario personalizado de sólo lectura.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-usuario/personalizados-lectura');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->view->title = "Crear usuario personalizado lectura";
        $this->renderScript('sistema-usuario/form-personalizado-lectura.phtml');
    }
    public function editarPersonalizadoLecturaAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        if ($mSession->mensajes != '') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int) $this->_getParam('id');

        $usuario = new Shipcode_Model_SistemaUsuario();
        $usuario->setId($id);

        $row = $usuario->getRow()->toArray();

        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaUsuarioPersonalizadoLectura();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/sistema-usuario/personalizados-lectura');");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $usuario->editarPersonalizadoLectura($form->getValues(), $this->usuario->id, $id);
                    $mSession->mensajes[] = 'El usuario externo fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-usuario/personalizados-lectura');
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el usuario externo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-usuario/personalizados-lectura');
                }
            } else {
                $form->populate($request->getPost());
            }
        }

        $form->populate($row);
        $form->setAction('/sistema-usuario/editar-personalizado-lectura/' . $id);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar usuario personalizado lectura";
        $this->renderScript('sistema-usuario/form-personalizado-lectura.phtml');
    }
    public function eliminarPersonalizadoLecturaAction() {
        $mSession = new Zend_Session_Namespace('shipcode');
        try {
            $usuario = new Shipcode_Model_SistemaUsuario();
            $id = (int) $this->_getParam('id');
            $usuario->setId($id);
            $usuario->eliminarPersonalizadoLectura();
            $mSession->mensajes[] = 'El usuario personalizado de sólo lectura fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/sistema-usuario/personalizados-lectura');
        } catch (Exception $e) {
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar al usuario personalizado lectura.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/sistema-usuario/personalizados-lectura');
        }
    }
    */
}
