<?php
class TipoEquipoController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        $this->view->pagina = 5;
        
        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();
        
        if(!$this->getRequest()->isXmlHttpRequest() && $this->usuario){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig' , $this->view->render('menu-base.phtml'));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Tipos de Equipos";
        
        try {
            $tipo = new Shipcode_Model_TipoEquipo();
            $this->view->tipos = $tipo->getAll();
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_TipoEquipo();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/tipo-equipo');");
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $tipo = new Shipcode_Model_TipoEquipo();
                    $tipo->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('El tipo de equipo fue creado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/tipo-equipo');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el tipo de equipo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/tipo-equipo');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $this->view->form = $form;
        $this->view->title = "Crear tipo de equipo";
        $this->view->pageTitle = "Tipo de equipo";
        $this->renderScript('tipo-equipo/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_TipoEquipo();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/tipo-equipo');");
        $tipo = new Shipcode_Model_TipoEquipo();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $tipo->editar($form->getValues(), $this->usuario->id, (int)$this->_getParam('id'));
                    
                    $mSession->mensajes = array('El tipo de equipo fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/tipo-equipo');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar el tipo de equipo.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/tipo-equipo');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $tipo->setId($id);
        $form->populate($tipo->getRow()->toArray());
        $form->setAction('/tipo-equipo/editar/' . $id);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->title = "Editar tipo de equipo";
        $this->renderScript('tipo-equipo/form.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $tipo = new Shipcode_Model_TipoEquipo();
            $tipo->setId($id);
            $tipo->eliminar();
            
            $mSession->mensajes[] = 'El tipo de equipo fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/tipo-equipo');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el tipo de equipo.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/tipo-equipo');
        }
    }
    
    /*
    public function codificarDatosAction()
    {
        $this->_helper->viewRenderer->setNoRender();
        $tipo = new Shipcode_Model_TipoEquipo();
        $result = $tipo->codificarDatos();        
        echo $result;
    }
    */
}