<?php
class TipoProyectoController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        $this->view->pagina = 5;
        
        $this->_helper->layout->setLayout('config');
        $this->view->action = $this->getRequest()->getActionName();
        $this->view->controller = $this->getRequest()->getControllerName();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
            $response->insert('menuConfig' , $this->view->render('menu-base.phtml'));
        }
    }
    
    /**************************************************************************/
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $this->view->pageTitle = "Tipos de Proyectos";
        
        try {
            $tipo = new Shipcode_Model_TipoProyecto();
            $this->view->tipos = $tipo->getAll();
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function crearAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_TipoProyecto();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/tipo-proyecto');");
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $tipo = new Shipcode_Model_TipoProyecto();
                    $tipo->crear($form->getValues());
                    $mSession->mensajes = array('El tipo de proyecto fue creado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/tipo-proyecto');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el tipo de proyecto.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/tipo-proyecto');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $this->view->form = $form;
        $this->view->title = "Crear tipo de proyecto";
        $this->view->pageTitle = "Tipo de proyecto";
        $this->renderScript('tipo-proyecto/form.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Shipcode_Form_TipoProyecto();
        $form->cancel->setAttrib('onclick', "javascript:goTo('/tipo-proyecto');");
        $tipo = new Shipcode_Model_TipoProyecto();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $tipo->editar($form->getValues());
                    
                    $mSession->mensajes = array('El tipo de proyecto fue editado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/tipo-proyecto');

                } catch (Exception $e) {

                    $mSession->mensajes = array('Ocurrió un error al intentar editar el tipo de proyecto.');
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/tipo-proyecto');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $tipo->setId($id);
        $form->id->setValue($id);
        $form->populate($tipo->getRow()->toArray());
        $form->setAction('/tipo-proyecto/editar/' . $id);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->view->pageTitle = "Editar tipo de proyecto";
        $this->view->title = "Editar tipo de proyecto";
        $this->renderScript('tipo-proyecto/form.phtml');
    }
    
    public function configurarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');

        try {
            
            $tipo = new Shipcode_Model_TipoProyecto();
            $tipo->setId($id);
            $this->view->tipo = $tipo->getRow();
            $cuenta = new Shipcode_Model_CuentaGasto();
            $this->view->cuentas = $cuenta->getAll();
            $this->view->pageTitle = "Configuración de tipo de proyecto";

        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar la configuración del tipo de proyecto.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect($_SERVER['HTTP_REFERER']);
        }
    }
    
    public function setCuentaAction()
    {   
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        if($this->getRequest()->isXmlHttpRequest()){
            try {
                $tipo_id = (int)$this->_getParam('tipo_id');
                $cuenta_id = (int)$this->_getParam('cuenta_id');
                
                $tipo = new Shipcode_Model_TipoProyecto();
                $tipo->setId($tipo_id);
                $tipo->setCuenta($cuenta_id);
                
                $data['error'] = false;
                echo Zend_Json::encode($data);
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $id = (int)$this->_getParam('id');
        
        try {

            $tipo = new Shipcode_Model_TipoProyecto();
            $tipo->setId($id);
            $tipo->eliminar();
            
            $mSession->mensajes[] = 'El tipo de proyecto fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/tipo-proyecto');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el tipo de proyecto.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/tipo-proyecto');
        }
    }
}