<?php
class UNaveController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        $this->view->controller = $this->getRequest()->getControllerName();
        $this->view->action = $this->getRequest()->getActionName();
        $this->nave_id = $this->view->nave_id = Shipcode_Model_SistemaUsuario::getNaveAsignada($this->view->autorizaciones['naves']);
        
        $nave = new Shipcode_Model_Nave();
        $nave->setId($this->nave_id);
        $this->view->naveToMenu = $nave->getRow()->nombre;
        $this->ultimaVisita = Shipcode_Model_SistemaLogIngreso::getVisitaAnteriorByUsuarioId($this->usuario->id);
        
        $mSession = new Zend_Session_Namespace('shipcode');
        if(isset($mSession->identidadUsuario)){
            $this->view->identidadUsuario = $this->identidadUsuario = $mSession->identidadUsuario;
        }
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    /****************************** IDENTIFICACIÓN ****************************/
    public function identificacionAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_Identificacion();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $usuario = new Shipcode_Model_SistemaUsuario();
                    $dataUsuario = $usuario->getIdentificacion($form->getValues());
                    if ($dataUsuario !== FALSE && $dataUsuario !== NULL) {
                        $mSession->identidadUsuario = $dataUsuario;
                        $this->_redirect($this->usuario->path);
                    } else {
                        $mSession->mensajes[] = 'Los datos de acceso proporcionados no son válidos. Por favor verifique su usuario y contraseña..';
                        $mSession->claseMensaje = 'error';
                        $this->_redirect('/u-nave/identificacion');
                    }
                    
                } catch (Exception $ex) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar autenticar la identidad dle usuario.';
                    $mSession->mensajes[] = $ex->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/u-nave/identificacion');
                }
            }
        }
        
        $this->view->pageTitle = "Identificación de Usuario Nave";
        $this->view->form = $form;
    }
    
    /************************** FUNCIONES MANTENIMIENTO ***********************/
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $this->view->pageTitle = "Programación mensual de mantenimiento";
        
        if(!$mSession->identidadUsuario){
            $this->_redirect('/u-nave/identificacion');
        }
        
        try {
            
            $programacion = new Shipcode_Model_ProgramacionMensual();
            $this->view->title = "Programación Mensual";
            $this->view->perfil = 'NAVE';
            $id = $programacion->getIdProgramacionAbiertaByNaveId($this->nave_id);
            if($id){
                $programacion->setId($id);
                $this->view->programacion = $programacion->getRowFull();
                $this->view->equiposTrabajos = $programacion->getTrabajosSeleccionados(1, 'NAVE');
                $infoMes = $this->view->programacion['year'] . "-" . $this->view->programacion['mes'];
                $mes = new Shipcode_Model_AuxMes();
                $mes->setMes($infoMes . "-01");
                $this->view->diasMes = $mes->getDiasMes();
                $this->view->mes = $infoMes;
            }
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar la programación mensual";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/u-nave');
        }
    }
    
    public function mantenimientosNoProgramadosAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        if(!$mSession->identidadUsuario){
            $this->_redirect('/u-nave/identificacion');
        }
        
        $this->view->pageTitle = "Mantenimientos no programados";
        
        try {
            
            $request = $this->getRequest();
            $form = new Shipcode_Form_MantenimientoInformado($this->nave_id);
            $mantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
            
            if ($this->getRequest()->isPost()) {
                if ($form->isValid($request->getPost())) {
                    try {

                        $mantenimiento->guardar($form->getValues(), $this->identidadUsuario['id']);
                        $mSession->mensajes = array('El mantenimiento fue registrado de forma exitosa.');
                        $mSession->claseMensaje = 'confirmacion';
                        $this->_redirect('/u-nave/mantenimientos-no-programados');
                        
                    } catch (Exception $e) {

                        $mSession->mensajes[] = 'Ocurrió un error al intentar registrar el mantenimiento no programado.';
                        $mSession->mensajes[] = $e->getMessage();
                        $mSession->claseMensaje = 'error';
                        $this->_redirect('/u-nave/mantenimientos-no-programados');
                    }
                } else {
                    $form->populate($request->getPost());
                }
            }
            //$form->equipo_id->setMultiOptions(array('' => '-- Equipo --'));
            $this->view->mantenimientos = $mantenimiento->getNoAsignadosByMes(array('mes' => date("m"), 'year' => date("Y")), $this->nave_id);
            $this->view->form = $form;
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar los mantenimientos no programados";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/u-nave');
        }
    }
    
    public function eliminarMantenimientoAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        if(!$mSession->identidadUsuario){
            $this->_redirect('/u-nave/identificacion');
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $mantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
            $mantenimiento->setId($id);
            $mantenimiento->eliminarBorrador();
            
            $mSession->mensajes[] = 'El mantenimiento fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/u-nave/mantenimientos-no-programados');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el registro de mantenimiento.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/u-nave/mantenimientos-no-programados');
        }
    }
    /**************************************************************************/
    
    /*************************** FUNCIONES LECTURAS ***************************/
    public function lecturasAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        if(!$mSession->identidadUsuario){
            $this->_redirect('/u-nave/identificacion');
        }
        
        $nave = new Shipcode_Model_Nave();
        $parametro = new Shipcode_Model_EquipoParametro();
        $parametroNave = new Shipcode_Model_NaveParametroLectura();
        
        $nave->setId($this->nave_id);
        $this->view->pageTitle = "Horómetros y Parámetros";
        $this->view->nave = $nave->getRowFull();
        $this->view->equipos = $nave->getEquiposInforme();
        $this->view->parametros = $parametro->getAll();
        $this->view->parametrosRequeridos = $parametroNave->getRequeridosByNaveId($this->nave_id);
    }
    
    public function horasOperacionAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            try {
                
                if($mSession->identidadUsuario){
                    $id = (int)$this->_getParam('id');
                    $equipo = new Shipcode_Model_NaveEquipo();
                    $equipo->setId($id);
                    $this->view->horasOperacion = $equipo->getHorasOperacionMensuales();
                    $this->view->equipo = $equipo->getRowFull();
                }
                
            } catch (Exception $ex) {
                echo $ex->getMessage();
            }
        }
    }
    
    public function ingresarHorometroAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                if($mSession->identidadUsuario){
                    $lecturaHorometro = new Shipcode_Model_NaveHorometroLectura();
                    $horometro = array(
                        'equipo_id' => (int)$this->_getParam('equipo_id'),
                        'fecha'     => $this->_getParam('fecha'),
                        'lectura'   => (int)$this->_getParam('lectura'),
                        'creador'   => $this->identidadUsuario['id'],
                        'estado'    => 1
                    );
                    $result =  $lecturaHorometro->validarUltimaLectura($horometro['lectura'], $horometro['equipo_id'], $horometro['fecha']);
                    if($result !==  TRUE){
                        $data['error']      = true;
                        $data['mensaje']    = $result; 
                        echo Zend_Json::encode($data);
                    } else {
                        $equipo = new Shipcode_Model_NaveEquipo();
                        $equipo->setId($horometro['equipo_id']);
                        $id = $equipo->registrarLecturaHorometro($horometro['lectura'], $horometro['fecha'], $this->idnetidadUsuario['id']);

                        if($id !== FALSE || $id !== NULL) {
                            $puntosAnclaje = $equipo->getPuntosAnclaje(); 
                            if(count($puntosAnclaje) > 0) {
                                $lecturaAnterior = $equipo->getLecturaAnterior($id);
                                foreach($puntosAnclaje as $puntoAnclaje){
                                    $fechaAnclaje = new Zend_Date($puntoAnclaje['fecha']);
                                    $fechaLectura = new Zend_Date($horometro['fecha']);
                                    if($fechaLectura->isLater($fechaAnclaje)){
                                        $diferenciaHoras = $horometro['lectura'] - $lecturaAnterior['lectura'];
                                        $equipoAnclado = new Shipcode_Model_NaveEquipo();
                                        $equipoAnclado->setId($puntoAnclaje['equipo_id']);
                                        $lecturaDependiente = $equipoAnclado->getLecturaHorometroDependiente($lecturaAnterior['id']);
                                        if($lecturaDependiente) {
                                            $lecturaAnclado = $lecturaDependiente->lectura + $diferenciaHoras;
                                            $equipoAnclado->registrarLecturaHorometro($lecturaAnclado, $horometro['fecha'], $this->usuario->id, $id);
                                        }
                                    }
                                }
                            }

                            $dataEquipo = $equipo->getRow()->toArray();
                            $lectura = $lecturaHorometro->getUltimaLectura($horometro['equipo_id']);
                            $lectura['fecha_formateada'] = $this->view->formatFechaCorta($lectura['fecha']);
                            $lectura['lectura_formateada'] = $this->view->formatDecimal($lectura['lectura']);
                            $lectura['equipo'] = $dataEquipo['nombre'];
                            $data['lectura'] = $lectura;
                            $data['anclados'] = $lecturaHorometro->getLecturasDependientes($lectura['id'], $dataEquipo['nombre']);
                            $data['error']      = false;
                            echo Zend_Json::encode($data);

                        } elseif($id == 0) {
                            $data['error'] = true;
                            $data['mensaje'] = "Ya existe otro registro con los valores ingresados";
                            echo Zend_Json::encode($data);

                        } else {    
                            $data['error'] = true;
                            $data['mensaje'] = "Ocurrió un error al intentar guardar el registro de horómetro";
                            echo Zend_Json::encode($data);
                        }
                    } 
                }
            } catch(Exception $e){
                $data['error'] = true;
                $data['mensaje'] = $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    
    public function ingresarParametroAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                if($mSession->identidadUsuario){
                    $lecturaParametro = new Shipcode_Model_NaveParametroLectura();
                    $parametro = array(
                        'parametro_id'  => (int)$this->_getParam('parametro_id'),
                        'equipo_id'     => (int)$this->_getParam('equipo_id'),
                        'fecha'         => $this->_getParam('fecha'),
                        'lectura'       => (int)$this->_getParam('lectura'),
                        'creador'       => $this->identidadUsuario['id']
                    );

                    $lecturaParametro->guardar($parametro);
                    $equipo = new Shipcode_Model_NaveEquipo();
                    $equipo->setId($parametro['equipo_id']);
                    $dataEquipo = $equipo->getRow()->toArray();
                    $lectura = $lecturaParametro->getUltimaLecturaByEquipoIdAndParametroId($parametro['equipo_id'], $parametro['parametro_id']);
                    $lectura['fecha_formateada'] = $this->view->formatFechaCorta($lectura['fecha']);
                    $lectura['lectura_formateada'] = $this->view->formatDecimal($lectura['lectura']);
                    $lectura['equipo'] = $dataEquipo['nombre'];
                    $data['lectura'] = $lectura;
                    $data['error']      = false;
                    echo Zend_Json::encode($data);
                }
            } catch(Exception $e){
                $data['error'] = true;
                $data['mensaje'] = $e->getMessage();
                echo Zend_Json::encode($data);
            }
        }
    }
    /**************************************************************************/
    
    /************************** FUNCIONES SOLICITUDES **************************/
    public function solicitudesAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        if(!$mSession->identidadUsuario){
            $this->_redirect('/u-nave/identificacion');
        }
        
        $this->view->pageTitle = "Solicitudes";
        
        try {
            
            $request = $this->getRequest();
            $form = new Shipcode_Form_Solicitud();
            $form->nave_id->setValue($this->nave_id);
            $solicitud = new Shipcode_Model_Solicitud();
            
            if ($this->getRequest()->isPost()) {
                if ($form->isValid($request->getPost())) {
                    try {

                        $solicitud = new Shipcode_Model_Solicitud();
                        $id = $solicitud->guardar($form->getValues(), $this->identidadUsuario['id']);
                        if(Zend_Registry::get('BORRADOR_SOLICITUDES') === TRUE){
                            $mSession->mensajes = array('La solicitud fue creada de forma exitosa.');
                            $mSession->claseMensaje = 'confirmacion';
                            $this->_redirect('/u-nave/solicitudes');
                        } else {
                            $mSession->mensajes = array('La solicitud fue creada de forma exitosa.');
                            $mSession->claseMensaje = 'confirmacion';
                            $this->_redirect('/u-nave/enviar-solicitud/' . $id);
                        }
                            

                    } catch (Exception $e) {

                        $mSession->mensajes[] = 'Ocurrió un error al intentar crear la solicitud.';
                        $mSession->mensajes[] = $e->getMessage();
                        $mSession->claseMensaje = 'error';
                        $this->_redirect('/u-nave/solicitudes');
                    }
                } else {
                    $form->populate($request->getPost());
                }
            }
            
            $this->view->form = $form;
            $this->view->solicitudes = $solicitud->getActivasNave($this->nave_id);
            $this->view->solicitudesConNuevosComentarios = $solicitud->getConNuevosComentarios($this->ultimaVisita, $this->nave_id);
            $this->view->numSolicitudesConNuevosComentarios = count(array_unique($this->view->solicitudesConNuevosComentarios));
            $this->view->fechaUltimaVisita = new Zend_Date($this->ultimaVisita['creacion']);
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar las solicitudes en curso";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/u-nave');
        }
    }
    
    public function enviarSolicitudAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        $id = (int)$this->_getParam('id');
        try {
            
            if(!$mSession->identidadUsuario){
                $this->_redirect('/u-nave/identificacion');
            }
            
            $solicitud = new Shipcode_Model_Solicitud();
            $solicitud->setId($id);
            $solicitud->enviar();
            
            $dataSolicitud = $solicitud->getRow();
            
            /******* NOTIFICACIONES ********/
            $nave = new Shipcode_Model_Nave();
            $nave->setId($this->nave_id);
            $dataNave = $nave->getRow();

            $mail = new Smt2_HtmlMailerDocument('UTF-8');
            $mail->setFrom(Zend_Registry::get('MAIL_FROM'), Zend_Registry::get('FIRMA_EMPRESA'));
            $mail->setSubject('Nueva solicitud - ID ' . $dataSolicitud->id)
                 ->setViewParam('detalles', $dataSolicitud->detalles)
                 ->setViewParam('prioridad', $dataSolicitud->prioridad)
                 ->setViewParam('nave', $dataNave->nombre)   
                 ->setViewParam('solicitado_por', $this->identidadUsuario['nombre']);

            $supervisores = $nave->getSupervisores();
            if(count($supervisores) > 0){
                foreach($supervisores as $supervisor){
                    $mail->addTo($supervisor['mail'], $supervisor['nombre']);
                }
                $mail->addCc(Zend_Registry::get('MAIL_SUPERADMIN'), Zend_Registry::get('NOMBRE_SUPERADMIN'));
            } else {
                $mail->addTo(Zend_Registry::get('MAIL_SUPERADMIN'), Zend_Registry::get('NOMBRE_SUPERADMIN'));
            }
            $mail->sendHtmlTemplate('solicitud-urgente.phtml'); 
            /******* FIN NOTIFICACIONES ******/
            
            $mSession->mensajes[] = "La solicitud fue enviada de forma exitosa";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/u-nave/solicitudes');
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar enviar la solicitud";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/u-nave/solicitudes');
        }
    }
    
    public function eliminarSolicitudAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        
        if(!$mSession->identidadUsuario){
            $this->_redirect('/u-nave/identificacion');
        }
        
        $id = (int)$this->_getParam('id');
        try {
            $solicitud = new Shipcode_Model_Solicitud();
            $solicitud->setId($id);
            $solicitud->eliminar();
            $mSession->mensajes[] = "La solicitud fue eliminada de forma exitosa";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/u-nave/solicitudes');
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar eliminar la solicitud";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/u-nave/solicitudes');
        }
    }
    
    public function cerrarSolicitudAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        
        if(!$mSession->identidadUsuario){
            $this->_redirect('/u-nave/identificacion');
        }
        
        $id = (int)$this->_getParam('id');
        try {
            $solicitud = new Shipcode_Model_Solicitud();
            $solicitud->setId($id);
            $solicitud->cerrar();
            $mSession->mensajes[] = "La solicitud fue cerrada de forma exitosa";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/u-nave/solicitudes');
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar cerrar la solicitud";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/u-nave/solicitudes');
        }
    }
    
    public function recepcionNoConformeAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        
        if(!$mSession->identidadUsuario){
            $this->_redirect('/u-nave/identificacion');
        }
        
        $id = (int)$this->_getParam('id');
        try {
            $solicitud = new Shipcode_Model_Solicitud();
            $solicitud->setId($id);
            $solicitud->setEstado(5);
            $mSession->mensajes[] = "La solicitud ha sido recibida como No Conforme.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/u-nave/solicitudes');
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar recibir como no conforme la solicitud";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/u-nave/solicitudes');
        }
    }

    public function guardarComentarioAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            if($mSession->identidadUsuario){
                $id = (int)$this->_getParam('id');

                if($this->_getParam('c')){

                    try{

                        $comentario = $this->_getParam('c');
                        $tipo = $this->_getParam("t");
                        $solicitud = new Shipcode_Model_Solicitud();
                        $solicitud->setId($id);
                        $row = $solicitud->agregarComentario($comentario, $tipo, $this->identidadUsuario['id']);
                        $data['error'] = false;
                        $data['fecha'] = $this->view->formatFechaCorta($row->creacion);
                        $data['comentario'] = $row->comentarios;

                    } catch(Exception $e){

                        $data['error'] = true;
                        $data['mensaje'] = $e->getMessage();

                    }
                    echo Zend_Json::encode($data);
                }
            }
        }
    }
}