<?php
class UtilidadesController extends Zend_Controller_Action
{
    public function init()
    {
        $this->view->acl = new Shipcode_Acl();
        $this->view->usuario = $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->autorizaciones = Zend_Json::decode($this->usuario->autorizaciones);
        $this->view->pagina = 6;
        $this->view->pageTitle = "Utilidades";
        $action = $this->getRequest()->getActionName();
        if(!$this->getRequest()->isXmlHttpRequest() && $action!= 'descargar-planilla-horometros'){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render($this->usuario->header));
        }
    }
    
    /********************* OPERACIONES CLONACIÓN DE NAVES *********************/
    public function clonarNaveAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_NaveClonar();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $nave = new Shipcode_Model_Nave();
                    $nave->setId($form->getValue('nave_id'));
                    $nueva_id = $nave->clonar($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('La nave fue clonada de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/nave/ver/' . $nueva_id);
                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar clonar la nave.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/utilidades/clonar-nave');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $this->view->form = $form;
        $this->view->title = "Clonar Nave";
        $this->renderScript('utilidades/form-clonar-nave.phtml');
    }
    
    public function clonarSistemaAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_SistemaClonar();
        
        if ($this->getRequest()->isPost()) {

            $values = $request->getPost();
            $optionsSistema = array('table' => 'naves_sistemas', 'field' => 'id');
            $validadorSistema = new Zend_Validate_Db_RecordExists($optionsSistema);
            
            if($validadorSistema->isValid($values['osistema_id']) 
                    && $validadorSistema->isValid($values['sistema_padre_id'])) {
                
                try {
                    
                    $sistema = new Shipcode_Model_NaveSistema();
                    $nave_id = $sistema->clonarSubsistema($values, $this->usuario->id);
                    $mSession->mensajes = array('El sistema fue clonado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/nave/ver/' . $nave_id . '/equipos');

                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar clonar el sistema.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/utilidades/clonar-sistema');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->view->title = "Clonar Sistema";
        $this->renderScript('utilidades/form-clonar-sistema.phtml');
    }
    
    public function clonarEquipoAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_EquipoClonar();
        
        if ($this->getRequest()->isPost()) {

            $values = $request->getPost();
            $optionsEquipo = array('table' => 'naves_equipos', 'field' => 'id');
            $validadorEquipo = new Zend_Validate_Db_RecordExists($optionsEquipo);
            $optionsSistema = array('table' => 'naves_sistemas', 'field' => 'id');
            $validadorSistema = new Zend_Validate_Db_RecordExists($optionsSistema);
            
            if($validadorEquipo->isValid($values['oequipo_id']) 
                    && $validadorSistema->isValid($values['sistema_id'])) {
                
                try {
                    $equipo = new Shipcode_Model_NaveEquipo();
                    $equipo->setId($values['oequipo_id']);
                    $nuevo_id = $equipo->clonar($values, $this->usuario->id);
                    $mSession->mensajes = array('El equipo fue clonado de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/equipo/ver/' . $nuevo_id);
                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar clonar el equipo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/utilidades/clonar-equipo');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->view->title = "Clonar Equipo";
        $this->renderScript('utilidades/form-clonar-equipo.phtml');
    }
    /**************************************************************************/
    
    /******************* OPERACIONES EXPORTACIÓN DE DATOS *********************/
    public function exportarNaveAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        if($this->getRequest()->isPost()){
            
            $nave_id = (int)$this->_getParam('nave_id', 0);
            $carenas = (int)$this->_getParam('carenas', 0);
            $siniestros = (int)$this->_getParam('siniestros', 0);
            $fotografias = (int)$this->_getParam('fotografias', 0);
            $archivos = (int)$this->_getParam('archivos', 0);
            $eliminar = (int)$this->_getParam('eliminar', 0);
            $descargar = (int)$this->_getParam('descargar', 0);
            
            if(isset($nave_id) && $nave_id !== 0) {
                try {
                    $nave = new Shipcode_Model_Nave();
                    $nave->setId($nave_id);
                    $data = $nave->getDataToExport(array(
                        'carenas' => $carenas,
                        'siniestros' => $siniestros,
                        'fotografias' => $fotografias,
                        'archivos' => $archivos 
                    ));
                    $content = Zend_Json::encode($data);
                    $timestamp =   "_" . date("YmdHis");
                    $pathFiles = Zend_Registry::get('PATH_SERVER') . "/files/";
                    $pathBackup = $pathFiles . "backups/nave_" . $data['Nave']['Ficha']['Matrícula'] . $timestamp;
                    $pathCompressedBackup = $pathFiles . "backups/nave_" . $data['Nave']['Ficha']['Matrícula'] . $timestamp . ".zip";
                    if(!is_dir($pathBackup)){ mkdir($pathBackup, 0777, true);}
                    $nameFile="Backup-JSON.txt";
                    $fp = fopen($pathBackup . "/".  $nameFile, "wb"); 
                    fwrite($fp, $content);
                    fclose($fp);
                    
                    if($archivos == 1){
                        // carpetas para guardar archivos de la nave
                        if(!is_dir($pathBackup . "/nave-archivos")){ mkdir($pathBackup . "/nave-archivos", 0777, true);}
                        if(!is_dir($pathBackup . "/nave-certificados")){ mkdir($pathBackup . "/nave-certificados", 0777, true);}
                        if(!is_dir($pathBackup . "/nave-observaciones")){ mkdir($pathBackup . "/nave-observaciones", 0777, true);}
                        if(!is_dir($pathBackup . "/nave-carenas")){ mkdir($pathBackup . "/nave-carenas", 0777, true);}
                        if(!is_dir($pathBackup . "/equipos-archivos")){ mkdir($pathBackup . "/equipos-archivos", 0777, true);}
                        if(!is_dir($pathBackup . "/mantenimientos-archivos")){ mkdir($pathBackup . "/mantenimientos-archivos", 0777, true);}
                        
                        // copio archivos adjuntos de la nave
                        if(count($data['Nave']['Archivos']) > 1) {
                            $fDestino = $pathBackup . "/nave-archivos/";
                            foreach($data['Nave']['Archivos'] as $ar){
                                $file = $pathFiles . "naves/adjuntos/" . $ar['Archivo'];
                                $copy = $fDestino . $ar['Archivo'];
                                if(file_exists($file)){
                                    if($eliminar == 1) {
                                        rename($file , $copy);
                                    } else {
                                        copy($file , $copy);
                                    }
                                }
                            }
                        }
                        // copio los archivos de los equipos
                        if(count($data['Nave']['Sistemas']) > 0){
                            foreach($data['Nave']['Sistemas'] as $sistema){
                                if(count($sistema['Equipos']) > 0){
                                    foreach($sistema['Equipos'] as $dataEquipo){
                                        if(count($dataEquipo['Archivos']) > 0){
                                            $fDestino = $pathBackup . "/equipos-archivos/" . $dataEquipo['ID'];
                                            if(!is_dir($fDestino)){
                                                mkdir($fDestino, 0777, true);
                                            }
                                            foreach($dataEquipo['Archivos'] as $cArchivo){
                                                $file = $pathFiles . "equipos/adjuntos/" . $cArchivo['Archivo'];
                                                $copy = $fDestino . "/". $cArchivo['Archivo'];
                                                if(file_exists($file)){
                                                    if($eliminar == 1) {
                                                        rename($file , $copy);
                                                    } else {
                                                        copy($file , $copy);
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                                if(count($sistema['Subsistemas']) > 0){
                                    foreach($sistema['Subsistemas'] as $subsistema) {
                                        if(count($subsistema['Equipos']) > 0){
                                            foreach($subsistema['Equipos'] as $dataEquipo){
                                                if(count($dataEquipo['Archivos']) > 0){
                                                    $fDestino = $pathBackup . "/equipos-archivos/" . $dataEquipo['ID'];
                                                    if(!is_dir($fDestino)){
                                                        mkdir($fDestino, 0777, true);
                                                    }
                                                    foreach($dataEquipo['Archivos'] as $cArchivo){
                                                        $file = $pathFiles . "equipos/adjuntos/" . $cArchivo['Archivo'];
                                                        $copy = $fDestino . "/". $cArchivo['Archivo'];
                                                        if(file_exists($file)){
                                                            if($eliminar == 1) {
                                                                rename($file , $copy);
                                                            } else {
                                                                copy($file , $copy);
                                                            }
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        // copio los archivos de los certificados
                        if(count($data['Nave']['Certificados']) > 0){
                            foreach($data['Nave']['Certificados'] as $dataCertificado){
                                if(count($dataCertificado['Archivos']) > 0){
                                    $fDestino = $pathBackup . "/nave-certificados/" . $dataCertificado['ID'];
                                    if(!is_dir($fDestino)){
                                        mkdir($fDestino, 0777, true);
                                    }
                                    foreach($dataCertificado['Archivos'] as $cArchivo){
                                        $file = $pathFiles . "naves/certificados/" . $dataCertificado['ID'] . "/" . $cArchivo['Archivo'];
                                        $copy = $fDestino . "/". $cArchivo['Archivo'];
                                        if(file_exists($file)){
                                            if($eliminar == 1) {
                                                rename($file , $copy);
                                            } else {
                                                copy($file , $copy);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        // copio los archivos de las observaciones
                        if(count($data['Nave']['Observaciones']) > 0){
                            foreach($data['Nave']['Observaciones'] as $dataObservacion){
                                if(count($dataObservacion['Archivos']) > 0){
                                    $fDestino = $pathBackup . "/nave-observaciones/" . $dataObservacion['ID'];
                                    if(!is_dir($fDestino)){
                                        mkdir($fDestino, 0777, true);
                                    }
                                    foreach($dataObservacion['Archivos'] as $cArchivo){
                                        $file = $pathFiles . "naves/observaciones/" . $dataObservacion['ID'] . "/" . $cArchivo['Archivo'];
                                        $copy = $fDestino . "/". $cArchivo['Archivo'];
                                        if(file_exists($file)){
                                            if($eliminar == 1) {
                                                rename($file , $copy);
                                            } else {
                                                copy($file , $copy);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        // copio los archivos de las carenas
                        if(count($data['Nave']['Carenas']) > 0){
                            foreach($data['Nave']['Carenas'] as $dataCarena){
                                if(count($dataCarena['Archivos']) > 0){
                                    $fDestino = $pathBackup . "/nave-carenas/" . $dataCarena['ID'];
                                    if(!is_dir($fDestino)){
                                        mkdir($fDestino, 0777, true);
                                    }
                                    foreach($dataCarena['Archivos'] as $cArchivo){
                                        $file = $pathFiles . "naves/carenas/" . $dataCarena['ID'] . "/" . $cArchivo['Archivo'];
                                        $copy = $fDestino . "/". $cArchivo['Archivo'];
                                        if(file_exists($file)){
                                            if($eliminar == 1) {
                                                rename($file , $copy);
                                            } else {
                                                copy($file , $copy);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        // copio los archivos de los siniestros
                        if(count($data['Nave']['Siniestros']) > 0){
                            foreach($data['Nave']['Siniestros'] as $dataSiniestro){
                                if(count($dataSiniestro['Archivos']) > 0){
                                    $fDestino = $pathBackup . "/nave-siniestros/" . $dataSiniestro['ID'];
                                    if(!is_dir($fDestino)){
                                        mkdir($fDestino, 0777, true);
                                    }
                                    foreach($dataSiniestro['Archivos'] as $cArchivo){
                                        $file = $pathFiles . "naves/siniestros/" . $dataSiniestro['ID'] . "/" . $cArchivo['Archivo'];
                                        $copy = $fDestino . "/". $cArchivo['Archivo'];
                                        if(file_exists($file)){
                                            if($eliminar == 1) {
                                                rename($file , $copy);
                                            } else {
                                                copy($file , $copy);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        // copio los archivos de los mantenimientos realizados
                        if(count($data['Nave']['Sistemas']) > 0){
                            foreach($data['Nave']['Sistemas'] as $sistema){
                                if(count($sistema['Equipos']) > 0){
                                    foreach($sistema['Equipos'] as $dataEquipo){
                                        if(count($dataEquipo['Mantenimientos']) > 0) {
                                            foreach($dataEquipo['Mantenimientos'] as $dataMantenimiento){
                                                if(count($dataMantenimiento['Archivos']) > 0){
                                                    $fDestino = $pathBackup . "/mantenimientos-archivos/" . $dataMantenimiento['ID'];
                                                    if(!is_dir($fDestino)){
                                                        mkdir($fDestino, 0777, true);
                                                    }
                                                    foreach($dataMantenimiento['Archivos'] as $cArchivo){
                                                        $file = $pathFiles . "mantenimientos/" . $cArchivo['Archivo'];
                                                        $copy = $fDestino . "/". $cArchivo['Archivo'];
                                                        if(file_exists($file)){
                                                            if($eliminar == 1) {
                                                                rename($file , $copy);
                                                            } else {
                                                                copy($file , $copy);
                                                            }
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                                if(count($sistema['Subsistemas']) > 0){
                                    foreach($sistema['Subsistemas'] as $subsistema) {
                                        if(count($subsistema['Equipos']) > 0){
                                            foreach($subsistema['Equipos'] as $dataEquipo){
                                                if(count($dataEquipo['Mantenimientos']) > 0) {
                                                    foreach($dataEquipo['Mantenimientos'] as $dataMantenimiento){
                                                        if(count($dataMantenimiento['Archivos']) > 0){
                                                            $fDestino = $pathBackup . "/mantenimientos-archivos/" . $dataMantenimiento['ID'];
                                                            if(!is_dir($fDestino)){
                                                                mkdir($fDestino, 0777, true);
                                                            }
                                                            foreach($dataMantenimiento['Archivos'] as $cArchivo){
                                                                $file = $pathFiles . "mantenimientos/" . $cArchivo['Archivo'];
                                                                $copy = $fDestino . "/". $cArchivo['Archivo'];
                                                                if(file_exists($file)){
                                                                    if($eliminar == 1) {
                                                                        rename($file , $copy);
                                                                    } else {
                                                                        copy($file , $copy);
                                                                    }
                                                                }
                                                            }
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                    if($fotografias == 1){
                        // carpetas para guardar las fotografias de nave y equipos
                        if(!is_dir($pathBackup)){ mkdir($pathBackup, 0777, true);}
                        if(!is_dir($pathBackup . "/nave-fotografias")){ mkdir($pathBackup . "/nave-fotografias", 0777, true);}
                        if(!is_dir($pathBackup . "/equipos-fotografias")){ mkdir($pathBackup . "/equipos-fotografias", 0777, true);}
                        // copio la fotografia d ela nave
                        if($data['Nave']['Fotografía']) {
                            $file = $pathFiles . "naves/fotografias/" . $data['Nave']['Fotografía'];
                            $copy = $pathBackup . "/nave-fotografias/" . $data['Nave']['Fotografía'];
                            if(file_exists($file)){
                                if($eliminar == 1) {
                                    rename($file , $copy);
                                } else {
                                    copy($file , $copy);
                                }
                            }
                        }
                        // copio las fotografias de los equipos
                        foreach($data['Nave']['Sistemas'] as $dataSistema){
                            if(count($dataSistema['Equipos']) > 0) {
                                foreach($dataSistema['Equipos'] as $dEquipo){
                                    if($dEquipo['Fotografía']){
                                        $fDestino = $pathBackup . "/equipos-fotografias/" . $dEquipo['ID'];
                                        if(!is_dir($fDestino)){ mkdir($fDestino, 0777, true);}
                                        $file = $pathFiles . "equipos/fotografias/" . $dEquipo['Fotografía'];
                                        $copy = $fDestino . "/" . $dEquipo['Fotografía'];
                                        if(file_exists($file)){
                                            if($eliminar == 1) {
                                                rename($file , $copy);
                                            } else {
                                                copy($file , $copy);
                                            }
                                        }
                                    }
                                }
                            }
                            if(count($dataSistema['Subsistemas']) > 0) {
                                foreach($dataSistema['Subsistemas'] as $subSistema){
                                    if(count($subSistema['Equipos']) > 0) {
                                        foreach($subSistema['Equipos'] as $dEquipo){
                                            if($dEquipo['Fotografía']){
                                                $fDestino = $pathBackup . "/equipos-fotografias/" . $dEquipo['ID'];
                                                if(!is_dir($fDestino)){ mkdir($fDestino, 0777, true);}
                                                $file = $pathFiles . "equipos/fotografias/" . $dEquipo['Fotografía'];
                                                $copy = $fDestino . "/" . $dEquipo['Fotografía'];
                                                if(file_exists($file)){
                                                    if($eliminar == 1) {
                                                        rename($file , $copy);
                                                    } else {
                                                        copy($file , $copy);
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                                    
                        }
                    }
                    if($eliminar == 1){
                        $nave->eliminarEquiposAsociados($data['Nave']['Sistemas']);
                        $nave->eliminar();
                    }
                    
                    if($descargar == 1){
                        $fichero = new Shipcode_Model_Fichero();
                        $fichero->comprimir($pathBackup, $pathCompressedBackup);
                        $args = array(
                            'download_path'     =>	$pathFiles . "/backups/",
                            'file'              =>	basename($pathCompressedBackup),		
                            'extension_check'   =>	TRUE,
                            'referrer_check'    =>	FALSE,
                            'referrer'          =>	NULL,
                        );
                        $download = new App_Download($args);
                        $download_hook = $download->get_download_hook();
                        if($download_hook['download'] == TRUE ) {
                            $download->get_download();
                        }
                    } else {
                        echo "El Backup fue realizado de forma satisfactoria.";
                    }
                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar clonar la nave.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/utilidades/exportar-nave');
                }
            }
        }
        $empresa = new Shipcode_Model_Empresa();
        $this->view->empresas = $empresa->getAll();
        $this->view->title = "Exportar Nave";
        $this->renderScript('utilidades/exportar-nave.phtml');
    }
    /**************************************************************************/
    
    /************************* OPERACIONES UBICACIONES ************************/
    public function moverEquipoAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_EquipoMover4();
        
        if ($this->getRequest()->isPost()) {

            $values = $request->getPost();
            try {

                $equipo = new Shipcode_Model_NaveEquipo();
                $equipo->setId($values['oequipo_id']);
                $result = $equipo->mover($values, $this->usuario->id);
                if($result == TRUE){
                    $mSession->mensajes = array('El equipo fue movido de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/utilidades/mover-equipo');
                } else {
                    $mSession->mensajes[] = 'No ha enviado todos los datos requeridos. Por favor seleccione el equipo a mover y su destino.';
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/utilidades/mover-equipo');
                }
            } catch (Exception $e) {
                $mSession->mensajes[] = 'Ocurrió un error al intentar movido el equipo.';
                $mSession->mensajes[] = $e->getMessage();
                $mSession->claseMensaje = 'error';
                $this->_redirect('/utilidades/mover-equipo');
            }
        }
        $this->view->form = $form;
        $this->view->title = "Mover Equipo";
    }
    
    public function getFormMoverEquipoAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
            
        if($this->getRequest()->isXmlHttpRequest()){
            
            $tipo = (int)$this->_getParam('tipo');
            if($tipo == 1) {
                $title = "Mover Equipos de nave a Nave";
                $form = new Shipcode_Form_EquipoMover1();
            } elseif($tipo == 2){
                $title = "Mover Equipo de Nave a Ubicación Virtual";
                $form = new Shipcode_Form_EquipoMover2();
            } elseif($tipo == 3){
                $title = "Mover Equipo de Ubicación Virtual a Nave";
                $form = new Shipcode_Form_EquipoMover3();
            } elseif($tipo == 4){
                $title = "Mover Equipo de Ubicación Virtual a Ubicación Virtual";
                $form = new Shipcode_Form_EquipoMover4();
            }
            
            $this->view->title = $title;
            $this->view->form = $form;
            $this->renderScript('utilidades/form-mover-equipo.phtml');
            
        }
    }
    /**************************************************************************/
    
    /***************************** INDICES FALLAS *****************************/
    public function indicesFallasAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $equipo = new Shipcode_Model_NaveEquipo();
        
        if($this->_getParam('tipo')){
            $tipo = (int)$this->_getParam('tipo');
            $this->view->equipos = $equipo->getRowsConMasReparaciones(25, $tipo);
            $this->view->tipo = $tipo;
        } else {
            $this->view->equipos = $equipo->getRowsConMasReparaciones(25);
        }
        
        $this->view->title = "Índices de Fallas";
        $this->renderScript('utilidades/indices-fallas.phtml');
    }
    /**************************************************************************/
    
    /*************************** UTILIDADES OCULTAS ***************************/
    public function reprogramarTodosLosMantenimientosAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        try {
            
            $equipo = new Shipcode_Model_NaveEquipo();
            $equipo->reprogramarTodosLosMantenimientos($this->usuario->id);
            $this->view->title = "Reprogramación de mantenimientos";
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function eliminarMantenimientosUbicacionesVirtualesAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        try {
            
            $evento = new Shipcode_Model_NaveActividad();
            $evento->eliminarEventosUbicacionesVirtuales();
            $this->view->title = "Eliminar los Mantenimientos de Equipos en Ubicaciones Virtuales";
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
    
    public function configInicioOperacionesAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Shipcode_Form_ConfigInicioOperaciones();
        
        if ($this->getRequest()->isPost()) {

            $values = $request->getPost();
                
            try {

                if($values['sistema_id'] != ''){
                    
                    $modelSistema = new Shipcode_Model_NaveSistema();
                    $modelSistema->setId($values['sistema_id']);
                    $modelSistema->configInicioOperaciones($values['fecha']);
                    
                } else {
                    
                    $modelNave = new Shipcode_Model_Nave();
                    $modelNave->setId($values['nave_id']);
                    $modelNave->configInicioOperaciones($values['fecha']);
                    
                }
                
                $mSession->mensajes[] = "La fecha de inicio de operaciones fue configurada de forma exitosa.";
                $mSession->claseMensaje = "confirmacion";
                $this->_redirect('/utilidades/config-inicio-operaciones');

            } catch (Exception $e) {

                $mSession->mensajes[] = 'Ocurrió un error al intentar configurar las fechas de inicio de operaciones de los equipos.';
                $mSession->mensajes[] = $e->getMessage();
                $mSession->claseMensaje = 'error';
                $this->_redirect('/utilidades/config-inicio-operaciones');
            }
        }
        $this->view->form = $form;
        $this->view->title = "Configurar Fecha de Inicio de Operaciones";
    }
    /**************************************************************************/
   
    
    
    /***************************************************************************
     * EN PROCESO DE ELIMINACIÓN 
     ***************************************************************************
    public function cargarGastosAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_Gastos();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $gasto = new Shipcode_Model_NaveGasto();
                    $ingresos = $gasto->registrarGastos($form->getValues(), $this->usuario->id);
                    if($ingresos != FALSE && is_int($ingresos)){
                        $mSession->mensajes[] = 'Los gastos fueron guardados de forma exitosa. Se ingresaron ' . $ingresos . ' registros.';
                        $mSession->claseMensaje = 'confirmacion';
                        $this->_redirect('/utilidades/cargar-gastos');
                    }
                    $mSession->mensajes[] = 'Ocurrió un error al intenar subir los gastos';
                    $mSession->mensajes[] = $ingresos;
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/utilidades/cargar-gastos');
                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar registrar los gastos.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/utilidades/cargar-gastos');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $this->view->form = $form;
        $this->view->title = "Subir gastos";
        $this->renderScript('utilidades/form-gastos.phtml');
    }
    
    public function subirGastosAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
            
        if($this->getRequest()->isXmlHttpRequest()){
            
            $path = 'files/gastos/';
            $allowedExtensions = array('csv');
            $sizeLimit = 2* 1024 * 1024;
            $uploader = new App_Upload_QqFileUploader($allowedExtensions, $sizeLimit);
            $result = $uploader->handleUpload($path, TRUE);
            
            if($result == TRUE){
              echo Zend_Json_Encoder::encode(array('success' => true, 'name' => $uploader->getName()));
            } 
        }    
    }
    
    public function descargarPlanillaGastosAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        $file="Planilla_Gastos.xls";
        header("Content-type: application/vnd.ms-excel");
        header("Content-Disposition: attachment; filename=$file");
        $this->renderScript('utilidades/planilla-gastos.phtml');     
    }
    public function cargarLecturasHorometrosAction()
    {
        $mSession = new Zend_Session_Namespace('shipcode');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Shipcode_Form_LecturasHorometros();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $equipo = new Shipcode_Model_NaveEquipo();
                    $equipo->registrarLecturasHorometros($form->getValues(), $this->usuario->id);
                    $mSession->mensajes = array('Las lecturas de horómetros fueron guardadas de forma exitosa.');
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/utilidades/cargar-lecturas-horometros');
                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar registrar las lecturas de horómetros.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/utilidades/cargar-lecturas-horometros');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $this->view->form = $form;
        $this->view->title = "Subir lecturas de horómetros";
        $this->renderScript('utilidades/form-lecturas-horometros.phtml');
    }
    
    public function subirLecturasHorometrosAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
            
        if($this->getRequest()->isXmlHttpRequest()){
            
            $path = 'files/lecturas-horometros/';
            $allowedExtensions = array('csv');
            $sizeLimit = 1024 * 1024;
            $uploader = new App_Upload_QqFileUploader($allowedExtensions, $sizeLimit);
            $result = $uploader->handleUpload($path, TRUE);
            
            if($result == TRUE){
              echo Zend_Json_Encoder::encode(array('success' => true, 'name' => $uploader->getName()));
            } 
        }    
    }
    
    public function descargarPlanillaHorometrosAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        $equipo = new Shipcode_Model_NaveEquipo();
        $this->view->horometros = $equipo->getAllHorometros();
        $file="Planilla_Horometros_" . date("Ymd") . ".xls";
        header("Content-type: application/vnd.ms-excel");
        header("Content-Disposition: attachment; filename=$file");
        $this->renderScript('utilidades/planilla-horometros.phtml');     
    }
    ***************************************************************************/
}