<?php
class Shipcode_Form_SistemaUsuarioMotorista extends Zend_Form
{
    public function __construct($options = null)
    {
        parent::__construct($options);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->setAttrib('autocomplete', 'off')  
              ->setAttrib('class', 'form-control input-sm')  
              ->addFilter('StringTrim');
        
        $mail = new Zend_Form_Element_Text('mail');
        $mail->setLabel('Email')
             ->setRequired(true)
             ->addFilter('StripTags')
             ->addFilter('StringTrim')
             ->setAttrib('autocomplete', 'off')  
             ->addValidator('EmailAddress')
             ->setAttrib('class', 'form-control input-sm')    
             ->setErrorMessages(array('Debe ingresar sólo letras y números. Sin espacios, ni signos.'));
        
        $valido_hasta = new Zend_Form_Element_Text('valido_hasta');
        $valido_hasta->setLabel('Válido Hasta el')
              ->setRequired(false)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator(new Zend_Validate_Date(array('format' => Zend_Registry::get('FORMAT_DATE'))))
              ->setAttrib('class', 'form-control input-sm show-calendar')
              ->setDescription('Si lo deja en blanco la validez es indefinida.')
              ->setErrorMessages(array('Debe ingresar sólo letras y números. Sin espacios, ni signos.'));
        
        $nave_id = new Zend_Form_Element_Select('nave_id');
        $nave_id->setLabel('Nave asignada')
                ->setRequired(true)
                ->addMultiOption("", "-- Seleccionar --")
                ->setAttrib('class', 'form-control input-sm')  
                ->addMultiOptions(Shipcode_Model_Nave::getAgrupadasPorEmpresaToSelect());

        $clave1 = new Zend_Form_Element_Password('clave1');
        $clave1->setLabel('Clave de acceso')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('class', 'form-control input-sm')
              ->setDescription("La clave debe tener entre 6 y 10 caractéres alfanuméricos (sólo letras y números)")
              ->addValidator('StringLength', false, array(6,10))
              ->addValidator('Alnum')
              ->setAttrib('autocomplete', 'off')
              ->setErrorMessages(array('Por favor ingrese una clave correcta'));
              
        $clave2 = new Zend_Form_Element_Password('clave2');
        $clave2->setLabel('Repetir clave de acceso')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator('Identical', false, array('token' => 'clave1'))
              ->setAttrib('class', 'form-control input-sm')
              ->setDescription("Ingrese nuevamente su nueva clave")  
              ->setAttrib('autocomplete', 'off')
              ->setErrorMessages(array('Debe introducir la misma clave que en el campo anterior'));
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn btn-default');
        
        $this->addElements(
            array(
                $id, $nombre, $mail, $nave_id, $valido_hasta,
                $clave1, $clave2, $submit, $cancel
            ));

        $this->addDisplayGroup(
            array(
                'nombre', 'mail', 'valido_hasta', 'nave_id'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-4'))
            )
        );
        
        $this->addDisplayGroup(
            array(
                'clave1', 'clave2'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-4'))
            )
        );
        
        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-12'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            'Label',
            'Description',
            array(array('row' => 'HtmlTag'), array('tag' => 'div', 'class' => 'form-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));

        $this->setAttribs(array(
            'name'      => 'usuario-motorista',
            'action'    => '/sistema-usuario/crear-motorista'
        ));

    } 
} 
