<?php
class Shipcode_Form_BasePlanMantItem extends Zend_Form
{ 
    public function __construct($options = null)
    {
        parent::__construct($options);
        
        $optionsPlan = array('table' => 'base_planesmant', 'field' => 'id');
        $validadorPlan = new Zend_Validate_Db_RecordExists($optionsPlan);

        $id = new Zend_Form_Element_Hidden('id');
        $id->addFilter('StripTags') 
           ->addFilter('StringTrim')
           ->addValidator('Int');
        
        $plan_id = new Zend_Form_Element_Hidden('plan_id');
        $plan_id->addFilter('StripTags') 
                ->addFilter('StringTrim')
                ->addValidator('Int')
                ->addValidator($validadorPlan);

        $cantidad_horas = new Zend_Form_Element_Text('cantidad_horas');
        $cantidad_horas->setLabel('Horas ciclo')
                       ->setRequired(false)
                       ->addFilter('StripTags') 
                       ->addFilter('StringTrim')
                       ->setAttrib('class', 'form-control input-sm help')
                       ->setAttrib('title', 'Cantidad de horas del ciclo.');
        
        $cantidad_dias = new Zend_Form_Element_Text('cantidad_dias');
        $cantidad_dias->setLabel('Días ciclo / Máx. días')
                       ->setRequired(false)
                       ->addFilter('StripTags') 
                       ->addFilter('StringTrim')
                       ->setAttrib('class', 'form-control input-sm help')
                       ->setAttrib('title', 'Cantidad de días del ciclo.');
        
        
        $dias_aviso = new Zend_Form_Element_Text('dias_aviso');
        $dias_aviso->setLabel('Días de anticipación aviso')
               ->setRequired(false)
               ->addFilter('StripTags') 
               ->addFilter('StringTrim')
               ->setAttrib('class', 'form-control input-sm help')
               ->setAttrib('title', 'Días de anticipación aviso.');
        
        $servicio_id = new Zend_Form_Element_Select('servicio_id');
        $servicio_id->setLabel('Servicio')
                ->setRequired(true)
                ->addValidator('Int')
                ->addFilter('StringTrim')
                ->addFilter('StripTags')
                ->setAttrib('class', 'form-control input-sm')
                ->addMultiOption('', '-- Seleccionar --')
                ->addMultiOptions(Shipcode_Model_BaseServicio::getPairsToSelect());
        
        $asignado_a = new Zend_Form_Element_Select('asignado_a');
        $asignado_a->setLabel('Asignado por defecto a')
                   ->setRequired(true)
                   ->addFilter('StringTrim')
                   ->addFilter('StripTags')
                   ->setAttrib('class', 'form-control input-sm')
                   ->addMultiOption('', '-- Seleccionar --')
                   ->addMultiOption('NAVE', 'NAVE')
                   ->addMultiOption('EXTERNO', 'EXTERNO');
        
        $descripcion = new Zend_Form_Element_Text('descripcion');
        $descripcion->setLabel('Descripción / Observaciones')
                    ->setRequired(false)
                    ->setAttrib('class', 'form-control input-sm')
                    ->addFilter('StripTags') 
                    ->addFilter('StringTrim');
        
        $asociar_proyecto = new Zend_Form_Element_Select('asociar_proyecto');
        $asociar_proyecto->setLabel('Asociar proyecto')
                  ->setRequired(true)
                  ->addFilter('StripTags')
                  ->addFilter('StringTrim')
                  ->setAttrib('class', 'form-control')
                  ->addMultiOption('NO', 'No')
                  ->addMultiOption('SI', 'Si');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn btn-default');

        $this->addElements(array(
            $id, $plan_id, $cantidad_horas, $cantidad_dias, $asignado_a,
            $dias_aviso, $servicio_id, $descripcion, $asociar_proyecto, $submit, $cancel
        ));
        
        $this->addDisplayGroup(
            array(
                'servicio_id', 'descripcion', 'cantidad_horas', 
                'cantidad_dias', 'dias_aviso', 'asignado_a', 'asociar_proyecto'
                
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-4'))
            )
        );
        
        $this->addDisplayGroup(
            array('submit', 'cancel', 'id', 'plan_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'col-lg-12'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            'Label',
            array(array('row' => 'HtmlTag'), array('tag' => 'div', 'class' => 'form-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
     
        $this->setAttribs(array(
            'class'     => 'form-vertical',
            'name'      => 'plan-mantenimiento-item'
        ));
    } 
} 
