<?php
class Shipcode_Form_Carena extends Zend_Form
{ 
    public function __construct($carena_id, $options = null)
    {
        parent::__construct($options);
        
        $campos = array();
        $nombres = array();
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addFilter('StripTags') 
           ->addFilter('StringTrim')
           ->addValidator('Int')
           ->setAttrib('class', 'form-control input-sm')
           ->setValue($carena_id);
        $campos [] = $id;
        
        $fecha = new Zend_Form_Element_Text('fecha');
        $fecha->setLabel('Fecha salida')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator(new Zend_Validate_Date(array('format' => Zend_Registry::get('FORMAT_DATE'))))
              ->setAttrib('class', 'form-control input-sm show-calendar');
        $campos[] = $fecha;
        
        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
              ->setRequired(false)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('rows', '6')
              ->setAttrib('class', 'form-control input-sm');
        $campos[] = $observaciones;
        
        $periodo = new Zend_Form_Element_Select('periodo');
        $periodo->setLabel('Próxima carena (meses)')
                ->setRequired(true)
                ->addFilter('StripTags') 
                ->addFilter('StringTrim')
                ->addValidator('Int');
        
        for($i = 12; $i <= 36; $i++){
            $periodo->addMultiOption($i, $i);
        }
        
        $campos [] = $periodo;
        
        $modelCuenta = new Shipcode_Model_CuentaCarena();
        $rowsCuentas = $modelCuenta->getAll();
        $modelGasto = new Shipcode_Model_NaveCarenaGasto();
        
        $i = 1;
        foreach($rowsCuentas as $row){

            $campo[$row->id] = new Zend_Form_Element_Text('cuenta' . $row->id);
            $campo[$row->id]->setLabel($row->nombre);
            $campo[$row->id]->setRequired(true)
                            ->setAttrib('class', 'form-control input-sm')
                            ->addValidator('Int');
            
            $gasto = $modelGasto->getGasto($carena_id, $row->id);
            if($gasto){
                $campo[$row->id]->setValue((int)$gasto->monto);
            } else {
                $campo[$row->id]->setValue(0);
            }
            
            $campos[] = $campo[$row->id];
            $nombres[] = 'cuenta' . $row->id;
            
            $i++;
        }
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Guardar')
               ->setAttrib('class','btn btn-primary');
        $campos[] = $submit;
        
        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn btn-default') 
               ->setAttrib('onclick', 'javascript:history.back();');
        $campos[] = $cancel;
        
        $this->addElements($campos);

        $this->addDisplayGroup(
            $nombres,
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-5'))
            )
        );
        
        $this->addDisplayGroup(
            array('fecha', 'periodo', 'observaciones'),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-7'))
            )
        );
       
        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag' => 'div', 'class' => 'col-lg-12'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            'Label',
            array(array('row' => 'HtmlTag'), array('tag' => 'div', 'class' => 'form-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
     
        $this->setAttribs(array(
            'class'     => 'form-vertical',
            'name'      => 'carena'
        ));
    } 
} 
