<?php
class Shipcode_Form_CertificadoFull extends Zend_Form
{ 
    public function __construct($options = null)
    {
        parent::__construct($options);
        
        $optionsNave = array('table' => 'naves', 'field' => 'id');
        $validadorNave = new Zend_Validate_Db_RecordExists($optionsNave);

        $nave_id = new Zend_Form_Element_Hidden('nave_id');
        $nave_id->addValidator('Int')
                ->addFilter('StringTrim')
                ->addFilter('StripTags')
                ->addValidator($validadorNave);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->setLabel('ID')
           ->addFilter('StripTags') 
           ->addFilter('StringTrim')
           ->addValidator('Int');
        
        $tipo_id = new Zend_Form_Element_Select('tipo_id');
        $tipo_id->setlabel('Tipo de certificado')
                ->setRequired(true)
                ->setAttrib('class', 'form-control input-sm')
                ->addMultiOption('', '-- Seleccionar --')
                ->addMultiOptions(Shipcode_Model_TipoCertificado::getPairsToSelect());
        
        $numero = new Zend_Form_Element_Text('numero');
        $numero->setRequired(false)
               ->setLabel('Nº')
               ->setAttrib('class', 'form-control input-sm')
               ->addFilter('StripTags') 
               ->addFilter('StringTrim');
        
        $descripcion = new Zend_Form_Element_Text('descripcion');
        $descripcion->setRequired(false)
                    ->setLabel('Detalle')
                    ->setAttrib('class', 'form-control input-sm')
                    ->addFilter('StripTags') 
                    ->addFilter('StringTrim');
        
        $fecha_emision = new Zend_Form_Element_Text('fecha_emision');
        $fecha_emision->setLabel('Fecha de emisión')
                      ->setRequired(false)
                      ->addFilter('StripTags') 
                      ->addFilter('StringTrim')
                      ->addValidator(new Zend_Validate_Date(array('format' => Zend_Registry::get('FORMAT_DATE'))))
                      ->setAttrib('class', 'form-control input-sm show-calendar help')
                      ->setAttrib('title', 'Si deja este campo vacío la fecha de emisión se considerará como desconocida.');
        
        $fecha_vencimiento = new Zend_Form_Element_Text('fecha_vencimiento');
        $fecha_vencimiento->setLabel('Fecha de vencimiento')
                          ->setRequired(false) 
                          ->addFilter('StripTags')
                          ->addFilter('StringTrim')
                          ->addValidator(new Zend_Validate_Date(array('format' => Zend_Registry::get('FORMAT_DATE'))))
                          ->setAttrib('class', 'form-control input-sm show-calendar help')
                          ->setAttrib('title', 'Si deja este campo vacío y el tipo de certificado no es indefinido, la fecha de vencimiento se considerará como desconocida.');
         
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Agregar')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn btn-default');

        $this->addElements(
            array(
                $nave_id, $id, $fecha_emision, $fecha_vencimiento,
                $descripcion, $numero, $tipo_id, $submit, $cancel
            ));

        $this->addDisplayGroup(
            array(
                'tipo_id', 'numero', 'descripcion', 'fecha_emision', 'fecha_vencimiento'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-3'))
            )
        );
        
        $this->addDisplayGroup(
            array('submit', 'cancel', 'nave_id', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'col-lg-12'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            'Label',
            array(array('row' => 'HtmlTag'), array('tag' => 'div', 'class' => 'form-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $nave_id->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
     
        $this->setAttribs(array(
            'class'     => 'form-vertical',
            'name'      => 'certificado'
        ));
    } 
} 
