<?php
class Shipcode_Form_MantenimientoInformado extends Zend_Form
{ 
    public function __construct($naveId, $options = null)
    {
        parent::__construct($options);
        
        $sistema = new Shipcode_Model_NaveSistema();
        $equipo = new Shipcode_Model_NaveEquipo();
        $sistemasNave = $sistema->getPairsToSelectByNaveId($naveId);
        $equiposNave = $equipo->getPairsToSelectByNaveId($naveId);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addFilter('StripTags') 
           ->addFilter('StringTrim')
           ->addValidator('Int');
        
        $tipo_id = new Zend_Form_Element_Hidden('tipo_id');
        $tipo_id->addValidator('Int')
                ->setRequired(true) 
                ->setValue(4);
      
        $sistema_id = new Zend_Form_Element_Select('sistema_id');
        $sistema_id->setRequired(true)
                   ->addValidator('Int')
                   ->addMultiOption('', '-- Sistema --')
                   ->setAttrib('class', 'form-control input-sm updateOther')
                   ->setAttrib('data-target', '#equipo_id')
                   ->setAttrib('data-url', '/ajax/get-equipos/')
                   ->addMultiOptions($sistemasNave);
        
        $equipo_id = new Zend_Form_Element_Select('equipo_id');
        $equipo_id->setRequired(true)
                  ->addValidator('Int')
                  ->setAttrib('class', 'form-control input-sm')
                  ->addMultiOption('', '-- Equipo --')
                  ->addMultiOptions($equiposNave);
        
        $servicio_id = new Zend_Form_Element_Select('servicio_id');
        $servicio_id->setRequired(true)
                    ->addValidator('Int')
                    ->setAttrib('class', 'form-control input-sm')
                    ->addMultiOption('', '-- Servicio realizado --')
                    ->addMultiOptions(Shipcode_Model_BaseServicio::getPairsToSelect());
        
        $detalles = new Zend_Form_Element_Textarea('detalles');
        $detalles->setRequired(false)
                 ->setAttrib('rows', '4')
                 ->setAttrib("class", "form-control input-sm")
                 ->setAttrib('placeholder', 'Detalle otras no clasificadas');
        
        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setRequired(false)
                 ->setAttrib('rows', '4')
                 ->setAttrib("class", "form-control input-sm")
                 ->setAttrib('placeholder', 'Observaciones/comentarios');
        
        $fecha = new Zend_Form_Element_Text('fecha');
        $fecha->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator(new Zend_Validate_Date(array('format' => Zend_Registry::get('FORMAT_DATE'))))
              ->setAttrib("class", "form-control input-sm show-calendar")
              ->setAttrib('placeholder', 'Fecha en que se realizó');
        
        $horometro = new Zend_Form_Element_Text('horometro');
        $horometro->setRequired(false)
                  ->addFilter('StripTags') 
                  ->addFilter('StringTrim')
                  ->addValidator('Int')
                  ->setAttrib("class", "form-control input-sm")
                  ->setAttrib('placeholder', 'Lectura del horómetro')
                  ->setErrorMessages(array('Para las horas ingrese sólo números.'));
        
        
        
        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Ingresar')
               ->setAttrib('type', 'submit')
               ->setAttrib('class','btn btn-primary');
        
        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Reset')
               ->setAttrib('type', 'reset')
               ->setAttrib('data-action-url', '/u-nave/mantenimientos-no-programados')
               ->setAttrib('data-submit-text', 'Ingresar')
               ->setAttrib('data-form-id', '#mantenimiento-informado') 
               ->setAttrib('class','btn btn-default');

        $this->addElements(array(
            $id, $tipo_id, $sistema_id, $equipo_id, $servicio_id, $detalles,
            $observaciones, $horometro, $fecha, $submit, $cancel));

        $this->addDisplayGroup(
            array(
                'sistema_id', 'equipo_id', 'fecha', 'horometro', 'servicio_id', 
                'detalles', 'observaciones', 'id', 'tipo_id', 'submit', 'cancel'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );

        $this->setElementDecorators(array(
            'ViewHelper',
            'Label',
            array(array('row' => 'HtmlTag'), array('tag' => 'div', 'class' => 'form-group')),
            'Errors'
        ));

        $id->setDecorators(array('ViewHelper'));
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
     
        $this->setAttribs(array(
            'class'     => 'well data-inline',
            'action'    => '/u-nave/mantenimientos-no-programados',
            'name'      => 'mantenimiento-informado'
        ));
    } 
} 
