<?php
class Shipcode_Form_ObservacionItem extends Zend_Form
{ 
    public function __construct($options = null)
    {
        parent::__construct($options);
        
        $optionsObs = array('table' => 'naves_observaciones', 'field' => 'id');
        $validadorObs = new Zend_Validate_Db_RecordExists($optionsObs);

        $id = new Zend_Form_Element_Hidden('id');
        $id->setLabel('ID')
           ->addFilter('StripTags') 
           ->addFilter('StringTrim')
           ->addValidator('Int');
        
        $observacion_id = new Zend_Form_Element_Hidden('observacion_id');
        $observacion_id->addValidator('Int')
                ->addFilter('StringTrim')
                ->addFilter('StripTags')
                ->addValidator($validadorObs);
        
        $item = new Zend_Form_Element_Text('item');
        $item->setLabel('Nº Ítem')
               ->setRequired(true)
               ->addFilter('StripTags') 
               ->addFilter('StringTrim')
               ->addValidator('Int')
               ->setAttrib('class', 'form-control input-sm');
        
        $area = new Zend_Form_Element_Select('area');
        $area->setLabel('Área')
               ->setRequired(true)
               ->addFilter('StripTags') 
               ->addFilter('StringTrim')
               ->setAttrib('class', 'form-control input-sm')
               ->addMultiOption('', '-- Seleccionar --')
               ->addMultiOption('TC', 'Telecomunicaciones')
               ->addMultiOption('MQ/CN', 'Máquinas y Construcción Naval')
               ->addMultiOption('NV/MAN', 'Navegación y Maniobra');
        
        $codigo = new Zend_Form_Element_Select('codigo');
        $codigo->setLabel('Código de plazo')
               ->setRequired(true)
               ->addFilter('StripTags') 
               ->addFilter('StringTrim')
               ->addValidator('Int')
               ->setAttrib('class', 'form-control input-sm') 
               ->addMultiOption('', '-- Seleccionar --')
               ->addMultiOptions(Shipcode_Model_CodigoObservacion::getPairsToSelect());
        
        $detalle = new Zend_Form_Element_Textarea('detalle');
        $detalle->setRequired(true)
                ->setLabel('Detalle')
                ->addFilter('StripTags') 
                ->addFilter('StringTrim')
                ->setAttrib('rows', '5')
                ->setAttrib('class', 'form-control input-sm');
        
        $argumentacion = new Zend_Form_Element_Textarea('argumentacion');
        $argumentacion->setRequired(false)
                      ->setLabel('Argumentación levantamiento')
                      ->addFilter('StripTags') 
                      ->addFilter('StringTrim')
                      ->setAttrib('rows', '5')
                      ->setAttrib('class', 'form-control input-sm');
         
        $estado = new Zend_Form_Element_Select('estado');
        $estado->setLabel('Estado')
               ->setRequired(true)
               ->setAttrib('class', 'form-control input-sm')
               ->addMultiOption('0', 'PENDIENTE')
               ->addMultiOption('2', 'CORREGIDA (SIN INSPECCIÓN O SIN SOLICITUD)')
               ->addMultiOption('3', 'SOLICITUD ENVIADA')
               ->addMultiOption('1', 'LEVANTADA');
        
        $boleta_aprob = new Zend_Form_Element_Text('boleta_aprob');
        $boleta_aprob->setLabel('Boleta levantamiento')
               ->setRequired(false)
               ->addFilter('StripTags') 
               ->addFilter('StringTrim')
               ->setAttrib('class', 'form-control input-sm');

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Guardar')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn btn-default');;

        $this->addElements(
            array(
                $observacion_id, $id, $detalle, $item, $area, $argumentacion,
                $codigo, $estado, $boleta_aprob, $submit, $cancel
            ));

        $this->addDisplayGroup(array('item', 'codigo', 'area', 'detalle', 'estado', 'argumentacion', 'boleta_aprob'), 'infoInputs');

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-3'))
            )
        );
        
        
        $this->addDisplayGroup(array('submit', 'cancel', 'nave_id', 'id'), 'submitButtons');

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-12'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            'Label',
            array(array('row' => 'HtmlTag'), array('tag' => 'div', 'class' => 'form-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $observacion_id->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
     
        $this->setAttribs(array(
            'name'      => 'observacion-item'
        ));
    } 
} 
