<?php
class Shipcode_Form_ProgramacionMensualTrabajo extends Zend_Form
{ 
    public function __construct($options = null)
    {
        parent::__construct($options);
        
        $optionsProgramacion = array('table' => 'programaciones_mensuales', 'field' => 'id');
        $validadorProgramacion = new Zend_Validate_Db_RecordExists($optionsProgramacion);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addFilter('StripTags') 
           ->addFilter('StringTrim')
           ->addValidator('Int')
           ->setRequired(true);
        
        $programacion_id = new Zend_Form_Element_Hidden('programacion_id');
        $programacion_id->addFilter('StripTags') 
                        ->addFilter('StringTrim')
                        ->addValidator('Int')
                        ->setRequired(true) 
                        ->addValidator($validadorProgramacion);
        
        $estado = new Zend_Form_Element_Select('estado');
        $estado->setLabel('Estado del trabajo')
               ->setRequired(true)
               ->addFilter('StripTags') 
               ->addFilter('StringTrim')
               ->setAttrib('class', 'form-control input-sm') 
               ->addMultiOption('TERMINADO', 'TERMINADO')
               ->addMultiOption('RECHAZADO', 'RECHAZADO / NO CORRESPONDE')
               ->addMultiOption('NO REALIZADO', 'NO REALIZADO');
      
        $inf_fecha = new Zend_Form_Element_Text('inf_fecha');
        $inf_fecha->setLabel('Fecha en que se realizó')
                  ->setRequired(false)
                  ->addFilter('StripTags') 
                  ->addFilter('StringTrim')
                  ->addValidator(new Zend_Validate_Date(array('format' => Zend_Registry::get('FORMAT_DATE'))))
                  ->setAttrib("class", "form-control input-sm show-calendar");
        
        $inf_horas = new Zend_Form_Element_Text('inf_horas');
        $inf_horas->setLabel('Lectura del horómetro')
                  ->setRequired(false)
                  ->addFilter('StripTags') 
                  ->addFilter('StringTrim')
                  ->addValidator('Int')
                  ->setAttrib('form-control input-sm')
                  ->setErrorMessages(array('Para las horas ingrese sólo números.'));
        
        $inf_comentarios = new Zend_Form_Element_Textarea('inf_comentarios');
        $inf_comentarios->setLabel('Detalles del mantenimiento / Observaciones')
                        ->setRequired(false)
                        ->setAttrib('rows', '8')
                        ->setAttrib('class', 'form-control input-sm');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Guardar informe')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn btn-default');;

        $this->addElements(array(
            $id, $programacion_id, $inf_fecha, $inf_horas, $inf_comentarios, 
            $submit, $cancel, $estado
        ));

        $this->addDisplayGroup(
            array(
                'estado', 'inf_fecha', 'inf_horas', 'inf_comentarios'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-6'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel', 'programacion_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-12'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            'Label',
            array(array('row' => 'HtmlTag'), array('tag' => 'div', 'class' => 'form-group')),
            'Errors'
        ));

        $id->setDecorators(array('ViewHelper'));
        $programacion_id->setDecorators(array('ViewHelper'));
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
     
        $this->setAttribs(array(
            'name'      => 'informe-cierre-trabajo',
            'action'    => '/programacion/crear'
        ));
    } 
} 
