<?php
class Shipcode_Form_Proyecto extends Zend_Form
{ 
    public function __construct($options = null)
    {
        parent::__construct($options);
        
        $years = array();
        for($i = date("Y") - 6; $i <= date("Y") + 8; $i++){
            $years[$i] = $i;
        }
        
        $optionsValidador = array('table' => 'proyectos', 'field' => 'id');
        $validadorProyecto = new Zend_Validate_Db_RecordExists($optionsValidador);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addFilter('StripTags') 
           ->addFilter('StringTrim')
           ->addValidator($validadorProyecto);

        $centro_costo_id = new Zend_Form_Element_Select('centro_costo_id');
        $centro_costo_id->setLabel('Centro de Costo')
                        ->setRequired(true)
                        ->addValidator('Int')
                        ->addFilter('StringTrim')
                        ->addFilter('StripTags')
                        ->addMultiOption('', '-- Seleccionar --')
                        ->setAttrib('class', 'form-control input-sm')
                        ->addMultiOptions(Shipcode_Model_CentroCosto::getPairsToSelect());
        
        $concepto_imputacion_id = new Zend_Form_Element_Select('concepto_imputacion_id');
        $concepto_imputacion_id->setLabel('Concepto de Imputación')
                               ->setRequired(true) 
                               ->addFilter('StringTrim')
                               ->addFilter('StripTags')
                               ->setAttrib('class', 'form-control input-sm')
                               ->addMultiOption('', '-- Seleccionar --')
                               ->addMultiOptions(Shipcode_Model_ConceptoImputacion::getPairsToSelect());
        
        $tipo_id = new Zend_Form_Element_Select('tipo_id');
        $tipo_id->setLabel('Tipo de proyecto')
                ->setRequired(true)
                ->addFilter('StringTrim')
                ->addFilter('StripTags')
                ->setAttrib('class', 'form-control input-sm')
                ->addMultiOption('', '-- Seleccionar --')
                ->addMultiOptions(Shipcode_Model_TipoProyecto::getPairsToSelect());
        
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->setAttrib('class', 'form-control input-sm')
              ->addFilter('StringTrim');
        
        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones proyecto')
                      ->addFilter('StripTags') 
                      ->addFilter('StringTrim')
                      ->setAttrib('rows', '6')
                      ->setAttrib('class', 'form-control input-sm');
        
        $moneda = new Zend_Form_Element_Select('moneda');
        $moneda->setLabel('Moneda')
               ->setRequired(true)
               ->addFilter('StringTrim')
               ->addFilter('StripTags')
               ->setAttrib('class', 'form-control input-sm')
               ->addMultiOption('PESO', '$ PESOS')
               ->addMultiOption('DOLAR', 'US$ DOLAR');
        
        $costo_total = new Zend_Form_Element_Text('costo_total');
        $costo_total->setLabel('Costo total')
                    ->setRequired(true)
                    ->addFilter('StripTags') 
                    ->addFilter('StringTrim')
                    ->setAttrib('class', 'form-control input-sm')
                    ->addValidator('Int');
        
        $fecha_termino = new Zend_Form_Element_Text('fecha_termino');
        $fecha_termino->setLabel('Fecha de ejecución proyecto')
                      ->setRequired(true)
                      ->addFilter('StripTags') 
                      ->addFilter('StringTrim')
                      ->addValidator(new Zend_Validate_Date(array('format' => Zend_Registry::get('FORMAT_DATE'))))
                      ->setAttrib('class', 'form-control input-sm show-calendar');
        
        $meses_prorrateo = new Zend_Form_Element_Text('meses_prorrateo');
        $meses_prorrateo->setLabel('Meses de prorrateo')
                        ->setRequired(true)
                        ->addFilter('StripTags') 
                        ->addFilter('StringTrim')
                        ->setAttrib('class', 'form-control input-sm')
                        ->addValidator('Int');
        
        $mes_inicio_prorrateo = new Zend_Form_Element_Select('mes_inicio_prorrateo');
        $mes_inicio_prorrateo->setLabel("Mes inicio prorrateo")
                        ->setRequired(true)
                        ->addFilter('StripTags') 
                        ->addFilter('StringTrim')
                        ->setAttrib('class', 'form-control input-sm')
                        ->addMultiOptions(array(
                            '01' => 'Enero',
                            '02' => 'Febrero',
                            '03' => 'Marzo',
                            '04' => 'Abril',
                            '05' => 'Mayo',
                            '06' => 'Junio',
                            '07' => 'Julio',
                            '08' => 'Agosto',
                            '09' => 'Septiembre',
                            '10' => 'Octubre',
                            '11' => 'Noviembre',
                            '12' => 'Diciembre',
                        ));
        
        $year_inicio_prorrateo = new Zend_Form_Element_Select('year_inicio_prorrateo');
        $year_inicio_prorrateo->setRequired(true)
                              ->setLabel("Año inicio prorrateo")
                              ->addFilter('StripTags') 
                              ->addFilter('StringTrim')
                              ->setAttrib('class', 'form-control input-sm')
                              ->addMultiOptions($years);
        
        $mantenimiento_id = new Zend_Form_Element_Text('mantenimiento_id');
        $mantenimiento_id->setLabel('Asociar al mantenimiento ID')
                         ->setRequired(false)
                         ->addFilter('StripTags') 
                         ->setAttrib('class', 'form-control input-sm')
                         ->addValidator('Int');

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Ingresar')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn btn-default');;

        $this->addElements(
            array(
                $id, $centro_costo_id, $concepto_imputacion_id, $tipo_id, $nombre, 
                $observaciones, $moneda, $costo_total, $fecha_termino, $meses_prorrateo,
                $mes_inicio_prorrateo, $year_inicio_prorrateo, $mantenimiento_id,
                $submit, $cancel
            ));

        $this->addDisplayGroup(
            array(
                'centro_costo_id', 'tipo_id', 'concepto_imputacion_id',  
                'nombre', 'fecha_termino'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-3'))
            )
        );
        
        $this->addDisplayGroup(
            array(
                'moneda', 'costo_total', 'meses_prorrateo', 
                'mes_inicio_prorrateo', 'year_inicio_prorrateo'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-3'))
            )
        );
        
        $this->addDisplayGroup(
            array(
                 'mantenimiento_id', 'observaciones'
            ),
            'infoInputs3'
        );

        $infoInputs3 = $this->getDisplayGroup('infoInputs3');
        $infoInputs3->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-6'))
            )
        );
        
        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'col-lg-12'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            'Label',
            array(array('row' => 'HtmlTag'), array('tag' => 'div', 'class' => 'form-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
     
        $this->setAttribs(array(
            'class'     => 'form-vertical',
            'name'      => 'proyecto'
        ));
    } 
} 
