<?php
class Shipcode_Form_ProyectoLiquidacion extends Zend_Form
{ 
    public function __construct($options = null)
    {
        parent::__construct($options);
        
        $years = array();
        for($i = date("Y") - 5; $i <= date("Y") + 5; $i++){
            $years[$i] = $i;
        }
        
        $optionsValidador = array('table' => 'proyectos', 'field' => 'id');
        $validadorProyecto = new Zend_Validate_Db_RecordExists($optionsValidador);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->setRequired(true)
           ->addFilter('StripTags') 
           ->addFilter('StringTrim')
           ->addValidator($validadorProyecto);
        
        $mes_liquidacion = new Zend_Form_Element_Select('mes_liquidacion');
        $mes_liquidacion->setRequired(true)
                        ->addFilter('StripTags') 
                        ->addFilter('StringTrim')
                        ->setAttrib('class', 'form-control input-sm')
                        ->addMultiOptions(array(
                            '01' => 'Enero',
                            '02' => 'Febrero',
                            '03' => 'Marzo',
                            '04' => 'Abril',
                            '05' => 'Mayo',
                            '06' => 'Junio',
                            '07' => 'Julio',
                            '08' => 'Agosto',
                            '09' => 'Septiembre',
                            '10' => 'Octubre',
                            '11' => 'Noviembre',
                            '12' => 'Diciembre',
                        ));
        
        $year_liquidacion = new Zend_Form_Element_Select('year_liquidacion');
        $year_liquidacion->setRequired(true)
                        ->addFilter('StripTags') 
                        ->addFilter('StringTrim')
                        ->setAttrib('class', 'form-control input-sm')
                        ->addMultiOptions($years);
        
        $observaciones_liquidacion = new Zend_Form_Element_Textarea('observaciones_liquidacion');
        $observaciones_liquidacion->setLabel('Observaciones')
                                  ->addFilter('StripTags') 
                                  ->addFilter('StringTrim')
                                  ->setAttrib('rows', '6')
                                  ->setAttrib('class', 'form-control input-sm');

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Liquidar proyecto')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn btn-default');;

        $this->addElements(
            array(
                $id, $mes_liquidacion, $year_liquidacion,
                $observaciones_liquidacion, $submit, $cancel
            ));

        $this->addDisplayGroup(
            array(
                'mes_liquidacion', 'year_liquidacion', 'observaciones_liquidacion'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'col-lg-6'))
            )
        );
        
        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'col-lg-12'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            'Label',
            array(array('row' => 'HtmlTag'), array('tag' => 'div', 'class' => 'form-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        $mes_liquidacion->setDecorators(
            array(
                'ViewHelper',
                array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'form-group')),
            )
        );
        $year_liquidacion->setDecorators(
            array(
                'ViewHelper',
                array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'form-group')),
            )
        );
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
     
        $this->setAttribs(array(
            'class'     => 'form-vertical',
            'name'      => 'proyecto-liquidacion'
        ));
    } 
} 
