<?php
class Shipcode_Form_SistemaUsuario extends Zend_Form
{
    public function __construct($options = null)
    {
        parent::__construct($options);
        
        $descEmail = "Si ingresa una casilla de email y activa las notificaciones, "
                   . "se le enviarán al usuario sus datos de acceso.";

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $perfil_id = new Zend_Form_Element_Select('perfil_id');
        $perfil_id->setLabel('Perfil asignado')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->setAttrib('class', 'form-control input-sm')
              ->addFilter('StringTrim')
              ->addMultiOption('', '-- Seleccionar --')
              ->addMultiOptions(Shipcode_Model_SistemaPerfilUsuario::getPairsToSelect());

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->setAttrib('class', 'form-control input-sm')
              ->addFilter('StringTrim');
        
        $mail = new Zend_Form_Element_Text('mail');
        $mail->setLabel('Email')
             ->setRequired(false)
             ->addFilter('StripTags')
             ->addFilter('StringTrim')
             ->addValidator('EmailAddress')
             ->setAttrib('class', 'form-control input-sm')
             ->setDescription($descEmail);
        
        $usuario = new Zend_Form_Element_Text('usuario');
        $usuario->setLabel('Usuario')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->setAttrib('class', 'form-control input-sm')
                ->setDescription("El nombre de usuario es único");
        
        $valido_hasta = new Zend_Form_Element_Text('valido_hasta');
        $valido_hasta->setLabel('Válido Hasta el')
                     ->setRequired(false)
                     ->addFilter('StripTags')
                     ->addFilter('StringTrim')
                     ->addValidator(new Zend_Validate_Date(array('format' => Zend_Registry::get('FORMAT_DATE'))))
                     ->setAttrib('class', 'form-control input-sm show-calendar')
                     ->setDescription('Si lo deja en blanco la validez es indefinida.')
                     ->setErrorMessages(array('Debe ingresar sólo letras y números. Sin espacios, ni signos.'));
        
        $notificaciones = new Zend_Form_Element_Select('notificaciones');
        $notificaciones->setLabel('Recibe notificaciones')
                       ->setRequired(true)
                       ->addFilter('StripTags')
                       ->setAttrib('class', 'form-control input-sm')
                       ->addFilter('StringTrim')
                       ->addMultiOption('0', 'NO')
                       ->addMultiOption('1', 'SI');
        
        $clave1 = new Zend_Form_Element_Password('clave1');
        $clave1->setLabel('Clave de acceso')
               ->setRequired(false)
               ->addFilter('StripTags') 
               ->addFilter('StringTrim')
               ->setAttrib('class', 'form-control input-sm')
               ->setDescription("La clave debe tener entre 6 y 10 caractéres alfanuméricos (sólo letras y números)")
               ->addValidator('StringLength', false, array(6,10))
               ->addValidator('Alnum')
               ->setAttrib('autocomplete', 'off')
               ->setErrorMessages(array('Por favor ingrese una clave correcta'));
              
        $clave2 = new Zend_Form_Element_Password('clave2');
        $clave2->setLabel('Repetir clave de acceso')
               ->setRequired(false)
               ->addFilter('StripTags') 
               ->addFilter('StringTrim')
               ->addValidator('Identical', false, array('token' => 'clave1'))
               ->setAttrib('class', 'form-control input-sm')
               ->setDescription("Ingrese nuevamente la clave")  
               ->setAttrib('autocomplete', 'off')
               ->setErrorMessages(array('Debe introducir la misma clave que en el campo anterior'));

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn btn-default');
        
        $this->addElements(array(
            $id, $perfil_id, $nombre, $mail, $usuario, $valido_hasta, 
            $notificaciones, $clave1, $clave2, $submit, $cancel));
        
        $this->addDisplayGroup(array(
            'perfil_id', 'nombre', 'usuario', 'notificaciones', 'mail', 'valido_hasta'
        ), 'infoInputs');

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-4'))
            )
        );
        
        $this->addDisplayGroup(array(
            'clave1', 'clave2'
        ), 'infoInputs2');

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-4'))
            )
        );
        
        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag', array('tag' => 'div', 'class' => 'col-lg-12'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            'Label',
            'Description',    
            array(array('row' => 'HtmlTag'), array('tag' => 'div', 'class' => 'form-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));

        $this->setAttribs(array(
            'name'      => 'usuario',
            'action'    => '/sistema-usuario/crear'
        ));

    } 
} 
