<?php
class Shipcode_Model_ImagestionGasto extends Zend_Db_Table_Abstract
{
    protected $_name = 'imagestion_gastos';
    protected $_primary = 'id';
    
    private $_dolar = 480;
    private $_euro = 640;
    private $_uf = 22860;
    
    public function buscar($data)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('g' => 'imagestion_gastos'), array(
                    'id', 'id_compra', 'cod_centro', 'cod_cuenta', 'mes_gasto', 
                    'ano_gasto', 'cantidad', 'producto_id', 'detalle', 'precio',
                    'monto', 'descuento', 'moneda', 'tipo_cambio', 'fecha_aprobacion',
                    'empresa', 'estado'))
               
               ->join(array('c' => 'cuentas_gastos'), 'c.cod_cuenta=g.cod_cuenta', array('cuenta' => 'nombre'))  
               ->join(array('p' => 'imagestion_productos'), 'p.id=g.producto_id', array('producto' => 'nombre'))
               ->join(array('n' => 'naves'), 'n.cod_centro=g.cod_centro', array('nave' => 'nombre'))  
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'));
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        
        if($data['cod_centro']!='') {
            $select->where("g.cod_centro=?", $data['cod_centro']);
        }
        
        if($data['desde']) {
            $select->where("g.fecha_aprobacion > ?", $data['desde']);
        }
        
        if($data['hasta']) {
            $select->where("g.fecha_aprobacion < ?", $data['hasta']);
        }
        
        return $adapter->fetchAll($select);
    }
    
    public function getHtmlToPdf($rows)
    {
        $content = '<h1>Informe Gastos</h1>'
                 . '<p class="text-muted">Realizado el ' . Shipcode_Model_Fecha::format(date("Y-m-d")) . ', a las ' . date("H:i") . '</p>'
                 . '<hr>'
                 . '<p>Se encontraron ' . count($rows) . ' resultados</p>'
                 . '<table border="1" cellpadding="4"><thead><tr>'
                 . '<th>Empresa</th>'
                 . '<th>C. Costo</th>'
                 . '<th>Cuenta de Gasto</th>'
                 . '<th>Fecha aprob</th>'    
                 . '<th>Detalle</th>'
                 . '<th>Cant</th>'
                 . '<th>Unitario</th>'
                 . '<th>Desc</th>' 
                 . '<th>Total</th>'
                 . '</tr></thead><tbody>';
        
        if(count($rows) > 0) {
            foreach($rows as $gasto) { 
                
                $content .= '<tr>'
                          . '<td class="border-right" valign="top">' . $gasto['empresa'] . '</td>'
                          . '<td valign="top">' . $gasto['nave'] . '</td>'
                          . '<td valign="top">' . $gasto['cuenta'] . '</td>'
                          . '<td valign="top">' . Shipcode_Model_Fecha::format($gasto['fecha_aprobacion']) . '</td>'
                          . '<td valign="top">' . $gasto['producto'] . '</td>'
                          . '<td valign="top">' . $gasto['cantidad'] . '</td>'
                          . '<td valign="top">' . $gasto['monto'] .'</td>'
                          . '<td valign="top">' . $gasto['descuento'] .'</td>'
                          . '<td valign="top">' . $this->_calculateTotalGasto($gasto) .'</td>'
                          . '</tr>';
                
            } 
        } else {
            $content .= '<tr><td colspan="9">No se encontraron registros coincidentes para su búsqueda.</td></tr>';
        }
        
        $content .= '</tbody></table></div></html>';
        
        return $content;
    }
    
    public function getYears($empresa_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT DISTINCT(year) FROM imagestion_gastos AS g "
             . "JOIN naves AS n ON n.cod_centro=g.cod_centro "
             . "WHERE n.empresa_id='$empresa_id'";
        return $adapter->fetchAll($sql);
    }
    
    public function crear($orden, $item)
    {
        if((float)$orden['tipo_cambio'] == 1.00 || (float)$orden['tipo_cambio'] == 0.10) {
            if($orden['moneda'] == 'UF'){
                $tipo_cambio = $this->_uf;
            } elseif($orden['moneda'] == 'Dolar') {
                $tipo_cambio = $this->_dolar;
            } elseif($orden['moneda'] == 'Euro'){
                $tipo_cambio = $this->_euro;
            } else {
                $tipo_cambio = $orden['tipo_cambio'];
            } 
        }  else {
            $tipo_cambio = $orden['tipo_cambio'];
        }
        
        $data = array(
            'id_compra'         => $orden['id_compra'],
            'cod_centro'        => $item['cod_centro'],
            'cod_cuenta'        => $item['cod_cuenta'],
            'mes_gasto'         => $orden['mes_gasto'],
            'ano_gasto'         => $orden['ano_gasto'],
            'cantidad'          => $item['cantidad'],  
            'producto_id'       => $item['producto_id'],
            'detalle'           => $item['especificacion'],
            'precio'            => $item['precio'],
            'descuento'         => $item['descuento'],    
            'monto'             => $item['precio'] * $tipo_cambio,
            'moneda'            => $orden['moneda'],
            'tipo_cambio'       => $tipo_cambio,
            'fecha_aprobacion'  => $orden['fecha_aprobacion'],
            'empresa'           => $orden['empresa'],
            'estado'            => $orden['estado']
        ); 
        
        $row = $this->createRow($data);
        $row->save();
    }
    
    public function getDetalleMensual($cod_centro, $mes, $year)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('g' => 'imagestion_gastos'), array(
                    'id', 'id_compra', 'cod_centro', 'cod_cuenta', 'mes_gasto', 
                    'ano_gasto', 'cantidad', 'producto_id', 'detalle', 'precio',
                    'monto', 'descuento', 'moneda', 'tipo_cambio', 'fecha_aprobacion',
                    'empresa', 'estado'))
               ->join(array('c' => 'cuentas_gastos'), 'c.cod_cuenta=g.cod_cuenta', array('cuenta' => 'nombre'))  
               ->join(array('p' => 'imagestion_productos'), 'p.id=g.producto_id', array('producto' => 'nombre')) 
               ->where("g.cod_centro=?", $cod_centro)
               ->where("g.ano_gasto=?", $year)
               ->where("g.mes_gasto=?", $mes);
        return $adapter->fetchAll($select);
    }
    
    public function getDetalleMensualCuenta($cod_centro, $cod_cuenta, $mes, $year)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('g' => 'imagestion_gastos'), array(
                    'id', 'id_compra', 'cod_centro', 'cod_cuenta', 'mes_gasto', 
                    'ano_gasto', 'cantidad', 'producto_id', 'detalle', 'precio',
                    'monto', 'descuento', 'moneda', 'tipo_cambio', 'fecha_aprobacion',
                    'empresa', 'estado'))
               ->join(array('c' => 'cuentas_gastos'), 'c.cod_cuenta=g.cod_cuenta', array('cuenta' => 'nombre'))  
               ->join(array('p' => 'imagestion_productos'), 'p.id=g.producto_id', array('producto' => 'nombre')) 
               ->where("g.cod_centro=?", $cod_centro)
               ->where("g.cod_cuenta=?", $cod_cuenta) 
               ->where("g.ano_gasto=?", $year)
               ->where("g.mes_gasto=?", $mes);
        return $adapter->fetchAll($select);
    }
    
    public function getDetalleAcumulado($cod_centro, $mes, $year)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('g' => 'imagestion_gastos'), array(
                    'id', 'id_compra', 'cod_centro', 'cod_cuenta', 'mes_gasto', 
                    'ano_gasto', 'cantidad', 'producto_id', 'detalle', 'precio',
                    'monto', 'descuento', 'moneda', 'tipo_cambio', 'fecha_aprobacion',
                    'empresa', 'estado'))
               ->join(array('c' => 'cuentas_gastos'), 'c.cod_cuenta=g.cod_cuenta', array('cuenta' => 'nombre'))  
               ->join(array('p' => 'imagestion_productos'), 'p.id=g.producto_id', array('producto' => 'nombre')) 
               ->where("g.cod_centro=?", $cod_centro)
               ->where("g.ano_gasto=?", $year)
               ->where("g.mes_gasto <= ?", $mes);
        return $adapter->fetchAll($select);
    }
    
    public function getTotalMensual($cod_centro, $year = NULL, $month = NULL)
    {
        if($year === NULL){
            $year = date("Y");
        }
        
        if($month === NULL){
            $month = date("m");
        }
        
        $sql = "SELECT SUM(g.monto) AS total_gasto_mensual "
             . "FROM imagestion_gastos AS g "
             . "WHERE g.cod_centro='$cod_centro' "
             . "AND g.ano_gasto='$year' AND g.mes_gasto='$month' "
             . "AND (g.estado='1' OR g.estado='2' OR g.estado='3' OR g.estado='6')";
        $adapter = $this->getAdapter();
        return $adapter->fetchOne($sql);
    }
    
    public function getTotalMensualProyectado($cod_centro, $year = NULL, $month = NULL)
    {
        if($year === NULL){
            $year = date("Y");
        }
        
        if($month === NULL){
            $month = date("m");
        }
        
        $sql = "SELECT SUM(g.monto) AS total_gasto_mensual "
             . "FROM imagestion_gastos AS g "
             . "WHERE g.cod_centro='$cod_centro' "
             . "AND g.ano_gasto='$year' AND g.mes_gasto='$month' "
             . "AND (g.estado='0' OR g.estado='7' OR g.estado='5')";
        $adapter = $this->getAdapter();
        return $adapter->fetchOne($sql);
    }
    
    public function getTotalMensualCuenta($cod_centro, $cod_cuenta, $year, $month)
    {
        $sql = "SELECT SUM(g.monto) AS total_gasto_mensual "
             . "FROM imagestion_gastos AS g "
             . "WHERE g.cod_centro='$cod_centro' AND g.cod_cuenta='$cod_cuenta' "
             . "AND g.ano_gasto='$year' AND g.mes_gasto='$month'";
        $adapter = $this->getAdapter();
        return $adapter->fetchOne($sql);
    }
    
    public function getTotalAcumuladoCuenta($cod_centro, $cod_cuenta, $year, $month)
    {
        $sql = "SELECT SUM(g.monto) AS total_gasto_mensual "
             . "FROM imagestion_gastos AS g "
             . "WHERE g.cod_centro='$cod_centro' AND g.cod_cuenta='$cod_cuenta' "
             . "AND g.ano_gasto='$year' AND g.mes_gasto <= '$month'";
        $adapter = $this->getAdapter();
        return $adapter->fetchOne($sql);
    }
    
    public function getTotalEjecutadoAcumulado($cod_centro, $year = NULL)
    {
        if($year === NULL){
            $year = date("Y");
        }
        
        $month = date("m");
        
        $sql = "SELECT SUM(g.monto) AS total_gasto_mensual "
             . "FROM imagestion_gastos AS g "
             . "WHERE g.cod_centro='$cod_centro' AND g.ano_gasto='$year' AND g.mes_gasto <= '$month' "
             . "AND (g.estado='1' OR g.estado='2' OR g.estado='3' OR g.estado='6')";
        $adapter = $this->getAdapter();
        return $adapter->fetchOne($sql);
    }
    
    public function getTotalProyectadoAcumulado($cod_centro, $year = NULL)
    {
        if($year === NULL){
            $year = date("Y");
        }
        
        $month = date("m");
        
        $sql = "SELECT SUM(g.monto) AS total_gasto_mensual "
             . "FROM imagestion_gastos AS g "
             . "WHERE g.cod_centro='$cod_centro' AND g.ano_gasto='$year' AND g.mes_gasto <= '$month' "
             . "AND (g.estado='0' OR g.estado='7' OR g.estado='5')";
        $adapter = $this->getAdapter();
        return $adapter->fetchOne($sql);
    }

    private function _calculateTotalGasto(array $gasto)
    {
        $total = $gasto['cantidad'] * $gasto['monto'];
        if($gasto['descuento'] > 0){
            $total = $total - ($total * $gasto['descuento']/100);
        }
        return $total;
    }
}