<?php
class Shipcode_Model_NaveInforme extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_informes';
    protected $_primary = 'id';
    
    private $_id;
    
    private function _validarId($id)
    {
        $optiosnInforme = array('table' => 'naves_informes', 'field' => 'id');
        $validadorInforme = new Zend_Validate_Db_RecordExists($optiosnInforme);
        
        if($validadorInforme->isValid($id)){
            return TRUE;
        }
        return FALSE;
    }
    
    public function setId($id)
    {
        if($this->_validarId($id) == FALSE){
            throw new Exception('El ID de informe solicitado no existe');   
        }
        $this->_id = $id;
    }
    
    public function getNoEnviados()
    {
        $data = array();
        $naves = $this->_getNavesConInformes();
        foreach($naves as $rowNave){
            
            $fechaUltimoInforme = $this->_getFechaUltimoInforme($rowNave['id']);
            if($fechaUltimoInforme != NULL){
                if($this->_checkIntervaloInforme($fechaUltimoInforme) == TRUE){
                    $rowNave['fecha_lectura'] = $fechaUltimoInforme;
                    $data[] = $rowNave;
                }
            }
        }
        return $data;
    }
    
    private function _getNavesConInformes()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT n.id, n.nombre FROM naves AS n "
             . "JOIN naves_informes AS ni ON ni.nave_id=n.id "
             . "WHERE ni.estado > 0 "
             . "GROUP BY n.id";
        return $adapter->fetchAll($sql);
    }
    
    private function _checkIntervaloInforme($fechaUltimoInforme)
    {
        $hoy = new Zend_Date();
        $fechaUltimo = new Zend_Date($fechaUltimoInforme);
        $fechaUltimo->add(7, Zend_Date::DAY);
        if($hoy->isLater($fechaUltimo)){
            return TRUE;
        }
        return FALSE;
    }
    
    private function _getFechaUltimoInforme($nave_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT fecha_lectura FROM naves_informes AS ni WHERE ni.nave_id='$nave_id' AND ni.estado > '0' ORDER BY id DESC LIMIT 1";
        $fechaUltimoInforme = $adapter->fetchOne($sql);
        if($fechaUltimoInforme){
            return $fechaUltimoInforme;
        }
        return NULL;
    }
    
    public function getPdfData()
    {
        $data = $this->getRowFull();
        $solicitudes = $this->getSolicitudes();
        $mantenimientos = $this->getMantenimientos();
        
        $dataPdf = array();
        
        $content = '<h1>Informe '. $data['nave'] .' - Semana ' . $data['semana'] . ' / ' . $data['year'] . '</h1>'
                  . '<p class="datos-envio">Enviado el ' . Shipcode_Model_Fecha::format($data['fecha_envio']) 
                  . ' - Lectura de datos del ' . Shipcode_Model_Fecha::format($data['fecha_lectura']) 
                  . ' - Enviado por '. $data['enviado_por_nombre'] .'</p>'  
                  . '<h5>Horómetros & Parámetros</h5>'
                  . '<table class="table table-condensed table-bordered table-preview-informe">'
                  . '<thead>'
                  . '<tr>'
                  . '<th width="20">&nbsp;</th>'
                  . '<th>Equipo</th>'
                  . '<th class="centrado td-input-parametro">H</th>';
        
        if(count($data['parametros'])) {
            foreach($data['parametros'] as $parametro) { 
                if(in_array($parametro['id'], $data['parametrosRequeridos'])) {
                   $content .= '<th class="centrado">' . $parametro['nombre'] . '</th>';
                }
            }
        }
        
        $content .= '</tr></thead><tbody>';
        
        if(count($data['equipos']) > 0) {
            $i = 1; 
            foreach($data['equipos'] as $equipo) {
                $parametrosEquipo = explode(",", $equipo['parametros']);
                $content .= '<tr class="tr-equipo-informe">'
                          . '<td class="centrado">' . $i . '</td>'
                          . '<td>' . $equipo['nombre'] . '</td>';

                if($equipo['horometro'] == 1) {
                    $content .= '<td class="centrado td-input-parametro">';
                    if($equipo['lectura_horometro']) { 
                        $content .= $equipo['lectura_horometro']; 
                    } 
                    $content .= '</td>';    
                } else {
                    $content .= '<td>&nbsp;</td>';
                }

                if(count($data['parametros'])) {
                    foreach($data['parametros'] as $parametro) {
                        if(in_array($parametro['id'], $data['parametrosRequeridos'])) {
                            if(in_array($parametro['id'], $parametrosEquipo)) {
                                $content .= '<td class="centrado td-input-parametro">';
                                if(array_key_exists($parametro['id'], $equipo['lecturas_parametros'])) { 
                                    $content .= number_format($equipo['lecturas_parametros'][$parametro['id']], 0, ',', '.'); 
                                }
                                $content .= '</td>';        
                            } else {
                                $content .= '<td>&nbsp;</td>'; 
                            }
                        }
                    }
                } 

                $content .= '</tr>';
                $i++; 
            }
        } else { 
                 
            $content .= '<tr>'
                      . '<td colspan="' . $this->colspan . '" class="text-muted">No se han agregado equipos al informe de esta nave</td>'
                      . '</tr>';
        }
        
        $content .= '</tbody>';
        $content .= '</table>';
        
        /* LISTADO DE MANTENIMIENTOS */
        $content .= '<h5>Mantenimientos realizados</h5>';
        $content .= '<table class="table">'
                  . '<thead>'
                  . '<tr>'
                  . '<th>Equipo</th>'
                  . '<th width="80">Fecha</th>'
                  . '<th width="80">Horas</th>'
                  . ' <th>Detalle</th>'
                  . '</tr>'
                  . '</thead>'
                  . '<tbody>';
        
        if(count($mantenimientos)) {
            foreach($mantenimientos as $mantenimiento) {
                $content .= '<tr>'
                          . '<td>' . $mantenimiento->equipo . '</td>'
                          . '<td>' . Shipcode_Model_Fecha::format($mantenimiento->fecha) . '</td>'
                          . '<td>';
                if($mantenimiento->horas != NULL) { 
                    $content .= $mantenimiento->horas; 
                }
                $content .= '</td>'
                          . '<td>' . nl2br($mantenimiento->detalles) . '</td>'
                          . '</tr>';
            }
        } else {
            $content .= '<tr>'
                      . '<td colspan="4" class="text-muted">No se han agregado mantenimientos en este informe semanal.</td>'
                      . '</tr>';
        } 
        
        $content .= '</tbody>'
                  . '</table>';
        /*********** FIN LISTADO DE MANTENIMIENTOS ***********/
        
        
        /* LISTADO DE SOLICITUDES */
        $content .= '<h5>Solicitudes de trabajos</h5>';
        $content .= '<table class="table">'
                  . '<thead>'
                  . '<tr>'
                  . '<th class="centrado" width="40">Prioridad</th>'
                  . '<th>Detalle</th>'
                  . '</tr>'
                  . '</thead>'
                  . '<tbody>';
        if(count($solicitudes)) {
            foreach($solicitudes as $solicitud) {
                $content .= '<tr>';
                if($solicitud['prioridad'] == 'NORMAL') {
                    $content .= '<td class="centrado"><span class="label">N</span></td>';
                } else {
                    $content .= '<td class="centrado"><span class="label label-danger">U</span></td>';
                }    
                $content .= '<td>' . nl2br($solicitud->detalles) . '</td>'
                          . '</tr>';    
            } 
        } else {
           $content .= '<tr>'
                     . '<td colspan="2" class="text-muted">No se han agregado solicitudes en este informe semanal.</td>'
                     . '</tr>';
        } 
        
        $content .= '</tbody>'
                  . '</table>';
        
        $content .= '</div></tbody></html>';
        
        $dataPdf['contents'] = $content;
        $nombreNave = str_replace(" ", "_", $data['nave']);
        $dataPdf['nombre'] = "Informe_Semanal_" . $nombreNave . "_Semana_" . $data['semana'] . ".pdf";
        return $dataPdf;
    }
    
    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getFechaLectura()
    {
        return $this->getRow()->fecha_lectura;
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ni' => 'naves_informes'), array(
                    'id', 'creacion', 'creador', 'nave_id', 'fecha_envio', 'fecha_lectura', 'semana', 'year',
                    'enviado_por_nombre', 'enviado_por_rut', 'revisado_por', 'estado'))
               ->join(array('u' => 'sistema_usuarios'), 'u.id=ni.creador', array('creado_por' => 'nombre'))
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->where('ni.id=?', $this->_id);
        
        $informe =  $adapter->fetchRow($select);
        $informe['equipos'] = $this->_getEquipos();
        $informe['parametros'] = $this->getParametros();
        $informe['parametrosRequeridos'] = $this->_getParametrosRequeridos();
        return $informe;
    }
    
    private function _getParametrosRequeridos()
    {
        $nave_id = $this->getNaveId();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT ne.parametros FROM naves_equipos AS ne "
             . "JOIN naves_equipos_ubicaciones AS neu ON neu.id=ne.ubicacion_id "
             . "JOIN naves_sistemas AS ns ON ns.id=neu.sistema_id "
             . "WHERE ns.nave_id='$nave_id' AND ne.parametros IS NOT NULL";
        $dataParametros = $adapter->fetchCol($sql);
        $parametros = array();
        foreach($dataParametros as $dataParametro){
            $arrayParametros = explode(",", $dataParametro);
            foreach($arrayParametros as $valor){
                if(!in_array($valor, $parametros)){
                    $parametros[] = $valor; 
                }
            }
           
        }
        return $parametros;
    }
    
    public function getParametros()
    {
        $parametro = new Shipcode_Model_EquipoParametro();
        return $parametro->getAll();
    }
    
    public function getMantenimientos()
    {
        $mantenimiento = new Shipcode_Model_NaveInformeMantenimiento();
        return $mantenimiento->getRowsByInformeId($this->_id);
    }
    
    public function getSolicitudes($prioridad = NULL)
    {
        $mantenimiento = new Shipcode_Model_NaveInformeSolicitud();
        return $mantenimiento->getRowsByInformeId($this->_id, $prioridad);
    }
    
    public function getNaveId()
    {
        return $this->getRow()->nave_id;
    }
    
    public function getNave()
    {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getRow()->nave_id);
        return $modelNave->getRowFull();
    }
    
    public function getUltimos($nave_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ni' => 'naves_informes'), array(
                    'id', 'creacion', 'creador', 'nave_id', 'fecha_envio', 'fecha_lectura', 'semana', 'year',
                    'enviado_por_nombre', 'enviado_por_rut', 'revisado_por', 'estado'))
               ->join(array('u' => 'sistema_usuarios'), 'u.id=ni.creador', array('creado_por' => 'nombre'))
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->joinLeft(array('r' => 'sistema_usuarios'), 'r.id=ni.revisado_por', array('revisado_por_nombre' => 'nombre'))
               ->where("ni.nave_id=?", $nave_id) 
               ->order("ni.id DESC")
               ->limit(10);
        
        return $adapter->fetchAll($select);
    }
    
    public function getPendientes()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ni' => 'naves_informes'), array(
                    'id', 'creacion', 'creador', 'nave_id', 'fecha_envio', 'fecha_lectura', 'semana', 'year',
                    'enviado_por_nombre', 'enviado_por_rut', 'revisado_por', 'estado'))
               ->join(array('u' => 'sistema_usuarios'), 'u.id=ni.creador', array('creado_por' => 'nombre'))
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->joinLeft(array('r' => 'sistema_usuarios'), 'r.id=ni.revisado_por', array('revisado_por_nombre' => 'nombre'))
               ->where("ni.estado = '1'")
               ->order("ni.id DESC");
        return $adapter->fetchAll($select);
    }
    
    public function getAll($estado = 0)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ni' => 'naves_informes'), array(
                    'id', 'creacion', 'creador', 'nave_id', 'fecha_envio', 'fecha_lectura', 'semana', 'year',
                    'enviado_por_nombre', 'enviado_por_rut', 'revisado_por', 'estado'))
               ->join(array('u' => 'sistema_usuarios'), 'u.id=ni.creador', array('creado_por' => 'nombre'))
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->joinLeft(array('r' => 'sistema_usuarios'), 'r.id=ni.revisado_por', array('revisado_por_nombre' => 'nombre'));
        
        if( $estado == 0 ){
            $select->where("ni.revisado_por IS NULL");
        } 
        
        $select->order("ni.id DESC");
        
        return $adapter->fetchAll($select);
    }
    
    public function getRowsByNaveId($nave_id)
    {
        $data = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT DISTINCT YEAR(fecha_lectura) AS year FROM naves_informes "
             . "WHERE nave_id='$nave_id' AND estado!='0' ORDER BY year DESC";
        
        $years = $adapter->fetchAll($sql);
        
        $i = 0;
        
        foreach($years as $year){
            
            $y = $year['year'];
            
            $sqlMeses = "SELECT DISTINCT MONTH(fecha_lectura) AS mes FROM naves_informes "
                      . "WHERE YEAR(fecha_lectura)='$y' "
                      . "AND nave_id='$nave_id' "
                      . "AND estado!='0' "  
                      . "ORDER BY semana DESC";
            
            $meses = $adapter->fetchAll($sqlMeses);
            
            $data[$i]['year'] = $y;
            
            foreach($meses as $mes){
                
                $m = $mes['mes'];
                /*
                $sqlInformes = "SELECT * FROM naves_informes "
                             . "WHERE YEAR(fecha_lectura)='$y' " 
                             . "AND MONTH(fecha_lectura)='$m' "
                             . "AND nave_id='$nave_id' "
                             . "AND estado!='0' "
                             . "ORDER BY semana DESC";
                */
                $select = $adapter->select();
                $select->from(array('ni' => 'naves_informes'), array(
                                'id', 'creacion', 'creador', 'nave_id', 'fecha_envio', 'fecha_lectura', 'semana', 'year',
                                'enviado_por_nombre', 'enviado_por_rut', 'revisado_por', 'estado'))
                        ->join(array('u' => 'sistema_usuarios'), 'u.id=ni.creador', array('creado_por' => 'nombre'))
                        ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
                        ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
                        ->join(array('r' => 'sistema_usuarios'), 'r.id=ni.revisado_por', array('revisado_por_nombre' => 'nombre'))
                        ->where("YEAR(fecha_lectura)=?", $y)
                        ->where("MONTH(fecha_lectura)=?", $m)
                        ->where("ni.nave_id=?", $nave_id)
                        ->where("ni.estado !='0'")
                        ->order("semana DESC");
                
                
                $informes = $adapter->fetchAll($select); 
                $dataMes['numero'] = $m; 
                $dataMes['informes'] = $informes;
                $data[$i]['meses'][] = $dataMes;
            }
            $i++;
        }
        return  $data;
    }
    
    public function registrarResponsable($rut, $nombre)
    {
        $rut = App_Rut::cleanToDb($rut);
        $row = $this->getRow();
        $row->enviado_por_nombre = $nombre;
        $row->enviado_por_rut = $rut;
        $row->save();
    }
    
    public function guardarValoresParametros($dataParametros, $user)
    {
        $valoresParametros = explode(";", $dataParametros);
        $lecturaParametro = new Shipcode_Model_NaveParametroLectura();
        foreach($valoresParametros as $valorParametro){
            $valores = explode(",", $valorParametro);
            $parametro['informe_id'] = $this->_id;
            $parametro['equipo_id'] = (int)$valores[0];
            $parametro['parametro_id'] = (int)$valores[1];
            
            if($valores[2] == ''){
                $parametro['lectura'] = NULL;
            } else {
                $parametro['lectura'] = $valores[2];
            }
            
            $parametro['creador'] = (int)$user;
            $parametro['fecha'] = $this->getFechaLectura();
            $lecturaParametro->guardar($parametro);
                
        }
    }
    
    public function guardarValoresHorometros($dataHorometros, $user)
    {
        $fecha_lectura = $this->getFechaLectura();
        $valoresHorometros = explode(";", $dataHorometros);
        $lecturaHorometro = new Shipcode_Model_NaveHorometroLectura();
        $errores = array();
        foreach($valoresHorometros as $valorHorometro){
            $valores = explode(",", $valorHorometro);
            $horometro['informe_id']    = $this->_id;
            $horometro['equipo_id']     = (int)$valores[0];
            
            if($valores[1] == ''){
                $horometro['lectura'] = NULL;
            } else {
                $horometro['lectura'] = $valores[1];
                $result = $lecturaHorometro->validarUltimaLectura($valores[1], $horometro['equipo_id'], $fecha_lectura);
                if($result !==  TRUE){
                    $result['id'] = "#h" . $horometro['equipo_id']; 
                    $errores[] = $result; 
                }
            }
            
            $horometro['creador']       = (int)$user;
            $horometro['fecha']         = $fecha_lectura;
            $lecturaHorometro->guardar($horometro);
        }
        return $errores;
    }
    
    public function guardarMantenimiento($data, $user)
    {
        $mantenimiento = new Shipcode_Model_NaveInformeMantenimiento();
        return $mantenimiento->guardar($data, $user);
    }
    
    public function guardarSolicitud($data, $user)
    {
        $solicitud = new Shipcode_Model_NaveInformeSolicitud();
        return $solicitud->guardar($data, $user);
    }
    
    public function eliminarMantenimiento($id)
    {
        $mantenimiento = new Shipcode_Model_NaveInformeMantenimiento();
        $mantenimiento->setId($id);
        return $mantenimiento->eliminar();
    }
    
    public function eliminarSolicitud($id)
    {
        $solicitud = new Shipcode_Model_NaveInformeSolicitud();
        $solicitud->setId($id);
        return $solicitud->eliminar();
    }
    
    public function buscar(array $data)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ni' => 'naves_informes'), array(
                    'id', 'creacion', 'creador', 'nave_id', 'fecha_envio', 'fecha_lectura', 
                    'semana', 'year', 'enviado_por_nombre', 'enviado_por_rut', 
                    'revisado_por', 'estado'
               ))
               ->join(array('u' => 'sistema_usuarios'), 'u.id=ni.creador', array('creado_por' => 'nombre'))
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
               ->joinLeft(array('r' => 'sistema_usuarios'), 'r.id=ni.revisado_por', array('revisado_por_nombre' => 'nombre'));
        
        if($data['estado'] == 0){
            $select->where("ni.estado='0'");
        } elseif($data['estado'] == 1){
            $select->where("ni.estado ='1'");
        } elseif($data['estado'] == 2){
            $select->where("ni.estado ='2'");
        }
        
        if($data['desde'] != ''){
            $select->where("ni.fecha_envio >= ? ", $data['desde']);
        }
        
        if($data['hasta'] != ''){
            $select->where("ni.fecha_envio <= ? ", $data['hasta']);
        }
        
        if($data['enviado_por'] != ''){
            $rut = App_Rut::cleanToDb($data['enviado_por']);
            $select->where("ni.enviado_por_nombre LIKE '%". $data['enviado_por'] ."%' OR ni.enviado_por_rut='$rut'");
        }
        
        if($data['empresa'] != 0){
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        
        if($data['nave'] != 0) {
            $select->where("ni.nave_id=?", $data['nave']);
        }
        
        $select->order("ni.year DESC");
        $select->order("ni.semana DESC");
        
        return $adapter->fetchAll($select);
    }
   
    public function crear($data, $user)
    {
        $fechaLectura = new Zend_Date($data['fecha_lectura']);
        $row = $this->createRow();
        $row->creador = $user;
        $row->nave_id = $data['nave_id'];
        $row->fecha_lectura = $data['fecha_lectura'];
        $row->semana = $fechaLectura->get(Zend_Date::WEEK);
        $row->year = $fechaLectura->get(Zend_Date::YEAR);
        $row->save();
        return $row->id;
    }
 
    public function validar()
    {
        return TRUE;
    }
    
    public function enviar()
    {
        $row = $this->getRow();
        $row->estado = 1;
        $row->fecha_envio = date("Y-m-d");
        $row->save();
    }
    
    public function aprobar($user)
    {
        $row = $this->getRow();
        $row->estado = 2;
        $row->revisado_por = $user;
        $row->save();
        $lecturasHorometros = new Shipcode_Model_NaveHorometroLectura();
        $lecturasHorometros->aprobarLecturasInforme($row->id);
    }
    
    public function editarFecha($fecha_lectura)
    {
        $dataSemana = $this->_getDataSemana($fecha_lectura);
        $row = $this->getRow();
        $row->fecha_lectura = $fecha_lectura;
        $row->semana = $dataSemana['semana'];
        $row->year = $dataSemana['year'];
        $row->save();
        $this->_actualizarFechasLecturas($fecha_lectura);
        return $row->semana;
    }
    
    public function validarFecha($fechaLectura, $naveId = NULL)
    {
        $dataSemana = $this->_getDataSemana($fechaLectura);
        
        // comprobación para editar la fecha
        // si los datos son iguales, ya los validé antes, por lo que están correctos
        if($naveId === NULL) {
            $dataActual = $this->getRow()->toArray();
            if($dataActual['semana'] === $dataSemana['semana'] && $dataActual['year'] === $dataSemana['year']){
                return TRUE;
            }
        }
        
        // si el informe es nuevo, empieza aquí la validación
        $fechaHoy  = new Zend_Date();
        $dataHoy['semana'] = $fechaHoy->get(Zend_Date::WEEK);
        $dataHoy['year'] = $fechaHoy->get(Zend_Date::YEAR);
        
        $adapter = $this->getAdapter();
        $sql = "SELECT id FROM naves_informes WHERE year='" . $dataSemana['year'] . "' AND semana='" . $dataSemana['semana'] . "' AND nave_id='$naveId'";
        $result = $adapter->fetchOne($sql);
        
        if(!$result){
            
            if($dataSemana['semana'] > $dataHoy['semana'] && $dataHoy['semana'] != 1 && $dataSemana['year'] == $dataHoy['year']){
                return "No puede crear una informe para una semana posterior a la actual. : 1";
            } elseif($dataSemana['year'] > $dataHoy['year']) {
                return "No puede crear una informe para una semana posterior a la actual. : 2";
            }
            return TRUE;
        }
        return "Ya existe un informe para la semana de la fecha seleccionada.";
        
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }

    private function _actualizarFechasLecturas($fecha_lectura)
    {
        $lecturaParametro = new Shipcode_Model_NaveParametroLectura();
        $lecturaParametro->actualizarFechaLecturasInforme($this->_id, $fecha_lectura);
        $lecturaHorometro = new Shipcode_Model_NaveHorometroLectura();
        $lecturaHorometro->actualizarFechaLecturasInforme($this->_id, $fecha_lectura);
    }
    
    private function _getDataSemana($fecha_lectura)
    {
        $fecha = new Zend_Date($fecha_lectura);
        $data['semana'] = $fecha->get(Zend_Date::WEEK);
        $data['year'] = $fecha->get(Zend_Date::YEAR);
        return $data;
    }
    
    private function _getLecturasParametros($equipo_id)
    {
        $lecturaParametro = new Shipcode_Model_NaveParametroLectura();
        return $lecturaParametro->getRowsByInformeIdAndEquipoId($this->_id, $equipo_id);
    }
    
    private function _getLecturasHorometro($equipo_id)
    {
        $lecturaHorometro = new Shipcode_Model_NaveHorometroLectura();
        return $lecturaHorometro->getRowByInformeIdAndEquipoId($this->_id, $equipo_id);
    }
    
    private function _getEquipos()
    {
        $nave = new Shipcode_Model_Nave();
        $nave->setId($this->getNaveId());
        $equipos = $nave->getEquiposInforme();
        if(count($equipos) > 0){
            $data = array();
            foreach($equipos as $equipo) {
                if($equipo['horometro'] != 0){
                    $equipo['lectura_horometro'] = $this->_getLecturasHorometro($equipo['id']);
                }
                if($equipo['parametros'] != NULL){
                    $equipo['lecturas_parametros'] = $this->_getLecturasParametros($equipo['id']);
                }
                $data[] = $equipo;
            }
            return $data;
        }
        return $equipos;
    }
    
    /*
    public function getSemanas($nave_id)
    {
        $ultimoInformeNave = $this->_getUltimoByNaveId($nave_id);
        $semanas = array();
        
        if($ultimoInformeNave == NULL || $ultimoInformeNave == FALSE){
            
            $fechaInicio = new Zend_Date();
            $dia = $fechaInicio->get(Zend_Date::WEEKDAY_DIGIT);
            $fechaInicio->sub($dia - 1, Zend_Date::DAY);
            $fechaInicio->sub(3, Zend_Date::WEEK);
            $numOpciones = 4;
            
        } else {
            // es posible mejorar este script considerando que no se hace el informe en la última semana, hasta un mes.
            // si no se hizo la semana pasada, se muestran las últimas dos semanas como opciones
            // si no hace el informe en las últimas dos semanas, se muestran 3 semanas como opción
            // así hasta un mes
            $fechaInicio = new Zend_Date($ultimoInformeNave['fecha_semana']);
            $fechaInicio->add(7, Zend_Date::DAY);
            $numOpciones = 1;
            
        }
        
        for($i = 1; $i <= $numOpciones; $i++){
            $semana['fecha'] = $fechaInicio->toString("yyyy-MM-dd");
            $fechaTermino = new Zend_Date($fechaInicio->toString("yyyy-MM-dd"), "yyyy-MM-dd");
            $fechaTermino->add(6, Zend_Date::DAY);
            $semana['fecha_termino'] = $fechaTermino->toString("yyyy-MM-dd");
            $semana['numero'] = $fechaInicio->get(Zend_Date::WEEK);     
            $fechaInicio->add(1, Zend_Date::WEEK);
            $semanas[] = $semana;
        }
        
        return $semanas;
    }
    
    private function _getUltimoByNaveId($nave_id)
    {
        $where = $this->getAdapter()->quoteInto("nave_id=?", $nave_id);
        $order = "id DESC";
        $ultimo = $this->fetchRow($where, $order);
        if($ultimo){
            return $ultimo;
        }
        return FALSE;
    }
    */
}