<?php
class Shipcode_Model_NaveInformeMantenimiento extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_informes_mantenimientos';
    protected $_primary = 'id';
    
    private $_id;
    
    private function _validarId($id)
    {
        $optiosnInforme = array('table' => $this->_name, 'field' => $this->_primary);
        $validadorInforme = new Zend_Validate_Db_RecordExists($optiosnInforme);
        
        if($validadorInforme->isValid($id)){
            return TRUE;
        }
        return FALSE;
    }
    
    public function setId($id)
    {
        if($this->_validarId($id) == FALSE){
            throw new Exception('El ID del mantenimiento no existe');   
        }
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nim' => 'naves_informes_mantenimientos'), array('id', 'informe_id', 'equipo', 'fecha', 'horas', 'detalles', 'estado'))
               ->join(array('ni' => 'naves_informes'), 'ni.id=nim.informe_id', array('nave_id', 'fecha_envio', 'semana', 'enviado_por_nombre', 'enviado_por_rut')) 
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->where("nim.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getAsignaciones()
    {
        $mantenimientoEquipo = new Shipcode_Model_NaveEquipoMantenimiento();
        return $mantenimientoEquipo->getRowsByMantenimientoInformeId($this->_id);
    }
    
    public function getInformeId()
    {
        return $this->getRow()->informe_id;
    }
    
    public function getNaveId()
    {
        $informe = new Shipcode_Model_NaveInforme();
        $informe->setId($this->getInformeId());
        return $informe->getRow()->nave_id;
    }
    
    public function getAll( $estado = 0 )
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nim' => 'naves_informes_mantenimientos'), array('id', 'creacion', 'creador', 'informe_id', 'equipo', 'fecha', 'horas', 'detalles', 'estado'))
               ->join(array('ni' => 'naves_informes'), 'ni.id=nim.informe_id', array('fecha_envio', 'semana', 'enviado_por_nombre', 'enviado_por_rut', 'nave_id')) 
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'));
        if( $estado == 0 ){
            $select->where("nim.estado='0'");
        } 
        $select->order("nim.id DESC");
        return $adapter->fetchAll($select);
    }
    
    public function buscar(array $data)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nim' => 'naves_informes_mantenimientos'), array('id', 'creacion', 'creador', 'informe_id', 'equipo', 'fecha', 'horas', 'detalles', 'estado'))
               ->join(array('ni' => 'naves_informes'), 'ni.id=nim.informe_id', array('fecha_envio', 'semana', 'enviado_por_nombre', 'enviado_por_rut')) 
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
               ->joinLeft(array('r' => 'sistema_usuarios'), 'r.id=ni.revisado_por', array('revisado_por_nombre' => 'nombre'));
        
        if($data['estado'] == 0){
            $select->where("nim.estado='0'");
        } elseif($data['estado'] == 1){
            $select->where("nim.estado ='1'");
        } elseif($data['estado'] == 2){
            $select->where("nim.estado ='2'");
        }
        
        if($data['desde'] != ''){
            $select->where("ni.fecha_envio >= ? ", $data['desde']);
        }
        
        if($data['hasta'] != ''){
            $select->where("ni.fecha_envio <= ? ", $data['hasta']);
        }

        if($data['enviado_por'] != ''){
            $rut = App_Rut::cleanToDb($data['enviado_por']);
            $select->where("ni.enviado_por_nombre LIKE '%". $data['enviado_por'] ."%' OR ni.enviado_por_rut='$rut'");
        }
        
        if($data['empresa'] != 0){
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        
        if($data['nave'] != 0) {
            $select->where("ni.nave_id=?", $data['nave']);
        }
        
        $select->where("ni.estado='2'");
        $select->order("ni.id DESC");
        
        return $adapter->fetchAll($select);
    }
    
    public function getNoAsignados()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nim' => 'naves_informes_mantenimientos'), array('id', 'informe_id', 'equipo', 'fecha', 'horas', 'detalles', 'estado'))
               ->join(array('ni' => 'naves_informes'), 'ni.id=nim.informe_id', array('fecha_envio', 'semana', 'enviado_por_nombre', 'enviado_por_rut')) 
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->where("ni.estado='2'")  
               ->where("nim.estado='0'")
               ->order("nim.id DESC");
        return $adapter->fetchAll($select);
    }
    
    public function getRowsByInformeId($informe_id)
    {
        $where = $this->getAdapter()->quoteInto("informe_id=?", $informe_id);
        return $this->fetchAll($where);
    }
    
    public function getNave()
    {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getRow()->nave_id);
        return $modelNave->getRowFull();
    }
    
    public function guardar($data, $user)
    {
        $data['creador'] = $user;
        
        if( $this->_validarId($data['id']) == TRUE ){
            $row = $this->find($data['id'])->current();
        } else {
            $row = $this->createRow();
        }
        
        $row->setFromArray($data);
        $row->save();
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = (int)$estado;
        $row->save();
    }
    
    public function reabrir($id)
    {
        $row = $this->find($id)->current();
        $row->estado = 0;
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
}