<?php
class Shipcode_Model_NaveInformeSolicitud extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_informes_solicitudes';
    protected $_primary = 'id';
    
    private $_id;
    
    private function _validarId($id)
    {
        $optiosnInforme = array('table' => $this->_name, 'field' => $this->_primary);
        $validadorInforme = new Zend_Validate_Db_RecordExists($optiosnInforme);
        
        if($validadorInforme->isValid($id)){
            return TRUE;
        }
        return FALSE;
    }
    
    public function setId($id)
    {
        if($this->_validarId($id) == FALSE){
            throw new Exception('El ID de la solicitud no existe');   
            exit;
        }
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getAll( $estado = 0 )
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nis' => 'naves_informes_solicitudes'), array(
                    'id', 'creacion', 'creador', 'informe_id', 'detalles', 'prioridad', 'estado'))
               ->join(array('u' => 'sistema_usuarios'), 'u.id=nis.creador', array('creado_por' => 'nombre'))
               ->join(array('ni' => 'naves_informes'), 'ni.id=nis.informe_id', array('fecha_envio', 'semana', 'nave_id')) 
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'));
        if( $estado == 0 ){
            $select->where("nis.estado='0'");
        } 
        $select->order("nis.id DESC");
        return $adapter->fetchAll($select);
    }
    
    public function getEnTramite()
    {
        $data = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nis' => 'naves_informes_solicitudes'), array('id', 'creacion', 'creador', 'informe_id', 'detalles', 'prioridad', 'estado'))
               ->join(array('ni' => 'naves_informes'), 'ni.id=nis.informe_id', array('fecha_envio', 'semana', 'enviado_por_nombre', 'enviado_por_rut'))  
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->where("ni.estado != '0' AND nis.estado != '4' AND nis.prioridad = 'NORMAL'")
               ->orWhere("nis.prioridad = 'URGENTE' AND nis.estado < '4'")
               ->order("nis.id DESC");
        
        $solicitudes = $adapter->fetchAll($select);
        $comentario = new Shipcode_Model_NaveInformeSolicitudComentario();
        foreach($solicitudes as $solicitud){
            $solicitud['comentarios'] = $comentario->getRowsBySolicitudId($solicitud['id']);
            $data[] = $solicitud;
        }
        return $data;
    }
    
    public function getEnTramiteSupervisor($empresa_id)
    {
        $data = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nis' => 'naves_informes_solicitudes'), array('id', 'creacion', 'creador', 'informe_id', 'detalles', 'prioridad', 'estado'))
               ->join(array('ni' => 'naves_informes'), 'ni.id=nis.informe_id', array('fecha_envio', 'semana', 'enviado_por_nombre', 'enviado_por_rut'))  
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->where("n.empresa_id='" . $empresa_id . "' AND ni.estado != '0' AND nis.estado != '4' AND nis.prioridad = 'NORMAL' ")
               ->orWhere("n.empresa_id='" . $empresa_id . "' AND nis.prioridad = 'URGENTE' AND nis.estado != '4'")
               ->order("nis.id DESC");
        
        $solicitudes = $adapter->fetchAll($select);
        $comentario = new Shipcode_Model_NaveInformeSolicitudComentario();
        foreach($solicitudes as $solicitud){
            $solicitud['comentarios'] = $comentario->getRowsBySolicitudId($solicitud['id']);
            $data[] = $solicitud;
        }
        return $data;
    }
    
    public function getEnTramiteInformeNave($nave_id)
    {
        $data = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nis' => 'naves_informes_solicitudes'), array('id', 'creacion', 'creador', 'informe_id', 'detalles', 'prioridad', 'estado'))
               ->join(array('ni' => 'naves_informes'), 'ni.id=nis.informe_id', array('fecha_envio', 'semana', 'enviado_por_nombre', 'enviado_por_rut'))  
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->where("ni.nave_id = '" . $nave_id . "' AND ni.estado != '0' AND nis.estado != '4' AND nis.prioridad = 'NORMAL'")
               ->orWhere("ni.nave_id='" . $nave_id . "' AND nis.prioridad = 'URGENTE' AND nis.estado != '4'")
               ->order("nis.id DESC");
        $solicitudes = $adapter->fetchAll($select);
        $comentario = new Shipcode_Model_NaveInformeSolicitudComentario();
        foreach($solicitudes as $solicitud){
            $solicitud['comentarios'] = $comentario->getRowsBySolicitudId($solicitud['id']);
            $data[] = $solicitud;
        }
        return $data;
    }
    
    // Función usada en el módulo de informe semanal
    public function filtrar(array $data, $empresa_id = NULL)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nis' => 'naves_informes_solicitudes'), 
                      array('id', 'creacion', 'creador', 'informe_id', 'detalles', 'prioridad', 'estado'))
               ->join(array('ni' => 'naves_informes'), 'ni.id=nis.informe_id', 
                      array('fecha_envio', 'semana', 'enviado_por_nombre', 'enviado_por_rut')) 
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
               ->joinLeft(array('r' => 'sistema_usuarios'), 'r.id=ni.revisado_por', array('revisado_por_nombre' => 'nombre'));
        
        $where = "nis.id IS NOT NULL ";
        
        if($empresa_id != NULL) {
            $where .= "AND n.empresa_id = '" . $empresa_id . "' ";
        }
        
        if($data['prioridad'] == 2){
            
            if($data['estado'] == 0){
                $where .= "AND (nis.prioridad='NORMAL' AND nis.estado > '0' AND nis.estado < '4') OR (nis.prioridad = 'URGENTE' AND nis.estado < '4') ";
            } elseif($data['estado'] == 2){
                $where .= "AND nis.estado ='2' ";
            } elseif($data['estado'] == 3){
                $where .= "AND nis.estado ='3' ";
            } elseif($data['estado'] == 4){
                $where .= "AND nis.estado ='4' ";
            } elseif($data['estado'] == 5){
                $where .= "AND nis.estado ='5' ";
            }

        } elseif($data['prioridad'] == 1){
            
            if($data['estado'] == 0){
                $where .= "AND nis.prioridad = 'URGENTE' AND nis.estado < '4' ";
            } elseif($data['estado'] == 2){
                $where .= "AND nis.prioridad = 'URGENTE' AND nis.estado ='2' ";
            } elseif($data['estado'] == 3){
                $where .= "AND nis.prioridad = 'URGENTE' AND nis.estado ='3' ";
            } elseif($data['estado'] == 4){
                $where .= "AND nis.prioridad = 'URGENTE' AND nis.estado ='4' ";
            } elseif($data['estado'] == 5){
                $where .= "AND nis.prioridad = 'URGENTE' AND nis.estado ='5' ";
            } elseif($data['estado'] == 10){
                $where .= "AND nis.prioridad = 'URGENTE' ";
            }
            
        } elseif($data['prioridad'] == 0) {
            if($data['estado'] == 0){
                $where .= "AND nis.prioridad = 'NORMAL' AND nis.estado < '4' ";
            } elseif($data['estado'] == 2){
                $where .= "AND nis.prioridad = 'NORMAL' AND nis.estado ='2' ";
            } elseif($data['estado'] == 3){
                $where .= "AND nis.prioridad = 'NORMAL' AND nis.estado ='3' ";
            } elseif($data['estado'] == 4){
                $where .= "AND nis.prioridad = 'NORMAL' AND nis.estado ='4' ";
            } elseif($data['estado'] == 5){
                $where .= "AND nis.prioridad = 'NORMAL' AND nis.estado ='5' ";
            } elseif($data['estado'] == 10){
                $where .= "AND nis.prioridad = 'NORMAL' ";
            }
        }
        
        if($data['desde'] != ''){
            $where .= "AND ni.fecha_envio >= '" . $data['desde'] . "' ";
        }
        
        if($data['hasta'] != ''){
            $where .= "AND ni.fecha_envio <= '" . $data['hasta'] . "' ";
        }
        
        if($data['enviado_por'] != ''){
            $rut = App_Rut::cleanToDb($data['enviado_por']);
            $select->where("ni.enviado_por_nombre LIKE '%". $data['enviado_por'] ."%' OR ni.enviado_por_rut='$rut'");
        }
        
        if($data['empresa'] != 0){
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        
        if($data['nave'] != 0) {
            $select->where("ni.nave_id=?", $data['nave']);
        }
        
        $select->where($where);
        $select->order("ni.id DESC");
        
        $data = array();
        $solicitudes = $adapter->fetchAll($select);
        $comentario = new Shipcode_Model_NaveInformeSolicitudComentario();
        foreach($solicitudes as $solicitud){
            $solicitud['comentarios'] = $comentario->getRowsBySolicitudId($solicitud['id']);
            $data[] = $solicitud;
        }
        return $data;
    }
    
    public function getConNuevosComentarios($ultimaVisita, $nave_id = NULL)
    {
        $comentario = new Shipcode_Model_NaveInformeSolicitudComentario();
        return $comentario->getPosterioresUltimaVisita($ultimaVisita, $nave_id);
    }
    
    // Función usada en los informes exportables
    public function buscar($data)
    {
        $dataSolicitudes = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nis' => 'naves_informes_solicitudes'), 
                      array('id', 'creacion', 'creador', 'informe_id', 'detalles', 'prioridad', 'estado',  'DATEDIFF(CURDATE(), nis.creacion) AS dias_creacion'))
               ->join(array('ni' => 'naves_informes'), 'ni.id=nis.informe_id', 
                      array('fecha_envio', 'semana', 'enviado_por_nombre', 'enviado_por_rut', 'DATEDIFF(CURDATE(), ni.fecha_envio) AS dias_aprobacion')) 
               ->join(array('n' => 'naves'), 'n.id=ni.nave_id', array('nave' => 'nombre'))
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
               ->joinLeft(array('r' => 'sistema_usuarios'), 'r.id=ni.revisado_por', array('revisado_por_nombre' => 'nombre'));
        
        $where = "nis.id IS NOT NULL ";
        
        if($data['prioridad'] == 0){
            $where .= "AND nis.prioridad = 'NORMAL' ";
        } elseif($data['prioridad'] == 1){
            $where .= "AND nis.prioridad = 'URGENTE' ";
        }
        
        
        if($data['estado'] == 0){
            $where .= "AND nis.estado = '0' ";
        } elseif($data['estado'] == 1){
            $where .= "AND nis.estado ='1' ";
        } elseif($data['estado'] == 2){
            $where .= "AND nis.estado ='2' ";
        } elseif($data['estado'] == 3){
            $where .= "AND nis.estado ='3' ";
        } elseif($data['estado'] == 4){
            $where .= "AND nis.estado ='4' ";
        } elseif($data['estado'] == 5){
            $where .= "AND nis.estado ='5' ";
        } 
        
        
        if($data['desde'] != ''){
            $where .= "AND ni.fecha_envio >= '" . $data['desde'] . "' ";
        }
        
        if($data['hasta'] != ''){
            $where .= "AND ni.fecha_envio <= '" . $data['hasta'] . "' ";
        }
        
        if($data['enviado_por_nombre'] != ''){
            $where .= "AND ni.enviado_por_nombre LIKE '%" . $data['enviado_por_nombre'] . "%' ";
        }
        
        if($data['empresa'] != '') {
            $where .= "AND n.empresa_id = '" . $data['empresa'] . "' ";
        }
        
        if($data['nave'] != '') {
            $where .= "AND ni.nave_id='" . $data['nave'] . "' ";
        } 
        
        $select->where($where);
        $select->order("ni.semana DESC");
        $rows = $adapter->fetchAll($select);
        if(count($rows) > 0){
            
            $comentario = new Shipcode_Model_NaveInformeSolicitudComentario();
            
            foreach($rows as $row){
                $dataSolicitud = $row;
                $dataSolicitud['comentarios'] = $comentario->getRowsBySolicitudId($row['id']);
                $dataSolicitudes[] = $dataSolicitud;
            }
            return $dataSolicitudes;
        }
        return NULL;
    }
    
    public function getHtmlToPdf($rows)
    {
        $content = '<h1>Informe Solicitudes</h1>'
                 . '<p class="text-muted">Realizado el ' . date("Y-m-d") . ', a las ' . date("H:i") . '</p>'
                 . '<hr>'
                 . '<p>Se encontraron ' . count($rows) . ' resultados</p>'
                 . '<table border="1" cellpadding="4"><thead><tr>'
                 . '<th>Empresa</th>'
                 . '<th>Nave</th>'
                 . '<th>Informe</th>'   
                 . '<th>Enviado por</th>'
                 . '<th>Detalles</th>'
                 . '<th>Prioridad</th>'   
                 . '<th>Estado</th>'
                 . '<th>Días</th>'
                 . '<th>Comentarios</th>'
                 . '</tr></thead><tbody>';
        
        if(count($rows) > 0) {
            foreach($rows as $solicitud) { 
                
                if($solicitud['estado'] == 0) {
                    $estado = 'PENDIENTE';
                } elseif($solicitud['estado'] == 1) {
                    $estado = 'EN CURSO';
                } elseif($solicitud['estado'] == 2) {
                    $estado = 'TERMINADA OK';
                } elseif($solicitud['estado'] == 3) {
                    $estado = 'RECHAZADA';
                } elseif($solicitud['estado'] == 4) {
                    $estado = 'CERRADA';
                } elseif($solicitud['estado'] == 5) {
                    $estado = 'NO CONFORME';
                }
                
                if($solicitud['prioridad'] == 'NORMAL'){
                    $dias = $solicitud['dias_aprobacion'];
                } else {
                    $dias = $solicitud['dias_creacion'];
                }
                
                if(count($solicitud['comentarios']) > 0) {
                    $comentarios = NULL;
                    foreach($solicitud['comentarios'] as $comentario){
                        $comentarios .= Shipcode_Model_Fecha::formatShort($comentario['creacion']);
                        if($comentario['tipo']=='supervisor') { 
                            $comentarios .= ' S : '; 
                        } else { 
                            $comentarios .= ' M : '; 
                        } 
                        
                        $comentarios .= $comentario['comentarios'];
                        $comentarios .= "<br>";
                    }
                    
                } else {
                    $comentarios = '---';
                }
                
                $content .= '<tr><td class="border-right">' . $solicitud['empresa'] . '</td>'
                          . '<td>' . $solicitud['nave'] . '</td>'
                          . '<td>S' . $solicitud['semana'] . ' ' . Shipcode_Model_Fecha::format($solicitud['fecha_envio']) . '</td>'
                          . '<td>' . $solicitud['enviado_por_nombre'] . '</td>'
                          . '<td>' . nl2br($solicitud['detalles']) . '</td>'
                          . '<td>' . $solicitud['prioridad'] . '</td>'
                          . '<td>' . $estado . '</td>'
                          . '<td>' . $dias . '</td>'
                          . '<td>' . $comentarios . '</td>'
                          . '</tr>';
                
            } 
        } else {
            $content .= '<tr><td colspan="7">No se encontraron registros coincidentes para su búsqueda.</td></tr>';
        }
        
        $content .= '</table></div></tbody></html>';
        
        return $content;
    }
    
    public function getRowsByInformeId($informe_id, $prioridad = NULL)
    {
        if($prioridad == 'NORNAL' || $prioridad == ' URGENTE'){
            $where = $this->getAdapter()->quoteInto("prioridad='$prioridad' AND informe_id=?", $informe_id);
        } else {
            $where = $this->getAdapter()->quoteInto("informe_id=?", $informe_id);
        }
            
        return $this->fetchAll($where);
    }
    
    public function guardar($data, $user)
    {
        $data['creador'] = $user;
        if($this->_validarId($data['id']) == TRUE ){
            $row = $this->find($data['id'])->current();
        } else {
            $row = $this->createRow();
        }
        $row->setFromArray($data);
        $row->save();
    }
    
    public function agregarComentario($comentario, $tipo, $user)
    {
        $comentarioSolicitud = new Shipcode_Model_NaveInformeSolicitudComentario();
        return $comentarioSolicitud->crear(array(
            'creador' => $user,
            'solicitud_id' => $this->_id,
            'comentarios' => $comentario,
            'tipo' => $tipo
        ));
    }
    
    public function setEstado($estado)
    {
        if(!isset($estado) || !is_numeric($estado)){
            throw new Exception("El estado indicado no es válido");
        }
        
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
}