<?php
class Shipcode_Model_AuditoriaInterna extends Zend_Db_Table_Abstract
{
    protected $_name = 'auditorias_internas';
    protected $_primary = 'id';
    
    private $_id;
       
    public function setId($id)
    {
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ai' => 'auditorias_internas'), array('ai.*', 'DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento DAY) AS fecha_vencimiento'))
               ->join(array('aip' => 'auditorias_internas_prioridades'), 'aip.id=ai.prioridad_id', array('prioridad' => 'nombre')) 
               ->join(array('r' => 'sistema_usuarios'), 'r.id=ai.responsable_id', array('responsable' => 'nombre', 'mail_responsable' => 'mail'))
               ->join(array('n' => 'naves'), 'n.id=ai.nave_id', array('nave' => 'nombre')) 
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=ai.area_id', array('area' => 'nombre')) 
               ->join(array('sui' => 'sistema_usuarios'), 'sui.id=ai.ingreso_por', array('ingresada_por' => 'nombre', 'mail_ingreso' => 'mail'))
               ->joinLeft(array('suc' => 'sistema_usuarios'), 'suc.id=ai.cierre_por', array('cerrada_por' => 'nombre'))  
               ->where("ai.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getNaveId()
    {
        return $this->getRow()->nave_id;
    }
    
    public function getRowsAvisoHoy()
    {
        $fecha = date("Y-m-d");
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ai' => 'auditorias_internas'), array('ai.*', 'DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento DAY) AS fecha_vencimiento'))
               ->join(array('aip' => 'auditorias_internas_prioridades'), 'aip.id=ai.prioridad_id', array(
                   'prioridad' => 'nombre', 
                   'notificaciones_aviso', 
                   'notificaciones_vencimiento'
               )) 
               ->join(array('r' => 'sistema_usuarios'), 'r.id=ai.responsable_id', array('responsable' => 'nombre', 'mail_responsable' => 'mail'))
               ->join(array('n' => 'naves'), 'n.id=ai.nave_id', array('nave' => 'nombre')) 
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=ai.area_id', array('area' => 'nombre')) 
               ->join(array('sui' => 'sistema_usuarios'), 'sui.id=ai.ingreso_por', array('ingresada_por' => 'nombre'))
               ->where("ai.estado = 'PENDIENTE' AND DATE_ADD(ai.ingreso_fecha, INTERVAL aip.dias_aviso DAY) = ? ", $fecha);
        return $adapter->fetchAll($select);
    }
    
    public function getRowsVencimientoHoy()
    {
        $fecha = date("Y-m-d");
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ai' => 'auditorias_internas'), array('ai.*', 'DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento DAY) AS fecha_vencimiento'))
               ->join(array('aip' => 'auditorias_internas_prioridades'), 'aip.id=ai.prioridad_id', array(
                   'prioridad' => 'nombre', 
                   'notificaciones_aviso', 
                   'notificaciones_vencimiento'
               )) 
               ->join(array('r' => 'sistema_usuarios'), 'r.id=ai.responsable_id', array('responsable' => 'nombre', 'mail_responsable' => 'mail'))
               ->join(array('n' => 'naves'), 'n.id=ai.nave_id', array('nave' => 'nombre')) 
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=ai.area_id', array('area' => 'nombre')) 
               ->join(array('sui' => 'sistema_usuarios'), 'sui.id=ai.ingreso_por', array('ingresada_por' => 'nombre'))
               ->where("ai.estado='PENDIENTE' AND DATE_ADD(ai.ingreso_fecha, INTERVAL aip.dias_vencimiento DAY) = ? ", $fecha);
        return $adapter->fetchAll($select);
    }
    
    public function getRowsByNaveId($nave_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ai' => 'auditorias_internas'), array('ai.*', 'DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento DAY) AS fecha_vencimiento'))
               ->join(array('aip' => 'auditorias_internas_prioridades'), 'aip.id=ai.prioridad_id', array('prioridad' => 'nombre', 'notificaciones_aviso', 'notificaciones_vencimiento')) 
               ->join(array('r' => 'sistema_usuarios'), 'r.id=ai.responsable_id', array('responsable' => 'nombre'))
               ->join(array('n' => 'naves'), 'n.id=ai.nave_id', array('nave' => 'nombre')) 
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=ai.area_id', array('area' => 'nombre')) 
               ->join(array('sui' => 'sistema_usuarios'), 'sui.id=ai.ingreso_por', array('ingresada_por' => 'nombre'))
               ->joinLeft(array('suc' => 'sistema_usuarios'), 'suc.id=ai.cierre_por', array('cerrada_por' => 'nombre'))
               ->where("ai.nave_id=?", $nave_id)
               ->order("ai.id DESC");
        $rows = $adapter->fetchAll($select);
        
        if(count($rows) > 0 ) {
            
            $auditorias = array();
            $i = 0;
            foreach($rows as $row) {
                $auditorias[$i] = $row;
                $auditorias[$i]['num_archivos'] = $this->_getNumArchivos($row['id']);
                $i++;
            }
            
            return $auditorias;
        } 
        return NULL;
    }
   
    public function getNave()
    {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getRow()->nave_id);
        return $modelNave->getRowFull();
    }
    
    public function crear($data, $user)
    {
        $data['ingreso_por'] = $user;
        $data['ingreso_fecha'] = date("Y-m-d");
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
 
    public function editar($data, $user, $id)
    {
        $data['ingreso_por'] = $user;
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function cerrar($data, $user)
    {
        $data['cierre_por'] = $user;
        $data['cierre_fecha'] = date("Y-m-d");    
        if($data['cierre_informe'] !== '') {
            $data['cierre_informe'] = $data['cierre_informe'];    
        } else {
            $data['cierre_informe'] = NULL;    
        }
        $data['estado'] = 'TERMINADA';
        $row = $this->find($this->_id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - AuditoriaInterna::eliminar()");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        $dir = Zend_Registry::get('PATH_SERVER') . 'files/auditorias-internas/' . $this->_id ;
        $tempDir = Zend_Registry::get('PATH_SERVER') . 'tmp/' . date("YmdHis"); 
        
        try {
            
            if(is_dir($dir)){
                rename($dir, $tempDir);
            }
            $this->delete($where);
            
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function buscar($data, $privilegiosNaves = NULL)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ai' => 'auditorias_internas'), array('ai.*', 'DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento DAY) AS fecha_vencimiento'))
               ->join(array('aip' => 'auditorias_internas_prioridades'), 'aip.id=ai.prioridad_id', array('prioridad' => 'nombre')) 
               ->join(array('r' => 'sistema_usuarios'), 'r.id=ai.responsable_id', array('responsable' => 'nombre'))
               ->join(array('n' => 'naves'), 'n.id=ai.nave_id', array('nave' => 'nombre')) 
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'))  
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=ai.area_id', array('area' => 'nombre')) 
               ->join(array('sui' => 'sistema_usuarios'), 'sui.id=ai.ingreso_por', array('ingresada_por' => 'nombre'))
               ->joinLeft(array('suc' => 'sistema_usuarios'), 'suc.id=ai.cierre_por', array('cerrada_por' => 'nombre'))  
               ->order("ai.nave_id")
               ->order("ai.id DESC");
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        if($data['nave']!='') {
            $select->where("ai.nave_id=?", $data['nave']);
        } elseif($privilegiosNaves !== NULL) {
            $navesIds = Shipcode_Model_SistemaUsuario::filtrarNavesAutorizadas($privilegiosNaves);
            $select->where("ai.nave_id IN($navesIds)");
        }
        if($data['area']!='') {
            $select->where("ai.area_id=?", $data['area']);
        }
        if($data['prioridad']!='') {
            $select->where("ai.prioridad_id=?", $data['prioridad']);
        }
        if($data['ingreso_desde']) {
            $select->where("ai.ingreso_fecha > ?", $data['ingreso_desde']);
        }
        if($data['ingreso_hasta']) {
            $select->where("ai.ingreso_fecha < ?", $data['ingreso_hasta']);
        }
        if($data['vencimiento_desde']) {
            $select->where("DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento DAY) > ?", $data['vencimiento_desde']);
        }
        if($data['vencimiento_hasta']) {
            $select->where("DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento DAY) < ?", $data['vencimiento_hasta']);
        }
        if($data['estado_cierre'] != 0) {
            if($data['estado_cierre'] == 1){
                $select->where("ai.estado = ?", 'PENDIENTE');
            } else if($data['estado_cierre'] == 2){
                $select->where("ai.estado = ?", 'TERMINADA');
            }
        }
        if($data['estado_vencimiento'] != 0) {
            if($data['estado_vencimiento'] == 1){
                $select->where("ai.estado ='PENDIENTE' AND now() >= DATE_ADD(ingreso_fecha, INTERVAL aip.dias_aviso DAY) AND now() < DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento DAY)");
            } else if($data['estado_vencimiento'] == 2){
                $select->where("ai.estado ='PENDIENTE' AND now() > DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento DAY)");
            }
        }
        return $adapter->fetchAll($select);
    }
    
    public function getHtmlToPdf($rows)
    {
        $content = '<h1>Auditorias internas</h1>'
                 . '<p class="text-muted">Realizado el ' . Shipcode_Model_Fecha::format(date("Y-m-d")) . ', a las ' . date("H:i") . '</p>'
                 . '<hr>'
                 . '<p>Se encontraron ' . count($rows) . ' resultados</p>'
                 . '<table border="1" cellpadding="4" cellspacing="0" style="font-size:11px;width:100%;"><thead><tr>'
                 . '<th>Empresa</th>'
                 . '<th>Nave</th>'
                 . '<th>Título</th>'
                 . '<th>Prioridad</th>'
                 . '<th>Ingreso</th>'
                 . '<th>Vencimiento</th>'
                 . '<th>Responsable</th>'
                 . '<th>Cierre</th>'
                 . '<th>Estado</th>'
                 . '</tr></thead><tbody>';
        
        if(count($rows) > 0) {
            foreach($rows as $auditoria) { 
                
                $content .= '<tr>'
                          . '<td>' . $auditoria['empresa'] . '</td>'  
                          . '<td>' . $auditoria['nave'] . '</td>'
                          . '<td>' . $auditoria['titulo'] . '</td>'
                          . '<td>' . $auditoria['prioridad'] . '</td>'
                          . '<td>' . Shipcode_Model_Fecha::format($auditoria['ingreso_fecha']) . '</td>'
                          . '<td>' . Shipcode_Model_Fecha::format($auditoria['fecha_vencimiento']) . '</td>'
                          . '<td>' . $auditoria['responsable'] . '</td>';
                
                if($auditoria['estado'] === 'PENDIENTE'){ 
                   $content .= '<td>----</td>';
                } else {
                   $content .= '<td>' . Shipcode_Model_Fecha::format($auditoria['cierre_fecha']) . '</td>';
                }

                $content .= '<td>' . $auditoria['estado'] . '</td>';
                
                $content .= '</tr>';
            } 
        } else {
            $content .= '<tr><td colspan="10">No se encontraron registros coincidentes para su búsqueda.</td></tr>';
        }
        
        $content .= '</table></div></tbody></html>';
        
        return $content;
    }
    
    public function getCountPorVencer($empresa_id = NULL)
    {
        $adapter = $this->getAdapter();
        if($empresa_id != NULL){
            $sql = "SELECT COUNT(*) FROM auditorias_internas AS ai "
                 . "JOIN naves AS n ON ai.nave_id=n.id "   
                 . "JOIN auditorias_internas_prioridades AS aip ON aip.id=ai.prioridad_id "
                 . "WHERE n.empresa_id='$empresa_id' "   
                 . "AND now() >= DATE_ADD(ingreso_fecha, INTERVAL aip.dias_aviso) " 
                 . "AND now() < DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento) " 
                 . "ORDER BY ai.id DESC";
        } else {
            $sql = "SELECT COUNT(*) FROM auditorias_internas AS ai "
                 . "JOIN auditorias_internas_prioridades AS aip ON aip.id=ai.prioridad_id " 
                 . "AND now() >= DATE_ADD(ingreso_fecha, INTERVAL aip.dias_aviso DAY) " 
                 . "AND now() < DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento DAY) " 
                 . "ORDER BY ai.id DESC";
        }
        $num = $adapter->fetchOne($sql);
        if($num){
            return $num;
        } 
        return 0;
    }
    
    public function getCountVencidos($empresa_id = NULL)
    {
        $adapter = $this->getAdapter();
        
        if($empresa_id != NULL){
            $sql = "SELECT COUNT(ai.id) FROM auditorias_internas AS ai "
                 . "JOIN naves AS n ON ai.nave_id=n.id "   
                 . "JOIN auditorias_internas_prioridades AS aip ON aip.id=ai.prioridad_id "
                 . "WHERE n.empresa_id='$empresa_id' "          
                 . "AND now() >= DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento DAY) " 
                 . "ORDER BY ai.id DESC";
        } else {
            $sql = "SELECT COUNT(ai.id) FROM auditorias_internas AS ai " 
                 . "JOIN auditorias_internas_prioridades AS aip ON aip.id=ai.prioridad_id "
                 . "AND now() >= DATE_ADD(ingreso_fecha, INTERVAL aip.dias_vencimiento DAY) " 
                 . "ORDER BY ai.id DESC";
        }
        
        $num = $adapter->fetchOne($sql);
        if($num){
            return $num;
        } 
        return 0;
    }
    
    /**************** FUNCIONES RELACIONADAS A LOS ARCHIVOS *******************/
    public static function getNumArchivos($id)
    {
        return self::_getNumArchivos($id);
    }
    
    public function getArchivos()
    {
        $archivo = new Shipcode_Model_AuditoriaInternaArchivo();
        return $archivo->getRowsByAuditoriaId($this->_id);
    }
    
    public function guardarArchivo($data, $user)
    {
        $archivo = new Shipcode_Model_AuditoriaInternaArchivo();
        return $archivo->crear($data, $user);
    }
    
    public function editarArchivo($data, $user)
    {
        $archivo = new Shipcode_Model_AuditoriaInternaArchivo();
        return $archivo->editar($data, $user);
    }
    
    private function _getNumArchivos($id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT COUNT(*) FROM auditorias_internas_archivos WHERE auditoria_id='$id'";
        $result = $adapter->fetchOne($sql);
        if($result > 0) {
            return $result;
        }
        return 0;
    }
}