<?php
class Shipcode_Model_BasePlanMant extends Zend_Db_Table_Abstract
{
    protected $_name = 'base_planesmant';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = (int)$id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getAll($tipo_id = NULL)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select();
        $select->from(array('p' => 'base_planesmant'), array('id', 'creacion', 'creador', 'tipo_id', 'nombre', 'observaciones', 'estado'))
               ->join(array('t' => 'equipos_tipos'), 't.id=p.tipo_id', array('tipo_equipo' => 'nombre')) 
               ->joinLeft(array('e' => 'naves_equipos'), 'e.planmant_id=p.id', array('num_equipos' => 'COUNT(e.id)'))  
               ->order("t.nombre");
        if(NULL != $tipo_id){
            $select->where("p.tipo_id=?", $tipo_id);
        }
        $select->group("p.id");
        return $adapter->fetchAll($select);
    }
    
    public function getPlanesSugeridos($tipo_id )
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select();
        $select->from(array('p' => 'base_planesmant'), array('id', 'creacion', 'creador', 'tipo_id', 'nombre', 'observaciones', 'estado'))
               ->join(array('t' => 'equipos_tipos'), 't.id=p.tipo_id', array('tipo_equipo' => 'nombre')) 
               ->order("t.nombre")
               ->where("p.tipo_id=? AND estado='HABILITADO'", $tipo_id);
        return $adapter->fetchAll($select);
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select();
        $select->from(array('p' => 'base_planesmant'), array('id', 'creacion', 'creador', 'tipo_id', 'nombre', 'observaciones', 'estado'))
               ->join(array('t' => 'equipos_tipos'), 't.id=p.tipo_id', array('tipo_equipo' => 'nombre')) 
               ->where("p.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    //  -> Función duplicada con getRowFull();
    public function getRowFullToEquipo()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('p' => 'base_planesmant'), array('id', 'creacion', 'creador', 'tipo_id', 'nombre', 'observaciones', 'estado'))
               ->join(array('t' => 'equipos_tipos'), 't.id=p.tipo_id', array('tipo_equipo' => 'nombre')) 
               ->where("p.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getItems()
    {
        $item = new Shipcode_Model_BasePlanMantItem();
        return $item->getRowsByPlanId($this->_id);
    }
    
    public function getItemsParaBusqueda($data)
    {
        $item = new Shipcode_Model_BasePlanMantItem();
        return $item->getRowsByPlanIdParaBusqueda($this->_id, $data);
    }
    
    public function getServiciosByEquipoIdToSelect($equipo_id = 0)
    {
        $item = new Shipcode_Model_BasePlanMantItem();
        return $item->getServiciosByPlanIdToSelect($equipo_id);
    }
    
    public function getItemsToEquipo()
    {
        $item = new Shipcode_Model_BasePlanMantItem();
        return $item->getRowsToEquipoByPlanId($this->_id);
    }
   
    public function getEquiposAsociados()
    {
        $equipo = new Shipcode_Model_NaveEquipo();
        return $equipo->getRowsByPlanmantId($this->_id);
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        if($data['observaciones'] == '') { $data['observaciones'] = NULL; }
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data,$id)
    {
        if($data['observaciones'] == '') { $data['observaciones'] = NULL; }
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function habilitar()
    {
        $row = $this->getRow();
        $row->estado = 'HABILITADO';
        $row->save();
    }
    
    public function deshabilitar()
    {
        $row = $this->getRow();
        $row->estado = 'DESHABILITADO';
        $row->save();
    }
    
    public function clonar($user)
    {
        $original = $this->getRow()->toArray();
        $original['nombre']  = $original['nombre'] . ' - 2';
        unset($original['creador']);
        unset($original['id']);
        
        $nuevo_id = $this->crear($original, $user);
        $items = $this->getItems();
        if(count($items) > 0 ){
            $modelItem = new Shipcode_Model_BasePlanMantItem();
            foreach($items as $item){
                $dataNuevoItem['servicio_id'] = $item->servicio_id;
                $dataNuevoItem['plan_id'] = $nuevo_id;
                $dataNuevoItem['periodo_id'] = $item->periodo_id;
                $dataNuevoItem['cantidad_dias'] = $item->cantidad_dias;
                $dataNuevoItem['cantidad_horas'] = $item->cantidad_horas;
                $dataNuevoItem['dias_aviso'] = $item->dias_aviso;
                $modelItem->crear($dataNuevoItem, $user);        
            }
        }
        return $nuevo_id;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Eliminar Servicio");
        }
        
        try {
            $actividad = new Shipcode_Model_NaveActividad();
            if($actividad->eliminarEventosAsociadosAlPlan($this->_id)){
                $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
                $this->delete($where);
            }
            
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function eliminarItem($id)
    {
        $item = new Shipcode_Model_BasePlanMantItem();
        $item->setId($id);
        $dataItem = $item->getRow()->toArray();
        
        $actividad = new Shipcode_Model_NaveActividad();
        if($actividad->eliminarEventosAsociadosAlItem($dataItem)){
            $item->eliminar();
            return $dataItem['plan_id'];
        }
        return FALSE;
    }
    
    public static function getPairsToSelect()
    {
        $adapter = self::getDefaultAdapter();
        $sql = 'SELECT id, nombre FROM base_planesmant ORDER BY nombre';
        return $adapter->fetchPairs($sql);
    }
    
    /* 
     * EN PROCESO DE ELIMINACIÓN
    public static function getItemsIdToReset($equipoId, $idItemsExcluir)
    {
        $planId = self::_getIdByEquipoId($equipoId);
        $modelItems = new Shipcode_Model_BasePlanMantItem();
        return $modelItems->getRowsIdByPlanIdToReset($planId, $idItemsExcluir);
    }
    
    
    
    private function _getIdByEquipoId($equipoId)
    {
        $modelEquipo = new Shipcode_Model_NaveEquipo();
        $modelEquipo->setId($equipoId);
        return $modelEquipo->getRow()->planmant_id;
    } 
    */
}