<?php
class Shipcode_Model_BasePlanMantItem extends Zend_Db_Table_Abstract
{
    protected $_name = 'base_planesmant_items';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = (int)$id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getDetalle()
    {
        $servicio = new Shipcode_Model_BaseServicio();
        $servicio->setId($this->getRow()->servicio_id);
        return $servicio->getRow()->nombre;
    }
    
    public function getPlan()
    {
        $plan = new Shipcode_Model_BasePlanMant();
        $plan->setId($this->getRow()->plan_id);
        return $plan->getRow();
    }
    
    public function getPlanId()
    {
        return $this->getRow()->plan_id;
    }
    
    public function getRowsByPlanId($plan_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select();
        $select->from(array('i' => 'base_planesmant_items'), array(
                    'id', 'creacion', 'creador', 'servicio_id', 'plan_id', 'asignado_a', 
                    'asociar_proyecto', 'dias_aviso', 'cantidad_horas', 'cantidad_dias', 
                    'descripcion'))
               ->join(array('s' => 'base_servicios'), 's.id=i.servicio_id', array('servicio' => 'nombre')) 
               ->order("i.cantidad_horas DESC")  
               ->order("i.cantidad_dias DESC")   
               ->where("i.plan_id=?", $plan_id);
        return $adapter->fetchAll($select);
    }
    
    public function getRowsByPlanIdParaBusqueda($plan_id, $data)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('i' => 'base_planesmant_items'), array(
                    'id', 'servicio_id', 'dias_aviso', 'cantidad_horas', 'asignado_a',
                    'cantidad_dias', 'descripcion'))
               ->join(array('s' => 'base_servicios'), 's.id=i.servicio_id', array('servicio' => 'nombre')) 
               ->where("i.plan_id=?", $plan_id);
        
        if($data['servicio'] != ''){
            $select->where("i.servicio_id='" . $data['servicio'] . "'");
        }
       
        return $adapter->fetchAll($select);
    }
    
    public function getServiciosByPlanIdToSelect($equipo_id = 0)
    {
        $optionsEquipo = array('table' => 'naves_equipos', 'field' => 'id');
        $validadorEquipo = new Zend_Validate_Db_RecordExists($optionsEquipo);
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT s.id, s.nombre FROM base_servicios s";
        if($equipo_id != 0 && $validadorEquipo->isValid($equipo_id)){
            $sql .= " JOIN base_planesmant_items i ON i.servicio_id=s.id ";
            $sql .= " JOIN naves_equipos e ON e.planmant_id = i.plan_id WHERE e.id='$equipo_id'";
        }
        $sql .= " ORDER BY s.nombre";
        return $adapter->fetchAll($sql);
        
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select();
        $select->from(array('i' => 'base_planesmant_items'), array(
                    'id', 'creacion', 'creador', 'servicio_id', 'plan_id', 'asignado_a',
                    'dias_aviso', 'cantidad_horas', 'cantidad_dias', 'descripcion'))
               ->join(array('s' => 'base_servicios'), 's.id=i.servicio_id', array('servicio' => 'nombre')) 
               ->where("i.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getRowsToEquipoByPlanId($plan_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('i' => 'base_planesmant_items'), array(
                    'id', 'servicio_id', 'plan_id', 'dias_aviso', 'asignado_a',
                    'cantidad_horas', 'cantidad_dias', 'descripcion'))
               ->join(array('s' => 'base_servicios'), 's.id=i.servicio_id', array('servicio' => 'nombre', 'destacar')) 
               ->where("i.plan_id=?", $plan_id)
               ->order("i.cantidad_horas DESC")
               ->order("i.cantidad_dias DESC");
        return $adapter->fetchAll($select);
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        
        if($data['cantidad_horas'] == '' && $data['cantidad_dias'] == ''){
            throw new Exception('No ha ingresado un período en días ni horas.');
        }
        
        if(!in_array($data['asignado_a'], array('NAVE', 'EXTERNO'))){
            $data['asignado_a'] = 'NAVE';
        }
        
        if($data['cantidad_horas'] == '') { $data['cantidad_horas'] = NULL; }
        if($data['cantidad_dias'] == '') { $data['cantidad_dias'] = NULL; }
        if($data['descripcion'] == '') { $data['descripcion'] = NULL; }
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $this->_programarEnEquiposAsociadosAlPlan($row, $user);
    }
    
    public function editar($data, $id, $user)
    {
        if($data['cantidad_horas'] == '' && $data['cantidad_dias'] == ''){
            throw new Exception('No ha ingresado un período en días ni horas.');
        }
        
        if(!in_array($data['asignado_a'], array('NAVE', 'EXTERNO'))){
            $data['asignado_a'] = 'NAVE';
        }
        
        if($data['cantidad_horas'] == '') { $data['cantidad_horas'] = NULL; }
        if($data['cantidad_dias'] == '') { $data['cantidad_dias'] = NULL; }
        if($data['descripcion'] == '') { $data['descripcion'] = NULL; }
        
        $row = $this->find($id)->current();
        $dataAnterior = $row->toArray();
        
        $row->setFromArray($data);
        $row->save();
        if($dataAnterior['cantidad_horas'] != $data['cantidad_horas'] 
                || $dataAnterior['cantidad_dias'] != $data['cantidad_dias']){
            return $this->_reprogramarEnEquiposAsociadosAlPlan($row->toArray(), $user);
        }
        return TRUE;
    }
    
    public function configResponsable($asignado_a = NULL)
    {
        if(!in_array($asignado_a, array('NAVE', 'EXTERNO'))){
            $asignado_a = 'NAVE';
        }
        $row = $this->getRow();
        $row->asignado_a = $asignado_a;
        $row->save();
    }
    
    
    /*
     * Cuando se agrega un ítem a un plan que ya está asignado a equipos
     * es necesario programar los eventos que corresponden    
     */
    private function _programarEnEquiposAsociadosAlPlan($itemPlan, $user)
    {
        $modelEquipo = new Shipcode_Model_NaveEquipo();
        $equipos = $modelEquipo->getRowsByPlanmantId($itemPlan->plan_id);
        if(count($equipos) > 0 ) {
            $modelEvento = new Shipcode_Model_NaveActividad();
            foreach($equipos as $equipo){
                $modelEquipo->setId($equipo['id']);
                $dataEquipo = $modelEquipo->getRow();
                $infoHorometroParaCalculo = $modelEquipo->getInfoHorometroParaCalculo($dataEquipo);
                $ultimoServicio = $modelEquipo->getUltimoServicio($itemPlan->servicio_id);
                $modelEvento->programarNuevoEvento($itemPlan, $dataEquipo , $user, $ultimoServicio, $infoHorometroParaCalculo);
            }
        }
        return TRUE;
    }
    
    /*
     * Cuando se edita un ítem de un plan de mantenimiento que ya está asignado 
     * a equipos es necesario resetear los eventos asociados
     */
    private function _reprogramarEnEquiposAsociadosAlPlan($itemPlan, $user)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT id FROM naves_equipos WHERE planmant_id='" . $itemPlan['plan_id'] . "'";
        $equipos = $adapter->fetchAll($sql, NULL, Zend_Db::FETCH_ASSOC);
        
        if(count($equipos) > 0 ) {
            $modelEvento = new Shipcode_Model_NaveActividad();
            foreach($equipos as $equipo){
                $sqlEventos = "SELECT id FROM naves_actividades WHERE estado='0' AND programacion='AUTOMATICA' AND equipo_id='" . $equipo['id'] . "' AND servicio_id='" . $itemPlan['servicio_id'] . "'";
                $eventosParaActualizar = $adapter->fetchAll($sqlEventos, NULL, Zend_Db::FETCH_ASSOC);
                $modelEvento->resetearEventos($eventosParaActualizar, $user);
            }
        }
        return TRUE;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Eliminar Item Plan de Mantenimiento");
        }
        
        try {
            
            $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
            $this->delete($where);
            
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getRowFullByServicioIdAndPlanId($servicio_id, $plan_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select();
        $select->from(array('i' => 'base_planesmant_items'), array(
                    'id', 'creacion', 'creador', 'servicio_id', 'plan_id', 'asignado_a',
                    'dias_aviso', 'cantidad_horas', 'cantidad_dias', 'descripcion'))
               ->join(array('s' => 'base_servicios'), 's.id=i.servicio_id', array('servicio' => 'nombre'))  
               ->where("i.plan_id=?", $plan_id)
               ->where("i.servicio_id=?", $servicio_id);
        $row = $adapter->fetchRow($select);
        if($row){
            return $row;
        }
        return FALSE;
    }
    
    public function getRowByServicioIdAndPlanId($servicio_id, $plan_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select();
        $select->from(array('i' => 'base_planesmant_items'), array(
                    'id', 'creacion', 'creador', 'servicio_id', 'plan_id', 'asignado_a', 
                    'asociar_proyecto', 'dias_aviso', 'cantidad_horas', 'cantidad_dias', 
                    'descripcion'))
               ->where("i.plan_id=?", $plan_id)
               ->where("i.servicio_id=?", $servicio_id);
        $row = $adapter->fetchRow($select);
        if($row){
            return $row;
        }
        return FALSE;
    }
    
    public function verificarDependenciaServicio($servicio_id)
    {
        $where = $this->getAdapter()->quoteInto("servicio_id=?", $servicio_id);
        $rows = $this->fetchAll($where);
        if(count($rows) > 0 ) {
            return TRUE;
        }
        return FALSE;
    }
    
    /* En proceso de eliminación
    // Revisada OK √
    public function verificarDependenciaPeriodo($periodo_id)
    {
        $where = $this->getAdapter()->quoteInto("periodo_id=?", $periodo_id);
        $rows = $this->fetchAll($where);
        if(count($rows) > 0 ) {
            return TRUE;
        }
        return FALSE;
    }
   
    public function getRowsIdByPlanIdToReset($plan_id, array $idItemsExcluir)
    {
        $idItemsExcluir = implode(",", $idItemsExcluir);
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('i' => 'base_planesmant_items'), 
                    array(
                        'id', 'creacion', 'creador', 
                        'servicio_id', 'plan_id', 'resetear'
                ))
               ->join(array('s' => 'base_servicios'), 's.id=i.servicio_id', array('servicio' => 'nombre')) 
               ->join(array('p' => 'base_periodos'), 'p.id=i.periodo_id', array('dias_aviso', 'cantidad_horas', 'cantidad_dias'))   
               ->where("i.plan_id=?", $plan_id)
               ->where("i.id NOT IN ($idItemsExcluir)");
        return $adapter->fetchAll($select);
    }
     
    public function configurarPeriodosItems()
    {
        $adapter = $this->getAdapter();
        $sqlItems = "SELECT id, periodo, unidad_medida FROM base_planesmant_items";
        $dataItems = $adapter->fetchAll($sqlItems);
        
        foreach($dataItems as $dataItem){
            $this->_asignarPeriodo($dataItem);
        }
    }
    
    private function _asignarPeriodo($dataItem)
    {
        $row = $this->find($dataItem['id'])->current();
        $row->periodo_id = $this->_getPeriodo($dataItem);
        $row->save();
    }
    
    private function _getPeriodo($dataItem)
    {
        $modelPeriodo = new Shipcode_Model_BasePeriodo();
        return $modelPeriodo->getPeriodoIdParaItem($dataItem);
    }
    */
}