<?php
class Shipcode_Model_BaseServicio extends Zend_Db_Table_Abstract
{
    protected $_name = 'base_servicios';
    protected $_primary = 'id';
    
    private $_id;
    
    // Revisada OK √
    public function setId($id)
    {
        $this->_id = (int)$id;
    }

    // Revisada OK √
    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    // Revisada OK √
    public function getAll($all = FALSE)
    {
        $where = NULL;
        if($all == FALSE){
            $where = $this->getAdapter()->quoteInto("mostrar=?", 1);
        }
        return $this->fetchAll($where, 'nombre');
    }
    
    // Revisada OK √
    public function crear($data)
    {
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    // Revisada OK √
    public function editar($data,$id)
    {
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    // Revisada OK √
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Eliminar Servicio");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        if($this->_planesAsociados() == TRUE){
            throw new Exception('No se puede eliminar el servicio porque está asociado a planes de mantenimiento.');
        }
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    // Revisada OK √
    private function _planesAsociados()
    {
        $itemPlan = new Shipcode_Model_BasePlanMantItem();
        return $itemPlan->verificarDependenciaServicio($this->_id);
    }
    
    // Revisada OK √
    public static function getPairsToSelect()
    {
        $adapter = self::getDefaultAdapter();
        $sql = 'SELECT id, nombre FROM base_servicios ORDER BY nombre';
        return $adapter->fetchPairs($sql);
    }
    
    // Revisada OK √
    public function getOtrosServicios($plan_id, $criterio = NULL)
    {
        $optionsPlan = array('table' => 'base_planesmant', 'field' => 'id');
        $validadorPlan = new Zend_Validate_Db_RecordExists($optionsPlan);
        
        if($validadorPlan->isValid($plan_id)){
            
            $sql = "SELECT * FROM base_servicios "
                 . "WHERE id NOT IN(SELECT servicio_id FROM base_planesmant_items WHERE plan_id='$plan_id')";
            if($criterio != NULL ){
                $like = $this->getAdapter()->quote("%" . $criterio . "%");
                $sql .= " AND nombre LIKE $like";
            }
                
        } else {
            
            $sql = "SELECT * FROM base_servicios";
            if($criterio != NULL ){
                $like = $this->getAdapter()->quote("%" . $criterio . "%");
                $sql .= " WHERE nombre LIKE $like";
            }
        }
        
        $sql .= " ORDER BY base_servicios.nombre";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        return $adapter->fetchAll($sql);
    }
            
    // Revisada Ok √
    public function codificarDatos()
    {
        $i = 0;
        try {
            $rows = $this->fetchAll();
            foreach($rows as $row){
                $row->nombre = utf8_encode($row->nombre);
                $row->save();
                $i++;
            }
            return "Se actualizaron los datos de $i trabajos de mantenimiento";
        } catch(Exception $e){
            return $e->getMessage();
        }
    }
}