<?php
class Shipcode_Model_BaseSistema extends Zend_Db_Table_Abstract
{
    protected $_name = 'base_sistemas';
    protected $_primary = 'id';
    private $_id = NULL;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - getRow()");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getRuta()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - getRuta()");
        }
        
        $row = $this->getRow();
        if(NULL!=$row->padre_id){
            return $this->_getNombre($row->padre_id, $row->nombre);
        } else {
            return $row->nombre;
        }
        
    }
    
    public function getAll()
    {
        $sistemas = array();
        $rows = $this->fetchAll("padre_id IS NULL")->toArray();
        
        foreach($rows as $row){
            $row['subsistemas'] = $this->_getSubsistemas($row['id']);
            $sistemas[] = $row;
        }
        return $sistemas;
    }
    
    private function _getSubsistemas($padre_id)
    {
        $where = $this->getAdapter()->quoteInto("padre_id=?", $padre_id);
        return $this->fetchAll($where)->toArray();
    }
    
    public function crear($data, $user)
    {
        if($data['padre_id']=='0'){$data['padre_id']= NULL; } 
        $data['creador'] = $user;
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editar($data, $user, $id)
    {
        if($data['padre_id']=='0'){ $data['padre_id']= NULL; }
        $data['creador'] = $user;
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public static function getPairsToSelect($id = NULL)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT id, nombre FROM base_sistemas ";
        if($id != NULL) {
            $sql .= "WHERE id!='$id' AND padre_id IS NULL ORDER BY id";
        } else {
            $sql .= "WHERE padre_id IS NULL ORDER BY id";
        }
        
        return $adapter->fetchPairs($sql);
    }
    
    public function getPairsSecundariosToSelect()
    {
        //$sistemas = array();
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT id, nombre FROM base_sistemas WHERE padre_id IS NOT NULL ORDER BY id";
        $rows = $adapter->fetchPairs($sql);
        return $rows;
    }
    
    private function _getNombre($id, $nombre)
    {
        $adapter = $this->getAdapter();
        $where = $adapter->quoteInto("id=?", $id);
        
        $row2 = $adapter->fetchRow($where);
        if($row2){
            $nombreFinal = $row2->nombre . ' > ' . $nombre;
        }
        
        if(NULL!==$row2->padre_id){
            $where = $adapter->quoteInto("id=?", $row2->padre_id);
            $row3 = $adapter->fetchRow($where);
            if($row3){
                $nombreFinal = $row3->nombre . ' > ' . $nombreFinal;
            }
        }
        return $nombreFinal;
    }
}