<?php
class Shipcode_Model_Empresa extends Zend_Db_Table_Abstract
{
    protected $_name = 'empresas';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = (int)$id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    

    public function getRowFull()
    {
        $row = $this->getRow()->toArray();
        return $row;
    }
    
    public function getSupervisores()
    {
        $modelUsuario = new Shipcode_Model_SistemaUsuario();
        return $modelUsuario->getSupervisoresByEmpresaId($this->_id);
    }
    
    public function getSupervisoresId()
    {
        $supervisoresIds = array();
        $supervisores = $this->getSupervisores();
        if(count($supervisores) > 0){
            foreach($supervisores as $supervisor){
                $privilegios = Zend_Json::decode($supervisor);
                $empresas = $privilegios['autorizaciones']['empresas'];
                if(count($empresas) > 0){
                    foreach($empresas as $id => $autorizacion){
                        if($autorizacion == 1){
                            $supervisoresIds[] = $id;
                        }
                    }
                }
            }
        }
        return $supervisoresIds;
    }
    
    public function getAll()
    {
        //$modelUsuario = new Shipcode_Model_SistemaUsuario();
        $modelNave = new Shipcode_Model_Nave();
        
        $rows = $this->fetchAll(null, 'nombre')->toArray();
        
        $empresas = array();
        
        foreach($rows as $row){
            $row['numNaves'] = $modelNave->getNumRowsByEmpresaId($row['id']);
            //$row['supervisores'] = $modelUsuario->getSupervisoresByEmpresaId($row['id']);
            $empresas[] = $row;

        }
        return $empresas;
    }
    
    public function getHorometrosActivos()
    {
        $empresas = $this->fetchAll(null, 'nombre')->toArray();
        $modelNave = new Shipcode_Model_Nave();
        $dataEmpresas = array();
        foreach($empresas as $empresa){
            $naves = $modelNave->getRowsByEmpresaId($empresa['id']);
            if(count($naves) > 0){
                foreach($naves as $nave){
                    $modelNave->setId($nave['id']);
                    $sistemas = $modelNave->getSistemasConHorometros();
                    if(count($sistemas) > 0){
                        $nave["sistemas"] = $sistemas;
                        $empresa['naves'][] = $nave;
                    }
                }
            }
            $dataEmpresas[] = $empresa;
        }
        return $dataEmpresas;
    }
    
    public function getIndiceNaves($empresa_id = NULL)
    {
        if($empresa_id != NULL){
            $where = $this->getAdapter()->quoteInto("id=?", $empresa_id);
            $rows = $this->fetchAll($where, 'nombre')->toArray();
        } else {
            $rows = $this->fetchAll(null, 'nombre')->toArray();
        }
            
        $modelNave = new Shipcode_Model_Nave();
        $empresas = array();
        
        foreach($rows as $row){
            $row['naves'] = $modelNave->getRowsByEmpresaId($row['id']);
            $empresas[] = $row;
        }
        return $empresas;
    }
    
    public function crear($data, $user)
    {
        $row = $this->createRow();
        $data['creador'] = $user;
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $user, $id)
    {
        $data['creador'] = $user;
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function configurarSupervisores($data, $user)
    {
        $modelUsuario = new Shipcode_Model_SistemaUsuario();
        $supervisores = $modelUsuario->getSupervisores();
        $empresasId = Shipcode_Model_Empresa::getAllId();
        $adapter = $this->getAdapter();
        $adapter->beginTransaction();
        
        try {
            
            foreach($supervisores as $supervisor){
                
                $privilegios = Zend_Json::decode($supervisor->privilegios);
                $empresasAutorizadas = $privilegios['autorizaciones']['empresas'];
                   
            }
            
            $adapter->commit();
            
        } catch(Exception $e){
            $adapter->rollBack();
            return $e->getMessage();
        }
    }
    
    public function configurarUsuariosOperaciones($data, $user)
    {
        $modelUsuario = new Shipcode_Model_SistemaUsuario();
        $usuariosOperaciones = $modelUsuario->getUsuariosOperaciones();
        $empresaOperaciones = new Shipcode_Model_EmpresaOperaciones();
        
        $adapter = $this->getAdapter();
        $adapter->beginTransaction();
        
        try {
            
            $empresaOperaciones->eliminarPorEmpresa($data['empresa_id']);
            
            foreach($usuariosOperaciones as $usuarioOperaciones){
                
                if($data[$usuarioOperaciones['id']] && $data[$usuarioOperaciones['id']] == '1'){
                    
                    $empresaOperaciones->crear(array(
                        'creador' => $user,
                        'usuario_id' => $usuarioOperaciones['id'],
                        'empresa_id' => $data['empresa_id']
                    ));
                }
            }
            
            $adapter->commit();
            
        } catch(Exception $e){
            $adapter->rollBack();
            return $e->getMessage();
        }
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Eliminar Nave");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getNumNaves()
    {
        $adapter = $this->getAdapter();
        $empresa_id = $adapter->quote($this->_id);
        $sql = "SELECT COUNT(*) FROM naves WHERE empresa_id=$empresa_id";
        return $adapter->fetchOne($sql);
    }
    
    public function getNaves()
    {
        $modelNave = new Shipcode_Model_Nave();
        return $modelNave->getRowsByEmpresaId($this->_id);
    }
    
    public static function getNavesId($empresa_id)
    {
        $nave = new Shipcode_Model_Nave();
        return $nave->getIdsPorEmpresaId($empresa_id);
    }
    
    public static function getPairsToSelect()
    {
        $adapter = self::getDefaultAdapter();
        $sql = 'SELECT id, nombre FROM empresas ORDER BY id';
        return $adapter->fetchPairs($sql);
    }
    
    public static function getPrimeraId()
    {
        $adapter = self::getDefaultAdapter();
        $sql = 'SELECT id FROM empresas ORDER BY id LIMIT 1';
        return $adapter->fetchOne($sql);
    }
    
    public static function getNavesToMenuByEmpresaId($empresa_id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT id, nombre FROM naves WHERE empresa_id='$empresa_id'";
        return $adapter->fetchAll($sql);
    }
    
    /*
    public static function getAllId()
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT id FROM sistema_usuarios WHERE tipo='2'";
        return $adapter->fetchCol($sql);
    }
    */
}