<?php
class Shipcode_Model_ListaVerificacionItem extends Zend_Db_Table_Abstract
{
    protected $_name = 'listas_verificacion_items';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = (int)$id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getListaId()
    {
        return $this->getRow()->lista_id;
    }
    
    public function getLista()
    {
        $lista = new Shipcode_Model_ListaVerificacion();
        $lista->setId($this->getListaId());
        return $lista->getRow();
    }
    
    public function getRowsByListaId($lista_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select();
        $select->from(array('i' => $this->_name), array('id', 'lista_id', 'nombre', 'descripcion', 'opcion_id'))
               ->join(array('o' => 'listas_verificacion_opciones_respuestas'), 'o.id=i.opcion_id', array('respuestas')) 
               ->order("i.lugar")  
               ->where("i.lista_id=?", $lista_id);
        return $adapter->fetchAll($select);
    }
    
    public function crear($data)
    {
        $data['lugar'] = $this->_getLugar();
        if($data['descripcion'] == '') { $data['descripcion'] = NULL; }
        $row = $this->createRow();
        $row->setFromArray($data);
        return $row->save();
    }
    
    public function editar($data, $id)
    {
        if($data['descripcion'] == '') { $data['descripcion'] = NULL; }
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        return $row->save();
    }
    
    public function setOrden($data)
    {
        $i = 1;
        $ids = explode(",", $data);
        foreach($ids as $id){
            $this->_setLugar($id, $i);
            $i++;
        }
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - ListaVerificacionItem::eliminar()");
        }
        
        try {
            
            $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
            $this->delete($where);
            
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    private function _setLugar($id, $lugar)
    {
        $tipo = $this->find($id)->current();
        if($tipo){
            $tipo->lugar = $lugar;
            $tipo->save();
        }
    }
    
    private function _getLugar()
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT MAX(lugar) FROM $this->_name";
        $ultimaPagina = $adapter->fetchOne($sql);
        if($ultimaPagina){
            return $ultimaPagina + 1;
        } else {
            return 1;
        }
    }
}