<?php
class Shipcode_Model_MantenimientoInformado extends Zend_Db_Table_Abstract
{
    protected $_name = 'mantenimientos_informados';
    protected $_primary = 'id';
    
    private $_id;
    
    private function _validarId($id)
    {
        $optiosnMantenimientoInformado = array('table' => $this->_name, 'field' => $this->_primary);
        $validadorMantenimientoInformado = new Zend_Validate_Db_RecordExists($optiosnMantenimientoInformado);
        
        if($validadorMantenimientoInformado->isValid($id)){
            return TRUE;
        }
        return FALSE;
    }
    
    public function setId($id)
    {
        if($this->_validarId($id) == FALSE){
            throw new Exception('El ID del mantenimiento no existe');   
        }
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('mi' => 'mantenimientos_informados'), array('*'))
               ->join(array('ne' => 'naves_equipos'), 'ne.id=mi.equipo_id', array('equipo' => 'nombre'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array('ubicacion_id' => 'id', 'sistema_id', 'ubicacionv_id'))    
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array('sistema' => 'nombre', 'nave_id')) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre', 'empresa_id'))  
               ->join(array('s' => 'base_servicios'), 's.id=mi.servicio_id', array('servicio' => 'nombre'))
               ->where("mi.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getAsignaciones()
    {
        $mantenimientoEquipo = new Shipcode_Model_NaveEquipoMantenimiento();
        return $mantenimientoEquipo->getRowsByMantenimientoInformadoId($this->_id);
    }
    
    public function getNaveId()
    {
        return $this->getRow()->nave_id;
    }
    
    public function getAll( $estado = 0 )
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('mi' => 'mantenimientos_informados'), array('*'))
               ->join(array('ne' => 'naves_equipos'), 'ne.id=mi.equipo_id', array('equipo' => 'nombre'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array('ubicacion_id' => 'id', 'sistema_id', 'ubicacionv_id'))    
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array('sistema' => 'nombre', 'nave_id')) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre', 'empresa_id'))  
               ->join(array('s' => 'base_servicios'), 's.id=mi.servicio_id', array('servicio' => 'nombre'));
        if( $estado == 0 ){
            $select->where("mi.estado='0'");
        } 
        $select->order("mi.id DESC");
        return $adapter->fetchAll($select);
    }
    
    public function getByMes($dataMes = NULL, $nave_id = NULL)
    {
        if($dataMes === NULL || $dataMes === FALSE || !is_array($dataMes)){
            throw new Exception('No se ha enviado los datos del mes solicitado - MantenimientoInformado::getByMes()');
        }
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('mi' => 'mantenimientos_informados'), array('*'))
               ->join(array('ne' => 'naves_equipos'), 'ne.id=mi.equipo_id', array('equipo' => 'nombre'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array('ubicacion_id' => 'id', 'sistema_id', 'ubicacionv_id'))    
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array('sistema' => 'nombre', 'nave_id')) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre', 'empresa_id'))  
               ->join(array('s' => 'base_servicios'), 's.id=mi.servicio_id', array('servicio' => 'nombre'))
               ->where("YEAR(mi.fecha_envio)=?", $dataMes['year'])
               ->where("MONTH(mi.fecha_envio)=?", $dataMes['mes']); 
        if($nave_id !== NULL){
            $select->where("ns.nave_id=?", $nave_id);
        }
        $select->order("mi.id DESC");
        return $adapter->fetchAll($select);
    }
    
    public function getUltimaSemana($nave_id = NULL)
    {
        $hoy = new Zend_Date(date("Y-m-d"));
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('mi' => 'mantenimientos_informados'), array(
                    'id', 'nave_id', 'fecha_envio', 'equipo', 
                    'fecha', 'horas', 'detalles', 'estado'))
               ->join(array('n' => 'naves'), 'n.id=mi.nave_id', array('nave' => 'nombre'))
               ->where("mi.fecha_envio >= ?", $hoy->sub(1, Zend_Date::WEEK)->toString("yyyy-MM-dd"));
        if($nave_id !== NULL){
            $select->where("mi.nave_id=?", $nave_id);
        }
        $select->order("mi.id DESC");
        return $adapter->fetchAll($select);
    }
    
    public function buscar(array $data)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('mi' => 'mantenimientos_informados'), array('*'))
               ->join(array('ne' => 'naves_equipos'), 'ne.id=mi.equipo_id', array('equipo' => 'nombre'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array('ubicacion_id' => 'id', 'sistema_id', 'ubicacionv_id'))    
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array('sistema' => 'nombre', 'nave_id')) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre', 'empresa_id'))  
               ->join(array('s' => 'base_servicios'), 's.id=mi.servicio_id', array('servicio' => 'nombre'))
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'));
        
        if($data['estado'] == "0"){
            $select->where("mi.estado='0'");
        } elseif($data['estado'] == "1"){
            $select->where("mi.estado ='1'");
        } elseif($data['estado'] == "2"){
            $select->where("mi.estado ='2'");
        }
        
        if($data['desde'] != ''){
            $select->where("mi.fecha_envio >= ? ", $data['desde']);
        }
        
        if($data['hasta'] != ''){
            $select->where("mi.fecha_envio <= ? ", $data['hasta']);
        }

        if($data['empresa'] != 0){
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        
        if($data['nave'] != 0) {
            $select->where("ns.nave_id=?", $data['nave']);
        }
        
        if($data['sistema'] != 0) {
            $select->where("neu.sistema_id=?", $data['sistema']);
        }
        
        if($data['equipo'] != 0) {
            $select->where("mi.equipo_id=?", $data['equipo']);
        }
        
        $select->order("mi.id DESC")
               ->order("mi.equipo_id");
        
        return $adapter->fetchAll($select);
    }
    
    public function getNoAsignados()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('mi' => 'mantenimientos_informados'), array('*'))
               ->join(array('ne' => 'naves_equipos'), 'ne.id=mi.equipo_id', array('equipo' => 'nombre'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array('ubicacion_id' => 'id', 'sistema_id', 'ubicacionv_id'))    
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array('sistema' => 'nombre', 'nave_id')) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre', 'empresa_id'))  
               ->join(array('s' => 'base_servicios'), 's.id=mi.servicio_id', array('servicio' => 'nombre'))
               ->where("mi.estado='0'")
               ->order("mi.id DESC");
        return $adapter->fetchAll($select);
    }
    
    public function getNave()
    {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getRow()->nave_id);
        return $modelNave->getRowFull();
    }
    
    public function guardar($data, $user)
    {
        $data['creador'] = $user;
        $data['fecha_envio'] = date("Y-m-d");
        if($data['horas'] === '') { $data['horas'] = NULL; }
        
        if(isset($data['id']) && $this->_validarId($data['id']) == TRUE ){
            $row = $this->find($data['id'])->current();
        } else {
            $row = $this->createRow();
        }
        
        $row->setFromArray($data);
        $row->save();
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = (int)$estado;
        $row->save();
    }
    
    public function reabrir($id)
    {
        $row = $this->find($id)->current();
        $row->estado = 0;
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
}