<?php
class Shipcode_Model_Nave extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves';
    protected $_primary = 'id';
    
    private $_id;
    
    /************************ FUNCIONES CARENAS *******************************/
    public function crearCarena($user)
    {
        $modelCuentaCarena = new Shipcode_Model_CuentaCarena();
        if($modelCuentaCarena->numCuentas() == 0) {
            throw new Exception('No se han creado cuentas de carenas para imputar los gastos');
        }
        
        $data = array('nave_id' => $this->_id,'fecha' => '0000-00-00' );
        $modelCarena = new Shipcode_Model_NaveCarena();
        return $modelCarena->crear($data, $user);
    }
    
    public function getProximasCarenas($cant, $empresa_id = NULL)
    {
        $adapter = self::getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $sql = "SELECT nombre, sig_carena_mes, sig_carena_year FROM naves "
             . "WHERE sig_carena_mes IS NOT NULL ";
             
        if($empresa_id != NULL){
            $sql .= "AND empresa_id='$empresa_id' ";
        }
        
        $sql .= "ORDER BY sig_carena_year, sig_carena_mes "
              . "LIMIT $cant";;
        
        return $adapter->fetchAll($sql);
    }
    
    public function getCarenas()
    {
        $modelCarena = new Shipcode_Model_NaveCarena();
        return $modelCarena->getRowsByNaveId($this->_id);
    }
    
    public function actualizarProximaCarena($data, $user)
    {
        $row = $this->getRow();
        $row->sig_carena_mes = $data['sig_carena_mes'];
        $row->sig_carena_year = $data['sig_carena_year'];
        $row->save();
        $evento = new Shipcode_Model_NaveActividad();
        $evento->actualizarEventosAncladosEnCarena(array(
            'nave_id' => $this->_id, 
            'fecha' => $this->getFechaCarena()
        ), $user);
    }
    
    public function getFechaCarena()
    {
        $row = $this->getRow();
        $fecha = new Zend_Date("15-" . $row->sig_carena_mes . "-" . $row->sig_carena_year, "dd-M-yyyy");
        return $fecha->toString("yyyy-MM-dd");
    }
    /**************************************************************************/
    
    /************************ FUNCIONES CERTIFICADOS **************************/
    public function agregarCertificado($data, $user)
    {
        $modelCertificado = new Shipcode_Model_NaveCertificado();
        return $modelCertificado->crear($data, $user);
    }
    
    public function getCertificados()
    {
        $modelCertificado = new Shipcode_Model_NaveCertificado();
        return $modelCertificado->getRowsByNaveId($this->_id);
    }
    
    private function _clonarCertificados($id, $nueva_id, $user)
    {
        $modelCertificado = new Shipcode_Model_NaveCertificado();
        $certificados = $modelCertificado->getCertificadosToClone($id);
        
        if(count($certificados) > 0) {
            foreach($certificados as $certificado){
                $modelCertificado->clonar($certificado, $nueva_id, $user);
            }  
        }
    }
    /**************************************************************************/
    
    /*********************** FUNCIONES OBSERVACIONES **************************/
    public function agregarObservacion($data, $user)
    {
        $modelObservacion = new Shipcode_Model_NaveObservacion();
        return $modelObservacion->crear($data, $user);
    }
    
    public function getObservaciones()
    {
        $modelObservacion = new Shipcode_Model_NaveObservacion();
        return $modelObservacion->getRowsByNaveId($this->_id);
    }
    /**************************************************************************/
    
    /****************** FUNCIONES AUDITORIAS INTERNAS ***********************/
    public function agregarAuditoriaInterna($data, $user)
    {
        $modelAuditoriaInterna = new Shipcode_Model_AuditoriaInterna();
        return $modelAuditoriaInterna->crear($data, $user);
    }
    
    public function getAuditoriasInternas()
    {
        $modelAuditoriaInterna = new Shipcode_Model_AuditoriaInterna();
        return $modelAuditoriaInterna->getRowsByNaveId($this->_id);
    }
    /**************************************************************************/
    
    /************************* FUNCIONES SINIESTROS ***************************/
    public function registrarSiniestro($data, $user)
    {
        $modelSiniestro = new Shipcode_Model_NaveSiniestro();
        return $modelSiniestro->crear($data, $user);
    }
    
    public function getSiniestros()
    {
        $modelSiniestro = new Shipcode_Model_NaveSiniestro();
        return $modelSiniestro->getRowsByNaveId($this->_id);
    }
    /**************************************************************************/
    
    /************************** FUNCIONES SISTEMAS ****************************/
    public function agregarSistema($data, $user)
    {
        $modelBaseSistema = new Shipcode_Model_BaseSistema();
        $modelBaseSistema->setId($data['principal_id']);
        $data['nombre'] = $modelBaseSistema->getRow()->nombre;
        $modelSistema = new Shipcode_Model_NaveSistema();
        return $modelSistema->crear($data, $user);
    }
    
    public function agregarSubsistema($data, $user)
    {
        $modelBaseSistema = new Shipcode_Model_BaseSistema();
        $modelBaseSistema->setId($data['secundario_id']);
        $data['nombre'] = $modelBaseSistema->getRow()->nombre;
        $modelSistema = new Shipcode_Model_NaveSistema();
        return $modelSistema->crear($data, $user);
    }
    
    public function getSistemas($plan = FALSE)
    {
        $modelSistema = new Shipcode_Model_NaveSistema();
        return $modelSistema->getRowsByNaveId($this->_id, $plan);
    }

    public function getSistemasConHorometros()
    {
        $modelSistema = new Shipcode_Model_NaveSistema();
        return $modelSistema->getRowsConHorometroByNaveId($this->_id);
    }
    
    public function getEquiposConPlanParaAnclaje()
    {
        $modelSistema = new Shipcode_Model_NaveSistema();
        return $modelSistema->getRowsConPlanByNaveId($this->_id);
    }
    
    public function getSistemasPrincipalesToSelect($id)
    {
        $naveSistema = new Shipcode_Model_NaveSistema();
        return $naveSistema->getPadresToSelectByNaveId($id);
    }
    
    private function _clonarSistemas($id, $nueva_id, $user, $clonarEquipos)
    {
        $modelSistema = new Shipcode_Model_NaveSistema();
        $sistemas = $modelSistema->getSistemasToClone($id);
        
        if(count($sistemas) > 0) {
            foreach($sistemas as $sistema){
                
                $padre_id = $modelSistema->clonar($sistema, $nueva_id, $user, $clonarEquipos, NULL);
                
                $subSistemas = $modelSistema->getSubSistemasToClone($sistema['id']);
                
                if(count($subSistemas) > 0){
                    
                    foreach($subSistemas as $subSistema){
                        
                        $modelSistema->clonar($subSistema, $nueva_id, $user, $clonarEquipos, $padre_id);
                    }
                }
            }  
        }
    }
    /**************************************************************************/
    
    /********************** FUNCIONES ARCHIVOS ADJUNTOS ***********************/
    public function adjuntarArchivo($data, $user)
    {
        $modelArchivo = new Shipcode_Model_NaveArchivo();
        $modelArchivo->crear($data, $user);
    }
    
    public function getArchivos()
    {
        $modelArchivo = new Shipcode_Model_NaveArchivo();
        return $modelArchivo->getRowsByNaveId($this->_id);
    }
    /**************************************************************************/
    
    /**************************** FUNCIONES INFORMES **************************/
    public function getUltimoInforme()
    {
        $informe = new Shipcode_Model_NaveInforme();
        return $informe->getUltimoByNaveId($this->_id);
    }
    
    public function getEquiposInformeToMail($naveId)
    {
        $this->setId($naveId);
        return $this->getEquiposInforme();
    }
    
    public function getEquiposInforme()
    {
        $modelEquipo = new Shipcode_Model_NaveEquipo();
        return $modelEquipo->getRowsToInformeByNaveId($this->_id);
    }
    
    public function getInformes()
    {
        $informe = new Shipcode_Model_NaveInforme();
        return $informe->getRowsByNaveId($this->_id);
    }
    /**************************************************************************/
    
    /***************************** FUNCIONES NAVE *****************************/
    public function setId($id)
    {
        $optionsNave = array('table' => 'naves', 'field' => 'id');
        $validadorNave = new Zend_Validate_Db_RecordExists($optionsNave);
        
        if(!$validadorNave->isValid($id)){
            throw new Exception("El ID indicado no Existe");
        }
        
        $this->_id = $id;
    }
   
    
    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select();
        $select->from(array('n' => 'naves'), array(
                    'id', 'matricula', 'creacion', 'creador', 'empresa_id', 
                    'nombre', 'cb', 'puerto_matricula', 'ismm', 'tipo_nave',
                    'clasificacion', 'construccion', 'sig_carena_mes',
                    'sig_carena_year', 'fotografia', 'otras_modificaciones', 
                    'info_tecnica', 'dimensiones', 'capacidades'))
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre', 'empresa_id' => 'id')) 
               ->where("n.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getAll($autorizaciones = NULL)
    {
        $data = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select();
        $select->from(array('n' => 'naves'), array(
                    'id', 'empresa_id', 'nombre', 'cod_centro'))
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
               ->order("e.nombre");
        $rows = $adapter->fetchAll($select);
        
        if($autorizaciones === NULL){
            return $rows;
        } 
        
        foreach($rows as $nave){
            if($autorizaciones['naves'][$nave['id']] == 1) {
                $data[] = $nave;
            }
        }
        
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        if($data['clasificacion'] == '') {$data['clasificacion'] = NULL; }
        if($data['otras_modificaciones'] == '') {$data['otras_modificaciones'] = NULL; }
        if($data['cb'] == '') {$data['cb'] = NULL; }
        if($data['ismm'] == '') {$data['ismm'] = NULL; }
        if($data['info_tecnica'] == '') {$data['info_tecnica'] = NULL; }
        if($data['dimensiones'] == '') {$data['dimensiones'] = NULL; }
        if($data['capacidades'] == '') {$data['capacidades'] = NULL; }
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $user, $id)
    {
        $data['creador'] = $user;
        if($data['clasificacion']=='') {$data['clasificacion'] = NULL; }
        
        if($data['otras_modificaciones']=='') {$data['otras_modificaciones'] = NULL; }
        if($data['cb'] == '') {$data['cb'] = NULL; }
        if($data['ismm'] == '') {$data['ismm'] = NULL; }
        if($data['info_tecnica'] == '') {$data['info_tecnica'] = NULL; }
        if($data['dimensiones'] == '') {$data['dimensiones'] = NULL; }
        if($data['capacidades'] == '') {$data['capacidades'] = NULL; }
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Eliminar Nave");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public static function getPairsToSelect($empresa_id = NULL)
    {
        $adapter = self::getDefaultAdapter();
        if($empresa_id !== NULL){
            $sql = "SELECT id, nombre FROM naves WHERE empresa_id='$empresa_id' ORDER BY nombre";
        } else {
            $sql = 'SELECT id, nombre FROM naves ORDER BY nombre';
        }
            
        return $adapter->fetchPairs($sql);
    }
    
    public static function getAgrupadasPorEmpresaToSelect()
    {
        $data = array();
        $adapter = self::getDefaultAdapter();
        $empresa = new Shipcode_Model_Empresa();
        $empresas = $empresa->fetchAll(null, 'nombre');
        
        foreach($empresas as $rowEmpresa){
            $sql = "SELECT id, nombre FROM naves WHERE empresa_id='" . $rowEmpresa['id'] . "' ORDER BY nombre";
            $naves = $adapter->fetchPairs($sql);
            $data[$rowEmpresa['nombre']] = $naves;
        }
        return $data;
    }
    
    public static function getAgrupadasPorEmpresa($empresa_id = NULL)
    {
        $data = array();
        $adapter = self::getDefaultAdapter();
        $empresa = new Shipcode_Model_Empresa();
        if($empresa_id !== NULL){
            $where = "empresa_id='$empresa_id'";
        } else {
            $where = NULL;
        }
        $empresas = $empresa->fetchAll($where, 'nombre');
        foreach($empresas as $rowEmpresa){
            
            $dataEmpresa = $rowEmpresa->toArray();
            $sql = "SELECT id, nombre, matricula, fotografia FROM naves WHERE empresa_id='" . $rowEmpresa['id'] . "' ORDER BY nombre";
            $dataEmpresa['naves'] = $adapter->fetchAll($sql);
            $data[] = $dataEmpresa;
        }
        return $data;
    }
    
    public function getRowsToSelectByEmpresaId($empresa_id, $autorizaciones = NULL)
    {
        $data = array();
        $adapter = $this->getAdapter();
        $select = $adapter->select()
                          ->from(array('n' => 'naves'), array('id','nombre'))
                          ->where("empresa_id=?", $empresa_id);
        $naves = $adapter->fetchAll($select);
        
        if($autorizaciones === NULL){
            return $naves;
        } 
        
        foreach($naves as $nave){
            if($autorizaciones['naves'][$nave['id']] == 1) {
                $data[] = $nave;
            }
        }
        return $data;
    }
    
    public function getCentrosDeCostoToSelectByEmpresaId($empresa_id)
    {
        $adapter = $this->getAdapter();
        $select = $adapter->select()
                          ->from(array('n' => 'naves'), array('id' => 'cod_centro','nombre'))
                          ->where("empresa_id=? AND cod_centro IS NOT NULL", $empresa_id);
        return $adapter->fetchAll($select);
    }
    
    public function clonar($data, $user)
    {
        $nueva_id = $this->_clonar($data, $user);
        
        if($nueva_id != FALSE){
            
            if($data['sistemas'] == 1 || $data['sistemas'] == 2) {
                $this->_clonarSistemas($this->_id, $nueva_id, $user, $data['sistemas']);
            }
            
            if($data['certificados'] == 1) {
                $this->_clonarCertificados($this->_id, $nueva_id, $user);
            }
            
            return $nueva_id;
            
        } else {
            throw new Exception('No fue posible clonar la nave');
        }    
    }
    
    public function actualizarFotografia($name)
    {
        $row = $this->getRow();
        $row->fotografia = $name;
        $row->save();
    }
    
    public function getEmpresa()
    {
        $modelEmpresa = new Shipcode_Model_Empresa();
        $modelEmpresa->setId($this->getRow()->empresa_id);
        return $modelEmpresa->getRow();
    }
    
    public function getRowsByEmpresaId($empresa_id)
    {
        $where = $this->getAdapter()->quoteInto("empresa_id=?", $empresa_id);
        return $this->fetchAll($where)->toArray();
    }
    
    public function getNumRowsByEmpresaId($empresa_id)
    {
        $adapter = $this->getAdapter();
        $empresa_id = $adapter->quote($empresa_id);
        $sql = "SELECT COUNT(*) FROM naves WHERE empresa_id=$empresa_id";
        return $adapter->fetchOne($sql);
    }
    
    public function getIdsPorEmpresaId($empresa_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT id FROM naves WHERE empresa_id='$empresa_id'";
        return $adapter->fetchCol($sql);
    }
    
    public function getHorometros()
    {
        $equipo = new Shipcode_Model_NaveEquipo();
        return $equipo->getHorometrosByNaveId($this->_id);
    }
    
    public function getItemsPorVencer($empresa_id = NULL)
    {
        $certificado = new Shipcode_Model_NaveCertificado();
        $observacion = new Shipcode_Model_NaveObservacion();
        $actividad = new Shipcode_Model_NaveActividad();
        $auditoria = new Shipcode_Model_AuditoriaInterna();
        $data = array();
        $data['certificadosPorVencer'] = $certificado->getCountPorVencer($empresa_id);
        $data['certificadosVencidos'] = $certificado->getCountVencidos($empresa_id);
        $data['observacionesPendientes'] = $observacion->getCountPendientes($empresa_id);
        $data['mantenimientosPorVencer'] = $actividad->getCountPorVencer($empresa_id);
        $data['mantenimientosVencidos'] = $actividad->getCountVencidos($empresa_id);
        $data['mantenimientosSinProyectoPorVencer'] = Shipcode_Model_NaveEquipoMantenimiento::getCountSinProyecto('NO');
        $data['mantenimientosSinProyectoVencidos'] = Shipcode_Model_NaveEquipoMantenimiento::getCountSinProyecto('VENCIDO');
        $data['auditoriasInternasPorVencer'] = $auditoria->getCountPorVencer($empresa_id);
        $data['auditoriasInternasVencidas'] = $auditoria->getCountVencidos($empresa_id);
        return $data;
    }
    
    public function configInicioOperaciones($fecha)
    {
        $sistemas = $this->getSistemasPrincipalesToSelect($this->_id);
        if(count($sistemas) > 0 ) {
            $sistema = new Shipcode_Model_NaveSistema();
            foreach($sistemas as $id => $nombre){
                $sistema->setId($id);
                $sistema->configInicioOperaciones($fecha);
            }
        }
        return TRUE;
    }
    
    public function getEquiposAgrupadosPorSistemaToSelect()
    {
        $dataEquipos = array();
        $modelSistema = new Shipcode_Model_NaveSistema();
        $sistemas = $modelSistema->getRowsToSelectByNaveId($this->_id);
        $modelEquipo = new Shipcode_Model_NaveEquipo();
        foreach($sistemas as $sistema){
            $equipos = $modelEquipo->getRowsToSelectBySistemaId($sistema['id']);
            if(count($equipos) > 0 ) {
                $dataEquipo['nombre'] = $sistema['nombre'];
                $dataEquipo['filas'] =  $equipos;
                $dataEquipos[] = $dataEquipo;
            } 
        }
        return $dataEquipos;
    }
    
    private function _clonar($data, $user)
    {
        $naveOrigen = $this->getRow()->toArray();
        $naveNueva = array(
            'id' => $data['id'],
            'empresa_id' => $data['empresa_id'],
            'nombre' => $data['nombre'],
            'puerto_matricula' => $data['puerto_matricula'],
            'ismm' => $data['ismm'],
            'clasificacion' => $data['clasificacion'],
            'otras_modificaciones' => $data['otras_modificaciones'],
            'cb' => $data['cb'],
            'construccion' => $data['construccion'],
            'tipo_nave' => $naveOrigen['tipo_nave'],
            'info_tecnica' => $naveOrigen['info_tecnica'],
            'dimensiones' => $naveOrigen['dimensiones'],
            'capacidades' => $naveOrigen['capacidades']
        );
        
        $id = $this->crear($naveNueva, $user);
        
        if($id != FALSE){
            return $id;
        }
        return FALSE;
    }
    /**************************************************************************/

    /*********************** PRESUPUESTOS & GASTOS ****************************/
    public static function getCentrosDeCosto()
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT cod_centro FROM naves WHERE cod_centro IS NOT NULL";
        return $adapter->fetchCol($sql);
    }
    
    public static function getCentrosDeCostoToSelect()
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT cod_centro, CONCAT(cod_centro, ' - ', nombre) AS nombre FROM naves WHERE cod_centro IS NOT NULL";
        return $adapter->fetchPairs($sql);
    }
   
    public function editarCentroCosto($data)
    {
        $row = $this->find($data['id'])->current();
        if($data['cod_centro'] != ''){
            $row->cod_centro = (int)$data['cod_centro'];
        } else {
            $row->cod_centro = NULL;
        }
        $row->save();
    }
    
    public function getRowsConCentroCosto($empresa_id = NULL)
    {
        if($empresa_id == NULL){
            $where = "cod_centro IS NOT NULL";
        } else {
            $where = "cod_centro IS NOT NULL AND empresa_id = '$empresa_id'";
        }
        return $this->fetchAll($where);
    }
    
    public function getGastos()
    {
        $modelGasto = new Shipcode_Model_ImagestionGasto();
        return $modelGasto->getRowsByNaveId($this->_id);
    }
    
    public function getGastosMensuales($year, $month)
    {
        $modelGasto = new Shipcode_Model_NaveGasto();
        return $modelGasto->getRowsMensualesByNaveId($this->_id, $year, $month);
    }
    
    public function getEstadoActual($empresa_id, $year = NULL)
    {
        if($year === NULL){
            $year = date("Y");
        }
        
        $data = array();
        $data['naves'] = $this->getCentrosDeCostoToSelectByEmpresaId($empresa_id);
        $data['presupuestosAnuales'] = $this->_getPresupuestosAnuales($data['naves'], $year);
        $data['presupuestosAcumulados'] = $this->_getPresupuestosAcumulados($data['naves'], $year);
        $data['gastosEjecutadosAcumulados'] = $this->_getGastosEjecutadosAcumulados($data['naves'], $year);
        $data['gastosProyectadosAcumulados'] = $this->_getGastosProyectadosAcumulados($data['naves'], $year);
        return $data;
    }
    
    public function getNavesSaldosNegativos($empresa_id, $year = NULL)
    {
        if($year === NULL){
            $year = date("Y");
        }
        $cuentaGasto = new Shipcode_Model_ImagestionCuentaGasto();
        $data = array();
        $data['year'] = $year;
        $naves = $this->getCentrosDeCostoToSelectByEmpresaId($empresa_id);
        if(count($naves) > 0) {
            foreach($naves as $nave){
                for($i = 1; $i <= 12; $i++){
                    $mes = array();
                    $mes['numero'] = $i;
                    $cuentas = $cuentaGasto->getAll(false, true);
                    foreach($cuentas as $cuenta){
                        $dataMes = $this->_getInfoMes($nave['id'], $cuenta['cod_cuenta'], $year, $i);
                        if($dataMes['saldo'] < 0){
                            $dataCuenta = array(
                                'mes'           => $i,
                                'nombre'        => $cuenta['nombre'],
                                'cod_cuenta'    => $cuenta['cod_cuenta'],    
                                'presupuesto'   => $dataMes['presupuesto'],
                                'gasto'         => $dataMes['gasto'],
                                'saldo'         => $dataMes['saldo']
                            );
                            $mes['cuentas'][] = $dataCuenta;
                        }
                    }
                    $nave['meses'][] = $mes;
                }
                $data['naves'][] = $nave;
            }
        }
        return $data;
    }
    
    public function getEstadoGasto($empresa_id, $year = NULL)
    {
        if($year === NULL){
            $year = date("Y");
        }
        $data = array();
        $data['year'] = $year;       
        $data['empresa_id'] = $empresa_id;
        $data['mesActual'] = date("m");
        
        $naves = $this->getCentrosDeCostoToSelectByEmpresaId($empresa_id);
        foreach($naves as $nave){
            $nave['presupuestosMensuales'] = $this->_getPresupuestosMensuales($nave['id'], $year);
            $data['naves'][] = $nave;
        }
        return $data;
    }
    
    private function _getPresupuestosMensuales($cod_centro, $year)
    {
        $data = array();
        for($month = 1; $month <= 12 ; $month++){
            $dataMes['presupuesto'] = $this->_getPresupuestoMensual($cod_centro, $year, $month);
            $dataMes['gasto'] = $this->_getGastoMensual($cod_centro, $year, $month);
            $dataMes['gasto_proyectado'] = $this->_getGastoMensualProyectado($cod_centro, $year, $month);
            $dataMes['saldo'] = $dataMes['presupuesto'] - $dataMes['gasto'];
            $dataMes['mes'] = $month;
            $data[] = $dataMes;
        }
        return $data;
    }
    
    private function _getInfoMes($cod_centro, $cod_cuenta, $year, $month)
    {
        $data = array();
        // obtención de presupuesto y gasto mensual por cuenta
        $data['presupuesto'] = $this->_getPresupuestoMensualCuenta($cod_centro, $cod_cuenta, $year, $month);
        $data['gasto'] = $this->_getGastoMensualCuenta($cod_centro, $cod_cuenta, $year, $month);
        $data['saldo'] = $data['presupuesto'] - $data['gasto'];
        return $data;
    }
    
    private function _getGastosEjecutadosAcumulados(array $naves, $year)
    {
        $data = array();
        if(count($naves) > 0) {
            foreach($naves as $nave){
                $data[] = $this->_getGastoEjecutadoAcumulado($nave['id'], $year);
            }
        }
        return $data;
    }
    
    private function _getGastosProyectadosAcumulados(array $naves, $year)
    {
        $data = array();
        if(count($naves) > 0) {
            foreach($naves as $nave){
                $data[] = $this->_getGastoProyectadoAcumulado($nave['id'], $year);
            }
        }
        return $data;
    }
    
    private function _getPresupuestosAnuales(array $naves, $year)
    {
        $data = array();
        if(count($naves) > 0) {
            foreach($naves as $nave){
                $data[] = $this->_getPresupuestoAnual($nave['id'], $year);
            }
        }
        return $data;
    }
    
    private function _getPresupuestosAcumulados(array $naves, $year)
    {
        $data = array();
        if(count($naves) > 0) {
            foreach($naves as $nave){
                $data[] = $this->_getPresupuestoAcumulado($nave['id'], $year);
            }
        }
        return $data;
    }
    
    private function _getPresupuestoAnual($cod_centro, $year)
    {
        $presupuesto = new Shipcode_Model_ImagestionPresupuestoAsignacion();
        return $presupuesto->getTotalAnual($cod_centro, $year);
    }
    
    private function _getPresupuestoMensual($cod_centro, $year = NULL, $month = NULL)
    {
        $presupuesto = new Shipcode_Model_ImagestionPresupuestoAsignacion();
        return $presupuesto->getTotalMensual($cod_centro, $year, $month);
    }
    
    private function _getPresupuestoMensualCuenta($cod_centro, $cod_cuenta, $year, $month)
    {
        $presupuesto = new Shipcode_Model_ImagestionPresupuestoAsignacion();
        return $presupuesto->getTotalMensualCuenta($cod_centro, $cod_cuenta, $year, $month);
    }
    
    private function _getPresupuestoAcumulado($cod_centro, $year)
    {
        $presupuesto = new Shipcode_Model_ImagestionPresupuestoAsignacion();
        return $presupuesto->getTotalAcumulado($cod_centro, $year);
    }
    
    private function _getGastoMensual($cod_centro, $year = NULL, $month = NULL)
    {
        $gasto = new Shipcode_Model_ImagestionGasto();
        return $gasto->getTotalMensual($cod_centro, $year, $month);
    }
    
    private function _getGastoMensualProyectado($cod_centro, $year = NULL, $month = NULL)
    {
        $gasto = new Shipcode_Model_ImagestionGasto();
        return $gasto->getTotalMensualProyectado($cod_centro, $year, $month);
    }
    
    private function _getGastoMensualCuenta($cod_centro, $cod_cuenta, $year, $month)
    {
        $gasto = new Shipcode_Model_ImagestionGasto();
        return $gasto->getTotalMensualCuenta($cod_centro, $cod_cuenta, $year, $month);
    }
    
    private function _getGastoEjecutadoAcumulado($cod_centro, $year)
    {
        $gasto = new Shipcode_Model_ImagestionGasto();
        return $gasto->getTotalEjecutadoAcumulado($cod_centro, $year);
    }
    
    private function _getGastoProyectadoAcumulado($cod_centro, $year)
    {
        $gasto = new Shipcode_Model_ImagestionGasto();
        return $gasto->getTotalProyectadoAcumulado($cod_centro, $year);
    }
    /**************************************************************************/
    public function getRowToExport($fotografia = 0)
    {
        $dataNave = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('n' => 'naves'), array(
                    'matricula', 'nombre', 'cb', 'puerto_matricula', 'ismm', 'tipo_nave',
                    'clasificacion', 'construccion', 'fotografia', 'otras_modificaciones', 
                    'info_tecnica', 'dimensiones', 'capacidades'))
               ->where("n.id=?", $this->_id);
        $row = $adapter->fetchRow($select);
        $dataNave['Ficha']['Nombre'] = $row['nombre'];
        $dataNave['Ficha']['Matrícula'] = $row['matricula'];
        $dataNave['Ficha']['CB'] = $row['cb'];
        $dataNave['Ficha']['Puerto de matrícula'] = $row['puerto_matricula'];
        $dataNave['Ficha']['ISMM'] = $row['ismm'];
        $dataNave['Ficha']['Tipo de nave'] = $row['tipo_nave'];
        $dataNave['Ficha']['Clasificación'] = $row['clasificacion'];
        $dataNave['Ficha']['Construcción'] = $row['construccion'];
        $dataNave['Ficha']['Modificaciones'] = $row['otras_modificaciones'];
        $dataNave['Ficha']['Información técnica'] = $row['info_tecnica'];
        $dataNave['Ficha']['Dimensiones'] = $row['dimensiones'];
        $dataNave['Ficha']['Capacidades'] = $row['capacidades'];
        if($fotografia == 1) {
            $dataNave['Fotografía'] = $row['fotografia'];
        }
        return $dataNave;  
    }
    
    public function getDataToExport(array $extras)
    {
        $dataNave = array();
        $dataNave['Nave'] = $this->getRowToExport($extras['fotografias']);
        if($extras['archivos'] == 1){
            $dataNave['Nave']['Archivos'] = $this->getArchivosToExport();
        }
        $dataNave['Nave']['Sistemas'] = $this->getSistemasToExport($extras['archivos'], $extras['fotografias']);
        $dataNave['Nave']['Certificados'] = $this->getCertificadosToExport($extras['archivos']);
        $dataNave['Nave']['Observaciones'] = $this->getObservacionesToExport($extras['archivos']);
        $dataNave['Nave']['Carenas'] = $this->getCarenasToExport($extras['archivos'], $extras['carenas']);
        
        if($extras['siniestros'] == 1){
            $dataNave['Nave']['Siniestros'] = $this->getSiniestrosToExport($extras['archivos']);
        }
        return $dataNave;
    }
    
    public function getSistemasToExport($archivos = 0, $fotografias = 0)
    {
        $modelSistema = new Shipcode_Model_NaveSistema();
        return $modelSistema->getRowsByNaveIdToExport($this->_id, $archivos, $fotografias);
    }
    
    public function getCertificadosToExport($archivos)
    {
        $modelCertificado = new Shipcode_Model_NaveCertificado();
        return $modelCertificado->getRowsByNaveIdToExport($this->_id, $archivos);
    }
    
    public function getObservacionesToExport($archivos)
    {
        $modelObservacion = new Shipcode_Model_NaveObservacion();
        return $modelObservacion->getRowsByNaveIdToExport($this->_id, $archivos);
    }
    
    public function getCarenasToExport($archivos = 0, $detallegastos = 0)
    {
        $modelCarena = new Shipcode_Model_NaveCarena();
        return $modelCarena->getRowsByNaveIdToExport($this->_id, $archivos, $detallegastos);
    }
    
    public function getSiniestrosToExport($archivos = 0)
    {
        $modelSiniestro = new Shipcode_Model_NaveSiniestro();
        return $modelSiniestro->getRowsByNaveIdToExport($this->_id, $archivos);
    }
    
    public function getArchivosToExport()
    {
        $modelArchivo = new Shipcode_Model_NaveArchivo();
        return $modelArchivo->getRowsByNaveIdToExport($this->_id);
    }
    
    public function eliminarEquiposAsociados(array $sistemas)
    {
        if(count($sistemas) > 0){
            foreach($sistemas as $sistema){
                if(count($sistema['Equipos']) > 0 ) {
                    foreach($sistema['Equipos'] as $equipo){
                        $mEquipo = new Shipcode_Model_NaveEquipo();
                        $mEquipo->setId($equipo['ID']);
                        $mEquipo->eliminar();
                    }
                }
                
                if(count($sistema['Subsistemas']) > 0) {
                    foreach($sistema['Subsistemas'] as $subsistema){
                        if(count($subsistema['Equipos']) > 0 ) {
                            foreach($subsistema['Equipos'] as $equipo){
                                $mEquipo = new Shipcode_Model_NaveEquipo();
                                $mEquipo->setId($equipo['ID']);
                                $mEquipo->eliminar();
                            }
                        }
                    }
                }
            }
        }
        
    }
    
    public function getSupervisores()
    {
        $empresa = new Shipcode_Model_Empresa();
        $empresa->setId($this->getRow()->empresa_id);
        return $empresa->getSupervisores();
    }
    
    /*
    

    public function getMotoristas()
    {
        $naveUsuario = new Shipcode_Model_NaveUsuario();
        return $naveUsuario->getRowsByNaveId($this->_id);
    }
    public function agregarPresupuesto($data, $user)
    {
        $modelPresupuesto = new Shipcode_Model_NavePresupuesto();
        return $modelPresupuesto->crear($data, $user);
    }
    
    public function cargarGastos()
    {
        $year = date("Y");
        $naves = $this->getRowsConCentroCosto();
        $presupuesto = new Shipcode_Model_NavePresupuesto();
        if(count($naves) > 0 ) {
            foreach($naves as $nave){
                $presupuesto->cargar($nave->id, $nave->cod_centro, $year);
            }
        }
    }
    
    public function subirInformeSemanal($data, $user)
    {
        $modelInforme = new Shipcode_Model_NaveInformeSemanal();
        $modelInforme->crear($data, $user);
    }
    
    public function getMotoristasId()
    {
        $adapter = $this->getAdapter();
        $nave_id = $adapter->quote($this->_id);
        $sql = "SELECT usuario_id FROM naves_usuarios WHERE nave_id=$nave_id";
        return $adapter->fetchCol($sql);
    }
    
    public function configurarUsuarios($data, $user)
    {
        $modelUsuario = new Shipcode_Model_SistemaUsuario();
        $motoristas = $modelUsuario->getMotoristas();
        $naveUsuario = new Shipcode_Model_NaveUsuario();
        
        $adapter = $this->getAdapter();
        $adapter->beginTransaction();
        
        try {
            
            $naveUsuario->eliminarPorNave($data['nave_id']);
            
            foreach($motoristas as $motorista){
                
                if($data[$motorista['id']] && $data[$motorista['id']] == '1'){
                    
                    $naveUsuario->crear(array(
                        'creador' => $user,
                        'usuario_id' => $motorista['id'],
                        'nave_id' => $data['nave_id']
                    ));
                }
            }
            
            $adapter->commit();
            
        } catch(Exception $e){
            $adapter->rollBack();
            return $e->getMessage();
        }
    }
    */
}