<?php
class Shipcode_Model_NaveActividad extends Zend_Db_Table_Abstract
{
    protected   $_name = 'naves_actividades';
    protected   $_primary = 'id';
    private     $_id;
    
    public static function getAsignacionResponsable($id)
    {
        $adapter = self::getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sqlActividad = "SELECT servicio_id, equipo_id FROM naves_actividades WHERE id='$id'";
        $dataActividad = $adapter->fetchRow($sqlActividad);
        
        $sql = "SELECT i.asignado_a FROM base_planesmant_items i "
             . "JOIN base_planesmant p ON p.id=i.plan_id "
             . "JOIN naves_equipos e ON e.planmant_id=p.id "
             . "WHERE i.servicio_id=". $adapter->quote($dataActividad['servicio_id']) . " "
             . "AND e.id=" . $adapter->quote($dataActividad['equipo_id']);
        $result = $adapter->fetchOne($sql);
        if(!in_array($result, array('NAVE', 'EXTERNO'))){
            return 'NAVE';
        }
        return $result;
    }
    
    public function setId($id)
    {
        $options = array('table' => 'naves_actividades', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception('El ID solicitado no existe - NaveActividad::setId() ');
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function asignarFechaManual($values, $user)
    {
        $data = array(
            'fecha_editada' => $values['fecha'],
            'codigo' => 401,
            'programacion' => 'MANUAL',
            'aviso' => NULL
        );
        
        $dataUpdate = array(
            'dependencia_tipo' => 'S',
            'dependencia_id' => $values['id'],
            'fecha_editada' => $values['fecha']
        );
        
        $this->setId($values['id']);
        return $this->_editarEvento($data, $user, $dataUpdate);
    }
    
    public function asignarFechaManualMasivamente($eventosIds, $fecha, $user)
    {
        $validadorFecha = new Zend_Validate_Date();
        if(!$validadorFecha->isValid($fecha)){
            throw new Exception('La fecha asignada no es válida');
        }
        
        $mFecha = new Zend_Date($fecha);
        $mFechaHoy = new Zend_Date();
        
        if($mFecha->equals($mFechaHoy) || $mFecha->isEarlier($mFechaHoy)){
            throw new Exception('La fecha asignada debe ser posterior al día de hoy.');
        }
        
        foreach($eventosIds as $key => $id){
            $this->asignarFechaManual(array('id' => $id, 'fecha' => $fecha), $user);
        }
    }
    
    public function anclarEventoEnEvento($primario_id, $secundario_id, $user)
    {
        $dataPrimario = $this->find($primario_id)->current();
        $this->setId($secundario_id);
        
        if($this->_verificarDependenciasSecundarias($secundario_id) == TRUE){
            throw new Exception('El ítem secundario tiene mantenimientos anclados. No es posible realizar la operación.');
        }
        
        if($dataPrimario->dependencia_tipo == 'S'){
            throw new Exception('El ítem primario ya está anclado a otro evento. No es posible realizar la operación.');
        }
        
        $data = array(
            'codigo' => 302,
            'fecha_editada' => $dataPrimario->fecha_editada,
            'dependencia_tipo' => "S",
            'dependencia_id' => $dataPrimario->id,
            'programacion' => 'MANUAL',
            'aviso' => NULL
        );
        
        return $this->_editarEvento($data, $user);
    }
    
    public function anclarEventoCarena($id, $user)
    {
        $this->setId($id);
        $dataCarena = $this->_getDataCarena();
        
        $data = array(
            'codigo' => 301,
            'fecha_editada' => $dataCarena['fecha_carena'],
            'dependencia_tipo' => "C",
            'dependencia_id' => $dataCarena['nave_id'],
            'programacion' => 'MANUAL',
            'aviso' => NULL
        );
        
        $dataUpdate = array(
            'dependencia_tipo' => 'S',
            'dependencia_id' => $id,
            'fecha_editada' => $dataCarena['fecha_carena']
        );
        
        return $this->_editarEvento($data, $user, $dataUpdate);
    }
    
    public function anclarEventoCarenaMasivamente($eventosIds, $user)
    {
        foreach($eventosIds as $key => $id){
            $this->anclarEventoCarena($id, $user);
        }
    }
    
    public function actualizarEventosAncladosEnCarena($dataCarena, $user)
    {
        $where = "dependencia_tipo='C' AND dependencia_id='" . $dataCarena['nave_id'] . "' AND estado='0'";
        $eventos = $this->fetchAll($where);
        foreach($eventos as $evento){
            
            $data = array('fecha_editada' => $dataCarena['fecha']);
            
            $dataUpdate = array(
                'dependencia_tipo' => 'S',
                'dependencia_id' => $evento->id,
                'fecha_editada' => $dataCarena['fecha']
            );
            
            $this->setId($evento->id);
            $this->_editarEvento($data, $user, $dataUpdate);
        }
    }
    
    public function guardarDataEventoEliminado($dataParaEliminar, $user)
    {
        $where = $this->getAdapter()->quoteInto("mantenimiento_id=?", $dataParaEliminar['id']);
        $row = $this->fetchRow($where);
        $row->data_backup = Zend_Json::encode($dataParaEliminar);
        $row->creador = $user;
        $row->save();
    }
    
    public function resetearEventosAncladosEnEvento($id, $user)
    {
        $where = "dependencia_tipo='S' AND dependencia_id='$id'";
        $rows = $this->fetchAll($where);
        if(count($rows) > 0){
            foreach($rows as $row){
                $this->resetearProgramacionEvento($row->id, $user);
            }
        }
    }
    
    public function resetearEventos($eventosId, $user)
    {
        if(count($eventosId) > 0){
            foreach($eventosId as $evento){
                $this->resetearProgramacionEvento($evento['id'], $user);
            }
        }
    }
    
    // Recibe array con id's de eventos a resetar
    public function resetearProgramacionEventosMasivamente($eventosId, $user)
    {
        if(count($eventosId) > 0){
            foreach($eventosId as $key => $id){
                $this->resetearProgramacionEvento($id, $user);
            }
        }
    }
    
    public function resetearProgramacionEvento($id, $user)
    {
        $this->setId($id);
        $dataEvento = $this->getRow();
        
        $equipo = new Shipcode_Model_NaveEquipo();
        $equipo->setId($dataEvento->equipo_id);
        $dataEquipo = $equipo->getRow();
        
        $itemPlan = $this->_getItemPlan($dataEvento->servicio_id, $dataEquipo->planmant_id);
        
        $ultimoServicio = $equipo->getUltimoServicio($dataEvento->servicio_id);
        $infoHorometroParaCalculo = $equipo->getInfoHorometroParaCalculo($dataEquipo);
        
        if($itemPlan->cantidad_dias != NULL && $itemPlan->cantidad_horas == NULL){
            $proximoEvento = $this->_obtenerInfoProximoEventoDias($itemPlan, $dataEquipo, $ultimoServicio);
        } elseif($itemPlan->cantidad_horas != NULL && $itemPlan->cantidad_dias == NULL){
            $proximoEvento = $this->_obtenerInfoProximoEventoHoras($itemPlan, $dataEquipo, $ultimoServicio, $infoHorometroParaCalculo);
        } elseif($itemPlan->cantidad_dias != NULL && $itemPlan->cantidad_horas != NULL) {
            $proximoEvento = $this->_obtenerInfoProximoEventoMixto($itemPlan, $dataEquipo, $ultimoServicio, $infoHorometroParaCalculo);
        }
        
        $data = array(
            'fecha_editada'     => $proximoEvento['fecha_original'],
            'codigo'            => $proximoEvento['codigo'],
            'aviso'             => $proximoEvento['aviso'],
            'horas'             => $proximoEvento['horas'],    
            'programacion'      => 'AUTOMATICA',
            'dependencia_tipo'  => NULL,
            'dependencia_id'    => NULL,
        );
        
        $dataUpdate = array(
            'dependencia_tipo' => 'S',
            'dependencia_id' => $id,
            'fecha_editada' => $proximoEvento['fecha_original']
        );
        
        return $this->_editarEvento($data, $user, $dataUpdate);
    }
    
    public function reabrirUltimoEvento($data, $user)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $sql = "SELECT id FROM naves_actividades WHERE equipo_id='" . $data['equipo_id'] . "' AND servicio_id='" . $data['servicio_id'] . "' AND estado ='1' ORDER BY id DESC LIMIT 1";
        $id = $adapter->fetchOne($sql);
        
        if($id){
            $row = $this->find($id)->current();
            $row->creador = $user;
            $row->estado = 0;
            $row->fecha_final = NULL;
            $row->save();
            $this->resetearProgramacionEvento($row->id, $user);
        }
        return $row;
    }
    
    public function crearEvento($data, $user, $programacion = 'AUTOMATICA')
    {
        $data['creador'] = $user;
        $data['programacion'] = $programacion;
        if(!isset($data['fecha_editada']) || $data['fecha_editada'] == '') {
            $data['fecha_editada'] = $data['fecha_original'];
        }
        $row = $this->createRow();
        $row->setFromArray($data);
        return $row->save();
    }
    
    private function _editarEvento($data, $user, $dataUpdate = NULL)
    {
        $data['creador'] = $user;
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        $row = $this->fetchRow($where);
        $row->setFromArray($data);
        $row->save();
        $data = $row->toArray();
        
        if(is_array($dataUpdate)){
            $this->_actualizarEventosAnclados($dataUpdate, $user);
        }
        
        return $data;
    }
    
    private function _actualizarEventosAnclados(array $dataUpdate, $user)
    {
        $where = "dependencia_tipo='" . $dataUpdate['dependencia_tipo'] . "' AND dependencia_id='" . $dataUpdate['dependencia_id'] . "'";
        $data = array('fecha_editada' => $dataUpdate['fecha_editada'], 'creador' => $user);
        $this->update($data, $where);
    }
    
    private function _getItemPlan($servicio_id, $plan_id)
    {
        $itemPlan = new Shipcode_Model_BasePlanMantItem();
        return $itemPlan->getRowByServicioIdAndPlanId($servicio_id, $plan_id);
    }
    
    private function _getDataCarena()
    {
        $data = array();
        $equipo = new Shipcode_Model_NaveEquipo();
        $nave = new Shipcode_Model_Nave();
        $equipo->setId($this->getRow()->equipo_id);
        $data['nave_id'] = $equipo->getNaveId();
        $nave->setId($data['nave_id']);
        $data['fecha_carena'] = $nave->getFechaCarena();
        return $data;
    }
    
    private function _verificarDependenciasSecundarias($secundario_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT COUNT(*) FROM naves_actividades AS na WHERE na.dependencia_tipo='S' AND dependencia_id='$secundario_id'";
        $numDependientes = $adapter->fetchOne($sql);
        if($numDependientes > 0){
            return TRUE;
        }
        return FALSE;
    }
    
    public function programarNuevoEvento($itemPlan, $dataEquipo, $user, $ultimoServicio, $infoHorometroParaCalculo)
    {
        if($itemPlan->cantidad_dias != NULL || $itemPlan->cantidad_horas != NULL){
            
            if($itemPlan->cantidad_dias != NULL && $itemPlan->cantidad_horas == NULL){
                $proximoEvento = $this->_obtenerInfoProximoEventoDias($itemPlan, $dataEquipo, $ultimoServicio);
            } elseif($itemPlan->cantidad_horas != NULL && $itemPlan->cantidad_dias == NULL){
                $proximoEvento = $this->_obtenerInfoProximoEventoHoras($itemPlan, $dataEquipo, $ultimoServicio, $infoHorometroParaCalculo);
            } elseif($itemPlan->cantidad_dias != NULL && $itemPlan->cantidad_horas != NULL) {
                $proximoEvento = $this->_obtenerInfoProximoEventoMixto($itemPlan, $dataEquipo, $ultimoServicio, $infoHorometroParaCalculo);
            }

            $data = array(
                'equipo_id'         => $dataEquipo->id,
                'servicio_id'       => $itemPlan->servicio_id,
                'fecha_original'    => $proximoEvento['fecha_original'],
                'fecha_editada'     => $proximoEvento['fecha_original'],
                'horas'             => $proximoEvento['horas'],
                'codigo'            => $proximoEvento['codigo'],
                'aviso'             => $proximoEvento['aviso']
            );

            return $this->crearEvento($data, $user);
            
        }
    }
    
    private function _obtenerInfoProximoEventoDias($itemPlan, $dataEquipo, $ultimoServicio = NULL)
    {
        if($ultimoServicio == NULL){
            $fechaInicio = new Zend_Date($dataEquipo->inicio_operaciones, Zend_Date::ISO_8601);
            $codigo = 201;
        } else {
            $fechaInicio = new Zend_Date($ultimoServicio['fecha'], Zend_Date::ISO_8601);
            $codigo = 202;
        }

        $data = array(
            'fecha_original' => $fechaInicio->add($itemPlan->cantidad_dias, Zend_Date::DAY)->toString('yyyy-MM-dd'),
            'codigo' => $codigo,
            'horas' => NULL,
            'aviso' => $fechaInicio->sub($itemPlan->dias_aviso, Zend_Date::DAY)->toString('yyyy-MM-dd')
        );
        
        return $data;
    }
    
    private function _obtenerInfoProximoEventoHoras($itemPlan, $dataEquipo, $ultimoServicio = NULL, $infoHorometroParaCalculo = NULL)
    {
        if($dataEquipo->horometro == 0){
            $data = array(
                'fecha_original'    => NULL,
                'codigo'            => 101,
                'horas'             => NULL,
                'aviso'             => NULL
            );
            return $data;
        } 

        if($infoHorometroParaCalculo == NULL){
            $data = array(
                'fecha_original'    => NULL,
                'codigo'            => 102,
                'horas'             => NULL,
                'aviso'             => NULL
            );
            return $data;
        } 
        
        if($ultimoServicio == NULL){
            
            if($infoHorometroParaCalculo['ultima_lectura'] > $itemPlan->cantidad_horas){
                $data = array(
                    'fecha_original'    => NULL,
                    'codigo'            => 103,
                    'horas'             => $itemPlan->cantidad_horas,
                    'aviso'             => NULL
                );
                return $data;
                
            }  else {
                
                // No se ha realizado nunca el servicio
                // las horas del último registro del horómetro son menores a las del ítem del plan
                // calculo la fecha del primer servicio/evento
                $fechaOriginal = $this->_calcularFechaPrimerEvento($dataEquipo, $itemPlan, $infoHorometroParaCalculo);
                $data = array(
                    'fecha_original'    => $fechaOriginal->toString('yyyy-MM-dd'),
                    'codigo'            => 211,
                    'horas'             => $itemPlan->cantidad_horas,
                    'aviso'             => $fechaOriginal->sub($itemPlan->dias_aviso, Zend_Date::DAY)->toString('yyyy-MM-dd')
                );
                return $data;
            }
            
        } else {
            
            if($ultimoServicio['horometro'] == NULL){
                $data = array(
                    'fecha_original'    => NULL,
                    'codigo'            => 104,
                    'horas'             => NULL,
                    'aviso'             => NULL
                );
                return $data;
                
            }  else {
                
                $fechaOriginal = $this->_calcularFechaProximoEvento($ultimoServicio, $itemPlan, $infoHorometroParaCalculo);
                $data = array(
                    'fecha_original'    => $fechaOriginal->toString('yyyy-MM-dd'),
                    'codigo'            => 212,
                    'horas'             => $ultimoServicio['horometro'] + $itemPlan->cantidad_horas,
                    'aviso'             => $fechaOriginal->sub($itemPlan->dias_aviso, Zend_Date::DAY)->toString('yyyy-MM-dd')
                );
                return $data;
            }
        }
    }
    
    private function _obtenerInfoProximoEventoMixto($itemPlan, $dataEquipo, $ultimoServicio = NULL, $infoHorometroParaCalculo = NULL)
    {
        // CÁLCULOS SÓLO BASADOS EN LAS FECHAS
        // PORQUE NO HAY INFORMACIÓN DE HOROMETROS
        if($dataEquipo->horometro == 0 || $infoHorometroParaCalculo == NULL){
            
            if($ultimoServicio == NULL){
                
                $fechaOriginal = $this->_calcularFechaPrimerEvento($dataEquipo, $itemPlan, NULL);
                $data = array(
                    'fecha_original'    => $fechaOriginal->toString('yyyy-MM-dd'),
                    'codigo'            => 221,
                    'horas'             => $itemPlan->cantidad_horas,
                    'aviso'             => $fechaOriginal->sub($itemPlan->dias_aviso, Zend_Date::DAY)->toString('yyyy-MM-dd')
                );
                
                return $data;
                
            } else {
                 
                $fechaOriginal = $this->_calcularFechaProximoEvento($ultimoServicio, $itemPlan, NULL);
                $data = array(
                    'fecha_original'    => $fechaOriginal->toString('yyyy-MM-dd'),
                    'codigo'            => 222,
                    'horas'             => NULL,
                    'aviso'             => $fechaOriginal->sub($itemPlan->dias_aviso, Zend_Date::DAY)->toString('yyyy-MM-dd')
                );
                
                return $data;
            }
        }
        
        // SE ASUME QUE SI HAY INFORMACIÓN DE HOROMETROS DISPONIBLE
        if($ultimoServicio == NULL){
            
            // No se ha realizado nunca el servicio
            // las horas del último registro del horómetro son menores a las del ítem del plan
            // calculo la fecha del primer servicio/evento
            $fechaOriginal = $this->_calcularFechaPrimerEvento($dataEquipo, $itemPlan, $infoHorometroParaCalculo);

            $data = array(
                'fecha_original'    => $fechaOriginal->toString('yyyy-MM-dd'),
                'codigo'            => 223,
                'horas'             => $itemPlan->cantidad_horas,
                'aviso'             => $fechaOriginal->sub($itemPlan->dias_aviso, Zend_Date::DAY)->toString('yyyy-MM-dd')
            );

            return $data;
            
        } else {
            
            if($ultimoServicio['horometro'] == NULL){
                
                $data = array(
                    'fecha_original'    => NULL,
                    'codigo'            => 104,
                    'horas'             => NULL,
                    'aviso'             => NULL
                );
                
                return $data;
                
            }  else {
                
                $fechaOriginal = $this->_calcularFechaProximoEvento($ultimoServicio, $itemPlan, $infoHorometroParaCalculo);
                
                $data = array(
                    'fecha_original'    => $fechaOriginal->toString('yyyy-MM-dd'),
                    'codigo'            => 224,
                    'horas'             => $ultimoServicio['horometro'] + $itemPlan->cantidad_horas,
                    'aviso'             => $fechaOriginal->sub($itemPlan->dias_aviso, Zend_Date::DAY)->toString('yyyy-MM-dd')
                );
                
                return $data;
            }
        }
    }
    
    private function _calcularFechaPrimerEvento($dataEquipo, $itemPlan, $infoHorometro = NULL)
    {
        if($infoHorometro != NULL){
            
            $fechaPrimerEventoCalculado = new Zend_Date($dataEquipo->inicio_operaciones, Zend_Date::ISO_8601);
            $diasCalculados = floor($itemPlan->cantidad_horas / $infoHorometro['promedio_diario_horas']);
            $fechaPrimerEventoCalculado->add($diasCalculados, Zend_Date::DAY);
            
            if($itemPlan->cantidad_dias != NULL){
                $fechaPrimerEventoTope = new Zend_Date($dataEquipo->inicio_operaciones, Zend_Date::ISO_8601);
                $fechaPrimerEventoTope->add($itemPlan->cantidad_dias, Zend_Date::DAY);
                if($fechaPrimerEventoCalculado->isLater($fechaPrimerEventoTope)){
                    return $fechaPrimerEventoTope;
                }
            }
            return $fechaPrimerEventoCalculado;        
                    
            /*
            $horasRestantes = $itemPlan->cantidad_horas - $infoHorometro['ultima_lectura'];
            $diasRestantes = floor($horasRestantes / $infoHorometro['promedio_diario_horas']);
            $fechaPrimerEventoCalculado = new Zend_Date(date("Y-m-d"), Zend_Date::ISO_8601);
            $fechaPrimerEventoCalculado->add($diasRestantes, Zend_Date::DAY);
            
            if($itemPlan->cantidad_dias != NULL){
                $fechaPrimerEventoTope = new Zend_Date($dataEquipo->inicio_operaciones, Zend_Date::ISO_8601);
                $fechaPrimerEventoTope->add($itemPlan->cantidad_dias, Zend_Date::DAY);
                if($fechaPrimerEventoCalculado->isLater($fechaPrimerEventoTope)){
                    return $fechaPrimerEventoTope;
                }
            }
            return $fechaPrimerEventoCalculado;
            */
            
        } else {
            $fechaPrimerEvento = new Zend_Date($dataEquipo->inicio_operaciones, Zend_Date::ISO_8601);
            $fechaPrimerEvento->add($itemPlan->cantidad_dias, Zend_Date::DAY);
            return $fechaPrimerEvento;
        }
    }
    
    private function _calcularFechaProximoEvento($ultimoServicio, $itemPlan, $infoHorometro = NULL)
    {
        if($infoHorometro != NULL){
            $horasRestantes = $ultimoServicio['horometro'] + $itemPlan->cantidad_horas - $infoHorometro['ultima_lectura'];
            $diasRestantes = floor($horasRestantes / $infoHorometro['promedio_diario_horas']);
            $fechaProximoEventoCalculado = new Zend_Date(date("Y-m-d"), Zend_Date::ISO_8601);
            $fechaProximoEventoCalculado->add($diasRestantes, Zend_Date::DAY);
            
            if($itemPlan->cantidad_dias != NULL){
                $fechaProximoEventoTope = new Zend_Date($ultimoServicio['fecha'], Zend_Date::ISO_8601);
                $fechaProximoEventoTope->add($itemPlan->cantidad_dias, Zend_Date::DAY);
                if($fechaProximoEventoCalculado->isLater($fechaProximoEventoTope)){
                    return $fechaProximoEventoTope;
                }
                
            }
            return $fechaProximoEventoCalculado;
            
        } else {
            $fechaProximoEvento = new Zend_Date($ultimoServicio['fecha'], Zend_Date::ISO_8601);
            $fechaProximoEvento->add($itemPlan->cantidad_dias, Zend_Date::DAY);
            return $fechaProximoEvento;
        }
    }
    
    public function cerrarEvento($dataMantenimiento)
    {
        $row = $this->getRow();
        $row->estado = 1;
        $row->fecha_final = $dataMantenimiento['fecha'];
        $row->mantenimiento_id = $dataMantenimiento['id'];
        $row->save();
    }
    
    public function getEventoByData($servicio_id, $equipo_id)
    {
        $where = $this->getAdapter()->quoteInto("servicio_id=? AND equipo_id='$equipo_id' AND estado='0'", $servicio_id);
        $row = $this->fetchRow($where);
        if($row){
            $data = $row->toArray();
            $data['referencia'] = NULL;
            if($row['dependencia_tipo'] === 'S'){
                $dataReferencia = $this->find($row['dependencia_id'])->current();
                if($dataReferencia){
                    $equipo = $this->_getEquipo($dataReferencia['equipo_id']);
                    $servicio = $this->_getServicio($dataReferencia['servicio_id']);
                    $data['referencia'] = $equipo['nombre'] . ' > ' . $servicio['nombre'];
                } 
            } 
            return $data;
        }
        return NULL;
    }
    
    public function getInfoByDataToProyeccion($servicio_id, $equipo_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('na' => 'naves_actividades'), array('id', 'fecha_editada', 'horas'))
               ->join(array('s' => 'base_servicios'), 'na.servicio_id=s.id', array('servicio' => 'nombre')) 
               ->where("na.estado='0'") 
               ->where("na.servicio_id=?", $servicio_id)
               ->where("na.equipo_id=?", $equipo_id);
        return $adapter->fetchRow($select);
    }
    
    private function _getServicio($id)
    {
        $servicio = new Shipcode_Model_BaseServicio();
        $servicio->setId($id);
        return $servicio->getRow()->toArray();
    }
    
    private function _getEquipo($id)
    {
        $equipo = new Shipcode_Model_NaveEquipo();
        $equipo->setId($id);
        return $equipo->getRow()->toArray();
    }
    
    public function eliminarEventosAsociadosAlItem($dataItem)
    {
        $where = "estado = '0' AND servicio_id = '" . $dataItem['servicio_id'] ."' AND equipo_id IN (SELECT id FROM naves_equipos WHERE planmant_id='" . $dataItem['plan_id'] . "')";
        $registros = $this->fetchAll($where);
        if(count($registros) > 0) {
            return $this->delete($where);
        }
        return TRUE;
    }
    
    public function eliminarEventosAsociadosAlPlan($plan_id)
    {
        $where = "estado = '0' AND equipo_id IN (SELECT id FROM naves_equipos WHERE planmant_id='$plan_id')";
        $registros = $this->fetchAll($where);
        if(count($registros) > 0){
            return $this->delete($where);
        }
        return TRUE;
    }
    
    public function eliminarEventosUbicacionesVirtuales()
    {
        $uVirtual = new Shipcode_Model_UbicacionVirtual();
        $uVirtuales = $uVirtual->fetchAll();
        
        if(count($uVirtuales) > 0 ) { 
            $modelEquipo = new Shipcode_Model_NaveEquipo();
            foreach($uVirtuales as $ubicacion){
                $equipos = $modelEquipo->getRowsByUbicacionvId($ubicacion->id);
                if(count($equipos) > 0){
                    foreach($equipos as $equipo){
                        $this->eliminarEventosAsociadosAlEquipo($equipo['id']);
                    }
                }
                return $equipos;
            }
        }
    }
    
    public function eliminarEventosAsociadosAlEquipo($equipo_id, $programacion = NULL)
    {
        if($programacion == NULL){
            $where = $this->getAdapter()->quoteInto("estado = '0' AND equipo_id=?", $equipo_id);
        } else {
            $where = $this->getAdapter()->quoteInto("programacion = '$programacion' AND estado = '0' AND equipo_id = ?", $equipo_id);
        }
        return $this->delete($where);
    }
    
    public function eliminarUltimoByData(array $dataParaEliminar)
    {
        if(!is_array($dataParaEliminar)) {
            throw new Exception("No se ha la información requerda para eliminar el evento");
        }
        $where = "servicio_id='". $dataParaEliminar['servicio_id'] ."' AND equipo_id='" . $dataParaEliminar['equipo_id'] . "' AND estado='0'";
        $this->delete($where);
    }
    
    public function eliminarEventoById()
    {
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getNaveId()
    {
       $equipo = new Shipcode_Model_NaveEquipo();
       $equipo->setId($this->getRow()->equipo_id);
       return $equipo->getNaveId();
    }
    
    public function getCountVencidos($empresa_id = NULL)
    {
        $adapter = $this->getAdapter();
        
        if($empresa_id != NULL){
            $sql = "SELECT COUNT(*) FROM naves_actividades AS na "
                 . "JOIN naves_equipos AS ne ON ne.id=na.equipo_id "   
                 . "JOIN naves_equipos_ubicaciones AS neu ON neu.id=ne.ubicacion_id " 
                 . "JOIN naves_sistemas AS ns ON ns.id=neu.sistema_id "
                 . "JOIN naves AS n ON n.id=ns.nave_id "   
                 . "WHERE n.empresa_id ='$empresa_id' "
                 . "AND na.estado ='0' "   
                 . "AND na.fecha_editada IS NOT NULL AND CURDATE() >= na.fecha_editada";
        } else {
            $sql = "SELECT COUNT(*) FROM naves_actividades AS na "
                 . "WHERE na.fecha_editada IS NOT NULL "
                 . "AND na.estado ='0' "      
                 . "AND CURDATE() >= na.fecha_editada";
        }
        
        $num = $adapter->fetchOne($sql);
        if($num){
            return $num;
        } 
        return 0;
    }
    
    public function getCountPorVencer($empresa_id = NULL)
    {
        $adapter = $this->getAdapter();
        
        if($empresa_id != NULL){
            $sql = "SELECT COUNT(*) FROM naves_actividades AS na " 
                 . "JOIN naves_equipos AS ne ON ne.id=na.equipo_id "   
                 . "JOIN naves_equipos_ubicaciones AS neu ON neu.id=ne.ubicacion_id " 
                 . "JOIN naves_sistemas AS ns ON ns.id=neu.sistema_id "
                 . "JOIN naves AS n ON n.id=ns.nave_id "   
                 . "WHERE n.empresa_id ='$empresa_id' "
                 . "AND na.estado='0' "   
                 . "AND na.fecha_editada IS NOT NULL "
                 . "AND CURDATE() > na.aviso AND CURDATE() < na.fecha_editada ";
        } else {
            $sql = "SELECT COUNT(*) FROM naves_actividades AS na "
                 . "WHERE na.fecha_editada IS NOT NULL "
                 . "AND na.estado='0' "     
                 . "AND na.fecha_editada >= CURDATE() "
                 . "AND CURDATE() > na.aviso AND CURDATE() < na.fecha_editada ";
        }
        
        
        $num = $adapter->fetchOne($sql);
        if($num){
            return $num;
        } 
        return 0;
    }
    
    public function buscar($data, $privilegiosNaves = NULL)
    {
        $dataEventos = array();
        $dataEvento = array();
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('na' => 'naves_actividades'), array(
                    'id', 'equipo_id', 'servicio_id', 'fecha_original', 'fecha_editada', 'horas', 
                    'codigo', 'programacion', 'dependencia_tipo', 'dependencia_id', 'aviso',
                    'DATEDIFF(fecha_editada, CURDATE()) AS dias_restantes'
               ))
               ->join(array('s' => 'base_servicios'), 'na.servicio_id=s.id', array('servicio' => 'nombre')) 
               ->join(array('ne' => 'naves_equipos'), 'na.equipo_id=ne.id', array('equipo' => 'nombre', 'modelo', 'horometro', 'planmant_id'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->join(array('ns' => 'naves_sistemas'), 'neu.sistema_id=ns.id', array('sistema' => 'nombre'))  
               ->join(array('n' => 'naves'), 'ns.nave_id=n.id', array('nave' => 'nombre', 'nave_id' => 'id'))  
               ->where("ne.planmant_id IS NOT NULL")
               ->where("na.estado='0'");
       
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        if($data['nave']!='') {
            $select->where("ns.nave_id=?", $data['nave']);
        } elseif($privilegiosNaves !== NULL) {
            $navesIds = Shipcode_Model_SistemaUsuario::filtrarNavesAutorizadas($privilegiosNaves);
            $select->where("ns.nave_id IN($navesIds)");
        }
        if($data['sistema']!='') {
            $select->where("neu.sistema_id=?", $data['sistema']);
        }
        if($data['equipo']!='') {
            $select->where("ne.id=?", $data['equipo']);
        }
        if($data['servicio']!='' && $data['servicio'] != 0) {
            $select->where("na.servicio_id=?", $data['servicio']);
        }
        if($data['desde'] != NULL){
           $select->where('na.fecha_editada >= ?', $data['desde']);
        }
        if($data['hasta'] != NULL){
            $select->where('na.fecha_editada <= ?', $data['hasta']);
        }
        if($data['programacion'] != NULL){
            $select->where('na.programacion=?', $data['programacion']);
        }
        if($data['estado'] != 0){
            if($data['estado'] == 1){
                $select->where('CURDATE() > na.aviso AND CURDATE() < na.fecha_editada');
            } elseif($data['estado'] == 2){
                $select->where('CURDATE() >= na.fecha_editada');
            }
        }
        $rows = $adapter->fetchAll($select);
        
        if(count($rows) > 0){
            
            $modelHorometro = new Shipcode_Model_NaveHorometroLectura();
            $modelItemPlan = new Shipcode_Model_BasePlanMantItem();
            
            foreach($rows as $row){
                
                $dataEvento = $row;
                $dataEvento['horas_actuales'] = NULL;
                $dataEvento['horas_restantes'] = NULL;
                
                if($row['horometro'] == 1){
                    
                    $horometro = $modelHorometro->getUltimaLectura($row['equipo_id']);
                    $dataEvento['horas_actuales'] = $horometro['lectura'];
                    $dataEvento['horas_restantes'] = $row['horas'] - $dataEvento['horas_actuales'];
                } 
                
                $itemPlan = $modelItemPlan->getRowByServicioIdAndPlanId($row['servicio_id'], $row['planmant_id']);
                if($itemPlan->cantidad_horas != NULL && $itemPlan->cantidad_dias != NULL) {
                    $dataEvento['ciclo'] = $itemPlan->cantidad_horas . ' H / ' . $itemPlan->cantidad_dias . ' D';
                } elseif($itemPlan->cantidad_horas != NULL && $itemPlan->cantidad_dias == NULL){
                    $dataEvento['ciclo'] = $itemPlan->cantidad_horas . ' H';
                } elseif($itemPlan->cantidad_horas == NULL && $itemPlan->cantidad_dias != NULL){
                    $dataEvento['ciclo'] = $itemPlan->cantidad_dias . ' D';
                }
                
                if($row['programacion'] == 'AUTOMATICA'){
                    $dataEvento['programacion'] = 'A';
                } else {
                    $dataEvento['programacion'] = 'M';
                }
                $dataEventos[] = $dataEvento;
            }
        }
        return $dataEventos;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('na' => 'naves_actividades'), array(
                    'id', 'equipo_id', 'servicio_id', 'fecha_original', 'fecha_editada', 'horas', 
                    'codigo', 'programacion', 'dependencia_tipo', 'dependencia_id', 'aviso',
                    'DATEDIFF(fecha_editada, CURDATE()) AS dias_restantes'
               ))
               ->join(array('s' => 'base_servicios'), 'na.servicio_id=s.id', array('servicio' => 'nombre')) 
               ->join(array('ne' => 'naves_equipos'), 'na.equipo_id=ne.id', array('equipo' => 'nombre', 'modelo', 'horometro', 'planmant_id'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->join(array('ns' => 'naves_sistemas'), 'neu.sistema_id=ns.id', array('sistema' => 'nombre'))  
               ->join(array('n' => 'naves'), 'ns.nave_id=n.id', array('nave' => 'nombre', 'nave_id' => 'id'))  
               ->where("na.id=?", $this->_id);
        
        $actividad = $adapter->fetchRow($select);
        if($actividad){
            
            $modelHorometro = new Shipcode_Model_NaveHorometroLectura();
            $modelItemPlan = new Shipcode_Model_BasePlanMantItem();
            
            $dataEvento = $actividad;
            $dataEvento['horas_actuales'] = NULL;
            $dataEvento['horas_restantes'] = NULL;
            if($actividad['horometro'] == 1){

                $horometro = $modelHorometro->getUltimaLectura($actividad['equipo_id']);
                $dataEvento['horas_actuales'] = $horometro['lectura'];
                $dataEvento['horas_restantes'] = $actividad['horas'] - $dataEvento['horas_actuales'];
            } 
            $itemPlan = $modelItemPlan->getRowByServicioIdAndPlanId($actividad['servicio_id'], $actividad['planmant_id']);
            if($itemPlan->cantidad_horas != NULL && $itemPlan->cantidad_dias != NULL) {
                $dataEvento['ciclo'] = $itemPlan->cantidad_horas . ' H / ' . $itemPlan->cantidad_dias . ' D';
            } elseif($itemPlan->cantidad_horas != NULL && $itemPlan->cantidad_dias == NULL){
                $dataEvento['ciclo'] = $itemPlan->cantidad_horas . ' H';
            } elseif($itemPlan->cantidad_horas == NULL && $itemPlan->cantidad_dias != NULL){
                $dataEvento['ciclo'] = $itemPlan->cantidad_dias . ' D';
            }
            if($actividad['programacion'] == 'AUTOMATICA'){
                $dataEvento['programacion'] = 'A';
            } else {
                $dataEvento['programacion'] = 'M';
            }
            return $dataEvento;
        }
        return FALSE;
    }
    
    public function getRowsForProgramacionMensual($programacion, $full = TRUE)
    {
        $fechaInicio = $programacion->year . "-" . $programacion->mes . "-01"; 
        $mes = new Shipcode_Model_AuxMes();
        $mes->setMes($fechaInicio);
        $fechaLimite = $programacion->year . "-" . $programacion->mes . "-" . $mes->getUltimoDia();
        
        $adapter = $this->getDefaultAdapter();
        $selActividades = $adapter->select();
        $selActividades->from(array('na' => 'naves_actividades'), array(
                            'id', 'equipo_id', 'servicio_id', 'fecha_original', 'fecha_editada', 'horas', 
                            'codigo', 'programacion', 'dependencia_tipo', 'dependencia_id', 'aviso'))   
                       ->join(array('ne' => 'naves_equipos'), 'na.equipo_id=ne.id', array())
                        ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
                        ->join(array('ns' => 'naves_sistemas'), 'neu.sistema_id=ns.id', array())
                       ->join(array('s' => 'base_servicios'), 'na.servicio_id=s.id', array('servicio' => 'nombre')) 
                       ->where("ns.nave_id=?", $programacion->nave_id)
                       ->where("na.id NOT IN(SELECT actividad_id FROM programaciones_mensuales_trabajos WHERE sel='1' AND estado='TERMINADO')")
                       ->where("na.estado='0'");
        
        if($full === FALSE) {
            $selActividades->where("YEAR(na.fecha_editada)=?", $programacion->year)
                           ->where("MONTH(na.fecha_editada)=?", $programacion->mes);
        } else {
            $selActividades->where("na.fecha_editada <=?", $fechaLimite);
        }
        $selActividades->order("na.equipo_id");

        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $actividades = $adapter->fetchAll($selActividades);
        return $actividades;
    }
    
    public function getRowsByEventosId(array $eventosIds)
    {
        if(count($eventosIds) > 0){
            
            $adapter = $this->getAdapter();
            $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
            $eventos = array();
            
            foreach($eventosIds as $key => $id){
                $select = $adapter->select();
                $select->from(array('na' => 'naves_actividades'), array(
                        'id', 'equipo_id', 'servicio_id', 'fecha_original', 'DATE_FORMAT(fecha_editada, "%d/%m/%Y") AS fecha_editada', 'horas', 
                        'codigo', 'programacion', 'dependencia_tipo', 'dependencia_id', 'aviso',
                        'DATEDIFF(fecha_editada, CURDATE()) AS dias_restantes'
                        ))
                        ->join(array('s' => 'base_servicios'), 'na.servicio_id=s.id', array('servicio' => 'nombre')) 
                        ->join(array('ne' => 'naves_equipos'), 'na.equipo_id=ne.id', array('equipo' => 'nombre', 'modelo', 'horometro', 'planmant_id'))
                        ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
                        ->join(array('ns' => 'naves_sistemas'), 'neu.sistema_id=ns.id', array('sistema' => 'nombre'))  
                        ->join(array('n' => 'naves'), 'ns.nave_id=n.id', array('nave' => 'nombre', 'nave_id' => 'id'))  
                        ->where("na.id='$id'");
                $eventos[] = $adapter->fetchRow($select);
            }
            return $eventos;
        }
        return NULL;
    }
    
    public function getRowsByEquipoId($equipo_id, $estado = NULL, $tipoProgramacion = NULL)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('na' => 'naves_actividades'), array('id'))
               ->where("na.equipo_id='$equipo_id'");
        
        if($estado != NULL && $estado == 0 || $estado == 1) {
            $select->where("na.estado='$estado'");
        } 
        
        if($tipoProgramacion != NULL && $tipoProgramacion == 'AUTOMATICA' || $estado == 'MANUAL') {
               $select->where("na.programacion='$tipoProgramacion'");
        }
        
        $eventosId = $adapter->fetchCol($select);
        return $eventosId;
    }
    
    public function getHtmlToPdf($rows)
    {
        $content = '<h1>Informe Mantenimientos Programados</h1>'
                 . '<p class="text-muted">Realizado el ' . Shipcode_Model_Fecha::format(date("Y-m-d")) . ', a las ' . date("H:i") . '</p>'
                 . '<hr>'
                 . '<p>Se encontraron ' . count($rows) . ' resultados</p>'
                 . '<table border="1" cellpadding="4"><thead><tr>'
                 . '<th>Nave</th>'
                 . '<th>Equipo</th>'
                 . '<th>Servicio</th>'
                 . '<th>Ciclo</th>'
                 . '<th>Fecha programada</th>'
                 . '<th>Días restantes</th>'
                 . '<th>Horas programación</th>'
                 . '<th>Horas última lectura</th>'
                 . '<th>Horas restantes</th>'
                 . '</tr></thead><tbody>';
        
        if(count($rows) > 0) {
            foreach($rows as $actividad) { 
                $content .= '<tr>'
                          . '<td>' . $actividad['nave'] . '</td>'
                          . '<td>' . $actividad['equipo'] . '</td>'
                          . '<td>' . $actividad['servicio'] . '</td>'
                          . '<td>' . $actividad['ciclo'] . '</td>'
                          . '<td>' . Shipcode_Model_Fecha::formatShort($actividad['fecha_editada']) . '</td>'
                          . '<td>' . $actividad['dias_restantes'] . '</td>'
                          . '<td>' . $actividad['horas'] . '</td>'
                          . '<td>' . $actividad['horas_actuales'] . '</td>'
                          . '<td>' . $actividad['horas_restantes'] . '</td>';
                $content .= '</tr>';
            } 
        } else {
            $content .= '<tr><td colspan="9">No se encontraron registros coincidentes para su búsqueda.</td></tr>';
        }
        $content .= '</table></div></tbody></html>';
        return $content;
    }
    
    /* En proceso de eliminación
    public function buscar($data)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('na' => 'naves_actividades'), array(
                    'id', 'equipo_id', 'servicio_id', 'fecha_original', 'DATE_FORMAT(fecha_editada, "%d/%m/%Y") AS fecha_editada', 'horas', 
                    'codigo', 'programacion', 'dependencia_tipo', 'dependencia_id', 'aviso',
                    'DATEDIFF(fecha_editada, CURDATE()) AS dias_restantes'
               ))
               ->join(array('s' => 'base_servicios'), 'na.servicio_id=s.id', array('servicio' => 'nombre')) 
               ->join(array('ne' => 'naves_equipos'), 'na.equipo_id=ne.id', array('equipo' => 'nombre', 'modelo', 'horometro', 'planmant_id'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->join(array('ns' => 'naves_sistemas'), 'neu.sistema_id=ns.id', array('sistema' => 'nombre'))  
               ->join(array('n' => 'naves'), 'ns.nave_id=n.id', array('nave' => 'nombre', 'nave_id' => 'id'))  
               ->where("na.estado='0'")
               ->where("ne.planmant_id IS NOT NULL");
       
        
        if($data['empresa_id']!='') {
            $select->where("n.empresa_id=?", $data['empresa_id']);
        }
        
        if($data['nave_id']!='') {
            $select->where("ns.nave_id=?", $data['nave_id']);
        }
        
        if($data['sistema_id']!='') {
            $select->where("neu.sistema_id=?", $data['sistema_id']);
        }
        
        if($data['equipo_id']!='') {
            $select->where("ne.id=?", $data['equipo_id']);
        }
        
        if($data['servicio_id']!='') {
            $select->where("na.servicio_id=?", $data['servicio_id']);
        }
       
        $rows = $adapter->fetchAll($select);
        return $rows;
    }
    public function buscarPorEstado2($data)
    {
        $dataResult = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('ne' => 'naves_equipos'), 
                    array(
                        'id', 'creacion', 'creador', 'tipo_id', 'marca_id',  
                        'modelo', 'nombre', 'horometro', 'parametros', 'planmant_id'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->join(array('ns' => 'naves_sistemas'), 'neu.sistema_id=ns.id', array('sistema' => 'nombre'))  
               ->join(array('n' => 'naves'), 'ns.nave_id=n.id', array('nave' => 'nombre', 'nave_id' => 'id'))  
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'))
               ->where("ne.planmant_id IS NOT NULL");
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        
        if($data['nave']!='') {
            $select->where("ns.nave_id=?", $data['nave']);
        }
        
        if($data['sistema']!='') {
            $select->where("neu.sistema_id=?", $data['sistema']);
        }
        
        if($data['equipo']!='') {
            $select->where("ne.id=?", $data['equipo']);
        }
        
        $rowsEquipos = $adapter->fetchAll($select);
        
        if(count($rowsEquipos) > 0){
            $modelEquipo = new Shipcode_Model_NaveEquipo();
            foreach($rowsEquipos as $rowEquipo){
                
                $modelEquipo->setId($rowEquipo['id']);
                $ultimaLecturaHorometro = $modelEquipo->getUltimaLecturaHorometro();
                $itemsPlan = $modelEquipo->getItemsPlanMantenimientoParaBusqueda($rowEquipo['planmant_id'], $data);
                
                foreach($itemsPlan as $itemPlan){
                    
                    $proximoServicio = $this->getProximoServicio($itemPlan['id'], $rowEquipo['id']);
                    
                    $itemPlan['empresa'] = $rowEquipo['empresa'];
                    $itemPlan['nave'] = $rowEquipo['nave'];
                    $itemPlan['nave_id'] = $rowEquipo['nave_id'];
                    $itemPlan['sistema'] = $rowEquipo['sistema'];
                    $itemPlan['equipo'] = $rowEquipo['nombre'];
                    $itemPlan['proximo_servicio'] = $proximoServicio;
                    $itemPlan['horometro'] = $ultimaLecturaHorometro;
                    
                    $fechaEstimada = new Zend_Date($proximoServicio['fecha_estimada'], 'yyyy-MM-dd');
                    $fechaHoy = new Zend_Date(date("Y-m-d"), 'yyyy-MM-dd');
                    
                    if($data['desde'] != NULL || $data['hasta'] != NULL){
                        
                        if($proximoServicio['fecha_estimada'] != NULL){
                            if($data['desde'] != NULL){
                                $fechaDesde = new Zend_Date($data['desde'], 'yyyy-MM-dd');
                            }
                            if($data['hasta'] != NULL){
                                $fechaHasta = new Zend_Date($data['hasta'], 'yyyy-MM-dd');
                            }
                            if($data['desde'] != NULL && $data['hasta'] == NULL && $fechaEstimada->isLater($fechaDesde)){
                                $dataResult[] = $itemPlan;
                            } elseif($data['desde'] != NULL && $data['hasta'] != NULL && $fechaEstimada->isLater($fechaDesde) && $fechaEstimada->isEarlier($fechaHasta)){
                                $dataResult[] = $itemPlan;
                            } elseif($data['desde'] == NULL && $data['hasta'] != NULL && $fechaEstimada->isEarlier($fechaHasta)){
                                $dataResult[] = $itemPlan;
                            }
                        }
                        
                    } else {
                        
                        // ítems vencidos
                        if($data['estado'] == 0) {
                            $dataResult[] = $itemPlan;
                        } else {

                            

                            if($data['estado'] == 2) {
                                if($proximoServicio['fecha_estimada'] != NULL && $proximoServicio['lectura'] != NULL){
                                    if($ultimaLecturaHorometro['lectura'] > $proximoServicio['lectura'] || $fechaEstimada->isEarlier($fechaHoy)){
                                        $dataResult[] = $itemPlan;
                                    }
                                }    
                            } elseif($data['estado'] == 1) {

                                if($itemPlan['unidad_medida'] == 'H' && $proximoServicio['lectura'] != NULL){

                                    $horasAviso = $proximoServicio['lectura'] - $itemPlan['aviso_cant']; 
                                    if($ultimaLecturaHorometro['lectura'] > $horasAviso && $ultimaLecturaHorometro['lectura'] < $proximoServicio['lectura']){
                                        $dataResult[] = $itemPlan;
                                    }

                                } elseif($itemPlan['unidad_medida'] == 'D' && $proximoServicio['fecha_estimada'] != NULL) {

                                    $fechaAviso = new Zend_Date($fechaEstimada->toString("yyyy-MM-dd"), 'yyyy-MM-dd');
                                    $fechaAviso->sub($itemPlan['aviso_cant'], Zend_Date::DAY);
                                    if($fechaHoy->isLater($fechaAviso) && $fechaAviso->isEarlier($fechaEstimada)){
                                        $dataResult[] = $itemPlan;
                                    }
                                }
                            } 
                        }
                    }
                }
            }
        }
        return $dataResult;
    }
    // Falta probar **
    public function buscarPorFecha($data)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('na' => 'naves_actividades'), 
                    array(
                        'id', 'creacion', 'creador', 'fecha', 'equipo_id', 
                        'servicio_id', 'horas', 'tipo', 'programacion'))
               ->joinLeft(array('bpi' => 'base_planesmant_items'), 'na.item_id=bpi.id', array())  
               ->joinLeft(array('bs' => 'base_servicios'), 'bpi.servicio_id=bs.id', array('detalle' => 'nombre'))   
               ->joinLeft(array('ne' => 'naves_equipos'), 'na.equipo_id=ne.id', array('equipo' => 'nombre')) 
               ->join(array('ns' => 'naves_sistemas'), 'ne.sistema_id=ns.id', array('sistema' => 'nombre')) 
               ->join(array('n' => 'naves'), 'ns.nave_id=n.id', array('nave' => 'nombre'))  
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'));
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        
        if($data['nave']!='') {
            $select->where("ns.nave_id=?", $data['nave']);
        }
        
        if($data['sistema']!='') {
            $select->where("ns.id=?", $data['sistema']);
        }
        
        if($data['equipo']!='') {
            $select->where("na.equipo_id=?", $data['equipo']);
        }
        
        if($data['servicio']!='') {
            $select->where("na.servicio_id=?", $data['servicio']);
        }
        
        if($data['desde'] != NULL) {
            $select->where("na.fecha_estimada IS NOT NULL AND na.fecha_estimada >= ?", $data['desde']);
        }
        
        if($data['hasta'] != NULL) {
            $select->where("na.fecha_estimada IS NOT NULL AND na.fecha_estimada <= ?", $data['hasta']);
        }
        
        if($data['estado'] == 3){
            
            $select->where("na.fecha IS NULL");
            
        } elseif($data['estado'] == 2 ) {
            
            $select->where("na.fecha IS NOT NULL AND CURDATE() >= na.fecha");
            
        } elseif($data['estado'] == 1 ) {    
            
            $diasAviso = (int)Shipcode_Model_SistemaPreferencia::getPref('DIAS_AVISO_MANTENIMIENTOS');
            $select->where("na.fecha IS NOT NULL AND na.fecha >= CURDATE() AND na.fecha <= (CURDATE() + INTERVAL $diasAviso DAY)");
        }
        return $adapter->fetchAll($select);
    }

    public function editarEvento($data, $user, $programacion = 'AUTOMATICA')
    {
        $data['creador'] = $user;
        $data['programacion'] = $programacion;
        $where = "equipo_id = '" . $data['equipo_id'] . "' AND servicio_id = '" . $data['servicio_id'] . "'";
        $row = $this->fetchRow($where);
        $row->setFromArray($data);
        return $row->save();
    }
    public function buscarPorEstado($data)
    {
        $dataResult = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('ne' => 'naves_equipos'), 
                    array(
                        'id', 'creacion', 'creador', 'tipo_id', 'marca_id',  
                        'modelo', 'nombre', 'horometro', 'parametros', 'planmant_id'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->join(array('ns' => 'naves_sistemas'), 'neu.sistema_id=ns.id', array('sistema' => 'nombre'))  
               ->join(array('n' => 'naves'), 'ns.nave_id=n.id', array('nave' => 'nombre', 'nave_id' => 'id'))  
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'))
               ->where("ne.planmant_id IS NOT NULL");
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        
        if($data['nave']!='') {
            $select->where("ns.nave_id=?", $data['nave']);
        }
        
        if($data['sistema']!='') {
            $select->where("neu.sistema_id=?", $data['sistema']);
        }
        
        if($data['equipo']!='') {
            $select->where("ne.id=?", $data['equipo']);
        }
        
        $rowsEquipos = $adapter->fetchAll($select);
        
        if(count($rowsEquipos) > 0){
            $modelEquipo = new Shipcode_Model_NaveEquipo();
            foreach($rowsEquipos as $rowEquipo){
                
                $modelEquipo->setId($rowEquipo['id']);
                $ultimaLecturaHorometro = $modelEquipo->getUltimaLecturaHorometro();
                $itemsPlan = $modelEquipo->getItemsPlanMantenimientoParaBusqueda($rowEquipo['planmant_id'], $data);
                
                foreach($itemsPlan as $itemPlan){
                    
                    $proximoServicio = $this->getProximoServicio($itemPlan['id'], $rowEquipo['id']);
                    
                    $itemPlan['empresa'] = $rowEquipo['empresa'];
                    $itemPlan['nave'] = $rowEquipo['nave'];
                    $itemPlan['nave_id'] = $rowEquipo['nave_id'];
                    $itemPlan['sistema'] = $rowEquipo['sistema'];
                    $itemPlan['equipo'] = $rowEquipo['nombre'];
                    $itemPlan['proximo_servicio'] = $proximoServicio;
                    $itemPlan['horometro'] = $ultimaLecturaHorometro;
                    
                    $fechaEstimada = new Zend_Date($proximoServicio['fecha_estimada'], 'yyyy-MM-dd');
                    $fechaHoy = new Zend_Date(date("Y-m-d"), 'yyyy-MM-dd');
                    
                    if($data['desde'] != NULL || $data['hasta'] != NULL){
                        
                        if($proximoServicio['fecha_estimada'] != NULL){
                            if($data['desde'] != NULL){
                                $fechaDesde = new Zend_Date($data['desde'], 'yyyy-MM-dd');
                            }
                            if($data['hasta'] != NULL){
                                $fechaHasta = new Zend_Date($data['hasta'], 'yyyy-MM-dd');
                            }
                            if($data['desde'] != NULL && $data['hasta'] == NULL && $fechaEstimada->isLater($fechaDesde)){
                                $dataResult[] = $itemPlan;
                            } elseif($data['desde'] != NULL && $data['hasta'] != NULL && $fechaEstimada->isLater($fechaDesde) && $fechaEstimada->isEarlier($fechaHasta)){
                                $dataResult[] = $itemPlan;
                            } elseif($data['desde'] == NULL && $data['hasta'] != NULL && $fechaEstimada->isEarlier($fechaHasta)){
                                $dataResult[] = $itemPlan;
                            }
                        }
                        
                    } else {
                        
                        // ítems vencidos
                        if($data['estado'] == 0) {
                            $dataResult[] = $itemPlan;
                        } else {

                            

                            if($data['estado'] == 2) {
                                if($proximoServicio['fecha_estimada'] != NULL && $proximoServicio['lectura'] != NULL){
                                    if($ultimaLecturaHorometro['lectura'] > $proximoServicio['lectura'] || $fechaEstimada->isEarlier($fechaHoy)){
                                        $dataResult[] = $itemPlan;
                                    }
                                }    
                            } elseif($data['estado'] == 1) {

                                if($itemPlan['unidad_medida'] == 'H' && $proximoServicio['lectura'] != NULL){

                                    $horasAviso = $proximoServicio['lectura'] - $itemPlan['aviso_cant']; 
                                    if($ultimaLecturaHorometro['lectura'] > $horasAviso && $ultimaLecturaHorometro['lectura'] < $proximoServicio['lectura']){
                                        $dataResult[] = $itemPlan;
                                    }

                                } elseif($itemPlan['unidad_medida'] == 'D' && $proximoServicio['fecha_estimada'] != NULL) {

                                    $fechaAviso = new Zend_Date($fechaEstimada->toString("yyyy-MM-dd"), 'yyyy-MM-dd');
                                    $fechaAviso->sub($itemPlan['aviso_cant'], Zend_Date::DAY);
                                    if($fechaHoy->isLater($fechaAviso) && $fechaAviso->isEarlier($fechaEstimada)){
                                        $dataResult[] = $itemPlan;
                                    }
                                }
                            } 
                        }
                    }
                }
            }
        }
        return $dataResult;
    } 
    */
}