<?php
class Shipcode_Model_NaveArchivo extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_archivos';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getAll()
    {
        return $this->fetchAll();
    }
    
    public function setFileNotFound($archivoId)
    {
        $row = $this->find($archivoId)->current();
        $row->nombre = $row->nombre . " (NO ENCONTRADO)";
        $row->save();
    }
    
    public function getNaveId()
    {
        return $this->getRow()->nave_id;
    }
    
    public function getRowsByNaveId($nave_id)
    {
        $archivos = array();
        $etiqueta = new Shipcode_Model_EtiquetaArchivo();
        $etiquetasNave = $etiqueta->getParaNaves();
        if($etiquetasNave > 0){
            foreach($etiquetasNave as $etiquetaNave){
                
                $rowEtiqueta['id'] = $etiquetaNave['id'];
                $rowEtiqueta['nombre'] = $etiquetaNave['nombre'];
                    
                $whereEtiqueta = $this->getAdapter()->quoteInto("nave_id=? AND etiqueta_id='" .$etiquetaNave['id'] ."'", $nave_id);
                $archivosEtiqueta = $this->fetchAll($whereEtiqueta)->toArray();
                
                if(count($archivosEtiqueta) > 0 ) {
                    $rowEtiqueta['archivos'] = $archivosEtiqueta;
                } else {
                    $rowEtiqueta['archivos'] = NULL;
                }
                $archivos[] = $rowEtiqueta;
            }
        } 
        
        $whereOtros = $this->getAdapter()->quoteInto("nave_id=? AND etiqueta_id IS NULL", $nave_id);
        
        $otros['id'] = 0;
        $otros['nombre'] = "Otros";
        $otros['archivos'] = $this->fetchAll($whereOtros)->toArray();
        
        $archivos[] = $otros;
        
        return  $archivos;
    }
    
    public function getRowsByNaveIdToExport($nave_id)
    {
        $dataArchivos = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('a' => 'naves_archivos'), 
                    array('nombre', 'archivo', 'etiqueta_id'))
               ->joinLeft(array('e' => 'etiquetas_archivos'), 'e.id=a.etiqueta_id', array('etiqueta' => 'nombre')) 
               ->where("nave_id=?", $nave_id);
        
        $rows = $adapter->fetchAll($select);
        $i = 0;
        foreach($rows as $row){
            $dataArchivos[$i]['Nombre'] = $row['nombre'];
            $dataArchivos[$i]['Archivo'] = $row['archivo'];
            $dataArchivos[$i]['Etiqueta'] = array('ID' => $row['etiqueta_id'], 'Nombre' => $row['etiqueta']);
            $i++;
        }
        return  $dataArchivos;
    }
    
    public function getNave()
    {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getRow()->nave_id);
        return $modelNave->getRowFull();
    }
    
    public function crear($data, $user)
    {
        if(Shipcode_Archivo::guardar($data['archivo'], 'naves/')){
            $data['creador'] = $user;
            $row = $this->createRow();
            $row->setFromArray($data);
            return $row->save();
        } else {
            throw new Exception('No fue posible guardar el archivo en el directorio indicado. La operación fue cancelada.');
        }
    }
    
    public function editar($data, $user, $id)
    {
        $data['creador'] = $user;
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        try {
            if(Shipcode_Archivo::borrar($this->getRow()->archivo, 'naves/')){
                $this->delete($where);
            }
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
}