<?php
class Shipcode_Model_NaveCarena extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_carenas';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getNaveId()
    {
        return $this->getRow()->nave_id;
    }
    
    public function getRowsByNaveId($nave_id)
    {
        $where = $this->getAdapter()->quoteInto("nave_id=? AND estado='1'", $nave_id);
        $rows = $this->fetchAll($where, 'fecha DESC')->toArray();
        
        $carenas = array();
        $i = 0;
        foreach($rows as $row){
            $carenas[$i] = $row;
            $carenas[$i]['detalle_gastos'] = $this->_getDetalleGastos($row['id']);
            $carenas[$i]['num_archivos'] = $this->_getNumArchivos($row['id']);
            $carenas[$i]['total_gastos'] = $this->_getTotalGastos($row['id']);
            $i++;
        }
        return $carenas;
    }
    
    public static function getNumArchivos($id)
    {
        return self::_getNumArchivos($id);
    }
    
    private function _getNumArchivos($id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT COUNT(*) FROM naves_carenas_archivos WHERE carena_id='$id'";
        $result = $adapter->fetchOne($sql);
        if($result > 0) {
            return $result;
        }
        return 0;
    }
    
    public function getArchivos()
    {
        $archivo = new Shipcode_Model_NaveCarenaArchivo();
        return $archivo->getRowsByCarenaId($this->_id);
    }
    
    public function guardarArchivo($data, $user)
    {
        $archivo = new Shipcode_Model_NaveCarenaArchivo();
        return $archivo->crear($data, $user);
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function guardar($data, $user)
    {
        $this->_confirmarRegistro($data);
        $this->_actualizarProximaCarena($data, $user);
        $this->_detallarGastos($data, $user);
    }
    
    private function _actualizarProximaCarena($data, $user)
    {
        $fechaCarena = new Zend_Date($data['fecha']);
        $fechaCarena->add($data['periodo'], Zend_Date::MONTH);
        $proximaCarena = array(
            'sig_carena_mes' => $fechaCarena->toString('MM'),
            'sig_carena_year' => $fechaCarena->toString('yyyy')
        );
        
        $this->setId($data['id']);
        $nave = new Shipcode_Model_Nave();
        $nave->setId($this->getNaveId());
        $nave->actualizarProximaCarena($proximaCarena, $user);
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getNave()
    {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getRow()->nave_id);
        return $modelNave->getRowFull();
    }
    
    public function buscar($data, $privilegiosNaves = NULL)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('c' => 'naves_carenas'), 
                    array('id', 'creacion', 'creador', 'nave_id', 'fecha', 'periodo', 'observaciones'))
               ->join(array('n' => 'naves'), 'n.id=c.nave_id', array('nave' => 'nombre')) 
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'))
               ->where("c.estado='1'");
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        if($data['nave']!='') {
            $select->where("c.nave_id=?", $data['nave']);
        } elseif($privilegiosNaves !== NULL) {
            $navesIds = Shipcode_Model_SistemaUsuario::filtrarNavesAutorizadas($privilegiosNaves);
            $select->where("c.nave_id IN($navesIds)");
        }
        if($data['desde']) {
            $select->where("c.fecha > ?", $data['desde']);
        }
        if($data['hasta']) {
            $select->where("c.fecha < ?", $data['hasta']);
        }
        $rows = $adapter->fetchAll($select);
        if(count($rows) > 0){
            
            $carenas = array();
            foreach($rows as $row){
                $row['detalle_cuentas'] = $this->_getDetalleGastos($row['id']);
                $row['total_gastos'] = $this->_getTotalGastos($row['id']);
                $carenas[] = $row;
            }
            return $carenas;
        }
        
        return NULL;
    }
    
    public function getHtmlToPdf($rows)
    {
        $content = '<h1>Informe Carenas</h1>'
                 . '<p class="text-muted">Realizado el ' . Shipcode_Model_Fecha::format(date("Y-m-d")) . ', a las ' . date("H:i") . '</p>'
                 . '<hr>'
                 . '<p>Se encontraron ' . count($rows) . ' resultados</p>'
                 . '<table border="1" cellpadding="4"><thead><tr>'
                 . '<th>Empresa</th>'
                 . '<th>Nave</th>'
                 . '<th>Fecha</th>'
                 . '<th>Período</th>'    
                 . '<th>Costo total</th>'
                 . '<th>Desglose por cuentas</th>'   
                 . '</tr></thead><tbody>';
        
        if(count($rows) > 0) {
            foreach($rows as $carena) { 
                
                $content .= '<tr>'
                          . '<td class="border-right" valign="top">' . $carena['empresa'] . '</td>'
                          . '<td valign="top">' . $carena['nave'] . '</td>'
                          . '<td valign="top">' . Shipcode_Model_Fecha::format($carena['fecha']) . '</td>'
                          . '<td valign="top">' . $carena['periodo'] . '</td>'
                          . '<td valign="top">' . $carena['total_gastos'] . '</td>'
                          . '<td valign="top" class="sub-table"><table>';
                
                foreach($carena['detalle_cuentas'] as $cuenta) { 
                    $content .= '<tr>'
                              . '<td class="text-right">' . $cuenta['cuenta'] . '</td>'
                              . '<td class="text-right">' . $cuenta['monto'] . '</td>'
                              . '</tr>';
                } 
                $content .= '</table></td></tr>';
                
            } 
        } else {
            $content .= '<tr><td colspan="8">No se encontraron registros coincidentes para su búsqueda.</td></tr>';
        }
        
        $content .= '</table></div></tbody></html>';
        
        return $content;
    }
    
    private function _confirmarRegistro($data)
    {
        if($data['observaciones'] ==''){ $data['observaciones'] = NULL; }
        $row = $this->find($data['id'])->current();
        $row->fecha = $data['fecha'];
        $row->observaciones = $data['observaciones'];
        $row->estado = 1;
        $row->periodo = $data['periodo'];
        $row->save();
        $this->_actualizarPeriodoCarenaAnterior($data['fecha'], $row->nave_id);
    }
    
    private function _actualizarPeriodoCarenaAnterior($fecha, $nave_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT id, fecha FROM naves_carenas WHERE nave_id='$nave_id' ORDER BY id DESC LIMIT 1 OFFSET 1";
        $result = $adapter->fetchRow($sql);
        
        if($result != NULL && $result != FALSE){
            
            $fecha1 = new Zend_Date($result['fecha'], 'yyyy-MM-dd');
            $fecha2 = new Zend_Date($fecha, 'yyyy-MM-dd');
            $diferencia = $fecha2->sub($fecha1)->toValue();
            $periodo = floor($diferencia/60/60/24/30);
            $row = $this->find($result['id'])->current();
            $row->periodo = $periodo;
            $row->save();
        }
    }
    
    private function _detallarGastos($data, $user)
    {
        $adapter = $this->getAdapter();
        try {
            $adapter->beginTransaction();
            $modelGasto = new Shipcode_Model_NaveCarenaGasto();
            $modelCuentas = new Shipcode_Model_CuentaCarena();
            $rowsCuentas = $modelCuentas->fetchAll();

            foreach($rowsCuentas as $row){
                $campo =  'cuenta' . $row->id;
                if(isset($data[$campo])){
                    $modelGasto->crear(
                        array(
                            'carena_id' => $data['id'],
                            'cuenta_id' => $row->id,
                            'monto'     => $data[$campo]
                        ), 
                        $user
                    );
                }
            }
            $adapter->commit();
        } catch(Exception $e){
            $adapter->rollBack();
            return $e->getMessage();
        }
    }
    
    private function _getDetalleGastos($id)
    {
        $modelCarenaGasto = new Shipcode_Model_NaveCarenaGasto();
        return $modelCarenaGasto->getDetalle($id);
    }
    
    private function _getTotalGastos($id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT SUM(monto) FROM naves_carenas_gastos "
             . "WHERE carena_id = '$id'";
        return $adapter->fetchOne($sql);
    }
    
    
    public function getRowsByNaveIdToExport($nave_id, $archivos = 0, $detalleGastos = 0)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('c' => 'naves_carenas'), array('id', 'nave_id', 'fecha', 'observaciones'))
               ->where("nave_id=?", $nave_id) 
               ->where("c.estado='1'");
        
        $rows = $adapter->fetchAll($select);
        
        $carenas = array();
        $i = 0;
        foreach($rows as $row){
            $carenas[$i]['ID'] = $row['id'];
            $carenas[$i]['Fecha'] = $row['fecha'];
            $carenas[$i]['Observaciones'] = $row['observaciones'];
            if($detalleGastos == 1) {
                $carenas[$i]['Detalle de Gastos'] = $this->_getDetalleGastosToExport($row['id']);
            }
            if($archivos == 1){
                $carenas[$i]['Archivos'] = $this->_getArchivosToExport($row['id']);
            }    
            $i++;
        }
        return $carenas;
    }
    
    private function _getDetalleGastosToExport($id)
    {
        $modelCarenaGasto = new Shipcode_Model_NaveCarenaGasto();
        return $modelCarenaGasto->getDetalleToExport($id);
    }
    
    private function _getArchivosToExport($carena_id)
    {
        $archivo = new Shipcode_Model_NaveCarenaArchivo();
        return $archivo->getRowsByCarenaIdToExport($carena_id);
    }
    
    /*
    public function editar($data, $user)
    {
        $data['creador'] = $user;
        $row = $this->find($data['id'])->current();
        $row->setFromArray($data);
        $row->save();
    }
    */
}