<?php
class Shipcode_Model_NaveCertificado extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_certificados';
    protected $_primary = 'id';
    
    private $_id;
       
    public function setId($id)
    {
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('c' => 'naves_certificados'), 
                    array('id', 'creacion', 'creador', 'nave_id', 'numero', 'tipo_id', 'descripcion')
                )
               ->join(array('ct' => 'certificados_tipos'), 'ct.id=c.tipo_id', 
                      array('tipo' => 'nombre', 'indefinido', 'critico')) 
               ->join(array('n' => 'naves'), 'n.id=c.nave_id', array('nave' => 'nombre')) 
               ->where("c.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getRowToForm()
    {
        $emision = $this->_getUltimaEmision($this->_id);
        $data = $this->getRow()->toArray();
        $data['fecha_emision'] = $emision['fecha_emision'];
        $data['fecha_vencimiento'] = $emision['fecha_vencimiento'];
        return $data;
    }
    
    public function getNaveId()
    {
        return $this->getRow()->nave_id;
    }
    
    public function getRowsByNaveId($nave_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('c' => 'naves_certificados'), 
                    array('id', 'creacion', 'creador', 'nave_id', 'numero', 'tipo_id', 'descripcion')
                )
               ->join(array('ct' => 'certificados_tipos'), 'ct.id=c.tipo_id', 
                      array('tipo' => 'nombre', 'indefinido', 'critico')) 
               ->join(array('n' => 'naves'), 'n.id=c.nave_id', array('nave' => 'nombre')) 
               ->where("c.nave_id=?", $nave_id)
               ->order("ct.lugar")
               ->order("c.descripcion")
               ->order("c.id");
        $rows = $adapter->fetchAll($select);
        
        if(count($rows) > 0 ) {
            
            $certificados = array();
            $i = 0;
            foreach($rows as $row) {
                $emision = $this->_getUltimaEmision($row['id']);
                $certificados[$i] = $row;
                $certificados[$i]['fecha_emision'] = $emision['fecha_emision'];
                $certificados[$i]['fecha_vencimiento'] = $emision['fecha_vencimiento'];
                $certificados[$i]['num_archivos'] = $this->_getNumArchivos($row['id']);
                $i++;
            }
            
            return $certificados;
        } 
        return NULL;
    }
    
    
    
    public function getCertificadosToClone($nave_id)
    {
        $where = $this->getAdapter()->quoteInto("nave_id=?", $nave_id);
        return $this->fetchAll($where)->toArray();
    }
    
    public function clonar($certificado, $nave_id, $user)
    {
        $nuevoCertificado = array(
            'nave_id'           => $nave_id,
            'numero'            => '',
            'tipo_id'           => $certificado['tipo_id'],
            'descripcion'       => $certificado['descripcion'],
            'fecha_emision'     => NULL,
            'fecha_vencimiento' => NULL
        );
        $this->crear($nuevoCertificado, $user);
    }
   
    public function getNave()
    {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getRow()->nave_id);
        return $modelNave->getRowFull();
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        $data['certificado_id'] = $row->id; 
        $this->_agregarEmision($data, $user);
    }
    
    public function ingresarRenovacion($data, $user)
    {
        $data['certificado_id'] = $data['id'];
        unset($data['id']);
        return $this->_agregarEmision($data, $user);
    }
    
    public function _agregarEmision($data, $user)
    {
        $modelCertificadoEmision = new Shipcode_Model_NaveCertificadoEmision();
        return $modelCertificadoEmision->crear($data, $user);
    }
    
    private function _getUltimaEmision($certificado_id)
    {
        $modelCertificadoEmision = new Shipcode_Model_NaveCertificadoEmision();
        return $modelCertificadoEmision->getUltimaEmisionByCertificadoId($certificado_id);
    }
    
    public function editar($data, $user, $id)
    {
        $data['creador'] = $user;
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editarUltimaEmision($data, $user)
    {
        $modelCertificadoEmision = new Shipcode_Model_NaveCertificadoEmision();
        return $modelCertificadoEmision->editarUltimaByNaveId($data, $user);
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        $dir = Zend_Registry::get('PATH_SERVER') . 'files/certificados/' . $this->_id ;
        $tempDir = Zend_Registry::get('PATH_SERVER') . 'tmp/' . date("YmdHis"); 
        
        try {
            
            if(is_dir($dir)){
                rename($dir, $tempDir);
            }
            $this->delete($where);
            
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function buscar($data, $privilegiosNaves = NULL)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('c' => 'naves_certificados'), 
                    array('id', 'creacion', 'creador', 'nave_id', 'tipo_id', 'numero', 'descripcion')
               )
               ->join(array('ct' => 'certificados_tipos'), 'ct.id=c.tipo_id', 
                      array('tipo' => 'nombre', 'indefinido', 'critico')) 
               ->join(array('n' => 'naves'), 'n.id=c.nave_id', array('nave' => 'nombre')) 
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'))  
               ->order("c.nave_id")
               ->order("ct.lugar");
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        if($data['nave']!='') {
            $select->where("c.nave_id=?", $data['nave']);
        } elseif($privilegiosNaves !== NULL) {
            $navesIds = Shipcode_Model_SistemaUsuario::filtrarNavesAutorizadas($privilegiosNaves);
            $select->where("c.nave_id IN($navesIds)");
        }
        if($data['numero']!='') {
            $select->where("c.numero=?", $data['numero']);
        }
        if($data['tipo']!='') {
            $select->where("c.tipo_id=?", $data['tipo']);
        }
        $rows = $adapter->fetchAll($select);
        if(count($rows) > 0 ) {
            
            $certificados = array();
            $i = 0;
            $diasAviso = Shipcode_Model_SistemaPreferencia::getPref('DIAS_AVISO_CERTIFICADOS');
            
            foreach($rows as $row) {
                
                $emision = $this->_getUltimaEmision($row['id']);
                
                if($data['estado'] == 0) {
                    
                    $certificados[$i] = $row;
                    $certificados[$i]['fecha_emision'] = $emision['fecha_emision'];
                    $certificados[$i]['fecha_vencimiento'] = $emision['fecha_vencimiento'];
                    
                } else {
                    
                    $fechaVencimiento = new Zend_Date($emision['fecha_vencimiento']);
                    $fechaAviso = clone($fechaVencimiento);
                    $fechaAviso->sub($diasAviso, Zend_Date::DAY);
                    $hoy    = Zend_Date::now();
                    
                    if($data['estado'] == 1){
                        
                        if($hoy->isLater($fechaAviso) && $hoy->isEarlier($fechaVencimiento) && $emision['fecha_vencimiento'] != NULL){
                            $certificados[$i] = $row;
                            $certificados[$i]['fecha_emision'] = $emision['fecha_emision'];
                            $certificados[$i]['fecha_vencimiento'] = $emision['fecha_vencimiento'];
                        }
                        
                    } elseif($data['estado'] == 2){
                        
                        if($hoy->isLater($fechaVencimiento) && $emision['fecha_vencimiento'] != NULL){
                            $certificados[$i] = $row;
                            $certificados[$i]['fecha_emision'] = $emision['fecha_emision'];
                            $certificados[$i]['fecha_vencimiento'] = $emision['fecha_vencimiento'];
                        }
                        
                    } elseif($data['estado'] == 3){
                        
                        if($emision['fecha_vencimiento'] == NULL && $row['indefinido'] == 0){
                            $certificados[$i] = $row;
                            $certificados[$i]['fecha_emision'] = $emision['fecha_emision'];
                            $certificados[$i]['fecha_vencimiento'] = $emision['fecha_vencimiento'];
                        }
                        
                    } elseif($data['estado'] == 4){
                        
                        if($emision['fecha_vencimiento'] == NULL && $row['indefinido'] == 1){
                            $certificados[$i] = $row;
                            $certificados[$i]['fecha_emision'] = $emision['fecha_emision'];
                            $certificados[$i]['fecha_vencimiento'] = $emision['fecha_vencimiento'];
                        }
                    }
                }
                $i++;
            }
            
            return $certificados;
        } 
        return NULL;
    }
    
    public function getHtmlToPdf($rows, $titulo)
    {
        $content = '<h1>' . $titulo . '</h1>'
                 . '<p class="text-muted">Realizado el ' . Shipcode_Model_Fecha::format(date("Y-m-d")) . ', a las ' . date("H:i") . '</p>'
                 . '<hr>'
                 . '<p>Se encontraron ' . count($rows) . ' resultados</p>'
                 . '<table border="1" cellpadding="4"><thead><tr>'
                 . '<th>Empresa</th>'
                 . '<th>Nave</th>'
                 . '<th>Nombre</th>'
                 . '<th>Nº</th>'
                 
                 . '<th>Emisión</th>'
                 . '<th>Vencimiento</th>'
                 . '</tr></thead><tbody>';
        
        if(count($rows) > 0) {
            foreach($rows as $certificado) { 
                
                $content .= '<tr>'
                          . '<td class="border-right">' . $certificado['empresa'] . '</td>'
                          . '<td>' . $certificado['nave'] . '</td>'
                          . '<td>' . $certificado['tipo'] . ' ' . $certificado['descripcion'] . '</td>'
                          . '<td>' . $certificado['numero'] . '</td>';
                
                if($certificado['fecha_emision']==NULL){ 
                   $content .= '<td>Desconocida</td>';
                } else {
                   $content .= '<td>' . Shipcode_Model_Fecha::format($certificado['fecha_emision']) . '</td>';
                }

                if($certificado['fecha_vencimiento'] == NULL && $certificado['indefinido'] == 0 ){ 
                    $content .= '<td class="background-unknown">Desconocida</td>';
                } elseif($certificado['fecha_vencimiento'] == NULL && $certificado['indefinido'] == 1 ) { 
                    $content .= '<td class="background-ok">Indefinido</td>';
                } else {
                    $content .= '<td>' . Shipcode_Model_Fecha::format($certificado['fecha_vencimiento']) . '</td>';   
                }
                
                $content .= '</tr>';
            } 
        } else {
            $content .= '<tr><td colspan="8">No se encontraron registros coincidentes para su búsqueda.</td></tr>';
        }
        
        $content .= '</table></div></tbody></html>';
        
        return $content;
    }
    
    public function getCountPorVencer($empresa_id = NULL)
    {
        
        $diasAviso = Shipcode_Model_SistemaPreferencia::getPref('DIAS_AVISO_CERTIFICADOS');
        $adapter = $this->getAdapter();
        
        if($empresa_id != NULL){
            $sql = "SELECT COUNT(*) FROM naves_certificados_emisiones AS nce "
                 . "JOIN naves_certificados AS nc ON nce.certificado_id=nc.id "
                 . "JOIN naves AS n ON nc.nave_id=n.id "   
                 . "WHERE n.empresa_id='$empresa_id' "   
                 . "AND nce.fecha_vencimiento IS NOT NULL "
                 . "AND nce.fecha_vencimiento >= now() "
                 . "AND nce.fecha_vencimiento <= DATE_ADD(now(), INTERVAL " . $diasAviso . " DAY) "
                 . "AND nce.id = (SELECT id FROM naves_certificados_emisiones WHERE certificado_id=nc.id ORDER BY id DESC LIMIT 1) "
                 . "ORDER BY nce.id DESC";
        } else {
            $sql = "SELECT COUNT(*) FROM naves_certificados_emisiones AS nce "
                 . "JOIN naves_certificados AS nc On nce.certificado_id=nc.id "
                 . "WHERE nce.fecha_vencimiento IS NOT NULL "
                 . "AND nce.fecha_vencimiento >= now() "
                 . "AND nce.fecha_vencimiento <= DATE_ADD(now(), INTERVAL " . $diasAviso . " DAY) "
                 . "AND nce.id = (SELECT id FROM naves_certificados_emisiones WHERE certificado_id=nc.id ORDER BY id DESC LIMIT 1) "
                 . "ORDER BY nce.id DESC";
        }
        
            
        $num = $adapter->fetchOne($sql);
        if($num){
            return $num;
        } 
        return 0;
    }
    
    public function getCountVencidos($empresa_id = NULL)
    {
        $adapter = $this->getAdapter();
        
        if($empresa_id != NULL){
            $sql = "SELECT COUNT(nce.id) FROM naves_certificados_emisiones AS nce "
                 . "JOIN naves_certificados AS nc On nce.certificado_id=nc.id "
                 . "JOIN naves AS n ON nc.nave_id=n.id "   
                 . "WHERE n.empresa_id='$empresa_id' "          
                 . "AND nce.fecha_vencimiento IS NOT NULL "
                 . "AND nce.fecha_vencimiento <= now() " 
                 . "AND nce.id = (SELECT id FROM naves_certificados_emisiones WHERE certificado_id=nc.id ORDER BY id DESC LIMIT 1) "   
                 . "ORDER BY nce.id DESC";
        } else {
            $sql = "SELECT COUNT(nce.id) FROM naves_certificados_emisiones AS nce "
                 . "JOIN naves_certificados AS nc On nce.certificado_id=nc.id "
                 . "WHERE nce.fecha_vencimiento IS NOT NULL "
                 . "AND nce.fecha_vencimiento <= now() " 
                 . "AND nce.id = (SELECT id FROM naves_certificados_emisiones WHERE certificado_id=nc.id ORDER BY id DESC LIMIT 1) "   
                 . "ORDER BY nce.id DESC";
        }
        
        $num = $adapter->fetchOne($sql);
        if($num){
            return $num;
        } 
        return 0;
    }
    
    /**************** FUNCIONES RELACIONADAS A LOS ARCHIVOS *******************/
    public static function getNumArchivos($id)
    {
        return self::_getNumArchivos($id);
    }
    
    public function getArchivos()
    {
        $archivo = new Shipcode_Model_NaveCertificadoArchivo();
        return $archivo->getRowsByCertificadoId($this->_id);
    }
    
    public function guardarArchivo($data, $user)
    {
        $archivo = new Shipcode_Model_NaveCertificadoArchivo();
        return $archivo->crear($data, $user);
    }
    
    public function editarArchivo($data, $user)
    {
        $archivo = new Shipcode_Model_NaveCertificadoArchivo();
        return $archivo->editar($data, $user);
    }
    
    private function _getNumArchivos($id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT COUNT(*) FROM naves_certificados_archivos WHERE certificado_id='$id'";
        $result = $adapter->fetchOne($sql);
        if($result > 0) {
            return $result;
        }
        return 0;
    }
    
    /******************** FUNCIONES EXPORTACIÓN DE DATOS **********************/
    public function getRowsByNaveIdToExport($nave_id, $archivos = 0)
    {
        $dataCertificados = array();
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('c' => 'naves_certificados'), array('id', 'numero', 'tipo_id', 'descripcion'))
               ->join(array('ct' => 'certificados_tipos'), 'ct.id=c.tipo_id', 
                      array('tipo' => 'nombre', 'indefinido')) 
               ->where("c.nave_id=?", $nave_id);
        $rows = $adapter->fetchAll($select);
        
        $i = 0;
        foreach($rows as $row) {
            $this->setId($row['id']);
            $emision = $this->_getUltimaEmision($row['id']);
            $dataCertificados[$i]['ID'] = $row['id'];
            $dataCertificados[$i]['Tipo'] = array('id' => $row['tipo_id'], 'nombre' => $row['tipo']);
            if($row['indefinido'] == 0){
                $dataCertificados[$i]['Tipo']['duracion'] = 'DEFINIDA';
            } else {
                $dataCertificados[$i]['Tipo']['duracion'] = 'INDEFINIDA';
            }
            $dataCertificados[$i]['Número'] = $row['numero'];
            $dataCertificados[$i]['Descripción'] = $row['descripcion'];
            $dataCertificados[$i]['Fecha de emision'] = $emision['fecha_emision'];
            $dataCertificados[$i]['Fecha de vencimiento'] = $emision['fecha_vencimiento'];
            if($archivos == 1){
                $dataCertificados[$i]['Archivos'] = $this->getArchivosToExport();
            }
            $i++;
        }

        return $dataCertificados;
    }
    
    public function getArchivosToExport()
    {
        $archivo = new Shipcode_Model_NaveCertificadoArchivo();
        return $archivo->getRowsByCertificadoIdToExport($this->_id);
    }
}