<?php
class Shipcode_Model_NaveEquipo extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_equipos';
    protected $_primary = 'id';
    
    private $_id;
    
    /****************************  FUNCIONES BÁSICAS **************************/ 
    public function setId($id)
    {
        $optionsEquipo = array('table' => 'naves_equipos', 'field' => 'id');
        $validadorEquipo = new Zend_Validate_Db_RecordExists($optionsEquipo);
        if(!$validadorEquipo->isValid($id)){
            throw new Exception("El ID indicado no Existe - NaveEquipo");
        }
        $this->_id = $id;
    }
    
    public function getGastos()
    {
        $gasto = new Shipcode_Model_Gasto();
        return $gasto->getRowsByEquipoId($this->_id);
    }
    
    public function actualizarFotografia($name)
    {
        $row = $this->getRow();
        $row->fotografia = $name;
        $row->save();
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }

    public static function getNombreById($id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT nombre FROM naves_equipos WHERE id='$id'";
        return $adapter->fetchOne($sql);
    }
    
    public function getRowFull()
    {
        $ubicacionActual = $this->_getUbicacion($this->_id);
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        
        if($ubicacionActual['sistema_id'] != NULL){
            
            $select->from(array('ne' => 'naves_equipos'), array(
                    'id', 'creacion', 'creador', 'tipo_id', 'planmant_id', 'condicion',
                    'marca_id', 'modelo', 'nombre', 'serie', 'datos_tecnicos', 
                    'horometro', 'horometro_anclaje', 'parametros', 'inicio_operaciones', 
                    'promedio_calculado', 'promedio_asignado', 'promedio_usado', 'fotografia'))
                ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array('ubicacion_id' => 'id', 'sistema_id', 'ubicacionv_id'))    
                ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array('sistema' => 'nombre', 'nave_id')) 
                ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre', 'empresa_id')) 
                ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
                ->joinLeft(array('et' => 'equipos_tipos'), 'et.id=ne.tipo_id', array('tipo_equipo' => 'nombre'))  
                ->joinLeft(array('em' => 'equipos_marcas'), 'em.id=ne.marca_id', array('marca' => 'nombre')) 
                ->where("ne.id=?", $this->_id)
                ->where("neu.fecha_salida IS NULL")
                ->order("neu.id DESC");
            
        } elseif($ubicacionActual['ubicacionv_id'] != NULL){
            
            $select->from(array('ne' => 'naves_equipos'), array(
                    'id', 'creacion', 'creador', 'tipo_id', 'planmant_id', 'condicion',
                    'marca_id', 'modelo', 'nombre', 'serie', 'datos_tecnicos', 
                    'horometro', 'horometro_anclaje', 'parametros', 'inicio_operaciones', 'fotografia'))
                ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array('ubicacion_id' => 'id', 'sistema_id', 'ubicacionv_id'))       
                ->join(array('uv' => 'ubicaciones_virtuales'), 'uv.id=neu.ubicacionv_id', array('ubicacion_virtual' => 'nombre')) 
                ->joinLeft(array('et' => 'equipos_tipos'), 'et.id=ne.tipo_id', array('tipo_equipo' => 'nombre'))  
                ->joinLeft(array('em' => 'equipos_marcas'), 'em.id=ne.marca_id', array('marca' => 'nombre')) 
                ->where("ne.id=?", $this->_id);
        }  
        return $adapter->fetchRow($select);
    }
    
    public function getRowToForm()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array(
                'id', 'creacion', 'creador', 'tipo_id', 'planmant_id', 'condicion',
                'marca_id', 'modelo', 'nombre', 'serie', 'datos_tecnicos', 
                'horometro', 'parametros', 'inicio_operaciones', 'fotografia'))
            ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array('sistema_id'))    
            ->where("ne.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        $data['orden'] = $this->_getLugar();
        if($data['marca_id']=='') {$data['marca_id'] = NULL;}
        if($data['tipo_id']=='') {$data['tipo_id'] = NULL;}
        if($data['modelo']=='') {$data['modelo'] = NULL;}
        if($data['serie']=='') {$data['serie'] = NULL;}
        if($data['datos_tecnicos']=='') {$data['datos_tecnicos'] = NULL;}
        $data['ubicacion_id'] = NULL;
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        $row->ubicacion_id = $this->_abrirUbicacion($row->id, $data['sistema_id'], NULL, $user);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $user, $id)
    {  
        $data['creador'] = $user;
        if($data['marca_id']=='') {$data['marca_id'] = NULL;}
        if($data['tipo_id']=='') {$data['tipo_id'] = NULL;}
        if($data['modelo']=='') {$data['modelo'] = NULL;}
        if($data['serie']=='') {$data['serie'] = NULL;}
        if($data['datos_tecnicos']=='') {$data['datos_tecnicos'] = NULL;}
        
        $row = $this->find($id)->current();
        $dataAntigua = $row->toArray();
        $ubicacion = $this->_getUbicacion($id);
        
        if($ubicacion['sistema_id'] != NULL) {
            if($ubicacion['sistema_id'] != $data['sistema_id']) { 
                $data['ubicacion_id'] = $this->_cambiarUbicacionSistema($id, $ubicacion['id'], $data['sistema_id'], $user); 
            }
        }
        
        $row->setFromArray($data);
        $row->save();
        
        if($dataAntigua['planmant_id'] !== NULL 
                && $dataAntigua['inicio_operaciones'] !== $data['inicio_operaciones']){
            $this->eliminarEventos();
            $this->_programarItemsPlan($row->planmant_id, $user);
        }
    }
    
    public function clonar($data, $user)
    {
        $nuevo_id = $this->_clonar($data, $user);
        if($nuevo_id != FALSE){
            
            if($data['partes'] == 1) {
                $this->sincronizarInformacionTecnica(1, array($data['oequipo_id'], $nuevo_id), $user);
            }
            return $nuevo_id;
            
        } else {
            throw new Exception('No fue posible clonar el equipo');
        }    
    }
    
    private function _clonar($data, $user)
    {
        $equipoOrigen = $this->getRow()->toArray();
        $equipoNuevo = array(
            'sistema_id' => $data['sistema_id'],
            'tipo_id' => $equipoOrigen['tipo_id'],
            'marca_id' => $equipoOrigen['marca_id'],
            'modelo' => $equipoOrigen['modelo'],
            'nombre' => $equipoOrigen['nombre'],
            'serie' => $equipoOrigen['serie'],
            'datos_tecnicos' => $equipoOrigen['datos_tecnicos'],
            'planmant_id' => $equipoOrigen['planmant_id'],
            'inicio_operaciones' => $equipoOrigen['inicio_operaciones']
        );
        
        $id = $this->crear($equipoNuevo, $user);
        
        if($id != FALSE){
            return $id;
        }
        return FALSE;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        try {
            $this->eliminarEventos();
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getRowsByPlanmantId($planmant_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array('id','planmant_id', 'modelo', 'nombre'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array('sistema' => 'nombre')) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre')) 
               ->joinLeft(array('m' => 'equipos_marcas'), 'm.id=ne.marca_id', array('marca' => 'nombre'))  
               ->where("ne.planmant_id=?", $planmant_id);
        return $adapter->fetchAll($select);
    }
    
    public function buscar($data)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array('id', 'modelo', 'nombre', 'tipo_id'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'neu.id=ne.ubicacion_id', array());
        
        if($data['ubicacionv_id'] == 0){
            $select->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array()) 
                   ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('ubicacion' => 'nombre', 'empresa_id')) 
                   ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')); 
            
            if($data['empresa_id'] != 0 ) {
                $select->where("n.empresa_id=?", $data['empresa_id']);
            }
            if($data['nave_id'] != 0 ) {
                $select->where("ns.nave_id=?", $data['nave_id']);
            }
            if($data['sistema_id'] != 0 ) {
                $select->where("neu.sistema_id=? OR ns.padre_id=?", $data['sistema_id']);
            }
            
        } else {
            $select->join(array('uv' => 'ubicaciones_virtuales'), 'uv.id=neu.ubicacionv_id', array('ubicacion' => 'nombre')); 
            $select->where("neu.ubicacionv_id=?", $data['ubicacionv_id']);
        }
               
        $select->joinLeft(array('nep' => 'naves_equipos_partes'), 'ne.id=nep.equipo_id', array('num_partes' => 'COUNT(nep.id)')) 
               ->joinLeft(array('et' => 'equipos_tipos'), 'et.id=ne.tipo_id', array('tipo_equipo' => 'nombre'))  
               ->joinLeft(array('em' => 'equipos_marcas'), 'em.id=ne.marca_id', array('marca' => 'nombre')) 
               ->where("ne.id IS NOT NULL")
               ->where("neu.fecha_salida IS NULL");
        
        
        if($data['tipo_id'] != 0 ) {
            $select->where("ne.tipo_id=?", $data['tipo_id']);
        }
        if($data['marca_id'] != 0 ) {
            $select->where("ne.marca_id=?", $data['marca_id']);
        }
        if($data['modelo'] != NULL ) {
            $select->where("ne.modelo LIKE '%" . $data['modelo'] . "%'");
        }
        if($data['nombre'] != NULL ) {
            $select->where("ne.nombre LIKE '%" . $data['nombre'] . "%'");
        }
        if($data['plan'] != NULL ) {
            if($data['plan'] == 's'){
                $select->where("ne.planmant_id IS NOT NULL");
            } elseif($data['plan'] == 'n'){
                $select->where("ne.planmant_id IS NULL");
            } else {
                $select->where("ne.planmant_id=?", $data['plan']);
            }
        }
        
        if($data['info_tecnica'] != NULL ) {
            
            if($data['info_tecnica'] == 'sit'){
                
                $select->where("ne.datos_tecnicos IS NULL OR ne.datos_tecnicos=''");
                
            } elseif($data['info_tecnica'] == 'spp') {
                
                $select->having("num_partes = '0'");
                
            } elseif($data['info_tecnica'] == 'std') {
                
                $select->having("num_partes = '0'");
                $select->where("ne.datos_tecnicos IS NULL OR ne.datos_tecnicos = '' ");
                
            } elseif($data['info_tecnica'] == 'cit'){
                
                $select->where("ne.datos_tecnicos IS NOT NULL AND ne.datos_tecnicos!=''");
                
            }  elseif($data['info_tecnica'] == 'cpp'){
                
                $select->having("num_partes > '0'");
                
            } elseif($data['info_tecnica'] == 'ctd') {
                
                $select->having("num_partes > '0'");
                $select->where("ne.datos_tecnicos IS NOT NULL OR ne.datos_tecnicos != '' ");
                
            }
        }
        $select->group('ne.id')
               ->order("ne.orden");
        $rows = $adapter->fetchAll($select);
        
        if(count($rows) > 0){
            return $rows;
        }
        return NULL;
    }
    
    public function getNave()
    {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getNaveId());
        return $modelNave->getRowFull();
    }
    
    public function getNaveId()
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT ns.nave_id FROM naves_equipos AS ne "
             . "JOIN naves_equipos_ubicaciones AS neu ON neu.id=ne.ubicacion_id "
             . "JOIN naves_sistemas AS ns ON ns.id=neu.sistema_id "
             . "WHERE ne.id='" . $this->_id . "' AND neu.fecha_salida IS NULL ORDER BY neu.id DESC LIMIT 1";
        return $adapter->fetchOne($sql);
    }
    
    public function setParametroInforme($parametro_id)
    {
        $optionsParametro = array('table' => 'equipos_parametros', 'field' => 'id');
        $validadorParametro = new Zend_Validate_Db_RecordExists($optionsParametro);
        
        if(!$validadorParametro->isValid($parametro_id)){
            throw new Exception('El ID de parámetro asignado no existe.');
        }
        
        $row = $this->getRow();
        $rowParametros = $row->parametros;
        
        if($rowParametros != NULL){
            $parametros = explode(",", $rowParametros);
            $key = array_search($parametro_id, $parametros);
            if($key !== FALSE && $key !== NULL){
                unset($parametros[$key]);
            } else {
                $parametros[] = $parametro_id;
            }
        } else {
            $parametros[] = $parametro_id;
        }
        if(count($parametros) > 0) {
            $row->parametros = implode(",", $parametros);
        } else {
            $row->parametros = NULL;
        }
        $row->save();
    }
    
    public function getUbicacionToBack()
    {
        $ubicacionData = $this->_getUbicacion($this->_id);
        
        if($ubicacionData['sistema_id'] != NULL){
            $sistema = new Shipcode_Model_NaveSistema();
            $sistema->setId($ubicacionData['sistema_id']);
            $data['tipo'] = 'nave';
            $data['id'] = $sistema->getNaveId();
        } else {
            $data['id'] = $ubicacionData['id'];
            $data['tipo'] = 'ubicacion-virtual';
        }
        return $data; 
    }
    
    private function _setInicioOperaciones($id, $fecha)
    {
        $validadorFecha = new Zend_Validate_Date();
        if(!$validadorFecha->isValid($fecha)){
            throw new Exception('La fecha de inicio de operaciones no es válida.');
        }
        
        $row = $this->find($id)->current();
        if($row){
            $row->inicio_operaciones = $fecha;
            $row->save();
        }
        return TRUE;
    }
    
    public function setOrden($data)
    {
        $i = 1;
        $ids = explode(",", $data);
        foreach($ids as $id){
            $this->_setLugar($id, $i);
            $i++;
        }
    }
    
    private function _setLugar($id, $orden)
    {
        $ciudad = $this->find($id)->current();
        if($ciudad){
            $ciudad->orden = $orden;
            $ciudad->save();
        }
    }
    
    private function _getLugar()
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT MAX(orden) FROM naves_equipos";
        $ultimaPagina = $adapter->fetchOne($sql);
        if($ultimaPagina){
            return $ultimaPagina + 1;
        } else {
            return 1;
        }
    }
    /**************************************************************************/ 
    
    /********************** FUNCIONES ARCHIVOS ADJUNTOS ***********************/
    public function adjuntarArchivo($data, $user)
    {
        $modelArchivo = new Shipcode_Model_NaveEquipoArchivo();
        $modelArchivo->crear($data, $user);
    }
    
    public function getArchivos()
    {
        $modelArchivo = new Shipcode_Model_NaveEquipoArchivo();
        return $modelArchivo->getRowsByEquipoId($this->_id);
    }
    /**************************************************************************/
    
    /**************  FUNCIONES DE PARTES Y PIEZAS / INFO TECNICA **************/
    public function getPartes()
    {
        $modelPartes = new Shipcode_Model_NaveEquipoParte();
        return $modelPartes->getRowsByEquipoId($this->_id);
    }
    
    public function agregarParte($data, $user)
    {
        $parte = new Shipcode_Model_NaveEquipoParte();
        return $parte->crear($data, $user);
    }
    
    public function sincronizarInformacionTecnica($opcion, array $equipoIds, $user)
    {
        if($opcion != 1 && $opcion != 2 && $opcion != 3){
            throw new Exception('La opción enviada no es válida.');
        }
        if($opcion == 1){
            return $this->_sincronizarPartesyPiezasDesdeReferencia($equipoIds, $user);
        } elseif($opcion == 2) {
            return $this->_sincronizarInformacionTecnicaDesdeReferencia($equipoIds);
        } elseif($opcion == 3){
            $this->_sincronizarPartesyPiezasDesdeReferencia($equipoIds, $user);
            $this->_sincronizarInformacionTecnicaDesdeReferencia($equipoIds);
            return TRUE;
        }
        return FALSE;
    }
    
    private function _sincronizarInformacionTecnicaDesdeReferencia($equipoIds)
    {
        $adapter = $this->getAdapter();
        $adapter->beginTransaction();
        
        if(count($equipoIds) > 0){
            $i = 0;
            foreach($equipoIds as $id){
                if($i == 0){
                    $this->setId($id);
                    $infoTecnica = $this->getRow()->datos_tecnicos;
                } 
                if($i > 0){
                    $adapter->update(
                        'naves_equipos', 
                        array('datos_tecnicos' => $infoTecnica), 
                        "id=$id"    
                    );
                }
                $i++;
            }
            $adapter->commit();
            return TRUE;
            
        } else {
            $adapter->rollBack();
            throw new Exception("No se envieron ID de equipos para sincronizar por referencia");
        }
    }
    
    private function _agregarPartes($id, $partes, $user)
    {   
        /*
        if(!is_array($partes) || !count($partes) > 0){
            throw new Exception('No se han enviado las partes y piezas para agregar.');
        }
        */
        $modelParte = new Shipcode_Model_NaveEquipoParte();
        foreach($partes as $parte){
            $data = array(
                'equipo_id' => $id,
                'nombre' => $parte->nombre,
                'num_parte' => $parte->num_parte,
                'detalles' => $parte->detalles,
                'cantidad' => $parte->cantidad,
            );
            $modelParte->crear($data, $user);
        }
    }
    
    private function _eliminarPartes($id)
    {
        $modelPartes = new Shipcode_Model_NaveEquipoParte();
        return $modelPartes->eliminarPorEquipoId($id);
    }
    
    private function _sincronizarPartesyPiezasDesdeReferencia($equipoIds, $user)
    {
        $adapter = $this->getAdapter();
        $adapter->beginTransaction();
        try {
            if(count($equipoIds) > 0){
                $i = 0;
                foreach($equipoIds as $id){
                    if($i == 0){
                        $this->setId($id);
                        $partes = $this->getPartes();
                    } 
                    if($i > 0){
                        $this->_eliminarPartes($id);
                        $this->_agregarPartes($id, $partes, $user);
                    }
                    $i++;
                }
                $adapter->commit();
                return TRUE;
            } else {
                $adapter->rollBack();
                throw new Exception("No se envieron ID de equipos para sincronizar por referencia");
            }
        } catch(Exception $e){
            return $e->getMessage();
        }
    }
    /**************************************************************************/
    
    /************************  FUNCIONES DE HORÓMETROS ************************/
    public function getLecturasHorometro()
    {
        $horometro = new Shipcode_Model_NaveHorometroLectura();
        return $horometro->getLecturasPorEquipoId($this->_id);
    }
    
    public function getIdLecturaSiguiente($lectura_id)
    {
        $horometro = new Shipcode_Model_NaveHorometroLectura();
        return $horometro->getIdSiguienteById($lectura_id);
    }
    
    public function getLecturaAnterior($lectura_id)
    {
        $horometro = new Shipcode_Model_NaveHorometroLectura();
        return $horometro->getAnteriorById($lectura_id);
    }
    
    public function getLecturaHorometroDependiente($lectura_id)
    {
        $horometro = new Shipcode_Model_NaveHorometroLectura();
        return $horometro->getLecturaDependiente($this->_id, $lectura_id);
    }
    
    public function getLecturaHorometroById($lectura_id)
    {
        $horometro = new Shipcode_Model_NaveHorometroLectura();
        $horometro->setId($lectura_id);
        return $horometro->getRow()->toArray();
    }
    
    public function getLecturaHorometroByIdToJson($lectura_id)
    {
        $data = $this->getLecturaHorometroById($lectura_id);
        $data['fecha_formateada'] = Shipcode_Model_Fecha::formatShort($data['fecha']);
        $data['lectura_formateada'] = Shipcode_Model_Numero::formatDecimal($data['lectura']);
        return $data;
    }
    
    public function getSumarioHorometro()
    {
        $horometro = new Shipcode_Model_NaveHorometroLectura();
        $dataSumario = array(
            'primeraLectura' => $horometro->getPrimeraLectura($this->_id),
            'ultimaLectura' => $horometro->getUltimaLectura($this->_id),
            'promedioCalculado' => $this->getPromedioCalculado(),
            'numLecturas' => $horometro->getNumLecturasByEquipoId($this->_id)
        );
        return $dataSumario;
    }
    
    public function getSumarioHorometroToJson()
    {
        $dataSumario = $this->getSumarioHorometro();
        $dataSumario['primeraLectura']['fecha_formateada'] = Shipcode_Model_Fecha::formatShort($dataSumario['primeraLectura']['fecha']);
        $dataSumario['primeraLectura']['lectura_formateada'] = Shipcode_Model_Numero::formatDecimal($dataSumario['primeraLectura']['lectura']);
        $dataSumario['ultimaLectura']['fecha_formateada'] = Shipcode_Model_Fecha::formatShort($dataSumario['ultimaLectura']['fecha']);
        $dataSumario['ultimaLectura']['lectura_formateada'] = Shipcode_Model_Numero::formatDecimal($dataSumario['ultimaLectura']['lectura']);
        $dataSumario['promedioCalculado_formateado'] = Shipcode_Model_Numero::formatDecimal($dataSumario['promedioCalculado']);
        $dataSumario['numLecturas_formateado'] = Shipcode_Model_Numero::formatDecimal($dataSumario['numLecturas']);
        return $dataSumario;
    }
    
    public function getPromedioCalculado()
    {
        return $this->getRow()->promedio_calculado;
    }
    
    public function getUltimaLecturaHorometro()
    {
        $row = $this->getRow();
        if($row->horometro == 1){
            $horometro = new Shipcode_Model_NaveHorometroLectura();
            return $horometro->getUltimaLectura($row->id);
        }
        return NULL;
    }
    
    public function crearRegistroHorometro($data, $user)
    {
        $this->_activarHorometro($data['equipo_id']);
        $data['estado'] = 1;
        $horometroLectura = new Shipcode_Model_NaveHorometroLectura();
        $horometroLectura->crear($data, $user);
    }
    
    public function eliminarRegistroHorometro()
    {
        $row = $this->getRow();
        $row->horometro = 0;
        $row->promedio_calculado = 0;
        $row->horometro_anclaje = NULL;
        $row->save();
        $horometroLectura = new Shipcode_Model_NaveHorometroLectura();
        $horometroLectura->eliminarHistorial($this->_id);
        $horometroLectura->desbloquearRegistros($this->id);
        $horometroLectura->desbloquearRegistrosDependientes($this->id);
    }
    
    public function anclarHorometro($idMaestro)
    {
        $row = $this->getRow();
        $row->horometro_anclaje = $idMaestro;
        $row->save();
    }
    
    public function verificarSiEsUltimaLectura($fecha, $lectura)
    {
        $lecturaHorometro = new Shipcode_Model_NaveHorometroLectura();
        return $lecturaHorometro->validarUltimaLectura($lectura, $this->_id, $fecha);
    }
    
    public function eliminarAnclajeHorometro($limpiarRegistro = TRUE)
    {
        $row = $this->getRow();
        $row->horometro_anclaje = NULL;
        $row->save();
        
        if($limpiarRegistro == TRUE) {
            $horometro = new Shipcode_Model_NaveHorometroLectura();
            $horometro->desbloquearRegistros($this->_id);
        }
    }
    
    public function tieneLecturasReferidas()
    {
        $horometro = new Shipcode_Model_NaveHorometroLectura();
        $lecturasReferidas = $horometro->getLecturasReferidasByEquipoId($this->_id);
        if(count($lecturasReferidas) > 0){
            return TRUE;
        }
        return FALSE;
    }
    
    public function getPuntosAnclaje()
    {
        $data = array();
        $where = $this->getAdapter()->quoteInto("horometro_anclaje=?", $this->_id);
        $equiposAnclados = $this->fetchAll($where);
        
        if(count($equiposAnclados) > 0) {
            foreach($equiposAnclados as $equipoAnclado){
                $horometro = new Shipcode_Model_NaveHorometroLectura();
                $primeraLectura = $horometro->getPrimeraLecturaAnclada($equipoAnclado->id);
                $fila['equipo_id'] = $equipoAnclado->id;
                $fila['fecha'] = $primeraLectura['fecha'];
                $fila['lectura'] = $primeraLectura['lectura'];
                $data[] = $fila;
            }
        }
        return $data;
    }
    
    public function registrarLecturaHorometro($lectura, $fecha, $user, $ref_id = NULL)
    {
        $data = array(
            'equipo_id' => $this->_id,
            'lectura' => $lectura,
            'fecha' => $fecha,
            'estado' => 1,
            'ref_id' => $ref_id
        );
        $horometroLectura = new Shipcode_Model_NaveHorometroLectura();
        $resultadoCreacion = $horometroLectura->crear($data, $user);
        
        if($resultadoCreacion !== FALSE && $resultadoCreacion !== NULL && $resultadoCreacion !== 0){
            $resultadoAjuste = $this->revisaryAjustarPromedioCalculado($user);
            if($resultadoAjuste == TRUE && $this->getRow()->promedio_usado == 'C'){
                $this->reprogramarPlanMantenimiento($user, "AUTOMATICA");
            }
        }
        
        return $resultadoCreacion;
    }
    
    public function editarLecturaHorometro($id, $lectura, $fecha, $user)
    {
        $result = NULL;
        $data = array(
            'lectura' => $lectura,
            'fecha' => $fecha,
            'estado' => 1
        );
        
        try {
            
            $horometroLectura = new Shipcode_Model_NaveHorometroLectura();
            $horometroLectura->setId($id);

            $result['dataEditado'] = $horometroLectura->getRow()->toArray();
            $result['diferenciaHoras'] = $lectura - $result['dataEditado']['lectura'];
            $result['registrosReferidos'] = $horometroLectura->getReferidos($id);
            
            if($horometroLectura->editar($data, $id, $user)){
                $resultadoAjuste = $this->revisaryAjustarPromedioCalculado($user);
                if($resultadoAjuste == TRUE && $this->getRow()->promedio_usado == 'C'){
                    $this->reprogramarPlanMantenimiento($user, "AUTOMATICA");
                }
            }
            return $result;
            
        } catch (Exception $ex) {
            return $ex->getMessage();
        }
    }
    
    public function eliminarLecturaHorometro($id, $user)
    {
        $result = array();
        $horometroLectura = new Shipcode_Model_NaveHorometroLectura();
        $horometroLectura->setId($id);
        
        $result['dataEliminado'] = $horometroLectura->getRow()->toArray();
        $result['registrosReferidos'] = $horometroLectura->getReferidos();
        
        if($horometroLectura->eliminar()) {
            $resultadoAjuste = $this->revisaryAjustarPromedioCalculado($user);
            if($resultadoAjuste == TRUE && $this->getRow()->promedio_usado == 'C'){
                $this->reprogramarPlanMantenimiento($user, "AUTOMATICA");
            }
        }
        return $result;
    }
    
    public function getAllHorometros()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array('id','nombre'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array())   
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array()) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre')) 
               ->where("neu.fecha_salida IS NULL")   
               ->where("horometro='1'")
               ->group("ne.id");
        return $adapter->fetchAll($select);
    }
    
    public function getHorometrosByNaveId($nave_id)
    {
        $data = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array('id', 'nombre', 'horometro'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array())   
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array()) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array())  
               ->where("ne.horometro='1'")  
               ->where("neu.fecha_salida IS NULL")    
               ->where("ns.nave_id=?", $nave_id)
               ->group("ne.id")
               ->order("ne.orden");
        $rows = $adapter->fetchAll($select);
        
        if(count($rows) > 0 ) {
            $i = 0;
            $lecturaHorometro = new Shipcode_Model_NaveHorometroLectura();
            foreach($rows as $row){
                $ultimaLectura = $lecturaHorometro->getUltimaLectura($row['id']);
                $data[$i] = $row;
                $data[$i]['fecha'] = $ultimaLectura['fecha'];
                $data[$i]['lectura'] = $ultimaLectura['lectura'];
                $i++;
            }
            return $data;
        }
        return NULL;
    }
    
    public function setPromedioAsignado($promedio, $user)
    {
        $row = $this->getRow();
        if($row->promedio_asignado != $promedio){
            $row->promedio_asignado = (int)$promedio;
            $row->creador = $user;
            $row->save();
            if($row->promedio_usado == 'A'){
                return $this->reprogramarPlanMantenimiento($user, "AUTOMATICA");
            }
        }
    }
    
    public function setPromedioCalculado($promedio, $user)
    {
        $row = $this->getRow();
        if($row->promedio_asignado != $promedio){
            $row->promedio_calculado = (int)$promedio;
            $row->creador = $user;
            $row->save();
            if($row->promedio_usado == 'C'){
                return $this->reprogramarPlanMantenimiento($user, "AUTOMATICA");
            }
        }
    }
    
    public function setPromedioAsignadoMasivamente($equiposIds, $promedio, $user)
    {
        foreach($equiposIds as $key => $id){
            $this->setId($id);
            $this->setPromedioAsignado($promedio, $user);
        }
    }
    
    public function setPromedioCalculadoMasivamente($equiposIds, $user)
    {
        foreach($equiposIds as $key => $id){
            $this->setId($id);
            if($this->getRow()->horometro == 1) {
                $promedio = $this->calcularPromedioMensualOperacion($this->_id, $user);
                $this->setPromedioCalculado($promedio, $user);
            }
        }
    }
    
    public function setPromedioUsado($promedioUsado, $usuario_id)
    {
        $equipo = $this->getRow();
        
        if($equipo->horometro == 0){
            throw new Exception('Este equipo no tiene horómetro activado');
        }
        
        if($promedioUsado == "A" && $equipo->promedio_usado != "A"){
            
            $equipo->promedio_usado = "A";
            $equipo->save();
            return $this->reprogramarPlanMantenimiento($usuario_id, "AUTOMATICA");
            
        } elseif($promedioUsado == "C" && $equipo->promedio_usado != "C"){
            
            $equipo->promedio_usado = "C";
            $equipo->save();
            return $this->reprogramarPlanMantenimiento($usuario_id, "AUTOMATICA");
            
        }
    }
    
    public function revisaryAjustarPromedioCalculado($user)
    {
        $promedio = $this->calcularPromedioMensualOperacion();
        $dataActual = $this->getRow();
        if($promedio !== $dataActual['promedio_calculado']) {
            return $this->setPromedioCalculado($promedio, $user);
        }
        return FALSE;
    }
    
    public function getHorasOperacionMensuales()
    {
        $data = array();
        $ultimos12Meses = $this->_getUltimos12Meses();
        $i = 0;
        $ultimaLecturaMes = NULL;
        foreach($ultimos12Meses as $row){

            $lecturasMes = $this->_getLecturasMes($row['mes'], $row['year'], $this->_id);
            $regMes = count($lecturasMes) - 1;
            $row['lecturas'] = $lecturasMes;
            
            if($ultimaLecturaMes == NULL){
                $ultimaLecturaMes = $lecturasMes[0]['lectura'];
                $diferenciaPorDiasInicial = 0;
            } else {
                $diasDeDiferenciaInicial = $this->_getDiasDeDiferencia($ultimaLecturaMes['fecha'], $lecturasMes[0]['fecha']);
                $diasInicioMes = $this->_getDiasInicioMes($lecturasMes[0]['fecha']);
                $valorDiario = (int)(($lecturasMes[0]['lectura'] - $ultimaLecturaMes['lectura']) / $diasDeDiferenciaInicial);
                $diferenciaPorDiasInicial = $valorDiario * $diasInicioMes ;
                
                $diferenciaPorDiasFinal = $valorDiario * ($diasDeDiferenciaInicial - $diasInicioMes);
                $data[$i -1]['totalHoras'] = $data[$i -1]['totalHoras'] + $diferenciaPorDiasFinal;
            }
            
            $totalHorasMes = (int)($lecturasMes[$regMes]['lectura'] 
                           - $lecturasMes[0]['lectura'] + $diferenciaPorDiasInicial);
            
            $row['ultimaMesAnterior'] = $ultimaLecturaMes;
            $row['totalHoras'] = $totalHorasMes;
            $ultimaLecturaMes = end($lecturasMes);
            $data[$i] = $row;
            $i++;
        }
        return $data;
    }
    
    public function calcularPromedioMensualOperacion()
    {
        $data = array();
        $totalHoras = 0;
        $mesesDeLecturas = $this->_getTodosLosMesesCompletos($this->_id);

        if(count($mesesDeLecturas) > 1) {
            $i = 0;
            $ultimaLecturaMes = NULL;
            foreach($mesesDeLecturas as $row){

                $lecturasMes = $this->_getLecturasMes($row['mes'], $row['year'], $this->_id);
                $regMes = count($lecturasMes) - 1;
                $row['lecturas'] = $lecturasMes;

                if($ultimaLecturaMes == NULL){
                    $ultimaLecturaMes = $lecturasMes[0]['lectura'];
                    $diferenciaPorDiasInicial = 0;
                } else {
                    $diasDeDiferenciaInicial = $this->_getDiasDeDiferencia($ultimaLecturaMes['fecha'], $lecturasMes[0]['fecha']);
                    $diasInicioMes = $this->_getDiasInicioMes($lecturasMes[0]['fecha']);
                    $valorDiario = (int)(($lecturasMes[0]['lectura'] - $ultimaLecturaMes['lectura']) / $diasDeDiferenciaInicial);
                    $diferenciaPorDiasInicial = $valorDiario * $diasInicioMes ;

                    $diferenciaPorDiasFinal = $valorDiario * ($diasDeDiferenciaInicial - $diasInicioMes);
                    $data[$i -1]['totalHoras'] = $data[$i -1]['totalHoras'] + $diferenciaPorDiasFinal;
                    $totalHoras = $totalHoras + $diferenciaPorDiasFinal;
                }

                $totalHorasMes = (int)($lecturasMes[$regMes]['lectura'] 
                               - $lecturasMes[0]['lectura'] + $diferenciaPorDiasInicial);

                $row['ultimaMesAnterior'] = $ultimaLecturaMes;
                $row['totalHoras'] = $totalHorasMes;
                $ultimaLecturaMes = end($lecturasMes);
                $data[$i] = $row;

                $totalHoras = $totalHoras + $totalHorasMes;

                $i++;
            }
            $promedioOperacionMensual = $totalHoras / count($mesesDeLecturas);
            return $promedioOperacionMensual;
        } else {
            return 0;
        }
    }
    
    private function _getLecturasMes($mes, $year, $equipo_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT fecha, lectura FROM naves_horometros_lecturas "
             . "WHERE equipo_id='$equipo_id' "
             . "AND YEAR(fecha) = '$year' "
             . "AND MONTH(fecha) = '$mes' "
             . "AND estado='1' "
             . "ORDER BY fecha";
        return $adapter->fetchAll($sql);
    }
    
    private function _getUltimos12Meses()
    {
        $meses = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT YEAR(fecha) AS year, MONTH(fecha) AS mes FROM `naves_horometros_lecturas` "
             . "WHERE equipo_id='$this->_id' AND estado='1' "
             . "AND DATE_SUB(CURDATE(),INTERVAL 12 MONTH) <= fecha GROUP BY MONTH(fecha) "
             . "ORDER BY year, mes ";
        $rows = $adapter->fetchAll($sql);
        $i = 0;
        foreach($rows as $row){
            $meses[$i] = $row;
            $meses[$i]['nombre'] =  $this->_getNombreMes($row['mes']);
            $i++;
        }
        return $meses;
    }
    
    private function _getTodosLosMesesCompletos($equipo_id)
    {
        $meses = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT YEAR(fecha) AS year, MONTH(fecha) AS mes FROM `naves_horometros_lecturas` "
             . "WHERE equipo_id='$equipo_id' AND estado='1' "
             . "AND DATE_SUB(CURDATE(),INTERVAL 12 MONTH) <= fecha GROUP BY MONTH(fecha) "
             . "ORDER BY fecha";
        $rows = $adapter->fetchAll($sql);
        $i = 0;
        $total = count($rows) - 1;
        foreach($rows as $row){
            if($i > 0 && $i < $total) {
                $meses[$i] = $row;
                $meses[$i]['nombre'] =  $this->_getNombreMes($row['mes']);
            }
            $i++;
        }
        return $meses;
    }
    
    private function _activarHorometro($equipo_id)
    {
        $this->setId($equipo_id);
        $row = $this->getRow();
        $row->horometro = 1;
        return $row->save();
    }
    /**************************************************************************/
    
    /*************************  FUNCIONES UBICACIONES *************************/
    public function mover($data, $user)
    {
        $optionsSistema = array('table' => 'naves_sistemas', 'field' => 'id');
        $validadorSistema = new Zend_Validate_Db_RecordExists($optionsSistema);
        $optionsUbicacionv = array('table' => 'ubicaciones_virtuales', 'field' => 'id');
        $validadorUbicacionv = new Zend_Validate_Db_RecordExists($optionsUbicacionv);
        
        $valDestino = FALSE;
        if(isset($data['sistema_id']) && $validadorSistema->isValid($data['sistema_id'])) {
            $valDestino = TRUE;
            $data['ubicacionv_id'] = NULL;
        } elseif(isset($data['ubicacionv_id']) && $validadorUbicacionv->isValid($data['ubicacionv_id'])){
            $valDestino = TRUE;
            $data['sistema_id'] = NULL;
        }
        
        $ubicacionActualId = $this->_getUbicacionId();
        
        if($ubicacionActualId){
            $nueva_id = $this->_abrirUbicacion(
                $this->_id, 
                $data['sistema_id'], 
                $data['ubicacionv_id'], 
                $user,
                'Cambio de ubicación'
            );
            if($nueva_id != FALSE){
                $this->_cerrarUbicacion($ubicacionActualId);
                $this->_actualizarUbicacion($nueva_id);
                
                if($data['ubicacionv_id'] !== NULL && $data['ubicacionv_id'] !== ''){
                    $this->eliminarEventos();
                }
                
                if($data['oubicacionv_id'] !== NULL && $data['oubicacionv_id'] !== '' 
                        && $data['sistema_id'] !== NULL && $data['sistema_id'] !== ''){
                    $plan_id = $this->getRow()->planmant_id;
                    if($plan_id !== NULL){
                        $this->_programarItemsPlan($plan_id, $user);
                    }
                }
                
                return TRUE;
            }
            return FALSE;
        }
        
        return FALSE;
    }
    
    public function eliminarEventos()
    {
        $evento = new Shipcode_Model_NaveActividad();
        return $evento->eliminarEventosAsociadosAlEquipo($this->_id);
    }
    
    public function getUbicaciones($cant = NULL)
    {
        $ubicacion = new Shipcode_Model_NaveEquipoUbicacion();
        return $ubicacion->getRowsByEquipoId($this->_id, $cant);
    }
    
    private function _getUbicacionId()
    {
        $ubicacion = new Shipcode_Model_NaveEquipoUbicacion();
        return $ubicacion->getLastByEquipoId($this->_id);
    }
    
    public function getUbicacion($id)
    {
        return $this->_getUbicacion($id);
    }
    
    private function _getUbicacion($id)
    {
        $row = $this->find($id)->current();
        $ubicacion = new Shipcode_Model_NaveEquipoUbicacion();
        $ubicacion->setId($row->ubicacion_id);
        return $ubicacion->getRow()->toArray();
    }
    
    private function _getUbicacionFull($id)
    {
        $ubicacion = new Shipcode_Model_NaveEquipoUbicacion();
        $ubicacion->setId($id);
        return $ubicacion->getNombre();
    }
    
    private function _cambiarUbicacionSistema($equipo_id, $ubicacion_id, $sistema_id, $user)
    {
        $nueva_id = $this->_abrirUbicacion(
            $equipo_id, 
            $sistema_id, 
            NULL, 
            $user
        );
            
        if($nueva_id != FALSE){
            $this->_cerrarUbicacion($ubicacion_id);
            return $nueva_id;
        }
        return $ubicacion_id;
    }
    
    private function _abrirUbicacion($id, $sistema_id, $ubicacionv_id, $user, $observaciones = NULL)
    {
        if($observaciones == NULL) {
            $observaciones = 'Ubicación inicial. Creación del equipo o fecha de inicio de control de ubicaciones.';
        }
        
        $data = array(
            'equipo_id'     => $id,
            'sistema_id'    => $sistema_id,
            'ubicacionv_id' => $ubicacionv_id,
            'fecha_entrada' => date("Y-m-d"),
            'observaciones' => $observaciones
        );
        
        $modelUbicacion = new Shipcode_Model_NaveEquipoUbicacion();
        $id = $modelUbicacion->crear($data, $user);
        return $id;
    }

    private function _cerrarUbicacion($id)
    {
        $ubicacion = new Shipcode_Model_NaveEquipoUbicacion();
        $ubicacion->setId($id);
        $ubicacion->cerrar();
    } 
    
    private function _actualizarUbicacion($nueva_id)
    {
        $row = $this->getRow();
        $row->ubicacion_id = $nueva_id;
        $row->save();
    }
    
    public function getPairsToSelectByNaveId($nave_id)
    {
        $adapter = $this->getAdapter();
        $select = $adapter->select()
                          ->from(array('ne' => 'naves_equipos'), array('id','nombre'))
                          ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.id=neu.equipo_id', array())
                          ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array())
                          ->where("ns.nave_id=?", $nave_id);
        return $adapter->fetchPairs($select);
    }

    public function getRowsToSelectBySistemaId($sistema_id)
    {
        $adapter = $this->getAdapter();
        $select = $adapter->select()
                          ->from(array('ne' => 'naves_equipos'), array('id','nombre'))
                          ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.id=neu.equipo_id', array())
                          ->where("neu.sistema_id=?", $sistema_id);
        return $adapter->fetchAll($select, NULL, Zend_Db::FETCH_ASSOC);
    }
    
    public function getRowsConHorometroToSelectBySistemaId($sistema_id)
    {
        $adapter = $this->getAdapter();
        $select = $adapter->select()
                          ->from(array('ne' => 'naves_equipos'), array('id','nombre'))
                          ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.id=neu.equipo_id', array())
                          ->where("neu.sistema_id=?", $sistema_id)
                          ->where("neu.fecha_salida IS NULL")
                          ->where("ne.horometro='1'");
        
        return $adapter->fetchAll($select);
    }
    
    public function getRowsConHorometroBySistemaPadreId($sistema_padre_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select()
                          ->from(array('ne' => 'naves_equipos'), array('id','nombre', 'horometro_anclaje'))
                          ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array())
                          ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array())
                          ->where("ns.padre_id=?", $sistema_padre_id)
                          ->where("ne.horometro='1'");
        return $adapter->fetchAll($select);
    }
    
    public function getRowsConHorometroBySistemaId($sistema_id)
    {
        $adapter = $this->getAdapter();
        $select = $adapter->select()
                          ->from(array('ne' => 'naves_equipos'), array('id','nombre', 'horometro_anclaje'))
                          ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array())
                          ->where("neu.sistema_id=?", $sistema_id)
                          ->where("ne.horometro='1'");
        return $adapter->fetchAll($select, array(), Zend_Db::FETCH_ASSOC);
    }
    
    public function checkHorometrosDependientes($equipo_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT COUNT(*) FROM naves_equipos WHERE horometro_anclaje='$equipo_id'";
        $result = $adapter->fetchOne($sql);
        if($result){
            return TRUE;
        }
        return FALSE;
    }
    
    public function getRowsToInformeByNaveId($nave_id)
    {
        $data = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array('id', 'nombre', 'horometro', 'horometro_anclaje', 'parametros'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array()) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array()) 
               ->where("ns.nave_id=? AND (ne.horometro = '1' OR ne.parametros IS NOT NULL)", $nave_id)
               ->order("ne.orden");
        $equipos = $adapter->fetchAll($select);
        if(count($equipos) > 0){
            $data = array();
            $lecturaHorometro = new Shipcode_Model_NaveHorometroLectura();
            $lecturaParametro = new Shipcode_Model_NaveParametroLectura();
            foreach($equipos as $equipo) {
                if($equipo['horometro'] != 0){
                    $equipo['lectura_horometro'] = $lecturaHorometro->getUltimaLectura($equipo['id']);
                }
                if($equipo['parametros'] !== NULL){
                    $parametros = explode(",", $equipo['parametros']);
                    if(count($parametros) > 0 ) {
                        $dataParametros = array();
                        for($i = 0; $i < count($parametros); $i++){
                            $ultimaLectura = $lecturaParametro->getUltimaLecturaByEquipoIdAndParametroId($equipo['id'], $parametros[$i]);
                            if($ultimaLectura){
                                $dataParametros[$parametros[$i]] = $ultimaLectura;
                            }
                        }
                    }
                    $equipo['lecturas_parametros'] = $dataParametros;
                } else {
                   $equipo['lecturas_parametros'] = 'ok'; 
                }
                $data[] = $equipo;
            }
            return $data;
        }
    }
    
    public function getRowsBySistemaId($sistema_id, $plan = FALSE)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array(
                    'id', 'creacion', 'creador', 'tipo_id', 'planmant_id',
                    'marca_id', 'modelo', 'nombre', 'serie', 'datos_tecnicos', 
                    'horometro', 'parametros', 'promedio_usado', 'promedio_asignado', 'promedio_calculado'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array('sistema' => 'nombre', 'nave_id')) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre', 'empresa_id')) 
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
               ->joinLeft(array('et' => 'equipos_tipos'), 'et.id=ne.tipo_id', array('tipo_equipo' => 'nombre'))  
               ->joinLeft(array('em' => 'equipos_marcas'), 'em.id=ne.marca_id', array('marca' => 'nombre')) 
               ->where("ne.estado='1'") 
               ->where("neu.sistema_id=?", $sistema_id)
               ->where("neu.fecha_salida IS NULL");
        if($plan === TRUE){
            $select->where('ne.planmant_id IS NOT NULL');
        }
        $select->order("ne.orden");
        return $adapter->fetchAll($select);
    }
    
    public function setInicioOperacionesBySistemaId($sistema_id, $fecha)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array('id', 'inicio_operaciones'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array()) 
               ->where("neu.sistema_id=?", $sistema_id)
               ->where("neu.fecha_salida IS NULL");
        $equipos = $adapter->fetchAll($select);
        if(count($equipos) > 0){
            foreach($equipos as $equipo){
                $this->_setInicioOperaciones($equipo['id'], $fecha);
            }
        }
        return TRUE;
    }
    
    public function getRowsConPlanBySistemaId($sistema_id)
    {
        $data = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array('id','planmant_id', 'modelo', 'nombre'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->where("ne.estado='1'") 
               ->where("ne.planmant_id IS NOT NULL") 
               ->where("neu.sistema_id=?", $sistema_id)
               ->where("neu.fecha_salida IS NULL");
        $equipos = $adapter->fetchAll($select);
        foreach($equipos as $equipo){
            $this->setId($equipo['id']);
            $row = $equipo;
            $row['plan'] = $this->getPlanMantenimiento($equipo['planmant_id']);
            $data[] = $row;
        }
        return $data;
    }
    
    public function getRowsByUbicacionvId($ubicacionv_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array(
                    'id', 'creacion', 'creador', 'tipo_id', 'planmant_id', 'condicion',
                    'marca_id', 'modelo', 'nombre', 'serie', 'datos_tecnicos', 
                    'horometro', 'parametros'
               ))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'neu.id=ne.ubicacion_id', array())
               ->join(array('uv' => 'ubicaciones_virtuales'), 'neu.ubicacionv_id=uv.id', array('ubicacion_virtual' => 'nombre'))
               ->joinLeft(array('et' => 'equipos_tipos'), 'et.id=ne.tipo_id', array('tipo_equipo' => 'nombre'))  
               ->joinLeft(array('em' => 'equipos_marcas'), 'em.id=ne.marca_id', array('marca' => 'nombre')) 
               ->where("neu.ubicacionv_id=?", $ubicacionv_id)
               ->order('ne.id');
        return $adapter->fetchAll($select);
    }
    
    public function getEquiposToSelectByUbicacionVirtualId($ubicacionv_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT e.id, e.nombre "
             . "FROM naves_equipos_ubicaciones AS u "
             . "JOIN naves_equipos AS e ON u.equipo_id=e.id "
             . "WHERE u.ubicacionv_id='$ubicacionv_id' AND u.fecha_salida IS NULL "
             . "ORDER BY e.id";
        return $adapter->fetchAll($sql);
    }
    
    public function getEquiposToSelectBySistemaId($sistema_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT e.id, e.nombre "
             . "FROM naves_equipos_ubicaciones AS u "
             . "JOIN naves_equipos AS e ON u.equipo_id=e.id "
             . "WHERE u.sistema_id='$sistema_id' AND u.fecha_salida IS NULL "
             . "ORDER BY e.id";   
        return $adapter->fetchAll($sql);
    }
    
    public function getEquiposToCloneBySistemaId($sistema_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'),  array('*'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.id=neu.equipo_id', array()) 
               ->where("neu.sistema_id=?", $sistema_id)
               ->where("neu.fecha_salida IS NULL")
               ->order('ne.id');
        return $adapter->fetchAll($select);
    }
    
    public function getRowsByEquiposId(array $equiposIds)
    {
        if(count($equiposIds) > 0){
            
            $adapter = $this->getAdapter();
            $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
            $equipos = array();
            
            foreach($equiposIds as $key => $id){
                $select = $adapter->select();
                $select->from(array('ne' => 'naves_equipos'), array(
                            'id', 'creacion', 'creador', 'tipo_id', 'planmant_id',
                            'marca_id', 'modelo', 'nombre', 'serie', 'datos_tecnicos', 'horometro', 'parametros'))
                       ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array())  
                       ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array('sistema' => 'nombre', 'nave_id')) 
                       ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre', 'empresa_id')) 
                       ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
                       ->joinLeft(array('et' => 'equipos_tipos'), 'et.id=ne.tipo_id', array('tipo_equipo' => 'nombre'))  
                       ->joinLeft(array('em' => 'equipos_marcas'), 'em.id=ne.marca_id', array('marca' => 'nombre')) 
                       ->where("neu.fecha_salida IS NULL") 
                       ->where("ne.id=?", $id);
                $equipos[] = $adapter->fetchRow($select);
            }
            return $equipos;
        }
        return NULL;
    }
    
    public function getRowsByTipoId($tipo_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array(
                    'id', 'creacion', 'creador', 'sistema_id', 'tipo_id', 'planmant_id',
                    'marca_id', 'modelo', 'nombre', 'serie', 'datos_tecnicos', 'horometro', 'parametros'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.id=neu.equipo_id', array())   
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array('sistema' => 'nombre', 'nave_id')) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre', 'empresa_id')) 
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
               ->joinLeft(array('et' => 'equipos_tipos'), 'et.id=ne.tipo_id', array('tipo_equipo' => 'nombre'))  
               ->joinLeft(array('em' => 'equipos_marcas'), 'em.id=ne.marca_id', array('marca' => 'nombre')) 
               ->where("neu.fecha_salida IS NULL")  
               ->where("ne.tipo_id=?", $tipo_id);
        return $adapter->fetchAll($select);
    }
    
    public function getRowsConMasReparaciones($limit, $tipo = 9)
    {
        $data = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array(
                    'id', 'tipo_id', 'ubicacion_id', 'marca_id', 'modelo', 'nombre', 'serie'))
               ->join(array('nem' => 'naves_equipos_mantenimientos'), 'ne.id=nem.equipo_id', array('num_reparaciones' => 'COUNT(nem.id)')) 
               ->joinLeft(array('et' => 'equipos_tipos'), 'et.id=ne.tipo_id', array('tipo_equipo' => 'nombre'))  
               ->joinLeft(array('em' => 'equipos_marcas'), 'em.id=ne.marca_id', array('marca' => 'nombre'));
        
        if($tipo != 0){
            if($tipo == 4){
                $select->where("nem.tipo_id='4'");
            } else {
                $select->where("nem.tipo_id=?", $tipo);
            }
        }
        
        $select->group("ne.id")
               ->order("num_reparaciones DESC") 
               ->limit($limit);
        $rows = $adapter->fetchAll($select);
        foreach($rows as $row){
            $row['ubicacion'] = $this->_getUbicacionFull($row['ubicacion_id']);
            $data[] = $row;
        }
        return $data;
    }
    /**************************************************************************/ 

    /*************************  FUNCIONES UTILITARIAS *************************/
    private function _getNombreMes($numMes)
    {
        switch ($numMes) {
            case 1:
                $nombre = "Ene";
                break;
            case 2:
                $nombre = "Feb";
                break;
            case 3:
                $nombre = "Mar";
                break;
            case 4:
                $nombre = "Abr";
                break;
            case 5:
                $nombre = "May";
                break;
            case 6:
                $nombre = "Jun";
                break;
            case 7:
                $nombre = "Jul";
                break;
            case 8:
                $nombre = "Ago";
                break;
            case 9:
                $nombre = "Sep";
                break;
            case 10:
                $nombre = "Oct";
                break;
            case 11:
                $nombre = "Nov";
                break;
            case 12:
                $nombre = "Dic";
                break;
        }
        return $nombre;
    }
    
    private function _getDiasDeDiferencia($fechaInicial, $fechaFinal)
    {
        $d1 = new Zend_Date($fechaInicial);    
        $d2 = new Zend_Date($fechaFinal);
        $diff = $d2->sub($d1)->toValue();
        $days = floor(((($diff/60)/60)/24));
        return $days;
    }
    
    private function _getDiasInicioMes($fechaPrimeraLectura)
    {
        $fechaFinal = new Zend_Date($fechaPrimeraLectura);    
        $fechaInicial = new Zend_Date($fechaFinal->toString("yyy-MM"). "-01");
        return $this->_getDiasDeDiferencia($fechaInicial, $fechaFinal);
    }
    /**************************************************************************/
    
    /***********************  FUNCIONES MANTENIMIENTOS ************************/
    public function registrarMantenimiento($data, $user, $estado = 0)
    {
        try {
            $this->setId($data['equipo_id']);
            $dataEquipo = $this->getRow();
            $ubicacion = $this->_getUbicacion($data['equipo_id']);

            $asociarProyecto = 'NO';
            $itemPlan = FALSE;

            
            if($dataEquipo->planmant_id !== NULL){
                $itemPlan = $this->_getItemPlan($data['servicio_id'], $dataEquipo->planmant_id);
                if($itemPlan !== FALSE){
                    $asociarProyecto = $itemPlan->asociar_proyecto;
                }
            }
            
            if($data['horometro'] == '' ){ $data['horometro'] = NULL; }

            $data['observaciones'] = NULL;

            if($itemPlan !== FALSE) {
                $data['detalles'] = $this->_getDetalleServicio($data['servicio_id']);
                $data['tipo_id'] = 1;
            } else {
                if($data['detalles'] != NULL && $data['servicio_id'] == 59){
                    $data['tipo_id'] = 4; 
                } else {
                    $data['detalles'] = $this->_getDetalleServicio($data['servicio_id']);
                    $data['tipo_id'] = 4; 
                }
            } 

            $data['estado'] = $estado;

            $mantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
            $mantenimientoAgregado = $mantenimiento->crear($data, $user, $asociarProyecto);
            
            if($ubicacion['sistema_id'] !== NULL) {
                if($estado == 1 && $itemPlan != FALSE) {

                    $actividad = new Shipcode_Model_NaveActividad();
                    $evento = $actividad->getEventoByData($data['servicio_id'], $data['equipo_id']);
                    if($evento){
                        $actividad->setId($evento['id']);
                        $actividad->cerrarEvento($mantenimientoAgregado);
                    }
                    $infoHorometroParaCalculo = $this->_getInfoHorometroParaCalculo($dataEquipo);
                    $actividad->programarNuevoEvento($itemPlan, $dataEquipo , $user, $mantenimientoAgregado, $infoHorometroParaCalculo);
                }
            }
            
            return $mantenimientoAgregado;
        } catch (Exception $ex) {
            return $ex;
        }
    }
    
    private function _getDetalleServicio($servicio_id)
    {
        $servicio = new Shipcode_Model_BaseServicio();
        $servicio->setId($servicio_id);
        return $servicio->getRow()->nombre;
    }
    
    public function getMantenimientos($estado = 1)
    {
        $modelMantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
        return $modelMantenimiento->getRowsByEquipoId($this->_id, $estado);
    }
    
    public function getMantenimientosPorTipoId($tipo_id)
    {
        $modelMantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
        return $modelMantenimiento->getRowsByEquipoIdAndTipoId($this->_id, $tipo_id);
    }
    
    public function getHistorialMantenimiento()
    {
        $modelMantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
        return $modelMantenimiento->getHistorialByEquipoId($this->_id);
    }
    
    public function getTiposServiciosRealizados()
    {
        $modelMantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
        return $modelMantenimiento->getTiposRealizadosByEquipoId($this->_id);
    }
    
    public function confirmarReporte($user)
    {
        $adapter = $this->getAdapter();
        $adapter->beginTransaction();
        try{
            
            $dataEquipo = $this->getRow();
           
            $infoHorometroParaCalculo = $this->_getInfoHorometroParaCalculo($dataEquipo);
            $modelMantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
            $mantenimientos = $modelMantenimiento->confirmarReportesByEquipoId($this->_id);
            
            $ubicacion = $this->_getUbicacion($this->_id);
            if($ubicacion['sistema_id'] !== NULL) {
                $modelEvento = new Shipcode_Model_NaveActividad();

                foreach($mantenimientos as $mantenimiento){
                    $evento = $modelEvento->getEventoByData($mantenimiento['servicio_id'], $mantenimiento['equipo_id']);
                    if($evento){
                        $modelEvento->setId($evento['id']);
                        $modelEvento->cerrarEvento($mantenimiento);
                        $itemPlan = $this->_getItemPlan($mantenimiento['servicio_id'], $dataEquipo->planmant_id);
                        $ultimoServicio = $this->_getUltimoServicio($mantenimiento['servicio_id']);
                        $modelEvento->programarNuevoEvento($itemPlan, $dataEquipo , $user, $ultimoServicio, $infoHorometroParaCalculo);
                    }
                }
            }
            $adapter->commit();
            
        } catch (Exception $e){
            $adapter->rollBack();
            return $e->getMessage();
        }
    }
    
    public function descartarReporte()
    { 
        $modelMantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
        return $modelMantenimiento->descartarReportesByEquipoId($this->_id);
    }
    
    public function getPlanMantenimiento($id)
    {
        if($id){
            $modelPlan = new Shipcode_Model_BasePlanMant();
            $modelPlan->setId($id);
            $plan = $modelPlan->getRowFullToEquipo();
            $items = $modelPlan->getItemsToEquipo();
            foreach($items as $item){
                $row = $item;
                $row['ultimo_servicio'] = $this->_getUltimoServicio($item['servicio_id']);
                $row['proximo_servicio'] = $this->_getProximoServicio($item['servicio_id']);
                $plan['items'][] = $row;
            }
            return $plan; 
        }
        return NULL;
    }
    
    public function getPlanMantenimientoBasico($plan_id)
    {
        if($plan_id!= NULL && $plan_id != FALSE){
            $modelPlan = new Shipcode_Model_BasePlanMant();
            $modelPlan->setId($plan_id);
            $plan = $modelPlan->getRowFullToEquipo();
            $items = $modelPlan->getItemsToEquipo();
            foreach($items as $item){
                $row = $item;
                $plan['items'][] = $row;
            }
            return $plan; 
        }
        return NULL;
    }
    
    public function getOtrosServicios($plan_id, $criterio = NULL)
    {
        $modelBaseServicio = new Shipcode_Model_BaseServicio();
        return $modelBaseServicio->getOtrosServicios($plan_id, $criterio);
    }
   
    public function getUltimoServicio($servicio_id)
    {
        return $this->_getUltimoServicio($servicio_id);
    }
    
    private function _getItemPlan($servicio_id, $plan_id)
    {
        $basePlanItem = new Shipcode_Model_BasePlanMantItem();
        return $basePlanItem->getRowByServicioIdAndPlanId($servicio_id, $plan_id);
    }
    
    private function _getUltimoServicio($servicio_id)
    {
        $modelMantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
        return $modelMantenimiento->getUltimoServicio($servicio_id, $this->_id);
    }
    
    private function _getProximoServicio($servicio_id)
    {
        $modelActividad = new Shipcode_Model_NaveActividad();
        return $modelActividad->getEventoByData($servicio_id, $this->_id);
    }
    
    public function getInfoHorometroParaCalculo($dataEquipo)
    {
        return $this->_getInfoHorometroParaCalculo($dataEquipo);
    }
    
    private function _getInfoHorometroParaCalculo($dataEquipo)
    {
        $horometroLectura = new Shipcode_Model_NaveHorometroLectura();
        return $horometroLectura->getInfoParaCalculo($dataEquipo);
    }
    
    public function asignarPlanesDeMantenimientoMasivamente($plan_id, array $equipoIds, $user)
    {
        $optionsPlan = array('table' => 'base_planesmant', 'field' => 'id');
        $validadorPlan = new Zend_Validate_Db_RecordExists($optionsPlan);
        
        if(!$validadorPlan->isValid($plan_id)){
            throw new Exception('El ID de plan enviado no es válido');
        }
        
        if(count($equipoIds) > 0){
            foreach($equipoIds as $key => $id){
                $this->setId($id);
                $this->asignarPlanMantenimiento($plan_id, $user);
            }
        }
        return true;
    }
    
    public function asignarPlanMantenimiento($plan_id, $user)
    {
        try {
            
            $row = $this->eliminarPlanMantenimiento();
            $row->planmant_id = $plan_id;
            $row->save();
            
            $ubicacion = $this->_getUbicacion($row->id);
            if($ubicacion['sistema_id'] !== NULL){
                return $this->_programarItemsPlan($plan_id, $user);
            }
            return TRUE;
        } catch(Exception $e){
            return $e->getMessage();
        }
    }
    
    public function getItemsPlanMantenimientoParaBusqueda($plan_id, array $data)
    {
        $optionsPlan = array('table' => 'base_planesmant', 'field' => 'id');
        $validadorPlan = new Zend_Validate_Db_RecordExists($optionsPlan);
        
        if($validadorPlan->isValid($plan_id)){
            $modelPlan = new Shipcode_Model_BasePlanMant();
            $modelPlan->setId($plan_id);
            return $modelPlan->getItemsParaBusqueda($data);
        }
        return NULL;
    }
    
    public function eliminarPlanesMantenimientoMasivamente($equiposIds)
    {
        if(count($equiposIds) > 0){
            foreach($equiposIds as $key => $id){
                $this->setId($id);
                $this->eliminarPlanMantenimiento();
            }
        }
        return TRUE;
    }
    
    public function eliminarPlanMantenimiento()
    {
        $row = $this->getRow();
        $row->planmant_id = NULL;
        $row->save();
        $modelActividad = new Shipcode_Model_NaveActividad();
        $modelActividad->eliminarEventosAsociadosAlEquipo($this->_id);
        return $row;
    }
    
    public function getPlanesSugeridos()
    {
        $plan = new Shipcode_Model_BasePlanMant();
        return $plan->getPlanesSugeridos($this->getRow()->tipo_id);
    }

    public function reprogramarPlanMantenimiento($user, $tipoProgramacion = NULL)
    {
        /*
         * La reprogramación consiste en resetear los ítems programados que 
         * estén asociados al equipo    
         */
        
        try {
            $actividad = new Shipcode_Model_NaveActividad();
            $eventosIds = $actividad->getRowsByEquipoId($this->_id, 0, $tipoProgramacion);
            $actividad->resetearProgramacionEventosMasivamente($eventosIds, $user);
            return $eventosIds;
        } catch (Exception $e) {
            return $e->getMessage();
        }
        
            
        /*
        $dataEquipo = $this->getRow();
        $actividad = new Shipcode_Model_NaveActividad();
        $actividad->eliminarEventosAsociadosAlEquipo($this->_id, "AUTOMATICA");
        $plan = new Shipcode_Model_BasePlanMant();
        $plan->setId($dataEquipo['planmant_id']);
        $itemsPlan = $plan->getItems();
        $infoHorometroParaCalculo = $this->_getInfoHorometroParaCalculo($dataEquipo);
        
        foreach($itemsPlan as $itemPlan){
            if($actividad->getEventoByData($itemPlan->servicio_id, $this->_id) == NULL){
                $ultimoServicio = $this->_getUltimoServicio($itemPlan->servicio_id);
                $actividad->programarNuevoEvento($itemPlan, $dataEquipo , $user, $ultimoServicio, $infoHorometroParaCalculo);
            }
        }
        */
    }
    
    private function _programarItemsPlan($plan_id, $user)
    {
        $plan = new Shipcode_Model_BasePlanMant();
        $plan->setId($plan_id);
        $itemsPlan = $plan->getItems();
        $actividad = new Shipcode_Model_NaveActividad();
        $dataEquipo = $this->getRow();
        foreach($itemsPlan as $itemPlan){
            $ultimoServicio = $this->_getUltimoServicio($itemPlan->servicio_id);
            $infoHorometroParaCalculo = $this->_getInfoHorometroParaCalculo($dataEquipo);
            $actividad->programarNuevoEvento($itemPlan, $dataEquipo , $user, $ultimoServicio, $infoHorometroParaCalculo);
        }
    }
    /**************************************************************************/
    
    public function getRowsBySistemaIdToExport($sistema_id, $archivos = 0, $fotografia = 0)
    {
        $dataEquipos = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('ne' => 'naves_equipos'), array('id', 'modelo', 'nombre', 'serie', 'datos_tecnicos', 'fotografia'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->joinLeft(array('et' => 'equipos_tipos'), 'et.id=ne.tipo_id', array('tipo_equipo' => 'nombre'))  
               ->joinLeft(array('em' => 'equipos_marcas'), 'em.id=ne.marca_id', array('marca' => 'nombre')) 
               ->where("ne.estado='1'") 
               ->where("neu.sistema_id=?", $sistema_id)
               ->where("neu.fecha_salida IS NULL")
               ->order("ne.orden");
        $rows = $adapter->fetchAll($select);
        
        if($archivos == 1){
            $archivoEquipo = new Shipcode_Model_NaveEquipoArchivo();
        }
        
        if(count($rows) > 0){
            $i = 0;
            foreach($rows as $row){
                $dataEquipos[$i]['ID'] = $row['id'];
                $dataEquipos[$i]['Nombre'] = $row['nombre'];
                $dataEquipos[$i]['Marca'] = $row['marca'];
                $dataEquipos[$i]['Modelo'] = $row['modelo'];
                $dataEquipos[$i]['Serie'] = $row['serie'];
                $dataEquipos[$i]['Tipo'] = $row['tipo_equipo'];
                $dataEquipos[$i]['Mantenimientos'] = $this->_getHistorialMantenimientoToExport($row['id']);
                if($fotografia == 1){
                    $dataEquipos[$i]['Fotografía'] = $row['fotografia'];
                }
                $dataEquipos[$i]['Datos Técnicos'] = $row['datos_tecnicos'];
                if($archivos == 1){
                    $dataEquipos[$i]['Archivos'] = $archivoEquipo->getRowsByEquipoIdToExport($row['id']);
                }
                $i++;
            }
        }
        return $dataEquipos;
    }
    
    private function _getHistorialMantenimientoToExport($equipo_id)
    {
        $modelMantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
        return $modelMantenimiento->getHistorialByEquipoIdToExport($equipo_id);
    }
    
    /*
     * FUNCIONES PARA TEST DE DATOS
    private function _convertFecha($value)
    {
        $fecha = new Zend_Date($value, 'dd/MM/yyyy');
        if(Zend_Date::isDate($fecha)){
            return $fecha->get("yyyy-MM-dd");
        }
        return false;
    }
     public function getDetalleCalculoPromedioMensualOperacion()
    {
        $data = array();
        $dataMeses = array();
        $totalHoras = 0;
        $mesesDeLecturas = $this->_getTodosLosMesesCompletos($this->_id);
        
        if(count($mesesDeLecturas) > 1) {
            $i = 0;
            $ultimaLecturaMes = NULL;
            foreach($mesesDeLecturas as $row){

                $lecturasMes = $this->_getLecturasMes($row['mes'], $row['year'], $this->_id);
                $regMes = count($lecturasMes) - 1;
                $row['lecturas'] = $lecturasMes;

                if($ultimaLecturaMes == NULL){
                    $ultimaLecturaMes = $lecturasMes[0]['lectura'];
                    $diferenciaPorDiasInicial = 0;
                } else {
                    $diasDeDiferenciaInicial = $this->_getDiasDeDiferencia($ultimaLecturaMes['fecha'], $lecturasMes[0]['fecha']);
                    $diasInicioMes = $this->_getDiasInicioMes($lecturasMes[0]['fecha']);
                    $valorDiario = (int)(($lecturasMes[0]['lectura'] - $ultimaLecturaMes['lectura']) / $diasDeDiferenciaInicial);
                    $diferenciaPorDiasInicial = $valorDiario * $diasInicioMes ;

                    $diferenciaPorDiasFinal = $valorDiario * ($diasDeDiferenciaInicial - $diasInicioMes);
                    $data[$i -1]['totalHoras'] = $data[$i -1]['totalHoras'] + $diferenciaPorDiasFinal;
                }

                $totalHorasMes = (int)($lecturasMes[$regMes]['lectura'] 
                               - $lecturasMes[0]['lectura'] + $diferenciaPorDiasInicial);

                $row['ultimaMesAnterior'] = $ultimaLecturaMes;
                $row['totalHoras'] = $totalHorasMes;
                $ultimaLecturaMes = end($lecturasMes);
                $data[$i] = $row;

                $totalHoras = $totalHoras + $totalHorasMes;

                $i++;
            }
            return $data;
        } else {
            return 0;
        }
    }
    
    public function getInfoMesesFull()
    {
        return $this->_getTodosLosMesesCompletos(4442);
    }
    */
    
    /* EN PROCESO DE ELIMINACIÓN
    public function calcularPromedioMensualOperacionMasivamente($equiposIds, $user)
    {
        foreach($equiposIds as $key => $id){
            $this->setId($id);
            $promedio = $this->calcularPromedioMensualOperacion();
            if($promedio){
                $this->setPromedioCalculado($promedio, $user);
            }
        }    
    }
    public function generarUbicacionesIniciales($user)
    {
        $count = 0;
        $modelUbicacion = new Shipcode_Model_NaveEquipoUbicacion();
        $equipos = $this->fetchAll();
        foreach($equipos as $equipo){
            $data = array(
                'equipo_id' => $equipo->id,
                'sistema_id' => $equipo->sistema_id,
                'ubicacionv_id' => NULL,
                'fecha_entrada' => date("Y-m-d"),
                'observaciones' => 'Ubicación inicial. Fecha de inicio de control de ubicaciones.'
            );
            $ubicacion_id = $modelUbicacion->crear($data, $user);
            $equipo->ubicacion_id = $ubicacion_id;
            $equipo->save();
            $count++;
        }
        return $count;
    }
    public function registrarLecturasHorometros($formValues, $user)
    {
        $horometroLectura = new Shipcode_Model_NaveHorometroLectura();
        ini_set("auto_detect_line_endings", true);
        $filename = Zend_Registry::get('PATH_SERVER') . 'files/lecturas-horometros/' . $formValues['archivo'];
        $file = fopen($filename, 'r');
        while (($line = fgetcsv($file, 0, ";")) !== FALSE) {
            $data = array(
                'creador' => $user,
                'equipo_id' => $line[0],
                'fecha' => $this->_convertFecha($line[2]),
                'lectura' => $line[3],
                'informe_id' => NULL,
                'estado' => 1
            );
            $horometroLectura->crear($data, $user);
        }
        fclose($filename);
    }
    
    public function codificarDatos($start)
    {
        $x = 0;
        try {
            $where = "id > $start";
            $rows = $this->fetchAll($where);
            foreach($rows as $row){
                $row->modelo = utf8_encode($row->modelo);
                $row->nombre = utf8_encode($row->nombre);
                $row->datos_tecnicos = utf8_encode($row->datos_tecnicos);
                $row->save();
                $x++;
            }
            return "Se actualizaron los datos de $x equipos";
        } catch(Exception $e){
            return $e->getMessage();
        }
    }
    private function _getItemPlanFull($servicio_id, $planmant_id = NULL)
    {
        if($planmant_id == NULL){
            return FALSE;
        }
        $modelPlanItem = new Shipcode_Model_BasePlanMantItem();
        return $modelPlanItem->getRowFullByServicioIdAndPlanId($servicio_id, $planmant_id);
        
    }
    public function getProximoMantenimiento(array $mantenimientoRealizado)
    {
        return $this->_getProximoMantenimiento($mantenimientoRealizado);
    }
    
    private function _getProximoMantenimiento(array $mantenimientoRealizado, $item)
    {
        if(!is_array($mantenimientoRealizado) || !is_array($item)){
            throw new Exception('No se ha enviado la información requerida para calcular el próximo mantenimiento');
            exit;
        }
        
        $dataProximo = array();
        
        if($mantenimientoRealizado['horometro'] != NULL && $mantenimientoRealizado['horometro']!= ''){
            
            $fechaEstimada = $this->_getFechaEstimada(array(
                'equipo_id'         => $mantenimientoRealizado['equipo_id'],
                'fecha_inicial'     => $mantenimientoRealizado['fecha'],
                'lectura_actual'    => $mantenimientoRealizado['horometro'],
                'periodo'           => $periodo
            ));
            
            $dataProximo['lectura'] = $mantenimientoRealizado['horometro'] + $periodo;
            if($fechaEstimada != NULL){
                $dataProximo['fecha_estimada'] = $fechaEstimada;
                $dataProximo['tipo'] = 1;
            } else {
                $dataProximo['fecha_estimada'] = $fechaEstimada;
                $dataProximo['tipo'] = 3;
            }
        } else {
            $dataProximo['lectura'] = NULL;
            $dataProximo['fecha_estimada'] = NULL;
            $dataProximo['tipo'] = 4;
        }
        return $dataProximo;
    }
     
    private function _getFechaEstimada(array $data)
    {
            
            $promedioDiarioDeHoras = $this->_getPromedioMensualHorasFuncionamiento($dataHorometro);
  
            if($data['fecha_inicial'] != NULL){
                $diasParaProximoMantenimiento = floor($data['periodo'] / $promedioDiarioDeHoras);
                $fechaEstimada1 = new Zend_Date($data['fecha_inicial'], 'yyyy-MM-dd');
            } else {
                $diasParaProximoMantenimiento = floor(($data['periodo'] / $promedioDiarioDeHoras) - ($dataHorometro['final']['lectura'] / $promedioDiarioDeHoras));
                $fechaEstimada1 = new Zend_Date($dataHorometro['final']['fecha'], 'yyyy-MM-dd');
            }
            
            $fechaEstimada1->add($diasParaProximoMantenimiento, Zend_Date::DAY);
            
            // calculo los días que hay entre la última 
            // lectura del horómetro y la fecha estimada1
            $fechaUltimaLectura = new Zend_Date($dataHorometro['final']['fecha'], "yyyy-MM-dd");
            $fechaEstimada2 = new Zend_Date($data['fecha_inicial'], 'yyyy-MM-dd');
            $fechaEstimada2->add($diasParaProximoMantenimiento, Zend_Date::DAY);
            $diferenciaDiasRestantes = $fechaEstimada2->sub($fechaUltimaLectura)->toValue();
            $diasRestantesUltimaLectura = floor(((($diferenciaDiasRestantes/60)/60)/24));
            $horasRestantes = ($data['lectura_actual'] + $data['periodo']) - $dataHorometro['final']['lectura'];
            $horasPosibles = $promedioDiarioDeHoras * $diasRestantesUltimaLectura;
            
            if($horasRestantes > $horasPosibles){
                $diasParaProximoMantenimientoDiasRestantes = floor($horasRestantes/$promedioDiarioDeHoras);
                $fechaUltimaLectura->add($diasParaProximoMantenimientoDiasRestantes, Zend_Date::DAY);
                return $fechaUltimaLectura->toString("yyyy-MM-dd");
            }
            
            return $fechaEstimada1->toString("yyyy-MM-dd");
    }
    private function _getPromedioMensualHorasFuncionamiento($dataHorometro)
    {
        $fechaInicial = new Zend_Date($dataHorometro['inicial']['fecha'], 'yyyy-MM-dd');
        $fechaFinal = new Zend_Date($dataHorometro['final']['fecha'], 'yyyy-MM-dd');
        $diferenciaDias = $fechaFinal->sub($fechaInicial)->toValue();
        $dias = floor(((($diferenciaDias/60)/60)/24));
        $diferenciaHoras = $dataHorometro['final']['lectura'] - $dataHorometro['inicial']['lectura'];
        $promedioDiarioDeHoras = $diferenciaHoras / $dias;
        return $promedioDiarioDeHoras;
    }
    
    private function _getProximoMantenimientoPorHoras(array $mantenimientoRealizado, $item)
    {
        if(!is_array($mantenimientoRealizado)){
            throw new Exception('No se ha enviado la información del mantenimiento realizado');
            exit;
        }
        
        $dataProximo = array();
        if($mantenimientoRealizado['horometro'] != NULL && $mantenimientoRealizado['horometro']!= ''){
            
            $fechaEstimada = $this->_getFechaEstimada(array(
                'equipo_id'         => $mantenimientoRealizado['equipo_id'],
                'fecha_inicial'     => $mantenimientoRealizado['fecha'],
                'lectura_actual'    => $mantenimientoRealizado['horometro'],
                'periodo'           => $periodo
            ));
            
            $dataProximo['lectura'] = $mantenimientoRealizado['horometro'] + $periodo;
            if($fechaEstimada != NULL){
                $dataProximo['fecha_estimada'] = $fechaEstimada;
                $dataProximo['tipo'] = 1;
            } else {
                $dataProximo['fecha_estimada'] = $fechaEstimada;
                $dataProximo['tipo'] = 3;
            }
        } else {
            $dataProximo['lectura'] = NULL;
            $dataProximo['fecha_estimada'] = NULL;
            $dataProximo['tipo'] = 4;
        }
        return $dataProximo;
    }
    
    private function _getPrimerMantenimientoPorHoras(array $equipoData, $periodo)
    {
        if(!is_array($equipoData)){
            throw new Exception('No se ha enviado la información del equipo para calcular el primer mantenimiento');
            exit;
        }
        $dataFecha = array(
            'equipo_id'      => $equipoData['id'],
            'fecha_inicial'  => NULL,
            'lectura_actual' => 0,
            'periodo'        => $periodo
        );
        
        $fechaEstimada = $this->_getFechaEstimada($dataFecha);
        
        $dataProximo = array();
        $dataProximo['lectura'] = $periodo;
        
        if($fechaEstimada != NULL){
            $dataProximo['fecha_estimada'] = $fechaEstimada;
            $dataProximo['tipo'] = 1;
        } else {
            $dataProximo['fecha_estimada'] = $fechaEstimada;
            $dataProximo['tipo'] = 3;
        }
        return $dataProximo;
    }
    
    private function _getProximoMantenimientoPorDias(array $mantenimientoRealizado, $periodo)
    {
        if(!is_array($mantenimientoRealizado)){
            throw new Exception('No se ha enviado la información del mantenimiento realizado');
            exit;
        }
        $dataProximo = array();
        $fechaProximo = new Zend_Date($mantenimientoRealizado['fecha'], 'yyyy-MM-dd');
        $fechaProximo->add($periodo, Zend_Date::DAY);
        $dataProximo['fecha_estimada'] = $fechaProximo->toString("yyyy-MM-dd");
        $dataProximo['lectura'] = NULL;
        $dataProximo['tipo'] = 0;
        return $dataProximo;
    }
    
    private function _getPrimerMantenimientoPorDias(array $equipoData, $periodo)
    {
       if(!is_array($equipoData)){
            throw new Exception('No se ha enviado la información del equipo para calcular el primer mantenimiento');
            exit;
        }
        $dataFecha = array(
            'equipo_id'      => $equipoData['id'],
            'fecha_inicial'  => NULL,
            'lectura_actual' => 0,
            'periodo'        => $periodo
        );
        $fechaEstimada = $this->_getFechaEstimada($dataFecha);
        
        $dataProximo = array();
        $dataProximo['lectura'] = $periodo;
        
        if($fechaEstimada != NULL){
            $dataProximo['fecha_estimada'] = $fechaEstimada;
            $dataProximo['tipo'] = 1;
        } else {
            $dataProximo['fecha_estimada'] = $fechaEstimada;
            $dataProximo['tipo'] = 3;
        }
        
        return $dataProximo;
    }
   
    // Revisada √
    private function _getEquiposConPlanMantenimiento()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT id, horometro, planmant_id FROM naves_equipos WHERE planmant_id IS NOT NULL";
        return $adapter->fetchAll($sql);
    }
    
    
   
    public function reprogramarMantenimiento(array $data, $user)
    {
        return $this->_programarMantenimiento($data, $user);
    }
    
   
    
    private function _reprogramarMantenimientosReporte(array $mantenimientos, $user)
    {
        if(count($mantenimientos) > 0){
            foreach($mantenimientos as $mantenimiento){
                $this->_programarMantenimiento($mantenimiento, $user);
            }
        }
    }
    
    private function _programarMantenimiento(array $dataMantenimiento, $user)
    {
        $optionsItem = array('table' => 'base_planesmant_items', 'field' => 'id');
        $validadorItem = new Zend_Validate_Db_RecordExists($optionsItem);
        
        if($validadorItem->isValid($dataMantenimiento['item_id'])){
            $dataItem = $this->_getItemPlanMantenimiento($dataMantenimiento['item_id']);
            $dataUltimoMantenimiento = $this->_getUltimoMantenimiento($dataMantenimiento['item_id'], $dataMantenimiento['equipo_id']);
            $proximoMantenimiento = NULL;

            if($dataItem['unidad_medida'] == 'H'){
                $proximoMantenimiento = $this->_getProximoMantenimientoPorHoras($dataUltimoMantenimiento, $dataItem['periodo']);
            } else {
                $proximoMantenimiento = $this->_getProximoMantenimientoPorDias($dataUltimoMantenimiento, $dataItem['periodo']);
            }

            $data = array(
                'equipo_id' => $dataMantenimiento['equipo_id'],
                'item_id' => $dataMantenimiento['item_id'],
                'lectura' => $proximoMantenimiento['lectura'],
                'fecha_estimada' => $proximoMantenimiento['fecha_estimada'],
                'tipo' => $proximoMantenimiento['tipo']
            );
            $modelActividad = new Shipcode_Model_NaveActividad();
            $modelActividad->programarItem($data, $user);
        }
    }
    
    public function reprogramarTodosLosMantenimientos($user)
    {
        $contador = 0;
        $modelActividad = new Shipcode_Model_NaveActividad();
        $equiposConPlanMantenimiento = $this->_getEquiposConPlanMantenimiento();
        foreach($equiposConPlanMantenimiento as $equipoConPlan){
            
            $itemsPlan = $this->getItemsPlanMantenimiento($equipoConPlan['planmant_id']);
            foreach($itemsPlan as $item){
                
                $ultimoMantenimiento = $this->_getUltimoMantenimiento($item->id, $equipoConPlan['id']);
                
                if($item->unidad_medida == 'H' && $equipoConPlan['horometro'] == 0){
                    
                    $data = array(
                        'equipo_id' => $equipoConPlan['id'],
                        'item_id' => $item->id,
                        'fecha_estimada' => NULL,
                        'lectura' => NULL,
                        'tipo' => 2
                    );
                    
                } elseif($item->unidad_medida == 'D' && $ultimoMantenimiento == NULL && $equipoConPlan['horometro'] == 0) {
                    
                    $data = array(
                        'equipo_id' => $equipoConPlan['id'],
                        'item_id' => $item->id,
                        'fecha_estimada' => NULL,
                        'lectura' => NULL,
                        'tipo' => 5
                    );
                    
                } else {    
                    
                    if($ultimoMantenimiento != NULL){

                        $proximoMantenimiento = NULL;
                        if($item->unidad_medida == 'H' && $equipoConPlan['horometro'] == 1){
                            $proximoMantenimiento = $this->_getProximoMantenimientoPorHoras($ultimoMantenimiento, $item->periodo);
                        } else {
                            $proximoMantenimiento = $this->_getProximoMantenimientoPorDias($ultimoMantenimiento, $item->periodo);
                        }
                        $data = array(
                            'equipo_id' => $equipoConPlan['id'],
                            'item_id' => $item->id,
                            'fecha_estimada' => $proximoMantenimiento['fecha_estimada'],
                            'lectura' => $proximoMantenimiento['lectura'],
                            'tipo' => $proximoMantenimiento['tipo']
                        );

                    } else {

                        $proximoMantenimiento = NULL;
                        if($item->unidad_medida == 'H' && $equipoConPlan['horometro'] == 1){
                            $proximoMantenimiento = $this->_getPrimerMantenimientoPorHoras($equipoConPlan, $item->periodo);
                        } else {
                            $proximoMantenimiento = $this->_getPrimerMantenimientoPorDias($equipoConPlan, $item->periodo);
                        }
                        $data = array(
                            'equipo_id' => $equipoConPlan['id'],
                            'item_id' => $item->id,
                            'fecha_estimada' => $proximoMantenimiento['fecha_estimada'],
                            'lectura' => $proximoMantenimiento['lectura'],
                            'tipo' => $proximoMantenimiento['tipo']
                        );
                    } 
                }
                $modelActividad->programarItem($data, $user);
                $contador++;
            }
        }
        return $contador;
    }
    */
}