<?php
class Shipcode_Model_NaveEquipoMantenimiento extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_equipos_mantenimientos';
    protected $_primary = 'id';
    
    private $_id;
    
    private function _validarId($id)
    {
        $optionsEquipoMantenimiento = array('table' => 'naves_equipos_mantenimientos', 'field' => 'id');
        $validadorMantenimiento = new Zend_Validate_Db_RecordExists($optionsEquipoMantenimiento);
        
        if($validadorMantenimiento->isValid($id)){
            return TRUE;
        }
        return FALSE;
    }
    
    public function setId($id)
    {
        if(!$this->_validarId($id)){
            throw new Exception('El ID solicitado no existe - NaveEquipoMantenimiento::setId()');
        }
        $this->_id = $id;
    }
    
    public function setProyectoId($proyecto_id)
    {
        $row = $this->getRow();
        $row->proyecto_id = (int)$proyecto_id;
        $row->save();
    }
    
    public static function getCountSinProyecto($estado)
    {
        $plazoVencimiento = Shipcode_Model_SistemaPreferencia::getPref('DIAS_CIERRE_PROYECTO');
        $adapter = self::getDefaultAdapter();
        if($estado === 'NO'){
            $sql = "SELECT COUNT(*) FROM naves_equipos_mantenimientos m "
                 . "WHERE m.proyecto_requerido='SI' "
                 . "AND m.estado='1' "
                 . "AND now() <= DATE_ADD(m.fecha, INTERVAL " . $plazoVencimiento . " DAY)"
                 . "AND m.proyecto_id IS NULL"; 
        } elseif($estado === 'VENCIDO'){
            $sql = "SELECT COUNT(*) FROM naves_equipos_mantenimientos m "
                 . "WHERE m.proyecto_requerido='SI' "
                 . "AND m.estado='1' "
                 . "AND now() > DATE_ADD(m.fecha, INTERVAL " . $plazoVencimiento . " DAY)"   
                 . "AND m.proyecto_id IS NULL"; 
        }
        return $adapter->fetchOne($sql);
    }
    
    public function getNoAsignados()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nem' => 'naves_equipos_mantenimientos'), array('*'))
               ->join(array('ne' => 'naves_equipos'), 'ne.id=nem.equipo_id', array('equipo' => 'nombre'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array('ubicacion_id' => 'id', 'sistema_id', 'ubicacionv_id'))    
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array('sistema' => 'nombre', 'nave_id')) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre', 'empresa_id'))  
               ->join(array('s' => 'base_servicios'), 's.id=nem.servicio_id', array('servicio' => 'nombre'))
               ->join(array('su' => 'sistema_usuarios'), 'su.id=nem.creador', array('informado_por' => 'nombre')) 
               ->where("nem.estado='0'") 
               ->where("nem.informado_por = 'NAVE'"); 
        return $adapter->fetchAll($select);
    }
    
    public function getNoAsignadosByMes($dataMes = NULL, $nave_id = NULL)
    {
        if($dataMes === NULL || $dataMes === FALSE || !is_array($dataMes)){
            throw new Exception('No se ha enviado los datos del mes solicitado - NaveEquipoMantenimiento::getNoAsignadosByMes()');
        }
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nem' => 'naves_equipos_mantenimientos'), array('*'))
               ->join(array('ne' => 'naves_equipos'), 'ne.id=nem.equipo_id', array('equipo' => 'nombre'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array('ubicacion_id' => 'id', 'sistema_id', 'ubicacionv_id'))    
               ->join(array('ns' => 'naves_sistemas'), 'ns.id=neu.sistema_id', array('sistema' => 'nombre', 'nave_id')) 
               ->join(array('n' => 'naves'), 'n.id=ns.nave_id', array('nave' => 'nombre', 'empresa_id'))  
               ->join(array('s' => 'base_servicios'), 's.id=nem.servicio_id', array('servicio' => 'nombre'))
               ->join(array('su' => 'sistema_usuarios'), 'su.id=nem.creador', array('informado_por' => 'nombre')) 
               ->where("nem.estado='0'")
               ->where("nem.informado_por = 'NAVE'") 
               ->where("YEAR(nem.creacion)=?", $dataMes['year'])
               ->where("MONTH(nem.creacion)=?", $dataMes['mes']); 
        if($nave_id !== NULL){
            $select->where("ns.nave_id=?", $nave_id);
        }
        $select->order("nem.id DESC");
        return $adapter->fetchAll($select);
    }
    
    public function getTiposRealizadosByEquipoId($equipo_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nem' => 'naves_equipos_mantenimientos'), array())
               ->joinLeft(array('s' => 'base_servicios'), 'nem.servicio_id=s.id', array('id', 'nombre'))   
               ->where("nem.equipo_id=?", $equipo_id)
               ->group("s.id")
               ->order("s.nombre");
        return $adapter->fetchAll($select);
    }
    
    public function getServiciosByPlanIdToSelect($equipo_id = 0)
    {
        $optionsEquipo = array('table' => 'naves_equipos', 'field' => 'id');
        $validadorEquipo = new Zend_Validate_Db_RecordExists($optionsEquipo);
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT DISTINCT(s.id), s.nombre FROM base_servicios s";
        if($equipo_id != 0 && $validadorEquipo->isValid($equipo_id)){
            $sql .= " JOIN naves_equipos_mantenimientos m ON m.servicio_id=s.id WHERE m.equipo_id='$equipo_id'";
        }
        $sql .= " GROUP BY (s.id) ORDER BY s.nombre";
        return $adapter->fetchAll($sql);
        
    }
    
    public function getEquipo()
    {
        $modelEquipo = new Shipcode_Model_NaveEquipo();
        $modelEquipo->setId($this->getEquipoId());
        return $modelEquipo->getRowFull();
    }
    
    public function getUltimoServicio($servicio_id, $equipo_id)
    {
        $where = "servicio_id='$servicio_id' AND equipo_id='$equipo_id' AND estado='1'";
        $order =  "fecha DESC";
        $row = $this->fetchRow($where, $order);
        if($row){
            return $row->toArray();
        }
        return NULL;
    }
    
    public function confirmarReportesByEquipoId($equipo_id)
    {
        $where = $this->getAdapter()->quoteInto("estado='0' AND equipo_id=?", $equipo_id);
        $mantenimientos = $this->fetchAll($where)->toArray();
        $data = array("estado" => 1);
        $this->update($data, $where);
        return $mantenimientos;
    }
    
    public function descartarReportesByEquipoId($equipo_id)
    {
        try {
            $where = $this->getAdapter()->quoteInto("estado='0' AND informado_por='ADMIN' AND equipo_id=?", $equipo_id);
            
            return $this->delete($where);
        } catch (Exception $ex) {
            return $ex;
        }
    }
    
    public function getEquipoId()
    {
        return $this->getRow()->equipo_id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public static function getNumArchivos($id)
    {
        return self::_getNumArchivos($id);
    }
       
    public function getArchivos()
    {
        $archivo = new Shipcode_Model_NaveEquipoMantenimientoArchivo();
        return $archivo->getRowsByEquipoMantenimientoId($this->_id);
    }
    
    public function guardarArchivo($data, $user)
    {
        $archivo = new Shipcode_Model_NaveEquipoMantenimientoArchivo();
        return $archivo->crear($data, $user);
    }
    
    public function getHistorialByEquipoId($equipo_id)
    {
        $data = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT DISTINCT YEAR(fecha) AS year FROM naves_equipos_mantenimientos "
             . "WHERE equipo_id='$equipo_id' ORDER BY fecha DESC";
        
        $years = $adapter->fetchAll($sql);
        
        $i = 0;
        
        foreach($years as $year){
            
            $data[$i]['year'] = $year['year'];
            
            $adapter = $this->getAdapter();
            $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
            $select = $adapter->select();
            $select->from(array('nem' => 'naves_equipos_mantenimientos'), array(
                        'id', 'creacion', 'creador', 'equipo_id', 'tipo_id', 'fecha', 
                        'detalles', 'observaciones', 'servicio_id', 'horometro'))
                   ->join(array('mt' => 'mantenimientos_tipos'), 'nem.tipo_id=mt.id', array('tipo' => 'nombre')) 
                   ->joinLeft(array('s' => 'base_servicios'), 'nem.servicio_id=s.id', array('servicio' => 'nombre'))   
                   ->where("nem.equipo_id=?", $equipo_id)
                   ->where("nem.estado='1'")
                   ->where("YEAR(fecha)=?", $year['year']) 
                   ->order("nem.fecha DESC");
            $rows = $adapter->fetchAll($select);
            $mantenimientos = array();
            $x = 0;
            foreach($rows as $row){
                $mantenimientos[$x] = $row;
                $mantenimientos[$x]['num_archivos'] = $this->_getNumArchivos($row['id']);
                $x++;
            }
            $data[$i]['mantenimientos'] = $mantenimientos;
            $i++;
        }
        return  $data;
    }
    
    public function getRowsByEquipoId($equipo_id, $estado)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nem' => 'naves_equipos_mantenimientos'), array(
                    'id', 'creacion', 'creador', 'equipo_id', 'tipo_id', 'fecha', 
                    'detalles', 'observaciones', 'servicio_id', 'horometro', 'estado'))
               ->join(array('mt' => 'mantenimientos_tipos'), 'nem.tipo_id=mt.id', array('tipo' => 'nombre')) 
               ->join(array('s' => 'base_servicios'), 'nem.servicio_id=s.id', array('servicio' => 'nombre'))   
               ->where("nem.equipo_id=?", $equipo_id)
               ->where("nem.estado='$estado'")
               ->order("nem.fecha DESC");
        $rows = $adapter->fetchAll($select);
        $mantenimientos = array();
        $i = 0;
        foreach($rows as $row){
            $mantenimientos[$i] = $row;
            $mantenimientos[$i]['num_archivos'] = $this->_getNumArchivos($row['id']);
            $i++;
        }
        return $mantenimientos;
    }
    
    public function getRowsByEquipoIdAndTipoId($equipo_id, $tipo_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nem' => 'naves_equipos_mantenimientos'), array(
                    'id', 'equipo_id', 'tipo_id', 'fecha', 'detalles', 'observaciones'))
               ->join(array('mt' => 'mantenimientos_tipos'), 'nem.tipo_id=mt.id', array('tipo' => 'nombre')) 
               ->where("nem.equipo_id=?", $equipo_id)
               ->where("nem.tipo_id='$tipo_id'")
               ->order("nem.fecha DESC");
        return $adapter->fetchAll($select);
    }

    public function guardar($data, $user)
    {
        try {
            $data['informado_por'] = 'NAVE';
            $data['creador'] = $user;
            if($data['servicio_id'] != 59){
                $servicio = new Shipcode_Model_BaseServicio();
                $servicio->setId($data['servicio_id']);
                $data['detalles'] = $servicio->getRow()->nombre;
            }
            if($data['horometro'] === '') { $data['horometro'] = NULL; }
            if(isset($data['id']) && $this->_validarId($data['id']) == TRUE ){
                $row = $this->editarBorrador($data, $user);
            } else {
                $row = $this->crear($data, $user);
            }
        } catch (Exception $ex) {
            return $ex;
        }
    }
    
    public function crear($data, $user, $asociarProyecto = 'NO')
    {
        try {
            $data['creador'] = $user;
            if($data['observaciones'] == '') { $data['observaciones'] = NULL; }
            if($data['horometro'] == '') { $data['horometro'] = NULL; }
            $data['proyecto_requerido'] = $asociarProyecto;
            $row = $this->createRow();
            $row->setFromArray($data);
            $row->save();
            $dataMantenimiento = $row->toArray();
            $dataMantenimiento['tipo'] = $this->_getTipoMantenimiento($dataMantenimiento['tipo_id']);
            $dataMantenimiento['id'] = $row->id;
            return $dataMantenimiento;
        } catch (Exception $ex) {
            return $ex;
        }
    }
    
    public function editarBorrador($data, $user)
    {
        $id = $data['id'];
        unset($data['id']);
        $data['creador'] = $user;
        if($data['observaciones']=='') { $data['observaciones'] = NULL; }
        if($data['horometro']=='') { $data['horometro'] = NULL; }
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        $dataMantenimiento = $row->toArray();
        $dataMantenimiento['tipo'] = $this->_getTipoMantenimiento($dataMantenimiento['tipo_id']);
        return $dataMantenimiento;
    }
    
    private function _getUbicacionEquipo($equipo_id)
    {
        $equipo = new Shipcode_Model_NaveEquipo();
        return $equipo->getUbicacion($equipo_id);
    }
    
    public function editar($data, $user)
    {
        $id = $data['id'];
        
        $row = $this->find($id)->current();
        $dataSinEditar = $row->toArray();
        
        unset($data['id']);
        unset($data['detalles']);
        $data['creador'] = $user;
        if($data['mantenimiento_informado_id'] == '') { $data['mantenimiento_informado_id'] = NULL; }
        if($data['observaciones'] == '') { $data['observaciones'] = NULL; }
        if($data['horometro'] == '') { $data['horometro'] = NULL; }
        
        $row->setFromArray($data);
        $row->save();
        
        // Verifico que el equipo este asignado en una nave y no en una 
        // ubicación virtual, para ver las reprogramaciones correspondientes.
        $ubicacionEquipo = $this->_getUbicacionEquipo($row->equipo_id);
        if($ubicacionEquipo['sistema_id'] !== NULL){
            $ultimoMantenimiento = $this->getUltimoServicio($dataSinEditar['servicio_id'], $dataSinEditar['equipo_id']);

            if($ultimoMantenimiento['id'] == $row->id){
                if($dataSinEditar['fecha'] != $data['fecha'] || $dataSinEditar['horometro'] != $data['horometro']){
                    $modelEvento = new Shipcode_Model_NaveActividad();
                    $dataEvento = $modelEvento->getEventoByData($dataSinEditar['servicio_id'], $dataSinEditar['equipo_id']);
                    $modelEvento->resetearProgramacionEvento($dataEvento['id'], $user);
                }
            }
        }
    }
    
    public function eliminarBorrador()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        try {
            return $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function eliminar($user)
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        try {
            
            $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
            $dataParaEliminar = $this->getRow()->toArray();
            $ultimoMantenimiento = $this->getUltimoServicio($dataParaEliminar['servicio_id'], $dataParaEliminar['equipo_id']);
            
            $ubicacionEquipo = $this->_getUbicacionEquipo($dataParaEliminar['equipo_id']);
            
            $this->delete($where);
            
            if($ubicacionEquipo['sistema_id'] !== NULL){
                $modelEvento = new Shipcode_Model_NaveActividad();
                if($ultimoMantenimiento['id'] == $dataParaEliminar['id']){
                    $modelEvento->eliminarUltimoByData($dataParaEliminar);
                    $modelEvento->resetearEventosAncladosEnEvento($dataParaEliminar['id'], $user);
                    $modelEvento->reabrirUltimoEvento($dataParaEliminar, $user);
                } else {
                    $modelEvento->guardarDataEventoEliminado($dataParaEliminar, $user);
                }
            }
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function buscar($data, $privilegiosNaves = NULL)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('nem' => 'naves_equipos_mantenimientos'), 
                    array(
                        'id', 'creacion', 'creador', 'equipo_id', 'tipo_id', 'fecha', 
                        'detalles', 'observaciones', 'servicio_id', 'horometro', 'estado'
                        ))
               ->join(array('mt' => 'mantenimientos_tipos'), 'nem.tipo_id=mt.id', array('tipo' => 'nombre'))  
               ->join(array('ne' => 'naves_equipos'), 'nem.equipo_id=ne.id', array('equipo' => 'nombre')) 
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->join(array('ns' => 'naves_sistemas'), 'neu.sistema_id=ns.id', array('sistema' => 'nombre')) 
               ->join(array('n' => 'naves'), 'ns.nave_id=n.id', array('nave' => 'nombre'))  
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'))
               ->joinLeft(array('s' => 'base_servicios'), 'nem.servicio_id=s.id', array('servicio' => 'nombre'))  
               ->where("nem.estado='1'");
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        if($data['nave']!='') {
            $select->where("ns.nave_id=?", $data['nave']);
        } elseif($privilegiosNaves !== NULL) {
            $navesIds = Shipcode_Model_SistemaUsuario::filtrarNavesAutorizadas($privilegiosNaves);
            $select->where("ns.nave_id IN($navesIds)");
        }
        if($data['sistema']!='') {
            $select->where("ns.id=?", $data['sistema']);
        }
        if($data['equipo']!='') {
            $select->where("nem.equipo_id=?", $data['equipo']);
        }
        if($data['tipo']!='') {
            $select->where("nem.tipo_id=?", $data['tipo']);
        }
        if($data['servicio']!='') {
            $select->where("nem.servicio_id=?", $data['servicio']);
        }
        if($data['requiere_proyecto']!='') {
            $select->where("nem.proyecto_requerido=?", $data['requiere_proyecto']);
        }
        if($data['estado_proyecto']!='') {
            $plazoVencimiento = Shipcode_Model_SistemaPreferencia::getPref('DIAS_CIERRE_PROYECTO');
            if($data['estado_proyecto'] === 'SI'){
                $select->where("nem.proyecto_id IS NOT NULL");
            }
            if($data['tiene_proyecto'] === 'NO'){
                $select->where("nem.proyecto_id IS NULL");
                $select->where("now() <= DATE_ADD(m.fecha, INTERVAL " . $plazoVencimiento . " DAY)");
            }
            if($data['tiene_proyecto'] === 'VENCIDO'){
                $select->where("nem.proyecto_id IS NULL");
                $select->where("now() > DATE_ADD(m.fecha, INTERVAL " . $plazoVencimiento . " DAY)");
            }
        }
        if($data['desde']) {
            $select->where("nem.fecha > ?", $data['desde']);
        }
        if($data['hasta']) {
            $select->where("nem.fecha < ?", $data['hasta']);
        }
        $select->order("nem.fecha DESC");
        $rows = $adapter->fetchAll($select);
        if(count($rows) > 0){
            return $rows;
        }
        return NULL;
    }
    
    public function getHtmlToPdf($rows)
    {
        $content = '<h1>Informe Mantenimiento Realizados</h1>'
                 . '<p class="text-muted">Realizado el ' . Shipcode_Model_Fecha::format(date("Y-m-d")) . ', a las ' . date("H:i") . '</p>'
                 . '<hr>'
                 . '<p>Se encontraron ' . count($rows) . ' resultados</p>'
                 . '<table border="1" cellpadding="4"><thead><tr>'
                 . '<th>Empresa</th>'
                 . '<th>Nave</th>'
                 . '<th>Equipo</th>'
                 . '<th>Tipo</th>'
                 . '<th>Fecha</th>'
                 . '<th>Horómetro</th>'
                 . '<th>Detalles</th>'
                 . '<th>Observaciones</th>'
                 . '</tr></thead><tbody>';
        
        if(count($rows) > 0) {
            foreach($rows as $mantenimiento) { 
                
                $content .= '<tr><td class="border-right">' . $mantenimiento['empresa'] . '</td>'
                          . '<td>' . $mantenimiento['nave'] . '</td>'
                          . '<td>' . $mantenimiento['equipo'] . '</td>'
                          . '<td>' . $mantenimiento['tipo'] . '</td>'
                          . '<td>' . Shipcode_Model_Fecha::format($mantenimiento['fecha']) . '</td>'
                          . '<td>' . $mantenimiento['horometro'] . '</td>'
                          . '<td>' . $mantenimiento['detalles'] . '</td>'
                          . '<td>' . $mantenimiento['observaciones'] . '</td>'
                          . '</tr>';
                
            } 
        } else {
            $content .= '<tr><td colspan="8">No se encontraron registros coincidentes para su búsqueda.</td></tr>';
        }
        
        $content .= '</table></div></tbody></html>';
        
        return $content;
    }
    
    private function _getNumArchivos($id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT COUNT(*) FROM naves_equipos_mantenimientos_archivos WHERE mantenimiento_id='$id'";
        $result = $adapter->fetchOne($sql);
        if($result > 0) {
            return $result;
        }
        return 0;
    }
    
    private function _getTipoMantenimiento($tipo_id)
    {
        $tipoMantenimiento = new Shipcode_Model_TipoMantenimiento();
        $tipoMantenimiento->setId($tipo_id);
        return $tipoMantenimiento->getRow()->nombre;
    }
    
    public function getHistorialByEquipoIdToExport($equipo_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nem' => 'naves_equipos_mantenimientos'), array(
                    'id', 'tipo_id', 'fecha', 'detalles', 'observaciones', 
                    'servicio_id', 'horometro'
               ))
               ->join(array('mt' => 'mantenimientos_tipos'), 'nem.tipo_id=mt.id', array('tipo' => 'nombre')) 
               ->joinLeft(array('s' => 'base_servicios'), 'nem.servicio_id=s.id', array('servicio' => 'nombre'))   
               ->where("nem.equipo_id=?", $equipo_id)
               ->where("nem.estado='1'")
               ->order("nem.fecha DESC");
        $rows = $adapter->fetchAll($select);
        $mantenimientos = array();
        $x = 0;
        foreach($rows as $row){
            $mantenimientos[$x]['ID'] = $row['id'];
            $mantenimientos[$x]['Tipo'] = $row['tipo'];
            $mantenimientos[$x]['Fecha'] = $row['fecha'];
            $mantenimientos[$x]['Servicio'] = $row['servicio'];
            $mantenimientos[$x]['Detalles'] = $row['detalles'];
            $mantenimientos[$x]['Observaciones'] = $row['observaciones'];
            $mantenimientos[$x]['Horómetro'] = $row['horometro'];
            $mantenimientos[$x]['Archivos'] = $this->_getArchivosToExport($row['id']);
            $x++;
        }
        return $mantenimientos;
    }
    
    private function _getArchivosToExport()
    {
        $archivo = new Shipcode_Model_NaveEquipoMantenimientoArchivo();
        return $archivo->getRowsByEquipoMantenimientoIdToExport($this->_id);
    }
    
    /*
    private function _reabrirMantenimientosInformadosAsociados($mantenimiento_informado_id)
    {
        $mantenimientoInformado = new Shipcode_Model_MantenimientoInformado();
        return $mantenimientoInformado->reabrir($mantenimiento_informado_id);
    }
    public function descartarReportesByEquipoId($equipo_id)
    {
        try {
            $where = $this->getAdapter()->quoteInto("estado='0' AND informado_por='ADMIN' AND equipo_id=?", $equipo_id);
            $rowsToDelete = $this->fetchAll($where);
            if(count($rowsToDelete) > 0){
                foreach($rowsToDelete as $rowToDelete){
                    if($rowToDelete->mantenimiento_informado_id !== NULL){
                        $this->_reabrirMantenimientosInformadosAsociados($$rowToDelete->mantenimiento_informado_id);
                    }
                }
            }
            return $this->delete($where);
        } catch (Exception $ex) {
            return $ex;
        }
    }
    private function _hayMantenimientosAsociados($mantenimiento_informado_id)
    {
        $where = $this->getAdapter()->quoteInto("mantenimiento_informado_id=?", $mantenimiento_informado_id);
        $mantenimientosInformeAsociados = $this->fetchAll($where);
        if(count($mantenimientosInformeAsociados) > 0) {
            return TRUE;
        }
        return FALSE;
    }
    public function getRowsByMantenimientoInformadoId($mantenimiento_informado_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nem' => 'naves_equipos_mantenimientos'), array(
                    'id', 'creacion', 'creador', 'equipo_id', 'tipo_id', 'fecha', 'mantenimiento_informado_id',
                    'detalles', 'observaciones', 'servicio_id', 'horometro', 'estado'))
               ->join(array('ne' => 'naves_equipos'), 'nem.equipo_id=ne.id', array('equipo' => 'nombre'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->join(array('ns' => 'naves_sistemas'), 'neu.sistema_id=ns.id', array('sistema' => 'nombre')) 
               ->join(array('n' => 'naves'), 'ns.nave_id=n.id', array('nave' => 'nombre'))  
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
               ->join(array('mt' => 'mantenimientos_tipos'), 'nem.tipo_id=mt.id', array('tipo' => 'nombre')) 
               ->joinLeft(array('s' => 'base_servicios'), 'nem.servicio_id=s.id', array('servicio' => 'nombre'))   
               ->where("nem.mantenimiento_informado_id=?", $mantenimiento_informado_id);
        return $adapter->fetchAll($select);
    }
    public function getRowsByMantenimientoInformeId($mantenimiento_informe_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('nem' => 'naves_equipos_mantenimientos'), array(
                    'id', 'creacion', 'creador', 'equipo_id', 'tipo_id', 'fecha', 
                    'detalles', 'observaciones', 'servicio_id', 'horometro', 'estado'))
               ->join(array('ne' => 'naves_equipos'), 'nem.equipo_id=ne.id', array('equipo' => 'nombre'))
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array()) 
               ->join(array('ns' => 'naves_sistemas'), 'neu.sistema_id=ns.id', array('sistema' => 'nombre')) 
               ->join(array('n' => 'naves'), 'ns.nave_id=n.id', array('nave' => 'nombre'))  
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
               ->join(array('mt' => 'mantenimientos_tipos'), 'nem.tipo_id=mt.id', array('tipo' => 'nombre')) 
               ->joinLeft(array('s' => 'base_servicios'), 'nem.servicio_id=s.id', array('servicio' => 'nombre'))   
               ->where("nem.mantenimiento_informe_id=?", $mantenimiento_informe_id);
        return $adapter->fetchAll($select);
    }*/
}