<?php
class Shipcode_Model_NaveHorometroLectura extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_horometros_lecturas';
    protected $_primary = 'id';
    
    private $_id;
    
    private function _validarId($id)
    {
        $optionsLectura = array('table' => $this->_name, 'field' => $this->_primary);
        $validadorLectura = new Zend_Validate_Db_RecordExists($optionsLectura);
        
        if($validadorLectura->isValid($id)){
            return TRUE;
        }
        return FALSE;
    }
    
    public function validarSiguiente($id)
    {
        if($this->_validarId($id) == FALSE){
            throw new Exception('El ID de la lectura siguiente para validar no es válido.');
        }
        
        $data = array('error' => false, 'id' => $id);
        
        $lectura1 = $this->getRow();
        $lectura2 = $this->find($id)->current();
        
        $fechaLectura2 = new Zend_Date($lectura2->fecha);
        $fechaLectura1 = new Zend_Date($lectura1->fecha);
        
        $diasDeDiferencia = $fechaLectura2->sub($fechaLectura1)->toValue();
        if($diasDeDiferencia > 0){
            $diasDeDiferencia = $diasDeDiferencia / 60 / 60 / 24;
        }
        
        if($lectura2->lectura < $lectura1->lectura){
            $data['error'] = true;
            $data['mensajes'][] = "La lectura es menor a la anterior.";
        }
        
        if($lectura2->lectura > ($lectura1->lectura + ($diasDeDiferencia * 24))){
            $data['error'] = true;
            $data['mensajes'][] = "La lectura tiene registradas más horas de las posibles.";
        }
        
        return $data;
    }
    
    public function aprobarLecturasPendientesByNaveId($nave_id)
    {
        /*
        $where = $this->getAdapter()->quoteInto("informe_id=?", $informe_id);
        $data = array("estado" => 1);
        $this->update($data, $where);*/
    }
    
    public function setId($id)
    {
        if($this->_validarId($id) == FALSE){
            throw new Exception('El ID de la lectura del horómetro no existe - NaveHorometroLectura::setId');   
        }
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getEquipo()
    {
        $equipo = new Shipcode_Model_NaveEquipo();
        $equipo->setId($this->getEquipoId());
        return $equipo;
    }
    
    public function getReferidos()
    {
        $where = $this->getAdapter()->quoteInto("ref_id=?", $this->_id);
        $referidos = $this->fetchAll($where);
        if($referidos){
            return $referidos->toArray();
        }
        return FALSE;
    }
    
    public function getLecturasReferidasByEquipoId($equipo_id)
    {
        $where = $this->getAdapter()->quoteInto("ref_id IS NOT NULL AND equipo_id=?", $equipo_id);
        return $this->fetchAll($where);
    }
    
    public function getEquipoId()
    {
        return $this->getRow()->equipo_id;
    }
    
    public function desbloquearRegistrosDependientes($equipo_id)
    {
        $data = array("ref_id" => NULL);
        $where = "ref_id='$equipo_id'";
        $this->update($data, $where);
    }
    
    public function desbloquearRegistros($equipo_id)
    {
        $data = array("ref_id" => NULL);
        $where = "equipo_id='$equipo_id' AND ref_id IS NOT NULL";
        $this->update($data, $where);
    }
    
    public function crear($data, $user)
    {
        if($this->_checkExists($data) == FALSE){
            $data['creador'] = $user;
            $row = $this->createRow();
            $row->setFromArray($data);
            $row->save();
            return $row->id;
        }
        return  0;
    }
    
    public function editar($data, $id, $user)
    {
        $row = $this->find($id)->current();
        if($this->_checkExists($row->toArray(), $id) == FALSE){
            $data['creador'] = $user;
            $row->setFromArray($data);
            $row->save();
            return $row->id;
        }
        return  0;    
    }
    
    public function guardar($data)
    {
        $row = $this->_getByData($data);
        if($row === FALSE){
            $row = $this->createRow();
        } 
        $row->setFromArray($data);
        $row->save();
    }
    
    private function _getByData($data)
    {   
        $where = "equipo_id ='" . $data['equipo_id'] .  "' AND fecha='".$data['fecha']."'";
        $row = $this->fetchRow($where);
        if($row){
            return $row;
        }
        return FALSE;
    }
    
    private function _checkExists($data, $id = NULL)
    {   
        if($id == NULL) {
            $where = "equipo_id ='" . $data['equipo_id'] . "' AND lectura= '" . $data['lectura'] .  "' AND fecha='" . $data['fecha'] . "'";
        } else {
            $where = "id!='$id' AND equipo_id ='" . $data['equipo_id'] . "' AND lectura= '" . $data['lectura'] .  "' AND fecha='" . $data['fecha'] . "'";
        }
        $row = $this->fetchRow($where);
        if(!$row){
            return FALSE;
        }
        return TRUE;
    }
    
    public function validarUltimaLectura($valor, $equipo_id, $fecha_lectura)
    {
        $errores = NULL;
        $equipo = new Shipcode_Model_NaveEquipo();
        $equipo->setId($equipo_id);
        
        // obtengo el último valor registrado
        $ultimaLectura = $equipo->getUltimaLecturaHorometro();
            
        /*
        $fechaUltimaLectura = new Zend_Date($fecha_lectura);
        $fechaAnteriorLectura = new Zend_Date($ultimaLectura['fecha']);
        $diferenciaFechas = $fechaUltimaLectura->sub($fechaAnteriorLectura)->toValue();
        $maximoHoras  = floor(($diferenciaFechas / 60) / 60);
        $maximoLectura = $ultimaLectura['lectura'] + $maximoHoras;
        */
        
        $fechaHoy = new Zend_Date();
        $fechaUltimaLectura = new Zend_Date($fecha_lectura);
        $fechaAnteriorLectura = new Zend_Date($ultimaLectura['fecha']);
        $diferenciaFechas = $fechaHoy->sub($fechaAnteriorLectura)->toValue();
        $maximoHoras  = floor(($diferenciaFechas / 60) / 60);
        $maximoLectura = $ultimaLectura['lectura'] + $maximoHoras;
        
        // consulto si la fecha es anterior a la última lectura ingresada
        // de ser anterior, registro el error
        if($fechaUltimaLectura->isEarlier($fechaAnteriorLectura)){
            $errores[] = "La fecha ingresada es anterior a la última lectura ingresada previamente. "
                       . "La fecha debe ser mayor a " . Shipcode_Model_Fecha::formatShort($fechaAnteriorLectura->toString());
        }
        
        // consulto si la fecha es anterior a la igual lectura ingresada
        // de ser igual, registro el error
        if($fechaUltimaLectura->equals($fechaAnteriorLectura)){
            $errores[] = "La fecha ingresada es igual a la última lectura ingresada previamente. "
                       . "La fecha debe ser mayor a " . Shipcode_Model_Fecha::formatShort($fechaAnteriorLectura->toString());
        }
        
        // consulto si el valor indicado es menor aa la última lectura
        // de ser menor registro el error
        if($valor < $ultimaLectura['lectura']){
            $errores[] = "El valor ingresado es inferior al último ingresado previamente. "
                       . "El valor debe ser mayor a " . Shipcode_Model_Numero::formatDecimal($ultimaLectura['lectura']);
        }
        
        // consulto si el valor indicado es mayor al máximo posible
        // de ser mayor registro el error
        if($valor > $maximoLectura){
            $errores[] = "El valor ingresado es superior al máximo aceptado. "
                       . "El valor debe ser menor a " . Shipcode_Model_Numero::formatDecimal($maximoLectura);
        }
        
        // si no hay errores, retorno TRUE
        // de haberlos, retorno un array con los errores
        if($errores === NULL){
            return TRUE;
        }
        return $errores;
    }
    
    public function getUltimaLectura($equipo_id, $estado = 1)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT id, equipo_id, fecha, lectura, DATEDIFF(NOW(), fecha) AS dias_ultima_lectura FROM $this->_name "
             . "WHERE equipo_id='$equipo_id'";
        if($estado == 1){
            $sql .= " AND estado='1'";
        }
        $sql .= " ORDER BY fecha DESC LIMIT 1";
        return $adapter->fetchRow($sql, NULL, Zend_Db::FETCH_ASSOC);
    }
    
    public function getPrimeraLectura($equipo_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT id, equipo_id, fecha, lectura FROM $this->_name "
             . "WHERE equipo_id='$equipo_id' AND estado='1' "
             . "ORDER BY fecha LIMIT 1";
        return $adapter->fetchRow($sql, NULL, Zend_Db::FETCH_ASSOC);
    }
    
    public function getPrimeraLecturaAnclada($equipo_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT id, fecha, lectura FROM $this->_name "
             . "WHERE equipo_id='$equipo_id' AND estado='1' AND ref_id IS NOT NULL "
             . "ORDER BY fecha LIMIT 1";
        return $adapter->fetchRow($sql, NULL, Zend_Db::FETCH_ASSOC);
    }
    
    public function getLecturaDependiente($equipo_id, $ref_id)
    {
        $where = "ref_id='$ref_id' AND equipo_id='$equipo_id'";
        return $this->fetchRow($where);
    }
    
    public function getLecturasDependientes($lectura_id, $equipoMaestro)
    {
        $dataLecturas = array();
        $adapter = $this->getAdapter();
        $sql = "SELECT id, equipo_id, fecha, lectura, DATEDIFF(NOW(), fecha) AS dias_ultima_lectura "
             . "FROM $this->_name "
             . "WHERE ref_id='$lectura_id'";
        $lecturas = $adapter->fetchAll($sql, NULL, Zend_Db::FETCH_ASSOC);
        
        if(count($lecturas) > 0) {
            foreach($lecturas as $lectura){
                $rowLectura = $lectura;
                $rowLectura['fecha_formateada'] = Shipcode_Model_Fecha::formatShort($lectura['fecha']);
                $rowLectura['lectura_formateada'] = Shipcode_Model_Numero::formatDecimal($lectura['lectura']);
                $rowLectura['dependiente'] = true;
                $rowLectura['equipo_maestro'] = $equipoMaestro;
                $dataLecturas[] = $rowLectura;
            }
        }
        return $dataLecturas;
    }
    
    public function getIdSiguienteById($id)
    {
        //registro recién ingresado
        $data = $this->find($id)->current();
        $fecha = $data->fecha;
        $lectura = $data->lectura;
        $equipo_id = $data->equipo_id;
        
        $adapter = $this->getAdapter();
        $sql = "SELECT id FROM $this->_name WHERE estado='1' "
             . "AND equipo_id='$equipo_id' "
             . "AND fecha >= '$fecha' AND lectura > '$lectura' "
             . "ORDER BY fecha, lectura LIMIT 1";
        return $adapter->fetchOne($sql);
    }
    
    public function getAnteriorById($id)
    {
        $data = $this->find($id)->current();
        $fecha = $data->fecha;
        $lectura = $data->lectura;
        $equipo_id = $data->equipo_id;
        
        $adapter = $this->getAdapter();
        $sql = "SELECT * FROM $this->_name WHERE estado='1' "
             . "AND equipo_id='$equipo_id' "
             . "AND fecha <= '$fecha' AND lectura <= '$lectura' " 
             . "AND id != '$id' "   
             . "ORDER BY fecha DESC, lectura DESC LIMIT 1";
        return $adapter->fetchRow($sql, array(), Zend_Db::FETCH_ASSOC);
    }
    
    public function getLecturasPorEquipoId($equipo_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT id, equipo_id, fecha, lectura, ref_id FROM $this->_name "
             . "WHERE equipo_id='$equipo_id' AND estado='1' "
             . "ORDER BY fecha DESC";
        return $adapter->fetchAll($sql);
    }
    
    public function getAllByEquipoId($equipo_id)
    {
        $where = $this->getAdapter()->quoteInto("equipo_id=? AND estado='1'", $equipo_id);
        $order = "id DESC";
        $lecturas = $this->fetchAll($where, $order);
        if($lecturas){
            return $lecturas->toArray();
        }
        return NULL;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - NaveHorometroLectura::eliminar()");
        }
        $adapter = $this->getAdapter();
        $where = $adapter->quoteInto("id=?", $this->_id);
        try {
            return $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function eliminarHistorial($equipo_id = NULL)
    {
        if(NULL == $equipo_id) {
            throw new Exception("No se ha configurado el ID del equipo");
        }
        $where = $this->getAdapter()->quoteInto("equipo_id=?", $equipo_id);
        
        try {
            $this->delete($where);
            
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getInfoParaCalculo($dataEquipo)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sqlPrimerRegistro = "SELECT fecha, lectura FROM $this->_name "
                           . "WHERE equipo_id='" . $dataEquipo['id'] . "' AND estado='1' ORDER BY fecha LIMIT 1";
        $sqlUltimoRegistro = "SELECT fecha, lectura FROM $this->_name "
                           . "WHERE equipo_id='" . $dataEquipo['id'] . "' AND estado='1' ORDER BY fecha DESC LIMIT 1";
            
        $registroInicial = $adapter->fetchRow($sqlPrimerRegistro);
        $registroFinal = $adapter->fetchRow($sqlUltimoRegistro);

        if($dataEquipo['promedio_usado'] == 'A') {
            if($dataEquipo['promedio_asignado'] == NULL || $dataEquipo['promedio_asignado'] == 0 ) {
                return NULL;
            } else {
                $promedioDiarioHoras = floor($dataEquipo['promedio_asignado'] / 30);
            }
        } else {
            if($dataEquipo['promedio_calculado'] == NULL || $dataEquipo['promedio_calculado'] == 0 ) {
                return NULL;
            } else {
                $promedioDiarioHoras = floor($dataEquipo['promedio_calculado'] / 30);
            }
        }

        $data = array(
            'primera_lectura' => $registroInicial['lectura'],
            'ultima_lectura' => $registroFinal['lectura'],
            'promedio_diario_horas' => $promedioDiarioHoras
        );
        return $data;
    }
    
    public function getTodasLasLecturasPorEquipoId($equipo_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT id, lectura FROM $this->_name "
             . "WHERE equipo_id='$equipo_id'  AND estado='1' ORDER BY id";
        return $adapter->fetchAll($sql);
    }
    
    public function getNumLecturasByEquipoId($equipo_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT COUNT(*) AS numLecturas FROM $this->_name WHERE equipo_id='$equipo_id'  AND estado='1'";
        return $adapter->fetchOne($sql);
    }
    
    public function buscar($data, $privilegiosNaves = NULL)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('nrh' => $this->_name), 
                    array('id', 'creacion', 'equipo_id', 'fecha', 'lectura', 'ref_id'))
               ->join(array('ne' => 'naves_equipos'), 'nrh.equipo_id=ne.id', array('equipo' => 'nombre')) 
               ->join(array('neu' => 'naves_equipos_ubicaciones'), 'ne.ubicacion_id=neu.id', array())  
               ->join(array('ns' => 'naves_sistemas'), 'neu.sistema_id=ns.id', array('sistema' => 'nombre')) 
               ->join(array('n' => 'naves'), 'ns.nave_id=n.id', array('nave' => 'nombre'))  
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'));
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        if($data['nave']!='') {
            $select->where("ns.nave_id=?", $data['nave']);
        } elseif($privilegiosNaves !== NULL) {
            $navesIds = Shipcode_Model_SistemaUsuario::filtrarNavesAutorizadas($privilegiosNaves);
            $select->where("ns.nave_id IN($navesIds)");
        }
        if($data['sistema']!='') {
            $select->where("ns.id=?", $data['sistema']);
        }
        if($data['equipo']!='') {
            $select->where("nrh.equipo_id=?", $data['equipo']);
        }
        if($data['desde']) {
            $select->where("nrh.fecha >= ?", $data['desde']);
        }
        if($data['hasta']) {
            $select->where("nrh.fecha <= ?", $data['hasta']);
        }
        $select->order("nrh.fecha DESC");
        $select->order("nrh.equipo_id");
        $rows = $adapter->fetchAll($select);
        if(count($rows) > 0){
            return $rows;
        }
        return NULL;
    }
    
    public function getHtmlToPdf($rows)
    {
        $content = '<h1>Informe Registro Horómetros</h1>'
                 . '<p class="text-muted">Realizado el ' . Shipcode_Model_Fecha::format(date("Y-m-d")) . ', a las ' . date("H:i") . '</p>'
                 . '<hr>'
                 . '<p>Se encontraron ' . count($rows) . ' resultados</p>'
                 . '<table border="1" cellpadding="4"><thead><tr>'
                 . '<th>Empresa</th>'
                 . '<th>Nave</th>'
                 . '<th>Equipo</th>'
                 . '<th>Fecha</th>'
                 . '<th>Horas registradas</th>'
                 . '</tr></thead><tbody>';
        
        if(count($rows) > 0) {
            foreach($rows as $registro) { 
                
                $content .= '<tr><td class="border-right">' . $registro['empresa'] . '</td>'
                          . '<td>' . $registro['nave'] . '</td>'
                          . '<td>' . $registro['equipo'] . '</td>'
                          . '<td>' . Shipcode_Model_Fecha::format($registro['fecha']) . '</td>'
                          . '<td>' . $registro['lectura'] . '</td>'
                          . '</tr>';
                
            } 
        } else {
            $content .= '<tr><td colspan="5">No se encontraron registros coincidentes para su búsqueda.</td></tr>';
        }
        
        $content .= '</table></div></tbody></html>';
        
        return $content;
    }
}