<?php
class Shipcode_Model_NaveObservacion extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_observaciones';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = $id;
    }
    
    public function getCountPendientes($empresa_id = NULL)
    {
        $adapter = $this->getAdapter();
        
        if($empresa_id != NULL) {
            $sql = "SELECT COUNT(*) FROM naves_observaciones_items i "
                 . "JOIN naves_observaciones o ON i.observacion_id=o.id "
                 . "JOIN naves n ON o.nave_id=n.id "   
                 . "WHERE n.empresa_id = '$empresa_id' AND estado='0' ";
        } else {
            $sql = "SELECT COUNT(*) FROM naves_observaciones_items AS no "
                 . "WHERE estado='0' ";
        }
        
        $num = $adapter->fetchOne($sql);
        if($num){
            return $num;
        } 
        return 0;
    }
    
    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('o' => 'naves_observaciones'), array(
                        'id', 'creacion', 'creador', 'nave_id', 'boleta', 
                        'fecha_emision', 'inspector_tc', 'inspector_nv_man', 
                        'inspector_mq_cn'
                    ))
               ->join(array('n' => 'naves'), 'n.id=o.nave_id', array('nave' => 'nombre', 'empresa_id')) 
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre')) 
               ->where("o.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getItemsToUpload()
    {
        $item = new Shipcode_Model_NaveObservacionItem();
        return $item->getRowsByObservacionIdToUpload($this->_id);
    }
    
    public function getNaveId()
    {
        return $this->getRow()->nave_id;
    }
    
    public function getRowsByNaveId($nave_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('no' => 'naves_observaciones'), array(
                        'id', 'creacion', 'creador', 'nave_id', 'boleta', 
                        'inspector_tc', 'inspector_nv_man', 'inspector_mq_cn', 
                        'fecha_emision'
                    ))
               ->join(array('n' => 'naves'), 'n.id=no.nave_id', array('nave' => 'nombre')) 
               ->where("no.nave_id=?", $nave_id)
               ->order("no.id DESC");
        $rows = $adapter->fetchAll($select);
        
        if(count($rows) > 0 ) {
            $observaciones = array();
            $i = 0;
            foreach($rows as $row) {
                $observaciones[$i] = $row;
                $observaciones[$i]['num_archivos'] = $this->_getNumArchivos($row['id']);
                $observaciones[$i]['items_tc'] = $this->_getItems($row['id'], "TC");
                $observaciones[$i]['items_nv_man'] = $this->_getItems($row['id'], "NV/MAN");
                $observaciones[$i]['items_mq_cn'] = $this->_getItems($row['id'], "MQ/CN");
                $i++;
            }
            
            return $observaciones;
        } 
        return NULL;
    }
    
    public function getNave()
    {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getRow()->nave_id);
        return $modelNave->getRowFull();
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        if($data['boleta_aprob'] == '' ) { $data['boleta_aprob'] = NULL; }
        if($data['inspector_tc'] == '' ) { $data['inspector_tc'] = NULL; }
        if($data['inspector_nv_man'] == '' ) { $data['inspector_nv_man'] = NULL; }
        if($data['inspector_mq_cn'] == '' ) { $data['inspector_mq_cn'] = NULL; }
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editar($data, $user, $id)
    {
        $data['creador'] = $user;
        unset($data['id']);
        if($data['boleta_aprob'] == '' ) { $data['boleta_aprob'] = NULL; }
        if($data['inspector_tc'] == '' ) { $data['inspector_tc'] = NULL; }
        if($data['inspector_nv_man'] == '' ) { $data['inspector_nv_man'] = NULL; }
        if($data['inspector_mq_cn'] == '' ) { $data['inspector_mq_cn'] = NULL; }
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function buscar($data, $privilegiosNaves = NULL)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('i' => 'naves_observaciones_items'), 
                    array(
                        'id', 'item', 'codigo', 'detalle', 'estado', 'area',
                        'boleta_aprob', 'argumentacion', 
                    ))
               ->join(array('o' => 'naves_observaciones'), 'i.observacion_id=o.id', array(
                   'nave_id', 'boleta', 'fecha_emision', 'inspector_tc', 
                   'inspector_nv_man', 'inspector_mq_cn'
               )) 
               ->join(array('n' => 'naves'), 'n.id=o.nave_id', array('nave' => 'nombre')) 
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'));
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        if($data['nave']!='') {
            $select->where("o.nave_id=?", $data['nave']);
        } elseif($privilegiosNaves !== NULL) {
            $navesIds = Shipcode_Model_SistemaUsuario::filtrarNavesAutorizadas($privilegiosNaves);
            $select->where("o.nave_id IN($navesIds)");
        }
        if($data['codigo']!='') {
            $select->where("i.codigo=?", $data['codigo']);
        }
        if($data['area']!='') {
            $select->where("i.area=?", $data['area']);
        }
        if($data['estado'] == 0){
            $select->where("i.estado='0'");
        }
        if($data['estado'] == 1){
            $select->where("i.estado='1'");
        }
        if($data['estado'] == 2){
            $select->where("i.estado='2'");
        }
        if($data['estado'] == 3){
            $select->where("i.estado='3'");
        }
        if($data['desde']) {
            $select->where("o.fecha_emision > ?", $data['desde']);
        }
        if($data['hasta']) {
            $select->where("o.fecha_emision < ?", $data['hasta']);
        }
        
        $rows = $adapter->fetchAll($select);
        if(count($rows) > 0){
            return $rows;
        }
        return NULL;
    }
    
    public function getHtmlToPdf($rows)
    {
        $content = '<h1>Informe Observaciones</h1>'
                 . '<p class="text-muted">Realizado el ' . Shipcode_Model_Fecha::format(date("Y-m-d")) . ', a las ' . date("H:i") . '</p>'
                 . '<hr>'
                 . '<p>Se encontraron ' . count($rows) . ' resultados</p>'
                 . '<table border="1" cellpadding="4"><thead><tr>'
                 . '<th>Empresa</th>'
                 . '<th>Nave</th>'
                 . '<th>Nº Boleta / Ítem</th>'
                 . '<th>Código</th>'
                 . '<th>Área</th>'
                 . '<th>Detalles Observación</th>'
                 . '<th>Emisión</th>'
                 . '<th>Estado</th>'
                 . '<th>Boleta Lev.</th>'
                 . '</tr></thead><tbody>';
        
        if(count($rows) > 0) {
            foreach($rows as $observacion) { 
                
                $content .= '<tr><td class="border-right">' . $observacion['empresa'] . '</td>'
                          . '<td>' . $observacion['nave'] . '</td>'
                          . '<td>' . $observacion['boleta'] . ' / ' . $observacion['item'] . '</td>'
                          . '<td>' . $observacion['codigo'] . '</td>'
                          . '<td>' . $observacion['area'] . '</td>'
                          . '<td>' . $observacion['detalle'] . '</td>'
                          . '<td>' . Shipcode_Model_Fecha::format($observacion['fecha_emision']) . '</td>';
                
                if($observacion['estado'] == 0 ) { 
                    $content .= '<td>PENDIENTE</td>';    
                } elseif($observacion['estado'] == 2) { 
                    $content .= '<td>CORREGIDA SIN INSPECCIÓN</td>';
                } else { 
                    $content .= '<td>LEVANTADA</td>';
                }
                
                $content .= '<td>' . $observacion['boleta_aprob'] . '</td>'
                          . '</tr>';
                
            } 
        } else {
            $content .= '<tr><td colspan="8">No se encontraron registros coincidentes para su búsqueda.</td></tr>';
        }
        
        $content .= '</tbody></table></div></html>';
        
        return $content;
    }
    
    /****************** FUNCIONES RELACIONADAS A LOS ITEMS ********************/
    private function _getItems($id, $area)
    {
        $item = new Shipcode_Model_NaveObservacionItem();
        return $item->getRowsByObservacionId($id, $area);
    }
    
    public function agregarItem($data)
    {
        $item = new Shipcode_Model_NaveObservacionItem();
        return $item->crear($data);
    }


    /**************** FUNCIONES RELACIONADAS A LOS ARCHIVOS *******************/
    public static function getNumArchivos($id, $subcarpeta = FALSE)
    {
        return self::_getNumArchivos($id, $subcarpeta);
    }
    
    public function getArchivos()
    {
        $archivo = new Shipcode_Model_NaveObservacionArchivo();
        return $archivo->getRowsByObservacionId($this->_id);
    }
    
    public function guardarArchivo($data, $user)
    {
        $archivo = new Shipcode_Model_NaveObservacionArchivo();
        return $archivo->crear($data, $user);
    }
    
    public function editarArchivo($data, $user)
    {
        $archivo = new Shipcode_Model_NaveObservacionArchivo();
        return $archivo->editar($data, $user);
    }
    
    private function _getNumArchivos($id, $subcarpeta = FALSE)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT COUNT(*) FROM naves_observaciones_archivos WHERE observacion_id='$id'";
        if($subcarpeta !== FALSE){
            if($subcarpeta == 0){
                $sql .= " AND carpeta IS NULL";
            } else {
                $sql .= " AND carpeta ='$subcarpeta'";
            }
            
        }
        $result = $adapter->fetchOne($sql);
        if($result > 0) {
            return $result;
        }
        return 0;
    } 
    
    // Separa los ítems de las observaciones para agruparlos por Nº de boleta.
    // Una vez aplicado, hay que eliminar los campos sobrantes de la tabla naves_observaciones
    public function transformData()
    {
        $dataGuardados = array();
        $adapter = $this->getAdapter();
        try {
            $adapter->beginTransaction();
            $sql = "SELECT * FROM naves_observaciones GROUP BY boleta";
            $rows = $adapter->fetchAll($sql);
            foreach($rows as $row){
                $sqlItems = "SELECT * FROM naves_observaciones WHERE boleta='". $row['boleta'] ."'";
                $rowsItems = $adapter->fetchAll($sqlItems);
                $boletaItem = new Shipcode_Model_NaveObservacionItem();
                foreach($rowsItems as $rowItem){
                    $data['observacion_id'] = $row['id'];
                    $data['item'] = $rowItem['item'];
                    $data['codigo'] = $rowItem['codigo'];
                    $data['area'] = $rowItem['area'];
                    $data['detalle'] = $rowItem['detalle'];
                    $data['estado'] = $rowItem['estado'];
                    $data['boleta_aprob'] = $rowItem['boleta_aprob'];
                    $data['argumentacion'] = $rowItem['argumentacion'];
                    $boletaItem->crear($data);
                }
                $dataGuardados[] = $row['id'];
            }
            $whereDelete = "id NOT IN(SELECT DISTINCT(i.observacion_id) FROM naves_observaciones_items i)";
            $this->delete($whereDelete);
            $adapter->commit();
            return "Traspaso exitoso";
        } catch (Exception $ex) {
            $adapter->rollback();
            return $ex->getMessage();
        }
    }
    
    public function getRowsByNaveIdToExport($nave_id, $archivos = 0)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('no' => 'naves_observaciones'), array(
                        'id', 'boleta', 'inspector_tc', 'inspector_nv_man', 
                        'inspector_mq_cn', 'fecha_emision'
                    ))
               ->join(array('n' => 'naves'), 'n.id=no.nave_id', array('nave' => 'nombre')) 
               ->where("no.nave_id=?", $nave_id)
               ->order("no.id DESC");
        $rows = $adapter->fetchAll($select);
        $observaciones = array();
        if(count($rows) > 0 ) {
            $i = 0;
            foreach($rows as $row) {
                $observaciones[$i]['ID'] = $row['id'];
                $observaciones[$i]['Boleta'] = $row['boleta'];
                $observaciones[$i]['Fecha emisión'] = $row['fecha_emision'];
                $observaciones[$i]['Inspector - Telecomunicaciones'] = $row['inspector_tc'];
                $observaciones[$i]['Inspector - Navegación y Maniobras'] = $row['inspector_nv_man'];
                $observaciones[$i]['Inspector - Máquinas y Contrucción Naval'] = $row['inspector_mq_cn'];
                $observaciones[$i]['Ítems - Telecomunicaciones'] = $this->_getItemsToExport($row['id'], "TC");
                $observaciones[$i]['Ítems - Navegación y Maniobras'] = $this->_getItemsToExport($row['id'], "NV/MAN");
                $observaciones[$i]['Ítems- Máquinas y Construcción Naval'] = $this->_getItemsToExport($row['id'], "MQ/CN");
                if($archivos == 1){
                    $observaciones[$i]['Archivos'] = $this->getArchivosToExport();
                }
                $i++;
            }
        } 
        return $observaciones;
    }
    
    private function _getItemsToExport($id, $area)
    {
        $item = new Shipcode_Model_NaveObservacionItem();
        return $item->getRowsByObservacionIdToExport($id, $area);
    }
    
    public function getArchivosToExport()
    {
        $archivo = new Shipcode_Model_NaveObservacionArchivo();
        return $archivo->getRowsByObservacionIdToExport($this->_id);
    }
}