<?php
class Shipcode_Model_NaveObservacionArchivo extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_observaciones_archivos';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }

    public function getAll()
    {
        return $this->fetchAll();
    }
    
    public function setFileNotFound($archivoId)
    {
        $row = $this->find($archivoId)->current();
        $row->nombre = $row->nombre . " (NO ENCONTRADO)";
        $row->save();
    }
    
    public function getRowsByObservacionId($observacion_id)
    {
        $where = $this->getAdapter()->quoteInto("observacion_id=?", $observacion_id);
        $rows = $this->fetchAll($where);
        if($rows){
            return $rows->toArray();
        }
        return FALSE;
    }
    
    public function getRowsByObservacionIdAndItem($observacion_id, $item)
    {
        $where = "observacion_id=" . $this->getAdapter()->quote($observacion_id) 
               . " AND carpeta=" . $this->getAdapter()->quote($item);
        $rows = $this->fetchAll($where);
        if($rows){
            return $rows->toArray();
        }
        return FALSE;
    }
    
    public function getRowsByObservacionIdToExport($observacion_id)
    {
        $dataArchivos = array();
        $rows = $this->getRowsByObservacionId($observacion_id);
        if(count($rows) > 0){
            foreach ($rows as $row){
                $dataArchivo['Nombre'] = $row->nombre;
                $dataArchivo['Archivo'] = $row->archivo;
                $dataArchivos[] = $dataArchivo;
            }
        }
        return $dataArchivos;
    }
    
    public function crear($data, $user)
    {
        if(Shipcode_Archivo::guardar($data['archivo'], 'observaciones/')){
            $data['creador'] = $user;
            $row = $this->createRow();
            $row->setFromArray($data);
            return $row->save();
        } else {
            throw new Exception('No fue posible guardar el archivo en el directorio indicado. La operación fue cancelada.');
        }
            
    }    
    
    public function editar($data, $user)
    {
        $row = $this->find($data['id'])->current();
        $row->creador = $user;
        $row->nombre = $data['nombre'];
        return $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - NaveObservacionArchivo::eliminar()");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        $data = $this->getRow()->toArray();
        
        try {
            
            if(Shipcode_Archivo::borrar($data['archivo'], 'observaciones/')){
                $this->delete($where);
                return $data['observacion_id'];
            } else {
                return FALSE;
            }
            
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
}