<?php
class Shipcode_Model_NaveObservacionItem extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_observaciones_items';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }

    public function getObservacion()
    {
        $observacion = new Shipcode_Model_NaveObservacion();
        $observacion->setId($this->getRow()->observacion_id);
        return $observacion->getRowFull();
    }
    
    public function getRowsByObservacionId($observacion_id, $area)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('i' => 'naves_observaciones_items'), array('*'))
               ->join(array('c' => 'codigos_observaciones'), 'c.codigo=i.codigo', array('comentarios', 'plazo')) 
               ->where("i.observacion_id=?", $observacion_id)
               ->where("i.area=?", $area)
               ->order("i.item ASC");
        $rows = $adapter->fetchAll($select);
        if($rows){
            return $rows;
        }
        return FALSE;
    }
    
    public function getRowsByObservacionIdToUpload($observacion_id)
    {
        $dataItems = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('i' => 'naves_observaciones_items'), array('id', 'item'))
               ->where("i.observacion_id=?", $observacion_id)
               ->order("i.item ASC");
        $rows = $adapter->fetchAll($select);
        if($rows && count($rows) > 0){
            foreach($rows as $row){
                $dataItem = $row;
                $dataItem['archivos'] = $this->_getArchivos($observacion_id, $row['id']);
                $dataItems[] = $dataItem;
            }
            return $dataItems;
        }
        return FALSE;
    }
    
    private function _getArchivos($observacion_id, $item)
    {
        $archivo = new Shipcode_Model_NaveObservacionArchivo();
        return $archivo->getRowsByObservacionIdAndItem($observacion_id, $item);
    }
    
    public function crear($data)
    {
        $row = $this->createRow();
        $row->setFromArray($data);
        $result = $row->save();
        if($result){
            $this->_crearCarpeta($data['observacion_id'], $result);
        }
        return $result;
    }    
    
    public function editar($data)
    {
        $row = $this->find($data['id'])->current();
        unset($data['id']);
        $row->setFromArray($data);
        return $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - NaveObservacionItem::eliminar()");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        $data = $this->getRow()->toArray();
        
        try {
            $this->delete($where);
            return $data['observacion_id'];
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getRowsByObservacionIdToExport($observacion_id, $area)
    {
        $items = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('i' => 'naves_observaciones_items'), array(
                    'item', 'codigo', 'detalle', 'estado', 
                    'boleta_aprob', 'argumentacion'
               ))
               ->where("i.observacion_id=?", $observacion_id)
               ->where("i.area=?", $area)
               ->order("i.item ASC");
        $rows = $adapter->fetchAll($select);
        if(count($rows) > 0){
            foreach($rows as $row){
                $item['Ítem'] = $row['item'];
                $item['Código'] = $row['codigo'];
                $item['Detalle'] = $row['detalle'];
                $item['Estado'] = $row['estado'];
                $item['Boleta aprobación'] = $row['boleta_aprob'];
                $item['Argumentación'] = $row['argumentacion'];
                $items[] = $item;
            }
        }
        return $items;
    }
    
    private function _crearCarpeta($observacion_id, $item_id)
    {
        $path =  'files/naves/observaciones/' . $observacion_id . "/" . $item_id;
        if(!is_dir(Zend_Registry::get('PATH_SERVER') . $path)){
            mkdir(Zend_Registry::get('PATH_SERVER') . $path, 0777, true);
        }
    }
}