<?php
class Shipcode_Model_NaveSiniestro extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_siniestros';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getNaveId()
    {
        return $this->getRow()->nave_id;
    }
    
    public function getRowsByNaveId($nave_id)
    {
        $where = $this->getAdapter()->quoteInto("nave_id=?", $nave_id);
        $rows = $this->fetchAll($where, 'fecha DESC')->toArray();
        
        $siniestros = array();
        $i = 0;
        foreach($rows as $row) {
            $siniestros[$i] = $row;
            $siniestros[$i]['num_archivos'] = $this->_getNumArchivos($row['id']);
            $i++;
        }
        return $siniestros;
    }
    
    public static function getNumArchivos($id)
    {
        return self::_getNumArchivos($id);
    }
    
    private function _getNumArchivos($id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT COUNT(*) FROM naves_siniestros_archivos WHERE siniestro_id='$id'";
        $result = $adapter->fetchOne($sql);
        if($result > 0) {
            return $result;
        }
        return 0;
    }
    
    public function getNave()
    {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getRow()->nave_id);
        return $modelNave->getRowFull();
    }
    
    public function getArchivos()
    {
        $archivo = new Shipcode_Model_NaveSiniestroArchivo();
        return $archivo->getRowsBySiniestroId($this->_id);
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        $row = $this->createRow();
        $row->setFromArray($data);
        return $row->save();
    }
    
    public function editar($data, $user, $id)
    {
        $data['creador'] = $user;
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function guardarArchivo($data, $user)
    {
        $archivo = new Shipcode_Model_NaveSiniestroArchivo();
        return $archivo->crear($data, $user);
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function buscar($data)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(
                    array('s' => 'naves_siniestros'), 
                    array(
                        'id', 'creacion', 'creador', 'nave_id', 'numero', 
                        'fecha', 'detalle', 'valor', 'estado'
                    ))
               ->join(array('n' => 'naves'), 'n.id=s.nave_id', array('nave' => 'nombre')) 
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'));
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        
        if($data['nave']!='') {
            $select->where("s.nave_id=?", $data['nave']);
        }
        
        if($data['desde']) {
            $select->where("s.fecha > ?", $data['desde']);
        }
        
        if($data['hasta']) {
            $select->where("s.fecha < ?", $data['hasta']);
        }
        
        if($data['estado'] == 1 ){
            $select->where("s.estado = 'EN TRAMITE'");
        }
        
        if($data['estado'] == 2 ){
            $select->where("s.estado = 'DESPACHADO'");
        }
        if($data['estado'] == 3 ){
            $select->where("s.estado = 'LIQUIDADO'");
        }
        if($data['estado'] == 4 ){
            $select->where("s.estado = 'DESISTIDO'");
        }
        
        $rows = $adapter->fetchAll($select);
        
        if(count($rows) > 0){
            return $rows;
        }
        return NULL;
    }
    
    public function getHtmlToPdf($rows)
    {
        $content = '<h1>Informe Siniestros</h1>'
                 . '<p class="text-muted">Realizado el ' . Shipcode_Model_Fecha::format(date("Y-m-d")) . ', a las ' . date("H:i") . '</p>'
                 . '<hr>'
                 . '<p>Se encontraron ' . count($rows) . ' resultados</p>'
                 . '<table border="1" cellpadding="4"><thead><tr>'
                 . '<th>Empresa</th>'
                 . '<th>Nave</th>'
                 . '<th>Nº</th>'
                 . '<th>Fecha</th>'
                 . '<th>Detalle</th>'
                 . '<th>Monto reclamado</th>'
                 . '<th>Estado</th>'
                 . '</tr></thead><tbody>';
        
        if(count($rows) > 0) {
            foreach($rows as $siniestro) { 
                
                $content .= '<tr>'
                          . '<td class="border-right">' . $siniestro['empresa'] . '</td>'
                          . '<td>' . $siniestro['nave'] . '</td>'
                          . '<td>' . $siniestro['numero'] . '</td>'
                          . '<td>' . Shipcode_Model_Fecha::format($siniestro['fecha']) . '</td>'
                          . '<td>' . nl2br($siniestro['detalle']) . '</td>'
                          . '<td>' . $siniestro['valor'] . '</td>'
                          . '<td>' . $siniestro['estado'] . '</td>'
                          . '</tr>';
            } 
        } else {
            $content .= '<tr><td colspan="8">No se encontraron registros coincidentes para su búsqueda.</td></tr>';
        }
        
        $content .= '</table></div></tbody></html>';
        
        return $content;
    }
    
    public function getRowsByNaveIdToExport($nave_id, $archivos = 0)
    {
        $where = $this->getAdapter()->quoteInto("nave_id=?", $nave_id);
        $rows = $this->fetchAll($where, 'fecha DESC')->toArray();
        
        $siniestros = array();
        $i = 0;
        foreach($rows as $row) {
            $siniestros[$i]['ID'] = $row['id'];
            $siniestros[$i]['Número'] = $row['numero'];
            $siniestros[$i]['Fecha'] = $row['fecha'];
            $siniestros[$i]['Detalle'] = $row['detalle'];
            $siniestros[$i]['Valor'] = $row['valor'];
            $siniestros[$i]['Estado'] = $row['estado'];
            if($archivos == 1){
                $siniestros[$i]['Archivos'] = $this->_getArchivosToExport($row['id']);
            }
            $i++;
        }
        return $siniestros;
    }
    
    private function _getArchivosToExport($siniestro_id)
    {
        $archivo = new Shipcode_Model_NaveSiniestroArchivo();
        return $archivo->getRowsBySiniestroIdToExport($siniestro_id);
    }
}