<?php
class Shipcode_Model_NaveSistema extends Zend_Db_Table_Abstract
{
    protected $_name = 'naves_sistemas';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getNaveId()
    {
        return $this->getRow()->nave_id;
    }
    
    public function getRowsByNaveId($nave_id, $plan = FALSE)
    {
        $sistemas = array();
        
        $where = $this->getAdapter()->quoteInto("nave_id=? AND padre_id IS NULL", $nave_id);
        $principales =  $this->fetchAll($where, "id")->toArray();
        
        foreach($principales as $principal){
            $sistemas[$principal['id']] = $principal;
            $sistemas[$principal['id']]['subsistemas'] = $this->_getSubSistemas($principal['id']);
            $sistemas[$principal['id']]['equipos'] = $this->_getEquipos($principal['id'], $plan);
        }
        return $sistemas;
    }
    
    public function getRowsConPlanByNaveId($nave_id)
    {
        $sistemas = array();
        
        $where = $this->getAdapter()->quoteInto("nave_id=? AND padre_id IS NULL", $nave_id);
        $principales =  $this->fetchAll($where, "id")->toArray();
        
        foreach($principales as $principal){
            $sistemas[$principal['id']] = $principal;
            $sistemas[$principal['id']]['subsistemas'] = $this->_getSubSistemasConPlan($principal['id']);
            $sistemas[$principal['id']]['equipos'] = $this->_getEquiposConPlan($principal['id']);
        }
        return $sistemas;
    }
    
    public function getRowsConHorometroByNaveId($nave_id)
    {
        $sistemas = array();
        
        $where = $this->getAdapter()->quoteInto("nave_id=? AND padre_id IS NULL", $nave_id);
        $principales =  $this->fetchAll($where, "id")->toArray();
        
        foreach($principales as $principal){
            $horometros = $this->_getEquiposConHorometro($principal['id']);
            if(count($horometros) > 0) {
                $sistemas[$principal['id']] = $principal;
                $sistemas[$principal['id']]['horometros'] = $horometros;
            }
        }
        return $sistemas;
    }
    
    /**
     * Busca los otros equipos del sistema que poseen un registro de horómetro activado.
     * 
     * @return array $otrosEquiposConHorometro
     */
    public function getOtrosEquiposConHorometro($sistema_id, $equipo_id)
    {
        $equipo = new Shipcode_Model_NaveEquipo();
        $equipos = $equipo->getRowsConHorometroBySistemaId($sistema_id);
        $i = 0;
        foreach($equipos as $eq){
            if($eq['id'] == $equipo_id){
                unset($equipos[$i]);
            } else {
                $equipos[$i]['dependencias'] = $equipo->checkHorometrosDependientes($eq['id']);
            }
            $i++;
        }
        return $equipos;
    }
    
    public function getPadresToSelectByNaveId($nave_id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT id, nombre FROM naves_sistemas WHERE nave_id='$nave_id' AND padre_id IS NULL ORDER BY id";
        return $adapter->fetchPairs($sql);
    }
    
    public function getPairsToSelectByNaveId($nave_id, $type = NULL)
    {
        $data = array();
        
        $adapter = self::getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        
        $sqlPadres = "SELECT ns.id, ns.nombre FROM naves_sistemas AS ns "
                   . "WHERE ns.nave_id='$nave_id' AND ns.padre_id IS NULL "
                   . "ORDER BY ns.id";
        $padres = $adapter->fetchAll($sqlPadres);
        
        if($type == 'JSON'){
            
            foreach($padres as $padre){
                $filas = array();
                $subsistemas = $this->_getSubSistemas($padre['id']);
                foreach($subsistemas as $subsistema){
                      $filas[] = array('id' => $subsistema['id'], 'nombre' => $subsistema['nombre']);
                }
                $grupo['nombre'] = $padre['nombre'];
                $grupo['filas'] = $filas;
                $data[] = $grupo;
            }
            
        } else {
            
            foreach($padres as $padre){
                $subsistemas = $this->_getSubSistemas($padre['id']);
                $data[$padre['nombre']] = array();
                foreach($subsistemas as $subsistema){
                      $data[$padre['nombre']][$subsistema['id']] = $subsistema['nombre'];
                }
            }
            
        }
        return $data;
    }
    
    public function getRowsToSelectByNaveId($nave_id)
    {
        $data = array();
        
        $adapter = self::getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        
        $sqlPadres = "SELECT ns.id, ns.nombre FROM naves_sistemas AS ns "
                   . "WHERE ns.nave_id='$nave_id' AND ns.padre_id IS NULL "
                   . "ORDER BY ns.id";
        $padres = $adapter->fetchAll($sqlPadres);
        
        foreach($padres as $padre){
            $row['id'] = $padre['id'];
            $row['nombre'] = $padre['nombre'];
            $data[] = $row;
            $subsistemas = $this->_getSubSistemas($padre['id']);
            foreach($subsistemas as $subsistema){
                $row['id'] = $subsistema['id'];
                $row['nombre'] = $padre['nombre'] . " > " . $subsistema['nombre'];
                $data[] = $row;
            }
        }
        return $data;
    }
    
    public function getRowsConHorometroToSelectByNaveId($nave_id)
    {
        $adapter = self::getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT ns.id, ns.nombre, COUNT(ne.id) AS num_equipos "
             . "FROM naves_equipos AS ne "
             . "JOIN naves_equipos_ubicaciones AS neu ON ne.ubicacion_id=neu.id "   
             . "JOIN naves_sistemas AS ns ON neu.sistema_id=ns.id "
             . "WHERE ne.horometro='1' "     
             . "AND ns.nave_id='$nave_id' "
             . "GROUP BY neu.sistema_id " 
             . "ORDER BY ns.id";
        return $adapter->fetchAll($sql);
    }
    
    public function getSistemasToClone($id)
    {
        $where = "nave_id='" . $id . "' AND padre_id IS NULL";
        return $this->fetchAll($where)->toArray();
    }
    
    public function getSubSistemasToClone($id)
    {
        $where = "padre_id='" . $id . "'";
        return $this->fetchAll($where)->toArray();
    }
    
    public function clonar($sistema, $nave_nueva_id, $user, $clonarEquipos, $padre_id = NULL)
    {
        $nuevoSistema = array(
            'nave_id'   => $nave_nueva_id,
            'padre_id'  => $padre_id,
            'nombre'    => $sistema['nombre']
        );
        
        $id = $this->crear($nuevoSistema, $user);
        
        if($clonarEquipos == 1){
            $this->_clonarEquipos($sistema['id'], $id, $user);
        }
        return $id;
    }
    
    public function clonarSubsistema($values, $user)
    {
        $dataOrigen = $this->find($values['osistema_id'])->current();
        $dataPadre = $this->find($values['sistema_padre_id'])->current();
        $dataNuevo = array(
            'nave_id' => $dataPadre->nave_id,
            'padre_id' => $dataPadre->id,
            'nombre' => $dataOrigen->nombre
        );
        
        $nuevoId = $this->crear($dataNuevo, $user);
        $this->_clonarEquipos($dataOrigen->id, $nuevoId, $user);
        return $dataNuevo['nave_id'];
    }
    
    private function _clonarEquipos($sistema_origen_id, $sistema_nuevo_id, $user)
    {
        $modelUbicacion    = new Shipcode_Model_NaveEquipo();
        $equipos = $modelUbicacion->getEquiposToCloneBySistemaId($sistema_origen_id);
        
        $modelEquipo = new Shipcode_Model_NaveEquipo();
        
        if(count($equipos) > 0 ) {
            foreach($equipos as $equipo){
                $modelEquipo->setId($equipo['id']);
                $data = array(
                    'sistema_id' => $sistema_nuevo_id, 
                    'oequipo_id' => $equipo['id'],
                    'partes' => 1
                );
                $modelEquipo->clonar($data, $user);
            }
        }
    }
    
    private function _getEquipos($sistema_id, $plan = FALSE)
    {
        $equipo = new Shipcode_Model_NaveEquipo();
        return $equipo->getRowsBySistemaId($sistema_id, $plan);
    }

    private function _getEquiposConPlan($sistema_id)
    {
        $equipo = new Shipcode_Model_NaveEquipo();
        return $equipo->getRowsConPlanBySistemaId($sistema_id);
    }
    
    private function _getEquiposConHorometro($sistema_padre_id)
    {
        $equipo = new Shipcode_Model_NaveEquipo();
        return $equipo->getRowsConHorometroBySistemaPadreId($sistema_padre_id);
    }
    
    private function _getSubSistemas($padre_id, $plan = FALSE)
    {
        $data = array();
        
        $where = $this->getAdapter()->quoteInto("padre_id=?", $padre_id);
        $subSistemas = $this->fetchAll($where)->toArray();
        
        foreach($subSistemas as $subSistema){
            $data[$subSistema['id']] = $subSistema;
            $data[$subSistema['id']]['equipos'] = $this->_getEquipos($subSistema['id'], $plan);
        }
        return $data;
    }
    
    private function _getSubSistemasConPlan($padre_id)
    {
        $data = array();
        
        $where = $this->getAdapter()->quoteInto("padre_id=?", $padre_id);
        $subSistemas = $this->fetchAll($where)->toArray();
        
        foreach($subSistemas as $subSistema){
            $data[$subSistema['id']] = $subSistema;
            $data[$subSistema['id']]['equipos'] = $this->_getEquiposConPlan($subSistema['id']);
        }
        return $data;
    }
    
    public function getNave()
    {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getRow()->nave_id);
        return $modelNave->getRowFull();
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $user, $id)
    {
        $data['creador'] = $user;
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getNombreToUbicacion()
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT CONCAT(n.nombre, ' > ', s.nombre) "
             . "FROM naves_sistemas AS s "
             . "JOIN naves AS n ON s.nave_id=n.id "
             . "WHERE s.id='" . $this->_id . "'";
        return $adapter->fetchOne($sql);
    }

    public function configInicioOperaciones($fecha)
    {
        $this->_configInicioOperacionesEquipos($this->_id, $fecha);
        $this->_configInicioOperacionesSubsistemas($fecha);
    }

    private function _configInicioOperacionesEquipos($sistema_id, $fecha)
    {
        $equipo = new Shipcode_Model_NaveEquipo();
        return $equipo->setInicioOperacionesBySistemaId($sistema_id, $fecha);
    }
   
    private function _configInicioOperacionesSubsistemas($fecha)
    {
        $subsistemas = $this->_getSubsistemasId($this->_id);
        if(count($subsistemas) > 0){
            foreach($subsistemas as $subsistema){
                $this->_configInicioOperacionesEquipos($subsistema['id'], $fecha);
            }
        }
        return TRUE;
    }
    
    private function _getSubsistemasId($padre_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT id FROM naves_sistemas WHERE padre_id='$padre_id'";
        return $adapter->fetchAll($sql);
    }
    
    public static function getPairsToSelect($nave_id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT id, nombre FROM naves_sistemas WHERE nave_id='$nave_id' ORDER BY nombre";
        return $adapter->fetchPairs($sql);
    }
    
    /************************* EXPORTACIÓN DE DATOS ***************************/
    public function getRowsByNaveIdToExport($nave_id, $archivos = 0, $fotografias = 0)
    {
        $dataSistemas = array();
        $where = $this->getAdapter()->quoteInto("nave_id=? AND padre_id IS NULL", $nave_id);
        $principales =  $this->fetchAll($where, "id")->toArray();
        $i = 0;
        foreach($principales as $principal){
            $dataSistemas[$i]['Nombre'] = $principal['nombre'];
            $dataSistemas[$i]['Subsistemas'] = $this->_getSubSistemasToExport($principal['id'], $archivos, $fotografias);
            $dataSistemas[$i]['Equipos'] = $this->_getEquiposToExport($principal['id'], $archivos, $fotografias);
            $i++;
        }
        return $dataSistemas;
    }
    
    private function _getSubSistemasToExport($padre_id, $archivos = 0, $fotografias = 0)
    {
        $dataSubsistemas = array();
        
        $where = $this->getAdapter()->quoteInto("padre_id=?", $padre_id);
        $subSistemas = $this->fetchAll($where)->toArray();
        $i = 0;
        foreach($subSistemas as $subSistema){
            $dataSubsistemas[$i]['Nombre'] = $subSistema['nombre'];
            $dataSubsistemas[$i]['Equipos'] = $this->_getEquiposToExport($subSistema['id'], $archivos, $fotografias);
            $i++;
        }
        return $dataSubsistemas;
    }
    
    private function _getEquiposToExport($sistema_id, $archivos = 0, $fotografias = 0)
    {
        $equipo = new Shipcode_Model_NaveEquipo();
        return $equipo->getRowsBySistemaIdToExport($sistema_id, $archivos, $fotografias);
    }
    
    /*
    // EN PROCESO DE ELIMINACIÓN
    public function getRowsToSelectByNaveId($nave_id)
    {
        $data = array();
        
        $adapter = self::getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        
        $sqlPadres = "SELECT ns.id, ns.nombre FROM naves_sistemas AS ns "
                   . "WHERE ns.nave_id='$nave_id' AND ns.padre_id IS NULL "
                   . "ORDER BY ns.id";
        $padres = $adapter->fetchAll($sqlPadres);
        
        foreach($padres as $padre){
            $row['id'] = $padre['id'];
            $row['nombre'] = $padre['nombre'];
            $data[] = $row;
            $subsistemas = $this->_getSubSistemas($padre['id']);
            foreach($subsistemas as $subsistema){
                $row['id'] = $subsistema['id'];
                $row['nombre'] = $padre['nombre'] . " > " . $subsistema['nombre'];
                $data[] = $row;
            }
        }
        return $data;
    }
    
    public function getRowsToSelectByNaveId2($nave_id)
    {
        $data = array();
        
        $adapter = self::getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        
        $sqlPadres = "SELECT ns.id, ns.nombre "
                   . "FROM naves_sistemas AS ns "
                   . "WHERE ns.nave_id='$nave_id' AND ns.padre_id IS NULL "
                   . "ORDER BY ns.id";
        $padres = $adapter->fetchAll($sqlPadres);
        
        foreach($padres as $padre){
            $row['id'] = $padre['id'];
            $row['nombre'] = $padre['nombre'];
            $data[] = $row;
            $subsistemas = $this->_getSubSistemas($padre['id']);
            foreach($subsistemas as $subsistema){
                $row['id'] = $subsistema['id'];
                $row['nombre'] = $padre['nombre'] . " > " . $subsistema['nombre'];
                $data[] = $row;
            }
        }
        return $data;
    }
    public function getRowsToSelectByNaveId($nave_id)
    {
        $adapter = self::getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $data = array();
        $sql = "SELECT ns.id, ns.nombre, COUNT(ne.id) AS num_equipos "
             . "FROM naves_equipos AS ne "
             . "JOIN naves_equipos_ubicaciones AS neu ON ne.ubicacion_id=neu.id "   
             . "JOIN naves_sistemas AS ns ON neu.sistema_id=ns.id "
             . "WHERE ns.nave_id='$nave_id' "
             . "GROUP BY neu.sistema_id " 
             . "ORDER BY ns.id";
        return $adapter->fetchAll($sql);
    }
    */
}