<?php

class Shipcode_Model_ProgramacionMensual extends Zend_Db_Table_Abstract {

    protected $_name = 'programaciones_mensuales';
    protected $_primary = 'id';
    private $_id;

    private function _validarId($id) {
        $optiosnInforme = array('table' => 'programaciones_mensuales', 'field' => 'id');
        $validadorInforme = new Zend_Validate_Db_RecordExists($optiosnInforme);

        if ($validadorInforme->isValid($id)) {
            return TRUE;
        }
        return FALSE;
    }

    public function setId($id) {
        if ($this->_validarId($id) == FALSE) {
            throw new Exception('El ID de la programación mensual solicitada no existe - ProgramacionMensual::setId()');
        }
        $this->_id = $id;
    }

    public function getRow() {
        return $this->find($this->_id)->current();
    }
    
    public function getIdUltima($nave_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT id FROM programaciones_mensuales WHERE nave_id='$nave_id' ORDER BY id DESC LIMIT 1";
        $result = $adapter->fetchOne($sql);
        if($result){
            return $result;
        }
        return FALSE;
    }
    
    public function getIdProgramacionAbiertaByNaveId($nave_id){
        $adapter = $this->getAdapter();
        $sql = "SELECT id FROM programaciones_mensuales "
             . "WHERE nave_id='$nave_id' "
             . "AND estado='1' "
             . "ORDER BY id DESC "
             . "LIMIT 1";
        $result = $adapter->fetchOne($sql);
        if($result){
            return $result;
        }
        return FALSE;
    }

    public function getEstado() {
        return $this->getRow()->estado;
    }

    public function getRowFull() {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('pm' => 'programaciones_mensuales'), array(
                    'id', 'creacion', 'creador', 'nave_id', 'mes', 'year',
                    'fecha_apertura', 'fecha_envio', 'fecha_cierre', 'estado'))
                ->join(array('u' => 'sistema_usuarios'), 'u.id=pm.creador', array('creado_por' => 'nombre'))
                ->join(array('n' => 'naves'), 'n.id=pm.nave_id', array('nave' => 'nombre', 'empresa_id'))
                ->where('pm.id=?', $this->_id);
        $row = $adapter->fetchRow($select);
        $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
        $row['num_trabajos']                    = $trabajo->getNumTrabajosByProgramacionId($this->_id);
        $row['num_trabajos_nave']               = $trabajo->getNumTrabajosByProgramacionId($this->_id, 1, "NAVE");
        $row['num_trabajos_nave_terminados']    = $trabajo->getNumTrabajosByProgramacionId($this->_id, 1, "NAVE", "TERMINADO");
        $row['num_trabajos_externo']            = $trabajo->getNumTrabajosByProgramacionId($this->_id, 1, "EXTERNO");
        $row['num_trabajos_externo_terminados'] = $trabajo->getNumTrabajosByProgramacionId($this->_id, 1, "EXTERNO", "TERMINADO");
        $row['num_seleccionados']               = $trabajo->getNumTrabajosByProgramacionId($this->_id, 1);
        $row['num_realizados']                  = $trabajo->getNumTrabajosByProgramacionId($this->_id, 1, NULL, "TERMINADO");
        $row['num_pendientes']                  = $trabajo->getNumTrabajosByProgramacionId($this->_id, 1, NULL, "PENDIENTE");
        $row['num_no_realizados']               = $trabajo->getNumTrabajosByProgramacionId($this->_id, 1, NULL, "NO REALIZADO");
        $row['num_postergados']                 = $trabajo->getNumTrabajosByProgramacionId($this->_id, 1, NULL, "POSTERGADO");
        $row['num_rechazados']                  = $trabajo->getNumTrabajosByProgramacionId($this->_id, 1, NULL, "RECHAZADO");
        $row['num_mes_actual']                  = $trabajo->getNumTrabajosByFechaOriginal($this->_id, 0, $row['mes'], $row['year']);
        $row['num_mes_anterior']                = $trabajo->getNumTrabajosByFechaOriginal($this->_id, 30, $row['mes'], $row['year']);
        $row['num_meses_anteriores']            = $trabajo->getNumTrabajosByFechaOriginal($this->_id, 60, $row['mes'], $row['year']); 
        return $row;
    }
    
    public function getTrabajosSeleccionados($estado = NULL, $asignado_a = NULL) {
        $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
        return $trabajo->getRowsByProgramacionMensualId($this->_id, $estado, $asignado_a);
    }
    
    public function getTrabajosRealizadosUltimaSemana()
    {
        $hoy = new Zend_Date(date("Y-m-d"));
        $desde = $hoy->sub(1, Zend_Date::WEEK)->toString("yyyy-MM-dd");
        return $this->_getTrabajosRealizadosByProgramacionId($this->_id, $desde);
    }

    public function getNaveId() {
        return $this->getRow()->nave_id;
    }

    public function getNave() {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getRow()->nave_id);
        return $modelNave->getRowFull();
    }

    public function getPendientes() {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('pm' => 'programaciones_mensuales'), array(
                    'id', 'creacion', 'creador', 'nave_id', 'mes', 'year',
                    'fecha_apertura', 'fecha_envio', 'fecha_cierre', 'estado'))
                ->join(array('u' => 'sistema_usuarios'), 'u.id=pm.creador', array('creado_por' => 'nombre'))
                ->join(array('n' => 'naves'), 'n.id=pm.nave_id', array('nave' => 'nombre'))
                ->where('pm.estado=?', "0")
                ->order('year DESC')
                ->order('mes DESC');
        return $adapter->fetchAll($select);
    }

    public function getAll($estado = NULL, $empresa_id = NULL, $privilegiosNaves = NULL) {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('pm' => 'programaciones_mensuales'), array(
                    'id', 'creacion', 'creador', 'nave_id', 'mes', 'year',
                    'fecha_apertura', 'fecha_envio', 'fecha_cierre', 'estado'))
                ->join(array('u' => 'sistema_usuarios'), 'u.id=pm.creador', array('creado_por' => 'nombre'))
                ->join(array('n' => 'naves'), 'n.id=pm.nave_id', array('nave' => 'nombre'));
        if($estado !== NULL && in_array($estado, array(0,1,2))){
            $select->where("pm.estado=?", $estado); 
        }
        if($empresa_id !== NULL) {
            $select->where("n.empresa_id=?", $empresa_id);
        }
        if($privilegiosNaves !== NULL) {
            $navesIds = Shipcode_Model_SistemaUsuario::filtrarNavesAutorizadas($privilegiosNaves);
            $select->where("pm.nave_id IN($navesIds)");
        }
        $select->order('year DESC')
               ->order('mes DESC');
        return $adapter->fetchAll($select);
    }

    public function buscar(array $data, $empresa_id = NULL,$privilegiosNaves = NULL) {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('pm' => 'programaciones_mensuales'), array(
                    'id', 'creacion', 'creador', 'nave_id', 'mes', 'year',
                    'fecha_apertura', 'fecha_envio', 'fecha_cierre', 'estado'))
                ->join(array('u' => 'sistema_usuarios'), 'u.id=pm.creador', array('creado_por' => 'nombre'))
                ->join(array('n' => 'naves'), 'n.id=pm.nave_id', array('nave' => 'nombre'))
                ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'));

        if ($data['estado'] == 0) {
            $select->where("pm.estado='0'");
        } elseif ($data['estado'] == 1) {
            $select->where("pm.estado ='1'");
        } elseif ($data['estado'] == 2) {
            $select->where("pm.estado ='2'");
        }

        if ($data['empresa'] != 0) {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        
        if ($empresa_id !== NULL) {
            $select->where("n.empresa_id=?", $empresa_id);
        }

        if ($data['nave'] != 0) {
            $select->where("pm.nave_id=?", $data['nave']);
        } elseif($privilegiosNaves !== NULL) {
            $navesIds = Shipcode_Model_SistemaUsuario::filtrarNavesAutorizadas($privilegiosNaves);
            $select->where("pm.nave_id IN($navesIds)");
        }

        $select->order("pm.year DESC");
        $select->order("pm.mes DESC");

        return $adapter->fetchAll($select);
    }

    public function crear($data, $user) {
        
        $adapter = $this->getDefaultAdapter();
        try {
            
            $adapter->beginTransaction();
            
            $data['creador'] = $user;
            $dataMes = explode('-', $data['year_mes']);
            $data['year'] = $dataMes[0];
            $data['mes'] = $dataMes[1];
            $data['fecha_apertura'] = date("Y-m-d");
            $row = $this->createRow();
            $row->setFromArray($data);
            $row->save();
            $id = $row->id;
            
            $this->setId($id);
            $actividades = $this->_getActividadesForConfig();
            $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
            
            $fechaInicioMes = new Zend_Date($data['year'] . "-" . $data['mes'] . "-01");
            
            
            foreach ($actividades as $actividad) {
                
                // Si la fecha original es anterior al primer dia del mes de la programación
                // se deja como fecha programada el día 01 de ese mes, para que aparezca en el calendario.
                $fechaServicio = new Zend_Date($actividad['fecha_editada']);
                if($fechaInicioMes->isLater($fechaServicio)){
                    $actividad['fecha_servicio'] = $data['year'] . "-" . $data['mes'] . "-01";
                } else {
                    $actividad['fecha_servicio'] = $actividad['fecha_editada'];
                }
                $dataTrabajo = array(
                    'programacion_id'   => $this->_id,
                    'actividad_id'      => $actividad['id'],
                    'asignado_a'        => Shipcode_Model_NaveActividad::getAsignacionResponsable($actividad['id']),
                    'fecha_actividad'   => $actividad['fecha_editada'],
                    'fecha_servicio'    => $actividad['fecha_servicio'],
                    'fecha_configurada' => $actividad['fecha_servicio'],
                    'sel'               => 1
                );
                $trabajo->crear($dataTrabajo);
                //Zend_Debug::dump($dataTrabajo);
            }
            $adapter->commit();
            return $id;
            
        } catch (Exception $ex) {
            $adapter->rollBack();
            return $ex->getMessage();
        }
    }
    
    public function enviar() {
        $row = $this->getRow();
        if ($row->estado == 0) {
            $row->estado = 1;
            $row->fecha_envio = date("Y-m-d");
            $row->save();
        }
    }
    
    private function _getTrabajosRealizadosByProgramacionId($programacion_id, $desde = NULL){
        try {
            $adapter = $this->getAdapter();
            $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
            $selTrabajos = $adapter->select();
            $selTrabajos->from(array('t' => 'programaciones_mensuales_trabajos'), array('*'))
                        ->join(array('a' => 'naves_actividades'), 'a.id=t.actividad_id', array('equipo_id', 'servicio_id'))
                        ->join(array('e' => 'naves_equipos'), 'e.id=a.equipo_id', array('equipo' => 'nombre'))
                        ->join(array('s' => 'base_servicios'), 's.id=a.servicio_id', array('servicio' => 'nombre'))
                        ->where('t.programacion_id=?', $programacion_id)
                        ->where('t.estado=?', "TERMINADO");
            if($desde !== NULL){
                $selTrabajos->where("t.fecha_informe >=?", $desde);
            }
            return $adapter->fetchAll($selTrabajos);
        } catch (Exception $ex) {
            return $ex;
        }
    }
    
    public function cerrar($user) {
        $row = $this->getRow();
        if ($row->estado == 1) {
            $adapter = $this->getAdapter();
            try{
                $adapter->beginTransaction();
                $row->estado = 2;
                $row->fecha_cierre = date("Y-m-d");
                $row->save();
                $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
                $trabajo->cerrarNoInformadosByProgramacionId($this->_id);
                $trabajosRealizados = $this->_getTrabajosRealizadosByProgramacionId($this->_id);
                if(count($trabajosRealizados) > 0) {
                    $equipo = new Shipcode_Model_NaveEquipo();
                    foreach($trabajosRealizados as $trabajoRealizado){
                        if($trabajoRealizado['horas_realizacion'] == 0){
                            $horas = NULL;
                        } else {
                            $horas = $trabajoRealizado['horas_realizacion'];
                        }
                        $dataMantenimiento = array(
                            'fecha' => $trabajoRealizado['fecha_realizacion'],
                            'equipo_id' => $trabajoRealizado['equipo_id'],
                            'horometro' => $horas,
                            'servicio_id' => $trabajoRealizado['servicio_id'],
                            'detalles' => $trabajoRealizado['comentarios'],
                            'mantenimiento_informado_id' => NULL
                        );
                        $equipo->registrarMantenimiento($dataMantenimiento, $user, 1);
                    }
                }
                $adapter->commit();
            } catch (Exception $e) {
                $adapter->rollBack();
                return $e->getMessage();
            }
        }
    }
    
    public function reabrir() {
        $row = $this->getRow();
        if ($row->estado == 2) {
            $row->estado = 1;
            $row->fecha_cierre = NULL;
            $row->save();
        }
    }
    
    public function agregarActividades($data) {
        $ids = explode(",", $data);
        if (count($ids) > 0) {
            $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
            foreach ($ids as $id) {
                $trabajo->crear(array(
                    'programacion_id' => $this->_id,
                    'actividad_id' => $id,
                    'asignado_a' => Shipcode_Model_NaveActividad::getAsignacionResponsable($id)
                ));
            }
        }
    }
    
    public function eliminarActividades($data) {
        $ids = explode(",", $data);
        if (count($ids) > 0) {
            $trabajo = new Shipcode_Model_ProgramacionMensualTrabajo();
            foreach ($ids as $id) {
                $trabajo->eliminarByActividadId($id);
            }
        }
    }
    
    public function eliminar() {
        if (NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - ProgramacionMensual::eliminar()");
        }
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    private function _getActividadesForConfig() {
        try {
            $actividad = new Shipcode_Model_NaveActividad();
            return $actividad->getRowsForProgramacionMensual($this->getRow());
        } catch (Exception $ex) {
            return $ex->getMessage();
        }
    }
}
