<?php
class Shipcode_Model_ProgramacionMensualTrabajo extends Zend_Db_Table_Abstract
{
    protected $_name = 'programaciones_mensuales_trabajos';
    protected $_primary = 'id';
    
    private $_id;
    
    private function _validarId($id)
    {
        $optiosnInforme = array('table' => 'programaciones_mensuales_trabajos', 'field' => 'id');
        $validadorInforme = new Zend_Validate_Db_RecordExists($optiosnInforme);
        
        if($validadorInforme->isValid($id)){
            return TRUE;
        }
        return FALSE;
    }
    
    public function setId($id)
    {
        if($this->_validarId($id) == FALSE){
            throw new Exception('El ID del trabajo solicitado no existe - ProgramacionMensualTrabajo::setId()');   
        }
        $this->_id = $id;
    }
    
    public function getRow()
    {
        return $this->find($this->_id)->current();
    }

    public function abrir()
    {
        $row = $this->getRow();
        $row->estado = 'PENDIENTE';
        $row->save();
    }
    
    public function asignar($asignado_a = 'NAVE')
    {
        if(!in_array($asignado_a, array('NAVE', 'EXTERNO'))) {
            $asignado_a = 'NAVE';
        }
        $row = $this->getRow();
        $row->asignado_a = $asignado_a;
        $row->save();
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('t' => 'programaciones_mensuales_trabajos'), array(
                    'id', 'programacion_id', 'actividad_id', 'asignado_a', 
                    'fecha_servicio', 'fecha_configurada', 'fecha_realizacion', 
                    'fecha_informe', 'horas_realizacion', 'comentarios', 'estado',
                    'postergacion_motivo', 'postergacion_comentarios', 
                    'rechazo_comentarios', 'sel'))
               ->join(array('a' => 'naves_actividades'), 'a.id=t.actividad_id', array('equipo_id', 'fecha_original', 'fecha_editada', 'horas', 'codigo', 'programacion')) 
               ->join(array('s' => 'base_servicios'), 'a.servicio_id=s.id', array('servicio' => 'nombre'))  
               ->join(array('e' => 'naves_equipos'), 'a.equipo_id=e.id', array('equipo' => 'nombre', 'modelo')) 
               ->join(array('p' => 'programaciones_mensuales'), 'p.id=t.programacion_id', array('nave_id', 'mes', 'year', 'cierre_fecha')) 
               ->join(array('n' => 'naves'), 'n.id=p.nave_id', array('nave' => 'nombre'))
               ->where('t.id=?', $this->_id);
        return  $adapter->fetchRow($select);
    }
    
    public function getRowsByProgramacionMensualId($programacion_id, $sel = NULL, $asignado_a = NULL)
    {
        $dataEquipos = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $selEquipos = $adapter->select();
        $selEquipos->from(array('t' => 'programaciones_mensuales_trabajos'), array())
                   ->join(array('a' => 'naves_actividades'), 'a.id=t.actividad_id', array('DISTINCT(a.equipo_id)')) 
                   ->join(array('e' => 'naves_equipos'), 'a.equipo_id=e.id', array('equipo' => 'nombre', 'modelo', 'horometro')) 
                   ->join(array('u' => 'naves_equipos_ubicaciones'), 'e.ubicacion_id=u.id', array()) 
                   ->join(array('s' => 'naves_sistemas'), 'u.sistema_id=s.id', array('sistema' => 'nombre')) 
                   ->where('t.programacion_id=?', $programacion_id)
                   ->group("a.equipo_id");
        if($sel !== NULL && in_array($sel, array(0, 1))){
            $selEquipos->where("t.sel='$sel'");
        }
        
        if($asignado_a !== NULL && in_array($asignado_a, array('NAVE', 'EXTERNO'))){
            $selEquipos->where("t.asignado_a='$asignado_a'");
        }
        
        $selEquipos->order("s.id");
        $selEquipos->order("e.orden");
        
        
        
        $rowsEquipos = $adapter->fetchAll($selEquipos);
        
        if(count($rowsEquipos) > 0){
            foreach($rowsEquipos as $rowEquipo){
                
                $dataEquipo = $rowEquipo;
                $selTrabajos = $adapter->select();
                $selTrabajos->from(array('t' => 'programaciones_mensuales_trabajos'), array(
                                'trabajo_id' => 'id', 'programacion_id', 'actividad_id', 'asignado_a', 
                                'fecha_servicio', 'fecha_configurada', 'fecha_realizacion', 'fecha_informe', 
                                'horas_realizacion', 'comentarios', 'estado', 'postergacion_motivo', 
                                'postergacion_comentarios', 'rechazo_comentarios', 'sel'))
                            ->join(array('a' => 'naves_actividades'), 'a.id=t.actividad_id', array('equipo_id', 'fecha_original', 'fecha_editada', 'horas', 'codigo', 'programacion')) 
                            ->join(array('s' => 'base_servicios'), 'a.servicio_id=s.id', array('servicio' => 'nombre'))  
                            ->join(array('e' => 'naves_equipos'), 'a.equipo_id=e.id', array('equipo' => 'nombre', 'modelo')) 
                            ->join(array('p' => 'programaciones_mensuales'), 'p.id=t.programacion_id', array('nave_id', 'mes', 'year', 'fecha_cierre')) 
                            ->join(array('n' => 'naves'), 'n.id=p.nave_id', array('nave' => 'nombre'))
                            ->where('t.programacion_id=?', $programacion_id)
                            ->where('a.equipo_id=?', $rowEquipo['equipo_id']);
                
                if($sel !== NULL && in_array($sel, array(0, 1))){
                    $selTrabajos->where("t.sel='$sel'");
                }
                
                if($asignado_a !== NULL && in_array($asignado_a, array('NAVE', 'EXTERNO'))){
                    $selTrabajos->where("t.asignado_a='$asignado_a'");
                }
                
                $dataEquipo['trabajos'] = $adapter->fetchAll($selTrabajos);
                $dataEquipos[] = $dataEquipo;
            }
        }
        
        return  $dataEquipos;
    }
    
    public function getNumTrabajosByProgramacionId($programacion_id, $sel = NULL, $asignado_a = NULL, $estado = NULL)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT COUNT(*) FROM $this->_name WHERE programacion_id='$programacion_id'";
        if($sel === 1) {
            $sql .= " AND sel='1'";
        }
        if($asignado_a !== NULL && in_array($asignado_a, array('NAVE', 'EXTERNO'))){
            $sql .= " AND asignado_a='$asignado_a'";
        }
        if($estado !== NULL && in_array($estado, array(
            "PENDIENTE", "TERMINADO", "NO REALIZADO", 
            "NO REALIZADO", "RECHAZADO", "POSTERGADO"))){
            $sql .= " AND estado='$estado'";
        }
        $num = $adapter->fetchOne($sql);
        if($num){
            return $num;
        }
        return 0;
    }
    
    public function getNumTrabajosByFechaOriginal($programacion_id, $dias, $mes, $year)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT COUNT(*) FROM $this->_name WHERE programacion_id='$programacion_id'";
        $fecha_inicial = $year . '-' . $mes . '-' . '01';
        if($dias === 0) {
            $sql .= " AND fecha_actividad >='$fecha_inicial' ";
        } elseif($dias === 30){
            $sql .= " AND fecha_actividad >= date_sub('$fecha_inicial', INTERVAL 1 MONTH) AND fecha_actividad < '$fecha_inicial' ";
        } elseif($dias === 60){
            $sql .= " AND fecha_actividad <= date_sub('$fecha_inicial', INTERVAL 2 MONTH)";
        }
        $num = $adapter->fetchOne($sql);
        if($num){
            return $num;
        }
        return 0;
    }
    
    public function crear($data)
    {
        try {
            $row = $this->createRow();
            $row->setFromArray($data);
            $row->save();
            return $row->id;
        } catch (Exception $e){
            return $e->getMessage();
        }
            
    }
    
    public function editarFecha($fecha)
    {
        $row = $this->getRow();
        $row->fecha_configurada = $fecha;
        return $row->save();
    }
    
    public function cerrarNoInformadosByProgramacionId($programacion_id)
    {
        $adapter = $this->getAdapter();
        $data = array("estado" => "NO REALIZADO");
        $where['sel=?'] = "1";
        $where['estado=?'] ='PENDIENTE';
        $where['programacion_id=?'] = $programacion_id;
        $adapter->update($this->_name, $data, $where);
    }
    
    public function cambiarEstadoSeleccion()
    {
        $row = $this->getRow();
        if($row->sel == 0){
            $row->sel = 1;
        } elseif($row->sel == 1){
            $row->sel = 0;
        }
        return $row->save();
    }
    
    public function postergar($data)
    {
        $data['estado'] = "POSTERGADO";
        $row = $this->getRow();
        $row->setFromArray($data);
        $row->save();
        return $data['estado'];
    }
    
    public function rechazar($data)
    {
        $data['estado'] = "RECHAZADO";
        $row = $this->getRow();
        $row->setFromArray($data);
        $row->save();
        return $data['estado'];
    }
    
    public function terminar($data)
    {
        $data['estado'] = "TERMINADO";
        $row = $this->getRow();
        $row->setFromArray($data);
        $row->save();
        return $data['estado'];
    }
 
    public function getProgramacionId()
    {
        return $this->getRow()->programacion_id;
    }
    
    public function getProgramacion()
    {
        $programacion = new Shipcode_Model_ProgramacionMensual();
        $programacion->setId($this->getRow()->programacion_id);
        return $programacion->getRowFull();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - ProgramacionMensualTrabajo::eliminar()");
        }
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function eliminarByActividadId($actividad_id)
    {
        if(!$actividad_id) {
            throw new Exception("No se ha configurado el ID - ProgramacionMensualTrabajo::eliminarByActividadId()");
        }
        $where = $this->getAdapter()->quoteInto("actividad_id=?", $actividad_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
}