<?php

class Shipcode_Model_ProyeccionMantenimiento extends Zend_Db_Table_Abstract {

    protected $_name = 'proyecciones_mantenimientos';
    protected $_primary = 'id';
    private $_id;
    
    public function hacerProyeccion()
    {
        try {
            $dataServicios = array();
            $dataEventos = array();
            $dataGastos = array();
            
            $row = $this->getRow();
            $sistemas = Zend_Json::decode($row->data_config);
            $fechaDesde = new Zend_Date($row->desde);
            $fechaHasta = new Zend_Date($row->hasta);
            
            // 1. Obtener listado de eventos e info de gastos
            foreach($sistemas as $sistema){
                foreach($sistema['subsistemas'] as $subsistema){
                    foreach($subsistema['equipos'] as $equipo){
                        foreach($equipo['servicios'] as $servicio){
                            if($servicio['sel'] == 1){
                                $eventos = $this->_getEventos($fechaDesde, $fechaHasta, $servicio, $equipo, $subsistema, $sistema); 
                                $cantEventos = count($eventos);
                                if($cantEventos > 0 ){
                                    if($servicio['valor_unitario'] !== NULL && $servicio['valor_unitario'] !== 0){
                                        $valorTotal = $servicio['valor_unitario'] * $cantEventos;
                                    } else {
                                        $valorTotal = 0;
                                    }
                                    $rowGasto = array(
                                        'cantidad' => $cantEventos,
                                        'valor_total' => $valorTotal
                                    );
                                    $dataServicios[$servicio['id']] = $eventos;
                                    $dataGastos[$servicio['id']] = $rowGasto;
                                }
                            }
                        } 
                    }
                }
            } 
            
            // 2. Obtener listado de eventos para calendario
            foreach($dataServicios as $servicio){
                foreach($servicio as $evento){
                    $dataEquipo = $evento['equipo_nombre'];
                    if($evento['equipo_marca'] !== NULL && $evento['equipo_marca'] !== ''){
                        $dataEquipo .= " : " . $evento['equipo_marca']; 
                    }
                    if($evento['equipo_modelo'] !== NULL && $evento['equipo_modelo'] !== ''){
                        $dataEquipo .= " : " . $evento['equipo_modelo']; 
                    }
                    $dataEvento = $evento['servicio'];
                    if($evento['horas'] !== NULL && $evento['horas'] !== ''){
                        $dataEvento .= " : programado a las " . $evento['horas'] . " horas"; 
                    }
                    $rowEvento = array(
                        'title' => $evento['equipo_nombre'] . ' : ' . $evento['servicio'],
                        'start' => $evento['fecha'],
                        'equipo' => $dataEquipo,
                        'sistema' => $evento['sistema'] . " > " . $evento['subsistema'],
                        'servicio' => $dataEvento,
                        'id' => $evento['id']
                    );
                    $dataEventos[] = $rowEvento;
                } 
            }
            
            $row->data_servicios = Zend_Json::encode($dataServicios);
            $row->data_eventos = Zend_Json::encode($dataEventos);
            $row->data_gastos = Zend_Json::encode($dataGastos);
            
            if(!$row->save()){
                throw new Exception("ERROR");
            }
            
        } catch (Exception $ex) {
            return $ex;
        }
    }

    public function setDataConfig()
    {
        try {
            $row = $this->getRow();
            $nave = $this->_getNave($row->nave_id);
            $sistemas = $nave->getSistemas(TRUE);
            $dataSistemas = array(); 
            if(count($sistemas) > 0) {
                foreach($sistemas as $sistema){
                    $dataSistema = array();
                    $dataSistema['id'] = $sistema['id'];
                    $dataSistema['nombre'] = $sistema['nombre'];
                    $dataSistema['subsistemas'] = array();
                    // Aplica cuando los equipos están contenidos en subsistemas
                    if(count($sistema['subsistemas']) > 0){
                        foreach($sistema['subsistemas'] as $subsistema){
                            $dataSubSistema = array();
                            $dataSubSistema['id'] = $subsistema['id'];
                            $dataSubSistema['nombre'] = $subsistema['nombre'];
                            if(count($subsistema['equipos']) > 0) {
                                $dataSubSistema['equipos'] = $this->_getEquiposToDataConfig($subsistema['equipos']);
                                if(count($dataSubSistema['equipos']) > 0){
                                    $dataSubSistemas[] = $dataSubSistema;
                                }
                            } 
                        }
                        $dataSistema['subsistemas'] = $dataSubSistemas;
                        $dataSistemas[] = $dataSistema;
                        unset($dataSubSistemas);
                    }
                }
            }
            $row->data_config = Zend_Json::encode($dataSistemas);
            if($row->save()){
                return TRUE; 
            } else {
                throw new Exception("Ocurrió un error al internar guadar la información de configuración de los sistemas.");
            }
        } catch (Exception $ex) {
            return $ex;
        }
    }
    
    public function setServicios($id, $flag)
    {
        $row = $this->getRow();
        $sistemas = Zend_Json::decode($row->data_config);
        for($s = 0; $s < count($sistemas); $s++){
            for($ss = 0; $ss < count($sistemas[$s]['subsistemas']); $ss++){
                for($e = 0; $e < count($sistemas[$s]['subsistemas'][$ss]['equipos']); $e++){
                    for($sv = 0; $sv < count($sistemas[$s]['subsistemas'][$ss]['equipos'][$e]['servicios']); $sv++){
                        if($id == $sistemas[$s]['subsistemas'][$ss]['equipos'][$e]['servicios'][$sv]['id']){
                            $sistemas[$s]['subsistemas'][$ss]['equipos'][$e]['servicios'][$sv]['sel'] = $flag;
                        }
                    }
                }
            }
        }
        $row->data_config = Zend_Json::encode($sistemas);
        $row->save();
    }
    
    public function setValorUnitarioServicio($id, $valor = NULL)
    {
        if($valor !== NULL){
            $row = $this->getRow();
            $sistemas = Zend_Json::decode($row->data_config);
            for($s = 0; $s < count($sistemas); $s++){
                for($ss = 0; $ss < count($sistemas[$s]['subsistemas']); $ss++){
                    for($e = 0; $e < count($sistemas[$s]['subsistemas'][$ss]['equipos']); $e++){
                        for($sv = 0; $sv < count($sistemas[$s]['subsistemas'][$ss]['equipos'][$e]['servicios']); $sv++){
                            if($id == $sistemas[$s]['subsistemas'][$ss]['equipos'][$e]['servicios'][$sv]['id']){
                                $sistemas[$s]['subsistemas'][$ss]['equipos'][$e]['servicios'][$sv]['valor_unitario'] = (int)$valor;
                            }
                        }
                    }
                }
            }
            $row->data_config = Zend_Json::encode($sistemas);
            $row->save();
        }
    }
    
    public function setPromedioEquipo($eid, $promedio = 0)
    {
        $row = $this->getRow();
        $sistemas = Zend_Json::decode($row->data_config);
        for($s = 0; $s < count($sistemas); $s++){
            for($ss = 0; $ss < count($sistemas[$s]['subsistemas']); $ss++){
                for($e = 0; $e < count($sistemas[$s]['subsistemas'][$ss]['equipos']); $e++){
                    if($eid == $sistemas[$s]['subsistemas'][$ss]['equipos'][$e]['id'] ){
                        $sistemas[$s]['subsistemas'][$ss]['equipos'][$e]['promedio_configurado'] = $promedio;
                        $sistemas[$s]['subsistemas'][$ss]['equipos'][$e]['servicios'] = $this->_getServiciosProgramados($sistemas[$s]['subsistemas'][$ss]['equipos'][$e]);
                    }
                }
            }
        }
        $row->data_config = Zend_Json::encode($sistemas);
        $row->save();
    }

    public function setId($id) 
    {
        if ($this->_validarId($id) == FALSE) {
            throw new Exception('El ID de la proyección de mantenimiento solicitada no existe - ProyeccionMantenimiento::setId()');
        }
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getRowFull() 
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('pm' => 'proyecciones_mantenimientos'), array(
                    'id', 'creacion', 'creador', 'nombre', 'nave_id', 
                    'desde', 'hasta', 'data_config', 'data_servicios', 
                    'data_eventos', 'data_gastos'))
                ->join(array('u' => 'sistema_usuarios'), 'u.id=pm.creador', array('creado_por' => 'nombre'))
                ->join(array('n' => 'naves'), 'n.id=pm.nave_id', array('nave' => 'nombre'))
                ->where('pm.id=?', $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getNaveId() 
    {
        return $this->getRow()->nave_id;
    }

    public function getNave() 
    {
        $modelNave = new Shipcode_Model_Nave();
        $modelNave->setId($this->getRow()->nave_id);
        return $modelNave->getRowFull();
    }

    public function getAll($estado = NULL) 
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('pm' => 'proyecciones_mantenimientos'), array(
                    'id', 'creacion', 'creador', 'nombre', 'nave_id', 'desde', 'hasta',  
                    'data_eventos', 'data_servicios', 'data_config', 'data_gastos'))
                ->join(array('u' => 'sistema_usuarios'), 'u.id=pm.creador', array('creado_por' => 'nombre'))
                ->join(array('n' => 'naves'), 'n.id=pm.nave_id', array('nave' => 'nombre'));
        if($estado === 1){
            $select->where("pm.data_eventos IS NOT NULL"); 
        } 
        $select->order('creacion DESC');
        return $adapter->fetchAll($select);
    }

    public function buscar(array $data) 
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('pm' => 'proyecciones_mantenimientos'), array(
                    'id', 'creacion', 'creador', 'nombre', 'nave_id', 'desde', 'hasta'))
                ->join(array('u' => 'sistema_usuarios'), 'u.id=pm.creador', array('creado_por' => 'nombre'))
                ->join(array('n' => 'naves'), 'n.id=pm.nave_id', array('nave' => 'nombre'));
        if ($data['estado'] == 0) {
            $select->where("pm.data_eventos IS NULL");
        } elseif ($data['estado'] == 1) {
            $select->where("pm.data_eventos IS NOT NULL");
        }
        $select->order('creacion DESC');
        return $adapter->fetchAll($select);
    }

    public function crear($data, $user) 
    {
        try {
            $data['creador'] = $user;
            $row = $this->createRow();
            $row->setFromArray($data);
            $row->save();
            $id = $row->id;
            return $id;
        } catch (Exception $ex) {
            return $ex->getMessage();
        }
    }
    
    public function eliminar() 
    {
        if (NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - ProyeccionMantenimiento::eliminar()");
        }
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    private function _getNave($nave_id) 
    {
        $nave = new Shipcode_Model_Nave();
        $nave->setId($nave_id);
        return $nave;
    }
    
     private function _getEventos($fechaDesde, $fechaHasta, $servicio, $equipo, $subsistema, $sistema)
    {
        $dataEventos = array();
        $horasEvento = FALSE;
        $fechaEvento = new Zend_Date($servicio['fecha']);
        if($servicio['horas'] !== NULL){
            $horasEvento = $servicio['horas'];
        } 
        $dataGeneralEvento = array(
            'equipo_id' => $equipo['id'],
            'equipo_nombre' => $equipo['nombre'],
            'equipo_marca' => $equipo['marca'],
            'equipo_modelo' => $equipo['modelo'],
            'subsistema' => $subsistema['nombre'],
            'sistema' => $sistema['nombre'],
            'servicio' => $servicio['nombre'] 
        );
        while($fechaEvento->isEarlier($fechaHasta)){
            if($fechaEvento->isLater($fechaDesde)){
                $dataEvento = $dataGeneralEvento;
                $dataEvento['fecha'] = $fechaEvento->toString("yyyy-MM-dd");
                $dataEvento['horas'] = $horasEvento;        
                $dataEventos[] = $dataEvento;
            }
            if($horasEvento !== FALSE){
                $horasEvento += $servicio['intervalo_horas'];
            }
            $fechaEvento->add($servicio['intervalo_dias'], Zend_Date::DAY);
        }
        return $dataEventos;
    }
    
    private function _getEquiposToDataConfig($equipos)
    {
        try { 
            $dataEquipos = array();
            foreach($equipos as $equipo){
                $dataEquipo['id'] = $equipo['id'];
                $dataEquipo['nombre'] = $equipo['nombre'];
                $dataEquipo['marca'] = $equipo['marca'];
                $dataEquipo['modelo'] = $equipo['modelo'];
                if($equipo['horometro'] == 1 && ($equipo['promedio_asignado'] !== NULL || $equipo['promedio_calculado'] !== NULL)){
                    if($equipo['promedio_usado'] === 'A'){
                        $dataEquipo['promedio_default'] = $equipo['promedio_asignado'];
                    } else {
                        $dataEquipo['promedio_default'] = $equipo['promedio_calculado'];
                    }
                } else {
                    $dataEquipo['promedio_default'] = NULL;
                }
                    
                $dataEquipo['promedio_configurado'] = NULL;
                $dataEquipo['plan_id'] = $equipo['planmant_id'];
                $servicios = $this->_getServiciosProgramados($dataEquipo);
                if(count($servicios) > 0){
                    $dataEquipo['servicios'] = $servicios;
                    $dataEquipos[] = $dataEquipo;
                }
            }
            return $dataEquipos;
        } catch (Exception $ex) {
            return $ex;
        }
    }
    
    private function _getServiciosProgramados($dataEquipo)
    {
        try {
            $dataServicios = array();
            $plan = new Shipcode_Model_BasePlanMant();
            $plan->setId($dataEquipo['plan_id']);
            $items = $plan->getItems();
            if(count($items) > 0){
                $actividad = new Shipcode_Model_NaveActividad();
                foreach($items as $item){
                    $servicio = $actividad->getInfoByDataToProyeccion($item->servicio_id, $dataEquipo['id']);
                    if($servicio){
                        $intervaloDias = $this->_getIntervalo($item, $dataEquipo);
                        if($intervaloDias){
                            $dataServicio = array(
                                'id' => $servicio['id'],
                                'nombre' => $servicio['servicio'],
                                'fecha' => $this->_getFecha($servicio['fecha_editada']),
                                'horas' => $servicio['horas'],
                                'intervalo_horas' => $item->cantidad_horas,
                                'intervalo_dias' => $intervaloDias,
                                'valor_unitario' => NULL,
                                'sel' => 0
                            );
                            $dataServicios[] = $dataServicio;
                        } else {
                            throw new Exception('No es posible obtener el intervalo de días del servicio ' . $servicio['servicio'] . ' para el equipo ' . $dataEquipo['nombre']);
                        }
                    }
                }
            }
            return $dataServicios;
        } catch (Exception $ex) {
            return $ex;
        }
    }
    
    private function _getIntervalo($item, $dataEquipo)
    { 
        if($item->cantidad_horas !== NULL && $item->cantidad_horas !== '' && $dataEquipo['promedio_default'] > 0){
            if($dataEquipo['promedio_configurado'] !== NULL && $dataEquipo['promedio_configurado'] > 0){
                $horasPorDia = $dataEquipo['promedio_configurado'] / 30;
            } else {
                $horasPorDia = $dataEquipo['promedio_default'] / 30;
            }
            
            $intervalo = round($item->cantidad_horas / $horasPorDia);
            if($item->cantidad_dias > 0 && $intervalo > $item->cantidad_dias){
                return $item->cantidad_dias;
            } else {
                return $intervalo;
            }
        } elseif($item->cantidad_dias !== NULL && $item->cantidad_dias !== '' && $item->cantidad_dias > 0) {
            return $item->cantidad_dias;
        } 
        return FALSE;
    }
    
    private function _getFecha($fecha)
    {
        $fechaProgramada = new Zend_Date($fecha);
        $fechaHoy = new Zend_Date(date("Y-m-d"));
        if($fechaProgramada->isEarlier($fechaHoy)) {
            $dataFecha = date("Y-m-d");
        } else {
            $dataFecha = $fecha;
        }
        return $dataFecha;
    }
    
    private function _validarId($id)
    {
        $optionsProyeccion = array('table' => 'proyecciones_mantenimientos', 'field' => 'id');
        $validadorProyeccion = new Zend_Validate_Db_RecordExists($optionsProyeccion);

        if ($validadorProyeccion->isValid($id)) {
            return TRUE;
        }
        return FALSE;
    }
}
