<?php
class Shipcode_Model_Proyecto extends Zend_Db_Table_Abstract
{
    protected $_name = 'proyectos';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        if(!$validador->isValid($id)){
            throw new Exception("El ID indicado no Existe");
            exit;
        }
        $this->_id = $id;
    }
    
    public function getDataProrrateos($parametros)
    {
        $year = $parametros['year'];

        
        $dataProyectos = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        
        $sql = "SELECT p.id, p.nombre, p.observaciones, p.moneda, p.costo_total, p.fecha_termino, "
             . "p.meses_prorrateo, p.detalle_prorrateo, p.fecha_inicio_prorrateo, "
             . "DATE_ADD(p.fecha_inicio_prorrateo, INTERVAL (p.meses_prorrateo - 1) MONTH) AS fecha_termino_prorrateo, "
             . "p.costo_liquidacion, p.fecha_liquidacion, p.observaciones_liquidacion, p.estado, "   
             . "cc.nombre AS centro_costo, ci.nombre AS concepto_imputacion, pt.nombre AS tipo "
             . "FROM proyectos AS p "
             . "JOIN centros_costo AS cc ON cc.id=p.centro_costo_id "
             . "JOIN conceptos_imputacion AS ci ON ci.id=p.concepto_imputacion_id "
             . "JOIN proyectos_tipos AS pt ON pt.id=p.tipo_id "
             . "WHERE ((estado='EN LIQUIDACION' AND  $year >= YEAR(fecha_inicio_prorrateo) AND  $year <= YEAR(DATE_ADD(fecha_inicio_prorrateo, INTERVAL meses_prorrateo MONTH))) "
             . "OR (estado='LIQUIDADO' AND $year <= YEAR(fecha_inicio_prorrateo) AND $year <= YEAR(fecha_liquidacion))) ";
        
        if(count($parametros['centros']) > 0) {
            $sql .= "AND p.centro_costo_id IN (". implode(',', array_keys($parametros['centros'])) .")";
        }
        if(count($parametros['conceptos']) > 0) {
            $sql .= "AND p.concepto_imputacion_id IN(". implode(',', array_keys($parametros['conceptos'])) .")";
        }
        if(count($parametros['tipos']) > 0){
            $sql .= "AND p.tipo_id IN(". implode(',', array_keys($parametros['tipos'])) .")";
        }
        
        $proyectos = $adapter->fetchAll($sql);
        
        foreach($proyectos as $proyecto){
            if($proyecto['estado'] === 'EN LIQUIDACION'){
                
                $fechaInicioProrrateo = new Zend_Date($proyecto['fecha_inicio_prorrateo']);
                $fechaTerminoProrrateo = new Zend_Date($proyecto['fecha_termino_prorrateo']);
                $row = $proyecto;
                $meses = array();
                for($i = 1; $i <= 12; $i++){
                    if($i < 10){
                        $mes = '0' . $i;
                    } else {
                        $mes = $i;
                    }
                    $fechaMes = new Zend_Date($parametros['year']. '-' . $mes . '-01');
                    if(($fechaMes->isEarlier($fechaTerminoProrrateo) || $fechaMes->equals($fechaTerminoProrrateo)) 
                            && ($fechaMes->isLater($fechaInicioProrrateo) || $fechaMes->equals($fechaInicioProrrateo))){
                        $meses[]['prorrateado'] = TRUE;
                    } else {
                        $meses[]['prorrateado'] = FALSE;
                    }
                }
                $row['meses'] = $meses;
                $dataProyectos[] = $row;
                
            } elseif($proyecto['estado'] === 'LIQUIDADO'){
                
                $fechaLiquidacion = new Zend_Date($proyecto['fecha_liquidacion']);
                $row = $proyecto;
                $meses = array();
                for($i = 1; $i <= 12; $i++){
                    if($i < 10){
                        $mes = '0' . $i;
                    } else {
                        $mes = $i;
                    }
                    $fechaMes = new Zend_Date($parametros['year']. '-' . $mes . '-01');
                    if(($fechaMes->isEarlier($fechaLiquidacion) || $fechaMes->equals($fechaLiquidacion)) 
                            && ($fechaMes->isLater($fechaInicioProrrateo) || $fechaMes->equals($fechaInicioProrrateo))){
                        $meses[]['prorrateado'] = TRUE;
                    } else {
                        $meses[]['prorrateado'] = FALSE;
                    }
                }
                $row['meses'] = $meses;
                $dataProyectos[] = $row;
            }
        }
        return $dataProyectos;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('p' => 'proyectos'), array(
                    'id', 'creacion', 'creador', 'centro_costo_id', 'concepto_imputacion_id', 
                    'tipo_id', 'nombre', 'observaciones', 'moneda', 'costo_total', 'fecha_termino', 
                    'meses_prorrateo', 'detalle_prorrateo', 'fecha_inicio_prorrateo', 
                    "DATE_ADD(fecha_inicio_prorrateo, INTERVAL (meses_prorrateo - 1) MONTH) AS fecha_termino_prorrateo", 
                    'costo_liquidacion', 'fecha_liquidacion', 'observaciones_liquidacion', 'estado'))
               ->join(array('cc' => 'centros_costo'), 'cc.id=p.centro_costo_id', array('centro_costo' => 'nombre')) 
               ->join(array('ci' => 'conceptos_imputacion'), 'ci.id=p.concepto_imputacion_id', array('concepto_imputacion' => 'nombre')) 
               ->join(array('pt' => 'proyectos_tipos'), 'pt.id=p.tipo_id', array('tipo' => 'nombre'))  
               ->where("p.id=?", $this->_id);
        $data = $adapter->fetchRow($select);
        
        $dataLiquidacion = $this->_calcularDataLiquidacion($data);
        
        if($data['estado'] == 'EN LIQUIDACION'){
            $data['costo_liquidacion'] = $dataLiquidacion['costoLiquidacion'];
            $data['valor_cuota'] = $dataLiquidacion['valorMensual'];
            $data['meses_restantes'] = $dataLiquidacion['mesesRestantes'];
        }
        
        if($data['estado'] == 'LIQUIDADO'){
            $data['valor_cuota'] = $dataLiquidacion['valorMensual'];
            $data['meses_anticipacion'] = $dataLiquidacion['mesesRestantes'];
        }
        
        if($data['estado'] == 'BORRADOR'){
            $data['valor_cuota'] = $dataLiquidacion['valorMensual'];
        }
        
        return $data;
    }
    
    public function getRowToForm()
    {
        $data = $this->getRow()->toArray();
        $fechaInicioProrrateo = new Zend_Date($data['fecha_inicio_prorrateo']);
        $data['year_inicio_prorrateo'] = $fechaInicioProrrateo->get(Zend_Date::YEAR);
        $data['mes_inicio_prorrateo'] = $fechaInicioProrrateo->get(Zend_Date::MONTH);
        return $data;
    }
    
    public function getAll()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('p' => 'proyectos'), array('id', 'nombre', 'estado'))
               ->join(array('cc' => 'centros_costo'), 'cc.id=p.centro_costo_id', array('centro_costo' => 'nombre')) 
               ->order("p.id DESC");
        return $adapter->fetchAll($select);
    }
    
    public function getTerminadosParaCierre()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('p' => 'proyectos'), array(
                    'id', 'creacion', 'creador', 'centro_costo_id', 'concepto_imputacion_id', 
                    'tipo_id', 'nombre', 'observaciones', 'moneda', 'costo_total', 'fecha_termino', 
                    'meses_prorrateo', 'detalle_prorrateo', 'fecha_inicio_prorrateo', 
                    "DATE_ADD(fecha_inicio_prorrateo, INTERVAL (meses_prorrateo - 1) MONTH) AS fecha_termino_prorrateo", 
                    'costo_liquidacion', 'fecha_liquidacion', 'observaciones_liquidacion', 'estado'))
               ->join(array('cc' => 'centros_costo'), 'cc.id=p.centro_costo_id', array('centro_costo' => 'nombre')) 
               ->join(array('ci' => 'conceptos_imputacion'), 'ci.id=p.concepto_imputacion_id', array('concepto_imputacion' => 'nombre')) 
               ->join(array('pt' => 'proyectos_tipos'), 'pt.id=p.tipo_id', array('tipo' => 'nombre')) 
               ->where("DATE_ADD(fecha_inicio_prorrateo, INTERVAL (meses_prorrateo - 1) MONTH) < ?", date("Y-m-d"));
        return $adapter->fetchAll($select);
    }
    
    public function buscar($data)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('p' => 'proyectos'), array(
                    'id', 'creacion', 'creador', 'centro_costo_id', 'concepto_imputacion_id', 
                    'tipo_id', 'nombre', 'observaciones', 'moneda', 'costo_total', 'fecha_termino', 
                    'meses_prorrateo', 'detalle_prorrateo', 'fecha_inicio_prorrateo', 
                    "DATE_ADD(fecha_inicio_prorrateo, INTERVAL (meses_prorrateo - 1) MONTH) AS fecha_termino_prorrateo", 
                    'costo_liquidacion', 'fecha_liquidacion', 'observaciones_liquidacion', 'estado'))
               ->join(array('cc' => 'centros_costo'), 'cc.id=p.centro_costo_id', array('centro_costo' => 'nombre')) 
               ->join(array('ci' => 'conceptos_imputacion'), 'ci.id=p.concepto_imputacion_id', array('concepto_imputacion' => 'nombre')) 
               ->join(array('pt' => 'proyectos_tipos'), 'pt.id=p.tipo_id', array('tipo' => 'nombre')) 
               ->order("p.id DESC");
        
        if($data['centro_costo_id'] != '') {
            $select->where("p.centro_costo_id=?", $data['centro_costo_id']);
        }
        
        if($data['concepto_imputacion_id'] != '') {
            $select->where("p.concepto_imputacion_id=?", $data['concepto_imputacion_id']);
        }
        
        if($data['tipo_id'] != '') {
            $select->where("p.tipo_id=?", $data['tipo_id']);
        }
        
        if($data['nombre'] != '') {
            $select->where("p.nombre LIKE=?", "%". $data['nombre'] . "%");
        }
        
        if($data['estado'] == 1) {
            $select->where("p.estado=?", 'BORRADOR');
        }
        
        if($data['estado'] == 2) {
            $select->where("p.estado=?", 'EN LIQUIDACION');
        }
        
        if($data['estado'] == 3) {
            $select->where("p.estado=?", 'LIQUIDADO');
        }
        
        if($data['terminados']['desde'] != '') {
            $select->where("p.fecha_termino >= ?", $data['terminado']['desde']);
        }
        
        if($data['terminados']['hasta'] != '') {
            $select->where("p.fecha_termino <= ?", $data['terminado']['hasta']);
        }
        
        if($data['inicioProrrateo']['desde'] != '') {
            $select->where("p.fecha_inicio_prorrateo >= ?", $data['inicioProrrateo']['desde']);
        }
        
        if($data['inicioProrrateo']['hasta'] != '') {
            $select->where("p.fecha_inicio_prorrateo <= ?", $data['inicioProrrateo']['hasta']);
        }
        
        if($data['terminoProrrateo']['desde'] != '') {
            $select->where("DATE_ADD(fecha_inicio_prorrateo, INTERVAL (meses_prorrateo - 1) MONTH) >= ?", $data['terminoProrrateo']['desde']);
        }
        
        if($data['terminoProrrateo']['hasta'] != '') {
            $select->where("DATE_ADD(fecha_inicio_prorrateo, INTERVAL (meses_prorrateo - 1) MONTH) <= ?", $data['terminoProrrateo']['hasta']);
        }
        
        if($data['liquidados']['desde'] != '') {
            $select->where("p.fecha_liquidacion >= ?", $data['liquidacion']['desde']);
        }
        
        if($data['liquidados']['hasta'] != '') {
            $select->where("p.fecha_liquidacion <= ?", $data['liquidacion']['hasta']);
        }
        
        return $adapter->fetchAll($select);
    }
    
    public function crear($data, $user)
    {
        if($data['mes_inicio_prorrateo'] != '' && $data['year_inicio_prorrateo'] != ''){
            $data['fecha_inicio_prorrateo'] = $data['year_inicio_prorrateo'] . "-" . $data['mes_inicio_prorrateo'] ."-01";
        } else {
            $data['fecha_inicio_prorrateo'] = NULL;
        }
        
        $data['creador'] = $user;
        if($data['observaciones'] == '') {$data['observaciones'] = NULL; }
        
        if($this->_validarProyecto($data) === TRUE){
            
            $adapter = $this->getDefaultAdapter();
            
            try {
                $adapter->beginTransaction();
                
                $mantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
                
                $row = $this->createRow($data);
                $row->save();
                
                if($data['mantenimiento_id'] !== ''){
                    $mantenimiento->setId($data['mantenimiento_id']);
                    $mantenimiento->setProyectoId($row->id);
                }
                
                $adapter->commit();
                return $row->id;
                 
            } catch (Exception $ex) {

                $adapter->rollBack();
                return $ex->getMessage();
            }
        } else {
            throw new Exception("Existe un proyecto en proceso de liquidación o liquidado para el centro de costo, tipo y concepto de imputación seleccionado.");
        }
        
    }
    
    private function _validarProyecto($data)
    {
        $adapter = $this->getAdapter();
        $sqlEnLiquidacion = "SELECT COUNT(*) FROM proyectos "
                          . "WHERE centro_costo_id='" . $data['centro_costo_id'] . "' "
                          . "AND concepto_imputacion_id='" . $data['concepto_imputacion_id'] . "' "
                          . "AND tipo_id='" . $data['tipo_id'] . "' "
                          . "AND estado='EN LIQUIDACION' "
                          . "AND DATE_ADD(fecha_inicio_prorrateo, INTERVAL (meses_prorrateo - 1) MONTH) >= '" . $data['fecha_inicio_prorrateo'] . "'";
        $resultEnLiquidacion = $adapter->fetchOne($sqlEnLiquidacion);
        
        $sqlLiquidados = "SELECT COUNT(*) FROM proyectos "
                       . "WHERE centro_costo_id='" . $data['centro_costo_id'] . "' "
                       . "AND concepto_imputacion_id='" . $data['concepto_imputacion_id'] . "' "
                       . "AND tipo_id='" . $data['tipo_id'] . "' "
                       . "AND estado='LIQUIDADO' "
                       . "AND fecha_liquidacion >= '" . $data['fecha_inicio_prorrateo'] . "'";
        $resultLiquidados = $adapter->fetchOne($sqlLiquidados);
        
        if($resultEnLiquidacion > 0 || $resultLiquidados > 0){
            return FALSE;
        }
        return TRUE;
    }
    
    public function editar($data, $user)
    {
        if($data['mes_inicio_prorrateo'] != '' && $data['year_inicio_prorrateo'] != ''){
            $data['fecha_inicio_prorrateo'] = $data['year_inicio_prorrateo'] . "-" . $data['mes_inicio_prorrateo'] ."-01";
        } else {
            $data['fecha_inicio_prorrateo'] = NULL;
        }
        
        $data['creador'] = $user;
        if($data['observaciones'] == '') {$data['observaciones'] = NULL; }
        if($this->_validarProyecto($data) === TRUE){
            
            $adapter = $this->getDefaultAdapter();
            
            try {
                $adapter->beginTransaction();
                
                $mantenimiento = new Shipcode_Model_NaveEquipoMantenimiento();
                
                $row = $this->find($data['id'])->current();
                $row->setFromArray($data);
                $row->save();
                
                if($data['mantenimiento_id'] !== ''){
                    $mantenimiento->setId($data['mantenimiento_id']);
                    $mantenimiento->setProyectoId($row->id);
                }
                
                $adapter->commit();
                return $row->id;
                
            } catch(Exception $ex){
                 $adapter->rollBack();
                return $ex->getMessage();
            }
            
            
                
        } else {
            throw new Exception("Existe un proyecto en proceso de liquidación o liquidado para el centro de costo, tipo y concepto de imputación seleccionado.");
        }
    }
    
    public function checkInfoLiquidacion()
    {
        $data = $this->getRow()->toArray();
        if($this->_validarProyecto($data) === TRUE){
            return TRUE;
        } 
        return FALSE;
    }
    
    public function liquidar($data)
    {
        if($data['mes_liquidacion'] == '' || $data['year_liquidacion'] == ''){
            throw new Exception('No se ha ingresado el mes o año de liquidación.');
        } 
        
        $this->setId($data['id']);
        
        $data['fecha_liquidacion'] = $data['year_liquidacion'] . "-" . $data['mes_liquidacion'] ."-01";
        
        $dataLiquidacion = $this->_calcularDataLiquidacion($this->getRowFull(), $data['fecha_liquidacion']);
        
        $data['costo_liquidacion'] = $dataLiquidacion['costoLiquidacion'];
        $data['estado'] = 'LIQUIDADO';
        
        if($data['observaciones_liquidacion'] == '') {$data['observaciones_liquidacion'] = NULL; }
        
        $row = $this->getRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function liquidarAutomatico($id)
    {
        $this->setId($id);
        $data['fecha_liquidacion'] = date("Y-m-d") ;
        $data['costo_liquidacion'] = 0;
        $data['estado'] = 'LIQUIDADO';
        $data['observaciones_liquidacion'] = 'Cerrado automáticamente el ' . date("d/m/Y"); 
        $row = $this->getRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        return $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Eliminar Proyecto");
        }
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        try {
            return $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    private function _calcularDataLiquidacion($data, $fechaL = NULL)
    {
        $dataLiquidacion = array();
        $fechaInicio = new Zend_Date($data['fecha_inicio_prorrateo']);
        $fechaTermino = new Zend_Date($data['fecha_termino_prorrateo']);
        $fechaActual = new Zend_Date(date("Y-m-") . "01");
        $valorCuotaMensual = $data['costo_total'] / $data['meses_prorrateo'];
        
        if($fechaL != NULL){
            $fechaLiquidacion = new Zend_Date($fechaL);
            $mesesRestantes = floor($fechaTermino->sub($fechaLiquidacion)->toValue() / 30 / 60 / 60 / 24);
            $dataLiquidacion['costoLiquidacion'] = $valorCuotaMensual * $mesesRestantes;
        } else {
            if($data['estado'] == 'EN LIQUIDACION') {
                if($fechaActual->isEarlier($fechaInicio)){
                    $mesesRestantes = $data['meses_prorrateo'];
                } elseif($fechaActual->isLater($fechaTermino)) {
                    $mesesRestantes = 0;
                } else {
                    $mesesRestantes = floor($fechaTermino->sub($fechaActual)->toValue() / 30 / 60 / 60 / 24);
                }
                $dataLiquidacion['costoLiquidacion'] = $valorCuotaMensual * $mesesRestantes;
            } else {
                $fechaLiquidacion = new Zend_Date($data['fecha_liquidacion']);
                $mesesRestantes = floor($fechaTermino->sub($fechaLiquidacion)->toValue() / 30 / 60 / 60 / 24);
            }
        }
        $dataLiquidacion['mesesRestantes'] = $mesesRestantes;
        $dataLiquidacion['valorMensual'] = $valorCuotaMensual;
        return $dataLiquidacion; 
    }
}