<?php
class Shipcode_Model_SistemaPerfilUsuario extends Zend_Db_Table_Abstract
{
    protected $_name = 'sistema_perfiles_usuarios';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = (int)$id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getAll()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('p' => 'sistema_perfiles_usuarios'), array(
                    'id', 'creacion', 'creador', 'interfaz_id', 'nombre', 'privilegios', 'editable'))
               ->join(array('i' => 'sistema_interfaces'), 'i.id=p.interfaz_id', array('interfaz' => 'nombre'));
        return $adapter->fetchAll($select);
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        $data['privilegios'] = $this->_getPrivilegiosDefault($data['perfil_id']);
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editar($data, $user, $id)
    {
        $data['creador'] = $user;
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - SistemaPerfilUsuario::eliminar()");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public static function getPairsToSelect()
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT id, nombre FROM sistema_perfiles_usuarios ORDER BY nombre";
        return $adapter->fetchPairs($sql);
    }

    public function getPrivilegiosById($id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT privilegios FROM sistemna_perfiles_usuarios WHERE perfil_id='$id'";
        return $adapter->fetchOne($sql);
    }    
    
    public function setPrivilegio($ruta, $valor)
    {
        $row = $this->find($this->_id)->current();
        $dataPrivilegios = $row->privilegios;
        
        if($dataPrivilegios === NULL){
            $privilegios = $this->_getPrivilegiosDefault($row->interfaz_id);
        } else {
            $privilegios = Zend_Json::decode($dataPrivilegios);
        }
        $dataRuta = explode(":", $ruta);
        if(count($dataRuta) == 2){
            $privilegios[$dataRuta[0]][$dataRuta[1]] = $valor;
        } elseif(count($dataRuta) == 3) {
            $privilegios[$dataRuta[0]][$dataRuta[1]][$dataRuta[2]] = $valor;
        } elseif(count($dataRuta) == 4) {
            $privilegios[$dataRuta[0]][$dataRuta[1]][$dataRuta[2]][$dataRuta[3]] = $valor;
        }
        $row->privilegios = Zend_Json::encode($privilegios);
        $row->save();
        return $dataPrivilegios;
    }
    
    private function _getPrivilegiosDefault($interfaz_id = NULL)
    {
        // 00 : Super Admin
        // 01 : Administrador
        // 02 : Flota
        // 03 : Mantenimiento
        // 04 : Gerencia
        // >= 10 && < 20 : Supervisor
        // >= 20 : Nave
        
        
        // F : Full
        // R : Read
        // H : Hide
        
        // configuración de valores por defecto para perfiles
        if($interfaz_id === 0 
            || $interfaz_id === '0' 
            || $interfaz_id === 1 
            || $interfaz_id === '1'){
            $acceso = 'SI';
            $nivel = "F";
        } else {
            $acceso = 'NO';
            $nivel = "H";
        }
        
        $privilegios = array(
            "empresas" => array(
                "administrar" => $acceso,
                "naves" => array(
                    "administrar" => $acceso,
                    "sistemas" => array(
                        "administrar" => $acceso
                    ),
                    "equipos" => array(
                        "administrar" => $acceso,
                        "historial" => $nivel,
                        "plan" => $nivel,
                        "archivos" => $nivel,
                        "partes" => $nivel,
                        "gastos" => $nivel,
                        "ficha" => $nivel,
                        "horometros" => $nivel
                    ),
                    "ficha" => $nivel,
                    "certificados" => $nivel,
                    "observaciones" => $nivel,
                    "carenas" => $nivel,
                    "siniestros" => $nivel,
                    "archivos" => $nivel,
                    "solicitudes" => $nivel
                )
            ),
            "herramientas" => array(
                "menu" => $acceso,
                "list" => array(
                    "gestion_equipos" => $acceso,
                    "gestion_horometros" => $acceso,
                    "gestion_eventos" => $acceso,
                    "ubicaciones_virtuales" => $acceso,
                    "prorrateo_proyectos" => $acceso,
                    "control_gastos" => $acceso,
                    "programacion_mantenimiento" => $acceso,
                    "mantenimientos_informados" => $acceso,
                    "proyecciones" => $acceso,
                    "indice_fallas" => $acceso
                )
            ),
            "utilidades" => array(
                "menu" => $acceso,
                "list" => array(
                    "clonar_nave" => $acceso,
                    "clonar_sistema" => $acceso,
                    "clonar_equipo" => $acceso,
                    "exportar_nave" => $acceso,
                    "config_inicio_operaciones" => $acceso,
                    "mover_equipo" => $acceso
                )
            ),
            "informes" => array(
                "menu" => $acceso,
                "list" => array(
                    "certificados" => $acceso,
                    "observaciones" => $acceso,
                    "carenas" => $acceso,
                    "siniestros" => $acceso,
                    "mantenimientos" => $acceso,
                    "solicitudes" => $acceso,
                    "programaciones" => $acceso,
                    "horometros" => $acceso,
                    "guardados" => $acceso
                )
            ),
            "config" => array(
                "menu" => $acceso,
                "list" => array(
                    "mantenimientos" => $acceso,
                    "listas_verificacion" => $acceso,
                    "naves" => $acceso,
                    "equipos" => $acceso,
                    "gastos" => $acceso,
                    "informes" => $acceso,
                    "sistema" => $acceso
                )
            ),
            "usuarios" => array(
                "administrar" => $acceso
            )
        );
        return $privilegios;
    }
}