<?php
class Shipcode_Model_SistemaUsuario extends Zend_Db_Table_Abstract
{
    protected $_name = 'sistema_usuarios';
    protected $_primary = 'id';
    
    private $_id;
    
    public function getIdentificacion($data)
    {
        $adapter = $this->getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);+
        $select = $adapter->select();
        $select->from(array('vu' => 'vista_usuarios'), array('*'))
               ->where("vu.mail=?", $data['usuario'])
               ->where("vu.clave=?", md5($data['clave']));
        return $adapter->fetchRow($select);
    }
    
   
    
    
    
    public function setId($id)
    {
        $this->_id = (int)$id;
    }
    
    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getAll($perfil_start = NULL, $perfil_end = NULL)
    {
        return Shipcode_Model_VistaUsuarios::getAll($perfil_start, $perfil_end, 1);
    }
    
    public function getRowFull()
    {
        return Shipcode_Model_VistaUsuarios::getRowById($this->_id);
    }
    
    public static function getPairsToSelect($perfil_start = NULL, $perfil_end = NULL)
    {
        $sql = "SELECT id,nombre FROM sistema_usuarios ";
        if($perfil_start !== NULL && $perfil_end !== NULL) {
            $sql .= " WHERE perfil_id >='$perfil_start' AND perfil_id <='$perfil_end' ";
        }
        $sql .= "ORDER BY nombre";
        $adapter = self::getDefaultAdapter();
        return $adapter->fetchPairs($sql);
    }
    
    public function crear($data, $user)
    {
        if($data['valido_hasta'] == '') { $data['valido_hasta'] = NULL; }
        if($data['mail'] == '') { $data['mail'] = NULL; }
        $data['creador'] = $user;
        if($data['clave1'] != '') {
            $clave = $data['clave1'];
            $data['clave'] = md5($clave);
        } else {
            $clave = $this->_crearClave($data['nombre'] . $data['mail']);
            $data['clave'] = md5($clave);
        }
        $data['autorizaciones'] = Zend_Json::encode($this->_getAutorizacionesDefault($data['perfil_id']));
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return array(
            'id' => $row->id, 
            'clave' => $clave, 
            'mail' => $row->mail, 
            'notificaciones' => $row->notificaciones
        );
    }
    
    public function editar($data, $user, $id)
    {
        if($data['valido_hasta'] == '') { $data['valido_hasta'] = NULL; }
        if($data['mail'] == '') { $data['mail'] = NULL; }
        $data['creador'] = $user;
        if($data['clave1'] != '') {
            $data['clave'] = md5($data['clave1']);
        }
        //$data['autorizaciones'] = Zend_Json::encode($this->_getAutorizacionesDefault($data['perfil_id']));
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function bloquear()
    {
        $row = $this->getRow();
        $row->estado = 0;
        $row->save();
    }
    
    public function activar()
    {
        $row = $this->getRow();
        $row->estado = 1;
        $row->save();
    }
    
    public function resetearClave()
    {
        $row = $this->getRow();
        $clave = $this->_crearClave($row->nombre, $row->mail . Zend_Date::now());
        $row->clave = md5($clave);
        $row->save();
        return $clave;
    }
    
    public function existe($id)
    {
        $row = $this->find($id)->current();
        if($row){
            return TRUE;
        }
        return FALSE;
    }
    
    public function cambiarClave($data, $id)
    {
        $row = $this->find($id)->current();
        if($row->clave == md5($data['clave'])){
            $row->clave = md5($data['clave1']);
            return $row->save();
        }
        return FALSE;
    }
    
    public function eliminar()
    {
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        if($this->delete($where)){
            return TRUE;
        }
        return FALSE;
    }
    
    public static function getEmpresaAsignada($empresas)
    {
        if(count($empresas) > 0){
            foreach($empresas as $id => $permiso){
                if($permiso == 1){
                    return $id;
                }
            }
        }
        return FALSE;
    }
    
    public static function getNaveAsignada($naves)
    {
        if(count($naves) > 0){
            foreach($naves as $id => $permiso){
                if($permiso == 1){
                    return $id;
                }
            }
        }
        return FALSE;
    }
    
    public static function filtrarNavesAutorizadas($privilegiosNaves)
    {
        $data = array();
        foreach($privilegiosNaves as $key => $value){
            if($value == 1){
                $data[] = $key;
            }
        }
        return implode(",", $data);
    }
    
    public function setAccesoRecurso($recurso_tipo, $recurso_id, $valor)
    {
        $row = $this->find($this->_id)->current();
        $dataAutorizaciones = $row->autorizaciones;
        
        if($dataAutorizaciones === NULL || $row->perfil_id >= 20){
            $autorizaciones = $this->_getAutorizacionesDefault($row->perfil_id);
        } else {
            $autorizaciones = Zend_Json::decode($dataAutorizaciones);
        }

        if($recurso_tipo == 'empresas') { 
            $autorizaciones['empresas'][$recurso_id] = $valor;
        } elseif ($recurso_tipo == 'naves') { 
            $autorizaciones['naves'][$recurso_id] = $valor;
        }
        
        $row->autorizaciones = Zend_Json::encode($autorizaciones);
        $row->save();
        return $dataAutorizaciones;
    }
    
    private function _getUltimoAcceso($usuario_id)
    {
        return Shipcode_Model_SistemaLogIngreso::getLastByUsuarioId($usuario_id);
    }
    
    private function _getAutorizacionesDefault($perfil_id = NULL, array $empresas = array(), array $naves = array())
    {
        // 00 : Super Admin
        // 01 : Administrador
        // 02 : Flota
        // 03 : Mantenimiento
        // 04 : Gerencia
        // >= 10 && < 20 : Supervisor
        // >= 20 : Nave
        
        // configuración de valores por defecto para empresas
        if($perfil_id === 0 || $perfil_id === '0' 
            || $perfil_id === 1 || $perfil_id === '1'
            || $perfil_id === 2 || $perfil_id === '2'
            || $perfil_id === 3 || $perfil_id === '3'
            || $perfil_id === 4 || $perfil_id === '4'){
            $valorEmpresa = 1;
        } else {
            $valorEmpresa = 0;
        }
        
        // configuración de valores por defecto para naves
        if($perfil_id === 0 || $perfil_id === '0' 
            || $perfil_id === 1 || $perfil_id === '1'
            || $perfil_id === 2 || $perfil_id === '2'
            || $perfil_id === 3 || $perfil_id === '3'
            || $perfil_id === 4 || $perfil_id === '4'){
            $valorNave = 1;
        } else {
            $valorNave = 0;
        }
        
        $autorizaciones = array('empresas' => array(), 'naves' => array());
        
        $modelEmpresa = new Shipcode_Model_Empresa();
        $rowsEmpresas = $modelEmpresa->fetchAll();
        
        if(count($rowsEmpresas) > 0) {
            $rowsEmpresas = $rowsEmpresas->toArray();
            
            // recorro las empresas
            foreach($rowsEmpresas as $rowEmpresa){
                
                // si el ID fue enviado en el array a la función
                // se autoriza, sino se da el valor por defecto
                // según el tipo de usuario
                if(in_array($rowEmpresa['id'], $empresas)){
                   $autorizaciones['empresas'][$rowEmpresa['id']] = 1;
                } else {
                    $autorizaciones['empresas'][$rowEmpresa['id']] = $valorEmpresa;
                }
                
                // Se consultan las naves de cada empresa
                $modelEmpresa->setId($rowEmpresa['id']);
                $rowsNaves = $modelEmpresa->getNaves();
                
                // chequeo que la empresa tenga naves
                if(count($rowsNaves > 0)) {
                    // recorro las naves de la empresa
                    foreach($rowsNaves as $rowNave){
                        
                        // si la empresa
                        if(in_array($rowNave['id'], $naves) || in_array($rowEmpresa['id'], $empresas)){
                            $autorizaciones['naves'][$rowNave['id']] = 1;
                        } else {
                            $autorizaciones['naves'][$rowNave['id']] = $valorNave;
                        }
                    }
                }
            }
        }
        return $autorizaciones;
    }
    
    private function _eliminarInfoAcceso()
    {
        $logIngreso = new Shipcode_Model_SistemaLogIngreso();
        $where = $this->getAdapter()->quoteInto("usuario_id=?", $this->_id);
        $logIngreso->delete($where);
    }
    
    private function _crearClave($valor)
    {
        return substr(md5($valor), 0, 6);
    }
    
    /*
    public function getSupervisoresByEmpresaId($empresa_id)
    {
        $supervisoresAutorizados = NULL;
        $supervisores = $this->getSupervisoresFull();
        if(count($supervisores) > 0){
            foreach($supervisores as $supervisor){
                if($empresa_id == $supervisor['empresa_id']){
                    $supervisor['empresa_id2'] = $empresa_id;
                    $supervisoresAutorizados[] = $supervisor;
                }
            }
        }
        return $supervisoresAutorizados;
    }
    
    public function getSupervisoresFull()
    {
        $supervisores = Shipcode_Model_VistaUsuarios::getAll(10, 19);
        $data = array();
        if(count($supervisores) > 0){
            $modelEmpresa = new Shipcode_Model_Empresa();
            foreach($supervisores as $supervisor){
                $privilegios = Zend_Json::decode($supervisor['privilegios']);
                $empresa_id = self::getEmpresaAsignada($privilegios['autorizaciones']['empresas']);
                $supervisor['ultimo_acceso'] = $this->_getUltimoAcceso($supervisor['id']);
                if($empresa_id !== FALSE){
                    $modelEmpresa->setId($empresa_id);
                    $dataEmpresa = $modelEmpresa->getRow()->toArray();
                    $supervisor['empresa'] = $dataEmpresa['nombre'];
                    $supervisor['empresa_id'] = $dataEmpresa['id'];
                    
                } else {
                    $supervisor['empresa'] = NULL;
                    $supervisor['empresa_id'] = NULL;
                }
                $data[] = $supervisor;
            }
        }
        return $data;
    }
    
    public function getPrivilegios()
    {
        $privilegios = $this->getRow()->privilegios;
        if($privilegios != NULL) {
            return Zend_Json::decode($privilegios);
        }
        return NULL;
    }
    public function crearPersonalizadoLectura($data, $user)
    {
        if($data['valido_hasta'] == '') { $data['valido_hasta'] = NULL; }
        $privilegiosJson = file_get_contents(APPLICATION_PATH . '/configs/privilegios.json');
        $privilegiosArray = Zend_Json::decode($privilegiosJson);
        $privilegiosUsuario = $privilegiosArray[99];
        $privilegiosUsuario['autorizaciones'] = $this->_getAutorizacionesDefault();
        $clave = $this->_crearClave($data['nombre'] . $data['mail']);
        $data['creador'] = $user;
        $data['clave'] = md5($clave);
        $data['tipo'] = 99;
        $data['privilegios'] = Zend_Json::encode($privilegiosUsuario);
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return array('id' => $row->id, 'clave' => $clave);
    }
    
    public function editarPersonalizadoLectura($data, $user, $id)
    {
        if($data['valido_hasta'] == '') { $data['valido_hasta'] = NULL; }        
        $data['creador'] = $user;
        $data['tipo'] = 99;
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    public function crearSupervisor($data, $user)
    {
        if($data['valido_hasta'] == '') { $data['valido_hasta'] = NULL; }
        $data['tipo'] = 2;
        $data['creador'] = $user;
        $privilegiosJson = file_get_contents(APPLICATION_PATH . '/configs/privilegios.json');
        $privilegiosArray = Zend_Json::decode($privilegiosJson);
        $privilegiosUsuario = $privilegiosArray[$data['tipo']];
        $privilegiosUsuario['autorizaciones'] = $this->_getAutorizacionesDefault($data['tipo'], array($data['empresa_id']));
        $clave = $this->_crearClave($data['nombre'] . $data['mail']);
        $data['clave'] = md5($clave);
        $data['privilegios'] = Zend_Json::encode($privilegiosUsuario);
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    public function editarSupervisor($data, $user, $id)
    {
        if($data['valido_hasta'] == '') { $data['valido_hasta'] = NULL; }
        $data['tipo'] = 2;
        $data['creador'] = $user;
        $privilegiosJson = file_get_contents(APPLICATION_PATH . '/configs/privilegios.json');
        $privilegiosArray = Zend_Json::decode($privilegiosJson);
        $privilegiosUsuario = $privilegiosArray[$data['tipo']];
        $privilegiosUsuario['autorizaciones'] = $this->_getAutorizacionesDefault($data['tipo'], array($data['empresa_id']));
        $data['privilegios'] = Zend_Json::encode($privilegiosUsuario);
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function crearMotorista($data, $user)
    {
        if($data['valido_hasta'] == '') { $data['valido_hasta'] = NULL; }
        $data['tipo'] = 5;
        $data['creador'] = $user;
        $privilegiosJson = file_get_contents(APPLICATION_PATH . '/configs/privilegios.json');
        $privilegiosArray = Zend_Json::decode($privilegiosJson);
        $privilegiosUsuario = $privilegiosArray[$data['tipo']];
        $privilegiosUsuario['autorizaciones'] = $this->_getAutorizacionesDefault($data['tipo'], NULL, array($data['nave_id']));
        $data['clave'] = md5($data['clave1']);
        $data['privilegios'] = Zend_Json::encode($privilegiosUsuario);
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editarMotorista($data, $user, $id)
    {
        if($data['valido_hasta'] == '') { $data['valido_hasta'] = NULL; }
        $data['tipo'] = 5;
        $data['creador'] = $user;
        $privilegiosJson = file_get_contents(APPLICATION_PATH . '/configs/privilegios.json');
        $privilegiosArray = Zend_Json::decode($privilegiosJson);
        $privilegiosUsuario = $privilegiosArray[$data['tipo']];
        $privilegiosUsuario['autorizaciones'] = $this->_getAutorizacionesDefault($data['tipo'], NULL, array($data['nave_id']));
        if($data['clave1'] != '') {
            $data['clave'] = md5($data['clave1']);
        }
        $data['privilegios'] = Zend_Json::encode($privilegiosUsuario);
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    public static function getHeaderByTipoUsuarioId($tipo)
    {
        switch ($tipo) {
            case 0:
                $header = "header-superadministrador.phtml";
                break;
            case 1:
            case 2:    
            case 3:
                $header = "header-administrador.phtml";
                break;
            case 4:
                $header = "header-supervisor.phtml";
                break;
            case 5:
                $header = "header-nave.phtml";
                break;
            case 99:    
            default:
                $header = "header-invitado.phtml";
                break;
        }
        return $header;
    }
    public static function getStartByTipoUsuarioId($tipo)
    {
        switch ($tipo) {
            case 0:
            case 1:
            case 2:
            case 3:
                $start['controller'] = "u-administrador"; 
                break;
            case 4:
                $start['controller'] = "u-supervisor";
                break;
            case 5:
                $start['controller'] = "u-nave";
                break;
            case 99:    
            default:
                $start['controller'] = "u-invitado";
                break;
        }
        return $start;
    }
    private function _getPrivilegiosNavesDefault($tipo = NULL, array $naves = NULL)
    {
        if($tipo === 99 || $tipo === '99' 
                || $tipo === 2 || $tipo === '2' 
                || $tipo === 5 || $tipo === '5'){
            $valor = 0;
        } else {
            $valor = 1;
        }
        $data = array();
        
        $empresas = Shipcode_Model_Nave::getAgrupadasPorEmpresa();
        foreach($empresas as $empresa){
            if(count($empresa['naves']) > 0) {
                foreach($empresa['naves'] as $nave){
                    if(in_array($nave['id'], $naves)){
                        $data[$nave['id']] = 1;
                    } else {
                        $data[$nave['id']] = $valor;
                    }
                }
            }
        }
        return $data;
    }
    private function _asignarNave($usuario_id, $nave_id, $creador)
    {
        $naveUsuario = new Shipcode_Model_NaveUsuario();
        return $naveUsuario->crear(array(
            'creador' => $creador,
            'usuario_id' => $usuario_id, 
            'nave_id' => $nave_id,
        ));
        
    }
    private function _actualizarAsignacionNave($usuario_id, $nave_id, $creador)
    {
        $naveUsuario = new Shipcode_Model_NaveUsuario();
        return $naveUsuario->actualizarAsignacion(array(
            'creador' => $creador,
            'usuario_id' => $usuario_id,
            'nave_id' => $nave_id
        ));
    }
    public function getRowMotorista()
    {
        $row = Shipcode_Model_VistaUsuarios::getRowById($this->_id);
        $autorizaciones = Zend_Json::decode($row['autorizaciones']);
        $row['nave_id'] = self::getNaveAsignada($autorizaciones['naves']);
        return $row;
    }
    
    public function getRowSupervisor()
    {
        $row = Shipcode_Model_VistaUsuarios::getRowSupervisor($this->_id);
        $autorizaciones = Zend_Json::decode($row['autorizaciones']);
        $row['empresa_id'] = self::getEmpresaAsignada($autorizaciones['empresas']);
        return $row;
    }
    
    public function getSupervisores()
    {
        return Shipcode_Model_VistaUsuarios::getAll(10, 19);
    }
    
    public function getMotoristas()
    {
        return Shipcode_Model_VistaUsuarios::getAll(20, 29);
    }
    
    public function getPersonalizadosLectura()
    {
        return Shipcode_Model_VistaUsuarios::getAll(4, 4);
    }
    
    public function getSupervisoresByEmpresaId($empresa_id)
    {
        $supervisoresAutorizados = NULL;
        $supervisores = $this->getSupervisoresFull();
        if(count($supervisores) > 0){
            foreach($supervisores as $supervisor){
                if($empresa_id == $supervisor['empresa_id']){
                    $supervisor['empresa_id2'] = $empresa_id;
                    $supervisoresAutorizados[] = $supervisor;
                }
            }
        }
        return $supervisoresAutorizados;
    }
    
    public function getMotoristasByNaveId($nave_id)
    {
        $motoristas = $this->getMotoristasFull();
        if(count($motoristas) > 0){
            $motoristasAutorizados = NULL;
            foreach($motoristas as $motorista){
                $privilegios = Zend_Json::decode($motorista['privilegios']);
                if($privilegios['autorizaciones']['naves'][$nave_id] == 1){
                    $motoristasAutorizados[] = $motorista;
                }
            }
        }
        return $motoristasAutorizados;
    }

    public function getSupervisoresFull()
    {
        $supervisores = Shipcode_Model_VistaUsuarios::getAll(10, 19);
        $data = array();
        if(count($supervisores) > 0){
            $modelEmpresa = new Shipcode_Model_Empresa();
            foreach($supervisores as $supervisor){
                $privilegios = Zend_Json::decode($supervisor['privilegios']);
                $empresa_id = self::getEmpresaAsignada($privilegios['autorizaciones']['empresas']);
                $supervisor['ultimo_acceso'] = $this->_getUltimoAcceso($supervisor['id']);
                if($empresa_id !== FALSE){
                    $modelEmpresa->setId($empresa_id);
                    $dataEmpresa = $modelEmpresa->getRow()->toArray();
                    $supervisor['empresa'] = $dataEmpresa['nombre'];
                    $supervisor['empresa_id'] = $dataEmpresa['id'];
                    
                } else {
                    $supervisor['empresa'] = NULL;
                    $supervisor['empresa_id'] = NULL;
                }
                $data[] = $supervisor;
            }
        }
        return $data;
    }
    
    public function getMotoristasFull()
    {
        $motoristas = Shipcode_Model_VistaUsuarios::getAll(20, 29);
        $data = array();
        if(count($motoristas) > 0){
            $modelNave = new Shipcode_Model_Nave();
            foreach($motoristas as $motorista){
                $privilegios = Zend_Json::decode($motorista['privilegios']);
                $nave_id = self::getNaveAsignada($privilegios['autorizaciones']['naves']);
                if($nave_id !== FALSE){
                    $modelNave->setId($nave_id);
                    $dataNave = $modelNave->getRow()->toArray();
                    $motorista['ultimo_acceso'] = $this->_getUltimoAcceso($motorista['id']);
                    $motorista['nave'] = $dataNave['nombre'];
                    $motorista['nave_id'] = $dataNave['id'];
                    $data[] = $motorista;
                }
            }
        }
            
        return $data;
    }
    */
}