<?php
class Shipcode_Model_Solicitud extends Zend_Db_Table_Abstract
{
    protected $_name = 'solicitudes';
    protected $_primary = 'id';
    
    private $_id;
    
    private function _validarId($id)
    {
        $optiosnInforme = array('table' => $this->_name, 'field' => $this->_primary);
        $validadorInforme = new Zend_Validate_Db_RecordExists($optiosnInforme);
        
        if($validadorInforme->isValid($id)){
            return TRUE;
        }
        return FALSE;
    }
    
    public function setId($id)
    {
        if($this->_validarId($id) == FALSE){
            throw new Exception('El ID de la solicitud no existe');   
        }
        $this->_id = $id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getAll( $estado = 0 )
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('s' => 'solicitudes'), array(
                    'id', 'creacion', 'creador', 'nave_id', 
                    'num_solicitud', 'num_orden', 'total_neto',
                    'fecha_envio', 'fecha_recepcion', 'fecha_termino', 
                    'fecha_cierre', 'detalles', 'prioridad', 'estado', 
                    'enviada'))
               ->join(array('u' => 'sistema_usuarios'), 'u.id=s.creador', array('creador' => 'nombre'))
               ->join(array('n' => 'naves'), 'n.id=s.nave_id', array('nave' => 'nombre'))
               ->where("s.ocultar='0'");
        if( $estado == 0 ){
            $select->where("s.estado='0'");
        } 
        $select->order("s.id DESC");
        return $adapter->fetchAll($select);
    }
    
    public function getActivasNave($nave_id)
    {
        $dataSolicitudes = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('s' => 'solicitudes'), array(
                    'id', 'creacion', 'creador', 'nave_id', 
                    'num_solicitud', 'num_orden', 'total_neto',
                    'fecha_envio', 'fecha_recepcion', 'fecha_termino', 
                    'fecha_cierre', 'detalles', 'prioridad', 'estado', 
                    'enviada'))
               ->join(array('n' => 'naves'), 'n.id=s.nave_id', array('nave' => 'nombre'))
               ->join(array('u' => 'sistema_usuarios'), 'u.id=s.creador', array('solicitado_por' => 'nombre'))
               ->where("s.ocultar='0' AND s.nave_id = '" . $nave_id . "' AND s.estado != '4' AND s.prioridad = 'NORMAL'")
               ->orWhere("s.ocultar='0' AND s.nave_id='" . $nave_id . "' AND s.prioridad = 'URGENTE' AND s.estado != '4'");
        
        $select->order("s.id DESC");
        $solicitudes = $adapter->fetchAll($select);
        $comentario = new Shipcode_Model_SolicitudComentario();
        foreach($solicitudes as $solicitud){
            $solicitud['comentarios'] = $comentario->getRowsBySolicitudId($solicitud['id']);
            $dataSolicitudes[] = $solicitud;
        }
        return $dataSolicitudes;
    }
    
    public function getByMes($dataMes, $nave_id)
    {
        if($dataMes === NULL || $dataMes === FALSE || !is_array($dataMes)){
            throw new Exception('No se ha enviado los datos del mes solicitado - Solicitud::getByMes()');
        }
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('s' => 'solicitudes'), array(
                    'id', 'creacion', 'creador', 'nave_id', 
                    'num_solicitud', 'num_orden', 'total_neto',
                    'fecha_envio', 'fecha_recepcion', 'fecha_termino', 
                    'fecha_cierre', 'detalles', 'prioridad', 'estado'))
               ->join(array('n' => 'naves'), 'n.id=s.nave_id', array('nave' => 'nombre'))
               ->join(array('u' => 'sistema_usuarios'), 'u.id=s.creador', array('solicitado_por' => 'nombre'))
               ->where("s.ocultar='0'")
               ->where("MONTH(s.creacion)=?", $dataMes['mes'])
               ->where("YEAR(s.creacion)=?", $dataMes['year'])
               ->where("s.nave_id =?", (int)$nave_id)
               ->where("s.enviada='1'");
        return $adapter->fetchAll($select);
    }
    
    public function getUltimaSemana($nave_id)
    {
        $hoy = new Zend_Date(date("Y-m-d"));
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('s' => 'solicitudes'), array(
                    'id', 'creacion', 'creador', 'nave_id', 
                    'num_solicitud', 'num_orden', 'total_neto',
                    'fecha_envio', 'fecha_recepcion', 'fecha_termino', 
                    'fecha_cierre', 'detalles', 'prioridad', 'estado'))
               ->join(array('n' => 'naves'), 'n.id=s.nave_id', array('nave' => 'nombre'))
               ->join(array('u' => 'sistema_usuarios'), 'u.id=s.creador', array('solicitado_por' => 'nombre'))
               ->where("s.ocultar='0'") 
               ->where("s.creacion >=?", $hoy->sub(1, Zend_Date::WEEK)->toString("yyyy-MM-dd"))
               ->where("s.nave_id =?", (int)$nave_id)
               ->where("s.enviada='1'");
        return $adapter->fetchAll($select);
    }
    
    // Función usada en el módulo de informe semanal
    public function filtrar(array $data, $privilegiosNaves)
    {
        $dataSolicitudes = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('s' => 'solicitudes'), array(
                    'id', 'creacion', 'creador', 'nave_id', 
                    'num_solicitud', 'num_orden', 'total_neto',
                    'fecha_envio', 'fecha_recepcion', 'fecha_termino', 
                    'fecha_cierre', 'detalles', 'prioridad', 'estado', 
                    'enviada'))
               ->join(array('n' => 'naves'), 'n.id=s.nave_id', array('nave' => 'nombre'))
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'))
               ->where("s.ocultar='0' AND s.enviada='1'");
        
        $where = "s.id IS NOT NULL ";
            
        if($data['estado'] == 0){
            $where .= "AND s.estado ='0' ";
        } elseif($data['estado'] == 1){
            $where .= "AND s.estado ='1' ";
        } elseif($data['estado'] == 2){
            $where .= "AND s.estado ='2' ";
        } elseif($data['estado'] == 3){
            $where .= "AND s.estado ='3' ";
        } elseif($data['estado'] == 4){
            $where .= "AND s.estado ='4' ";
        } elseif($data['estado'] == 5){
            $where .= "AND s.estado ='5' ";
        } elseif($data['estado'] == 20){
            $where .= "AND (s.estado ='0' || s.estado='1' || s.estado='2' || s.estado='5')";
        }

        if($data['prioridad'] != 2){
            if($data['prioridad'] == 0) {
                $where .= "AND s.prioridad = 'NORMAL' ";
            } elseif($data['prioridad'] == 1){
                $where .= "AND s.prioridad = 'URGENTE' ";
            }
            
        }
        
        if($data['desde'] != ''){
            $where .= "AND s.fecha_envio >= '" . $data['desde'] . "' ";
        }
        
        if($data['hasta'] != ''){
            $where .= "AND s.fecha_envio <= '" . $data['hasta'] . "' ";
        }
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        if($data['nave']!='') {
            $select->where("s.nave_id=?", $data['nave']);
        } elseif($privilegiosNaves !== NULL) {
            $navesIds = Shipcode_Model_SistemaUsuario::filtrarNavesAutorizadas($privilegiosNaves);
            $select->where("s.nave_id IN($navesIds)");
        }
        
        $select->where($where);
        $select->order("s.id DESC");
        
        $solicitudes = $adapter->fetchAll($select);
        $comentario = new Shipcode_Model_SolicitudComentario();
        foreach($solicitudes as $solicitud){
            $solicitud['comentarios'] = $comentario->getRowsBySolicitudId($solicitud['id']);
            $dataSolicitudes[] = $solicitud;
        }
        return $dataSolicitudes;
    }
    
    public function getConNuevosComentarios($ultimaVisita, $nave_id = NULL)
    {
        $comentario = new Shipcode_Model_SolicitudComentario();
        return $comentario->getPosterioresUltimaVisita($ultimaVisita, $nave_id);
    }
    
    public function buscar($data, $privilegiosNaves)
    {
        $dataSolicitudes = array();
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select();
        $select->from(array('s' => 'solicitudes'), array(
                    'id', 'creacion', 'creador', 'nave_id', 
                    'num_solicitud', 'num_orden', 'total_neto',
                    'fecha_envio', 'fecha_recepcion', 'fecha_termino', 
                    'fecha_cierre', 'detalles', 'prioridad', 'estado'))
               ->join(array('n' => 'naves'), 'n.id=s.nave_id', array('nave' => 'nombre'))
               ->join(array('u' => 'sistema_usuarios'), 'u.id=s.creador', array('solicitado_por' => 'nombre'))
               ->join(array('e' => 'empresas'), 'e.id=n.empresa_id', array('empresa' => 'nombre'));
        
        $where = "s.id IS NOT NULL AND s.ocultar='0' ";
        
        if($data['prioridad'] == 0){
            $where .= "AND s.prioridad = 'NORMAL' ";
        } elseif($data['prioridad'] == 1){
            $where .= "AND s.prioridad = 'URGENTE' ";
        }
        
        if($data['estado'] == 0){
            $where .= "AND s.estado = '0' ";
        } elseif($data['estado'] == 1){
            $where .= "AND s.estado ='1' ";
        } elseif($data['estado'] == 2){
            $where .= "AND s.estado ='2' ";
        } elseif($data['estado'] == 3){
            $where .= "AND s.estado ='3' ";
        } elseif($data['estado'] == 4){
            $where .= "AND s.estado ='4' ";
        } elseif($data['estado'] == 5){
            $where .= "AND s.estado ='5' ";
        } 
        
        
        if($data['desde'] != ''){
            $where .= "AND s.fecha_envio >= '" . $data['desde'] . "' ";
        }
        
        if($data['hasta'] != ''){
            $where .= "AND s.fecha_envio <= '" . $data['hasta'] . "' ";
        }
        
        if($data['empresa']!='') {
            $select->where("n.empresa_id=?", $data['empresa']);
        }
        if($data['nave']!='') {
            $select->where("s.nave_id=?", $data['nave']);
        } elseif($privilegiosNaves !== NULL) {
            $navesIds = Shipcode_Model_SistemaUsuario::filtrarNavesAutorizadas($privilegiosNaves);
            $select->where("s.nave_id IN($navesIds)");
        }
        
        $select->where($where);
        $select->order("s.fecha_envio DESC");
        $rows = $adapter->fetchAll($select);
        if(count($rows) > 0){
            
            $comentario = new Shipcode_Model_SolicitudComentario();
            
            foreach($rows as $row){
                $dataSolicitud = $row;
                $dataSolicitud['comentarios'] = $comentario->getRowsBySolicitudId($row['id']);
                $dataSolicitudes[] = $dataSolicitud;
            }
            return $dataSolicitudes;
        }
        return NULL;
    }
    
    public function getHtmlToPdf($rows)
    {
        $content = '<h1>Informe Solicitudes</h1>'
                 . '<p class="text-muted">Realizado el ' . date("Y-m-d") . ', a las ' . date("H:i") . '</p>'
                 . '<hr>'
                 . '<p>Se encontraron ' . count($rows) . ' resultados</p>'
                 . '<table border="1" cellpadding="4"><thead><tr>'
                 . '<th>Empresa</th>'
                 . '<th>Nave</th>'
                 . '<th>Fecha envío</th>'   
                 . '<th>Enviado por</th>'
                 . '<th>Detalles</th>'
                 . '<th>Prioridad</th>'   
                 . '<th>Estado</th>'
                 . '<th>Días</th>'
                 . '<th>Comentarios</th>'
                 . '</tr></thead><tbody>';
        
        if(count($rows) > 0) {
            foreach($rows as $solicitud) { 
                
                if($solicitud['estado'] == 0) {
                    $estado = 'PENDIENTE';
                } elseif($solicitud['estado'] == 1) {
                    $estado = 'EN CURSO';
                } elseif($solicitud['estado'] == 2) {
                    $estado = 'TERMINADA OK';
                } elseif($solicitud['estado'] == 3) {
                    $estado = 'RECHAZADA';
                } elseif($solicitud['estado'] == 4) {
                    $estado = 'CERRADA';
                } elseif($solicitud['estado'] == 5) {
                    $estado = 'NO CONFORME';
                }
                
                if($solicitud['prioridad'] == 'NORMAL'){
                    $dias = $solicitud['dias_aprobacion'];
                } else {
                    $dias = $solicitud['dias_creacion'];
                }
                
                if(count($solicitud['comentarios']) > 0) {
                    $comentarios = NULL;
                    foreach($solicitud['comentarios'] as $comentario){
                        $comentarios .= Shipcode_Model_Fecha::formatShort($comentario['creacion']);
                        if($comentario['tipo']=='supervisor') { 
                            $comentarios .= ' S : '; 
                        } else { 
                            $comentarios .= ' M : '; 
                        } 
                        
                        $comentarios .= $comentario['comentarios'];
                        $comentarios .= "<br>";
                    }
                    
                } else {
                    $comentarios = '---';
                }
                
                $content .= '<tr><td class="border-right">' . $solicitud['empresa'] . '</td>'
                          . '<td>' . $solicitud['nave'] . '</td>'
                          . '<td>' . Shipcode_Model_Fecha::format($solicitud['fecha_envio']) . '</td>'
                          . '<td>' . $solicitud['solicitado_por'] . '</td>'
                          . '<td>' . nl2br($solicitud['detalles']) . '</td>'
                          . '<td>' . $solicitud['prioridad'] . '</td>'
                          . '<td>' . $estado . '</td>'
                          . '<td>' . $dias . '</td>'
                          . '<td>' . $comentarios . '</td>'
                          . '</tr>';
                
            } 
        } else {
            $content .= '<tr><td colspan="7">No se encontraron registros coincidentes para su búsqueda.</td></tr>';
        }
        
        $content .= '</table></div></tbody></html>';
        
        return $content;
    }
    
    public function guardar($data, $user)
    {
        $data['creador'] = $user;
        if($this->_validarId($data['id']) == TRUE ){
            $row = $this->find($data['id'])->current();
        } else {
            $row = $this->createRow();
        }
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function agregarComentario($comentario, $tipo, $user)
    {
        $comentarioSolicitud = new Shipcode_Model_SolicitudComentario();
        return $comentarioSolicitud->crear(array(
            'creador' => $user,
            'solicitud_id' => $this->_id,
            'comentarios' => $comentario,
            'tipo' => $tipo
        ));
    }
    
    public function setEstado($estado)
    {
        if(!isset($estado) || !is_numeric($estado)){
            throw new Exception("El estado indicado no es válido");
        }
        
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function enviar()
    {
        $row = $this->getRow();
        $row->enviada = 1;
        $row->fecha_envio = date("Y-m-d");
        $row->save();
    }
    
    public function recibir()
    {
        $row = $this->getRow();
        $row->estado = 1;
        $row->fecha_recepcion = date("Y-m-d");
        $row->save();
    }
    
    public function terminar()
    {
        $row = $this->getRow();
        $row->estado = 2;
        $row->fecha_termino = date("Y-m-d");
        $row->save();
    }
    
    public function rechazar($usuario_id)
    {
        $row = $this->getRow();
        $row->estado = 3;
        $row->fecha_rechazo = date("Y-m-d");
        $row->usuario_rechazo_id = $usuario_id;
        $row->save();
    }
    
    public function cerrar()
    {
        $row = $this->getRow();
        $row->estado = 4;
        $row->fecha_cierre = date("Y-m-d");
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Solicitud::eliminar()");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?", $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
}