<?php
class Shipcode_Model_TipoCertificado extends Zend_Db_Table_Abstract
{
    protected $_name = 'certificados_tipos';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = (int)$id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getAll()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $sql = "SELECT t.id, t.creacion, t.creador, t.nombre, t.critico, t.indefinido, t.lugar, "
             . "(SELECT COUNT(*) FROM naves_certificados AS c WHERE c.tipo_id=t.id) AS num_certificados "
             . "FROM certificados_tipos AS t ORDER BY t.lugar";
        return $adapter->fetchAll($sql);
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        $data['lugar'] = $this->_getLugar();
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editar($data, $user, $id)
    {
        $data['creador'] = $user;
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Eliminar Tipo Certificado");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function setOrden($data)
    {
        $i = 1;
        $ids = explode(",", $data);
        foreach($ids as $id){
            $this->_setLugar($id, $i);
            $i++;
        }
    }
    
    public static function getPairsToSelect()
    {
        $adapter = self::getDefaultAdapter();
        $sql = 'SELECT id, nombre FROM certificados_tipos ORDER BY nombre';
        return $adapter->fetchPairs($sql);
    }
    
    private function _setLugar($id, $lugar)
    {
        $tipo = $this->find($id)->current();
        if($tipo){
            $tipo->lugar = $lugar;
            $tipo->save();
        }
    }
    
    private function _getLugar()
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT MAX(lugar) FROM certificados_tipos";
        $ultimaPagina = $adapter->fetchOne($sql);
        if($ultimaPagina){
            return $ultimaPagina + 1;
        } else {
            return 1;
        }
    }
}