<?php
class Shipcode_Model_TipoProyecto extends Zend_Db_Table_Abstract
{
    protected $_name = 'proyectos_tipos';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $this->_id = (int)$id;
    }

    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getAll()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $sql = "SELECT t.id, t.nombre, t.detalle_mensual, t.requiere_presupuesto "
             . "FROM proyectos_tipos AS t ORDER BY t.nombre";
        return $adapter->fetchAll($sql);
    }
    
    public function crear($data)
    {
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editar($data)
    {
        $row = $this->find($data['id'])->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Eliminar Tipo Proyecto");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function setCuenta($cuenta_id)
    {
        $optionsCuenta = array('table' => 'cuentas_gastos', 'field' => 'id');
        $validadorCuenta = new Zend_Validate_Db_RecordExists($optionsCuenta);
        
        if(!$validadorCuenta->isValid($cuenta_id)){
            throw new Exception('El ID de cuenta asignada no existe.');
        }
        
        $row = $this->getRow();
        $rowCuentas = $row->config_cuentas;
        
        if($rowCuentas != NULL){
            $cuentas = explode(",", $rowCuentas);
            $key = array_search($cuenta_id, $cuentas);
            if($key !== FALSE && $key !== NULL){
                unset($cuentas[$key]);
            } else {
                $cuentas[] = $cuenta_id;
            }
        } else {
            $cuentas[] = $cuenta_id;
        }
        if(count($cuentas) > 0) {
            $row->config_cuentas = implode(",", $cuentas);
        } else {
            $row->config_cuentas = NULL;
        }
        $row->save();
    }
    
    public static function getPairsToSelect()
    {
        $adapter = self::getDefaultAdapter();
        $sql = 'SELECT id, nombre FROM proyectos_tipos ORDER BY nombre';
        return $adapter->fetchPairs($sql);
    }
}